const std = @import("std");
const serializeMap = @import("json.zig").serializeMap;
const smithy = @import("smithy");

const Self = @This();
pub const version: []const u8 = "2017-07-25";
pub const sdk_id: []const u8 = "AppSync";
pub const arn_namespace: []const u8 = "appsync";
pub const endpoint_prefix: []const u8 = "appsync";
pub const sigv4_name: []const u8 = "appsync";
pub const name: []const u8 = "AWSDeepdishControlPlaneService";
pub const aws_protocol: smithy.AwsProtocol = smithy.AwsProtocol.rest_json_1;

pub const service_metadata: struct {
    version: []const u8 = "2017-07-25",
    sdk_id: []const u8 = "AppSync",
    arn_namespace: []const u8 = "appsync",
    endpoint_prefix: []const u8 = "appsync",
    sigv4_name: []const u8 = "appsync",
    name: []const u8 = "AWSDeepdishControlPlaneService",
    aws_protocol: smithy.AwsProtocol = smithy.AwsProtocol.rest_json_1,
} = .{};
pub const create_api_cache: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/v1/apis/{apiId}/ApiCaches",
        .success_code = 200,
    };

    action_name: []const u8 = "CreateApiCache",
    Request: type = struct {
        api_id: []const u8,
        ttl: i64,
        transit_encryption_enabled: ?bool = null,
        at_rest_encryption_enabled: ?bool = null,
        api_caching_behavior: []const u8,
        type: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .api_id = "apiId",
                .ttl = "ttl",
                .transit_encryption_enabled = "transitEncryptionEnabled",
                .at_rest_encryption_enabled = "atRestEncryptionEnabled",
                .api_caching_behavior = "apiCachingBehavior",
                .type = "type",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(create_api_cache) } {
            return .{ .service_metadata = service_metadata, .action = create_api_cache };
        }
    },
    Response: type = struct {
        api_cache: ?ApiCache = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .api_cache = "apiCache",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        BadRequest,
        ConcurrentModification,
        InternalFailure,
        NotFound,
        Unauthorized,
    },
} = .{};
pub const create_api_key: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/v1/apis/{apiId}/apikeys",
        .success_code = 200,
    };

    action_name: []const u8 = "CreateApiKey",
    Request: type = struct {
        api_id: []const u8,
        description: ?[]const u8 = null,
        expires: ?i64 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .api_id = "apiId",
                .description = "description",
                .expires = "expires",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(create_api_key) } {
            return .{ .service_metadata = service_metadata, .action = create_api_key };
        }
    },
    Response: type = struct {
        api_key: ?ApiKey = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .api_key = "apiKey",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        ApiKeyLimitExceeded,
        ApiKeyValidityOutOfBounds,
        BadRequest,
        InternalFailure,
        LimitExceeded,
        NotFound,
        Unauthorized,
    },
} = .{};
pub const create_data_source: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/v1/apis/{apiId}/datasources",
        .success_code = 200,
    };

    action_name: []const u8 = "CreateDataSource",
    Request: type = struct {
        api_id: []const u8,
        name: []const u8,
        description: ?[]const u8 = null,
        type: []const u8,
        service_role_arn: ?[]const u8 = null,
        dynamodb_config: ?DynamodbDataSourceConfig = null,
        lambda_config: ?LambdaDataSourceConfig = null,
        elasticsearch_config: ?ElasticsearchDataSourceConfig = null,
        http_config: ?HttpDataSourceConfig = null,
        relational_database_config: ?RelationalDatabaseDataSourceConfig = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .api_id = "apiId",
                .name = "name",
                .description = "description",
                .type = "type",
                .service_role_arn = "serviceRoleArn",
                .dynamodb_config = "dynamodbConfig",
                .lambda_config = "lambdaConfig",
                .elasticsearch_config = "elasticsearchConfig",
                .http_config = "httpConfig",
                .relational_database_config = "relationalDatabaseConfig",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(create_data_source) } {
            return .{ .service_metadata = service_metadata, .action = create_data_source };
        }
    },
    Response: type = struct {
        data_source: ?DataSource = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .data_source = "dataSource",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        BadRequest,
        ConcurrentModification,
        InternalFailure,
        NotFound,
        Unauthorized,
    },
} = .{};
pub const create_function: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/v1/apis/{apiId}/functions",
        .success_code = 200,
    };

    action_name: []const u8 = "CreateFunction",
    Request: type = struct {
        api_id: []const u8,
        name: []const u8,
        description: ?[]const u8 = null,
        data_source_name: []const u8,
        request_mapping_template: ?[]const u8 = null,
        response_mapping_template: ?[]const u8 = null,
        function_version: []const u8,
        sync_config: ?SyncConfig = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .api_id = "apiId",
                .name = "name",
                .description = "description",
                .data_source_name = "dataSourceName",
                .request_mapping_template = "requestMappingTemplate",
                .response_mapping_template = "responseMappingTemplate",
                .function_version = "functionVersion",
                .sync_config = "syncConfig",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(create_function) } {
            return .{ .service_metadata = service_metadata, .action = create_function };
        }
    },
    Response: type = struct {
        function_configuration: ?FunctionConfiguration = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .function_configuration = "functionConfiguration",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        ConcurrentModification,
        InternalFailure,
        NotFound,
        Unauthorized,
    },
} = .{};
pub const create_graphql_api: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/v1/apis",
        .success_code = 200,
    };

    action_name: []const u8 = "CreateGraphqlApi",
    Request: type = struct {
        name: []const u8,
        log_config: ?LogConfig = null,
        authentication_type: []const u8,
        user_pool_config: ?UserPoolConfig = null,
        open_id_connect_config: ?OpenIDConnectConfig = null,
        tags: ?[]struct {
            key: ?[]const u8 = null,
            value: ?[]const u8 = null,
        } = null,
        additional_authentication_providers: ?[]AdditionalAuthenticationProvider = null,
        xray_enabled: ?bool = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .name = "name",
                .log_config = "logConfig",
                .authentication_type = "authenticationType",
                .user_pool_config = "userPoolConfig",
                .open_id_connect_config = "openIDConnectConfig",
                .tags = "tags",
                .additional_authentication_providers = "additionalAuthenticationProviders",
                .xray_enabled = "xrayEnabled",
            };
            return @field(mappings, field_name);
        }

        pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
            if (std.mem.eql(u8, "tags", field_name))
                return try serializeMap(self.tags, self.fieldNameFor("tags"), options, out_stream);
            return false;
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(create_graphql_api) } {
            return .{ .service_metadata = service_metadata, .action = create_graphql_api };
        }
    },
    Response: type = struct {
        graphql_api: ?GraphqlApi = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .graphql_api = "graphqlApi",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        ApiLimitExceeded,
        BadRequest,
        ConcurrentModification,
        InternalFailure,
        LimitExceeded,
        Unauthorized,
    },
} = .{};
pub const create_resolver: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/v1/apis/{apiId}/types/{typeName}/resolvers",
        .success_code = 200,
    };

    action_name: []const u8 = "CreateResolver",
    Request: type = struct {
        api_id: []const u8,
        type_name: []const u8,
        field_name: []const u8,
        data_source_name: ?[]const u8 = null,
        request_mapping_template: ?[]const u8 = null,
        response_mapping_template: ?[]const u8 = null,
        kind: ?[]const u8 = null,
        pipeline_config: ?PipelineConfig = null,
        sync_config: ?SyncConfig = null,
        caching_config: ?CachingConfig = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .api_id = "apiId",
                .type_name = "typeName",
                .field_name = "fieldName",
                .data_source_name = "dataSourceName",
                .request_mapping_template = "requestMappingTemplate",
                .response_mapping_template = "responseMappingTemplate",
                .kind = "kind",
                .pipeline_config = "pipelineConfig",
                .sync_config = "syncConfig",
                .caching_config = "cachingConfig",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(create_resolver) } {
            return .{ .service_metadata = service_metadata, .action = create_resolver };
        }
    },
    Response: type = struct {
        resolver: ?Resolver = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .resolver = "resolver",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        ConcurrentModification,
        InternalFailure,
        NotFound,
        Unauthorized,
    },
} = .{};
pub const create_type: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/v1/apis/{apiId}/types",
        .success_code = 200,
    };

    action_name: []const u8 = "CreateType",
    Request: type = struct {
        api_id: []const u8,
        definition: []const u8,
        format: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .api_id = "apiId",
                .definition = "definition",
                .format = "format",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(create_type) } {
            return .{ .service_metadata = service_metadata, .action = create_type };
        }
    },
    Response: type = struct {
        type: ?Type = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .type = "type",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        BadRequest,
        ConcurrentModification,
        InternalFailure,
        NotFound,
        Unauthorized,
    },
} = .{};
pub const delete_api_cache: struct {
    pub const http_config = .{
        .method = "DELETE",
        .uri = "/v1/apis/{apiId}/ApiCaches",
        .success_code = 200,
    };

    action_name: []const u8 = "DeleteApiCache",
    Request: type = struct {
        api_id: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .api_id = "apiId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(delete_api_cache) } {
            return .{ .service_metadata = service_metadata, .action = delete_api_cache };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        BadRequest,
        ConcurrentModification,
        InternalFailure,
        NotFound,
        Unauthorized,
    },
} = .{};
pub const delete_api_key: struct {
    pub const http_config = .{
        .method = "DELETE",
        .uri = "/v1/apis/{apiId}/apikeys/{id}",
        .success_code = 200,
    };

    action_name: []const u8 = "DeleteApiKey",
    Request: type = struct {
        api_id: []const u8,
        id: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .api_id = "apiId",
                .id = "id",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(delete_api_key) } {
            return .{ .service_metadata = service_metadata, .action = delete_api_key };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        BadRequest,
        InternalFailure,
        NotFound,
        Unauthorized,
    },
} = .{};
pub const delete_data_source: struct {
    pub const http_config = .{
        .method = "DELETE",
        .uri = "/v1/apis/{apiId}/datasources/{name}",
        .success_code = 200,
    };

    action_name: []const u8 = "DeleteDataSource",
    Request: type = struct {
        api_id: []const u8,
        name: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .api_id = "apiId",
                .name = "name",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(delete_data_source) } {
            return .{ .service_metadata = service_metadata, .action = delete_data_source };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        BadRequest,
        ConcurrentModification,
        InternalFailure,
        NotFound,
        Unauthorized,
    },
} = .{};
pub const delete_function: struct {
    pub const http_config = .{
        .method = "DELETE",
        .uri = "/v1/apis/{apiId}/functions/{functionId}",
        .success_code = 200,
    };

    action_name: []const u8 = "DeleteFunction",
    Request: type = struct {
        api_id: []const u8,
        function_id: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .api_id = "apiId",
                .function_id = "functionId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(delete_function) } {
            return .{ .service_metadata = service_metadata, .action = delete_function };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        ConcurrentModification,
        InternalFailure,
        NotFound,
        Unauthorized,
    },
} = .{};
pub const delete_graphql_api: struct {
    pub const http_config = .{
        .method = "DELETE",
        .uri = "/v1/apis/{apiId}",
        .success_code = 200,
    };

    action_name: []const u8 = "DeleteGraphqlApi",
    Request: type = struct {
        api_id: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .api_id = "apiId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(delete_graphql_api) } {
            return .{ .service_metadata = service_metadata, .action = delete_graphql_api };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        BadRequest,
        ConcurrentModification,
        InternalFailure,
        NotFound,
        Unauthorized,
    },
} = .{};
pub const delete_resolver: struct {
    pub const http_config = .{
        .method = "DELETE",
        .uri = "/v1/apis/{apiId}/types/{typeName}/resolvers/{fieldName}",
        .success_code = 200,
    };

    action_name: []const u8 = "DeleteResolver",
    Request: type = struct {
        api_id: []const u8,
        type_name: []const u8,
        field_name: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .api_id = "apiId",
                .type_name = "typeName",
                .field_name = "fieldName",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(delete_resolver) } {
            return .{ .service_metadata = service_metadata, .action = delete_resolver };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        ConcurrentModification,
        InternalFailure,
        NotFound,
        Unauthorized,
    },
} = .{};
pub const delete_type: struct {
    pub const http_config = .{
        .method = "DELETE",
        .uri = "/v1/apis/{apiId}/types/{typeName}",
        .success_code = 200,
    };

    action_name: []const u8 = "DeleteType",
    Request: type = struct {
        api_id: []const u8,
        type_name: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .api_id = "apiId",
                .type_name = "typeName",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(delete_type) } {
            return .{ .service_metadata = service_metadata, .action = delete_type };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        BadRequest,
        ConcurrentModification,
        InternalFailure,
        NotFound,
        Unauthorized,
    },
} = .{};
pub const flush_api_cache: struct {
    pub const http_config = .{
        .method = "DELETE",
        .uri = "/v1/apis/{apiId}/FlushCache",
        .success_code = 200,
    };

    action_name: []const u8 = "FlushApiCache",
    Request: type = struct {
        api_id: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .api_id = "apiId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(flush_api_cache) } {
            return .{ .service_metadata = service_metadata, .action = flush_api_cache };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        BadRequest,
        ConcurrentModification,
        InternalFailure,
        NotFound,
        Unauthorized,
    },
} = .{};
pub const get_api_cache: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/v1/apis/{apiId}/ApiCaches",
        .success_code = 200,
    };

    action_name: []const u8 = "GetApiCache",
    Request: type = struct {
        api_id: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .api_id = "apiId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(get_api_cache) } {
            return .{ .service_metadata = service_metadata, .action = get_api_cache };
        }
    },
    Response: type = struct {
        api_cache: ?ApiCache = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .api_cache = "apiCache",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        BadRequest,
        ConcurrentModification,
        InternalFailure,
        NotFound,
        Unauthorized,
    },
} = .{};
pub const get_data_source: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/v1/apis/{apiId}/datasources/{name}",
        .success_code = 200,
    };

    action_name: []const u8 = "GetDataSource",
    Request: type = struct {
        api_id: []const u8,
        name: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .api_id = "apiId",
                .name = "name",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(get_data_source) } {
            return .{ .service_metadata = service_metadata, .action = get_data_source };
        }
    },
    Response: type = struct {
        data_source: ?DataSource = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .data_source = "dataSource",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        BadRequest,
        ConcurrentModification,
        InternalFailure,
        NotFound,
        Unauthorized,
    },
} = .{};
pub const get_function: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/v1/apis/{apiId}/functions/{functionId}",
        .success_code = 200,
    };

    action_name: []const u8 = "GetFunction",
    Request: type = struct {
        api_id: []const u8,
        function_id: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .api_id = "apiId",
                .function_id = "functionId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(get_function) } {
            return .{ .service_metadata = service_metadata, .action = get_function };
        }
    },
    Response: type = struct {
        function_configuration: ?FunctionConfiguration = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .function_configuration = "functionConfiguration",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        ConcurrentModification,
        NotFound,
        Unauthorized,
    },
} = .{};
pub const get_graphql_api: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/v1/apis/{apiId}",
        .success_code = 200,
    };

    action_name: []const u8 = "GetGraphqlApi",
    Request: type = struct {
        api_id: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .api_id = "apiId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(get_graphql_api) } {
            return .{ .service_metadata = service_metadata, .action = get_graphql_api };
        }
    },
    Response: type = struct {
        graphql_api: ?GraphqlApi = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .graphql_api = "graphqlApi",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        BadRequest,
        InternalFailure,
        NotFound,
        Unauthorized,
    },
} = .{};
pub const get_introspection_schema: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/v1/apis/{apiId}/schema",
        .success_code = 200,
    };

    action_name: []const u8 = "GetIntrospectionSchema",
    Request: type = struct {
        api_id: []const u8,
        format: []const u8,
        include_directives: ?bool = null,

        pub const http_query = .{
            .format = "format",
            .include_directives = "includeDirectives",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .api_id = "apiId",
                .format = "format",
                .include_directives = "includeDirectives",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(get_introspection_schema) } {
            return .{ .service_metadata = service_metadata, .action = get_introspection_schema };
        }
    },
    Response: type = struct {
        schema: ?[]const u8 = null,

        pub const http_payload: []const u8 = "schema";
        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .schema = "schema",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        GraphQLSchema,
        InternalFailure,
        NotFound,
        Unauthorized,
    },
} = .{};
pub const get_resolver: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/v1/apis/{apiId}/types/{typeName}/resolvers/{fieldName}",
        .success_code = 200,
    };

    action_name: []const u8 = "GetResolver",
    Request: type = struct {
        api_id: []const u8,
        type_name: []const u8,
        field_name: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .api_id = "apiId",
                .type_name = "typeName",
                .field_name = "fieldName",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(get_resolver) } {
            return .{ .service_metadata = service_metadata, .action = get_resolver };
        }
    },
    Response: type = struct {
        resolver: ?Resolver = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .resolver = "resolver",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        ConcurrentModification,
        NotFound,
        Unauthorized,
    },
} = .{};
pub const get_schema_creation_status: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/v1/apis/{apiId}/schemacreation",
        .success_code = 200,
    };

    action_name: []const u8 = "GetSchemaCreationStatus",
    Request: type = struct {
        api_id: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .api_id = "apiId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(get_schema_creation_status) } {
            return .{ .service_metadata = service_metadata, .action = get_schema_creation_status };
        }
    },
    Response: type = struct {
        status: ?[]const u8 = null,
        details: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .status = "status",
                .details = "details",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        BadRequest,
        InternalFailure,
        NotFound,
        Unauthorized,
    },
} = .{};
pub const get_type: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/v1/apis/{apiId}/types/{typeName}",
        .success_code = 200,
    };

    action_name: []const u8 = "GetType",
    Request: type = struct {
        api_id: []const u8,
        type_name: []const u8,
        format: []const u8,

        pub const http_query = .{
            .format = "format",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .api_id = "apiId",
                .type_name = "typeName",
                .format = "format",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(get_type) } {
            return .{ .service_metadata = service_metadata, .action = get_type };
        }
    },
    Response: type = struct {
        type: ?Type = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .type = "type",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        BadRequest,
        ConcurrentModification,
        InternalFailure,
        NotFound,
        Unauthorized,
    },
} = .{};
pub const list_api_keys: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/v1/apis/{apiId}/apikeys",
        .success_code = 200,
    };

    action_name: []const u8 = "ListApiKeys",
    Request: type = struct {
        api_id: []const u8,
        next_token: ?[]const u8 = null,
        max_results: ?i64 = null,

        pub const http_query = .{
            .next_token = "nextToken",
            .max_results = "maxResults",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .api_id = "apiId",
                .next_token = "nextToken",
                .max_results = "maxResults",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_api_keys) } {
            return .{ .service_metadata = service_metadata, .action = list_api_keys };
        }
    },
    Response: type = struct {
        api_keys: ?[]ApiKey = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .api_keys = "apiKeys",
                .next_token = "nextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        BadRequest,
        InternalFailure,
        NotFound,
        Unauthorized,
    },
} = .{};
pub const list_data_sources: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/v1/apis/{apiId}/datasources",
        .success_code = 200,
    };

    action_name: []const u8 = "ListDataSources",
    Request: type = struct {
        api_id: []const u8,
        next_token: ?[]const u8 = null,
        max_results: ?i64 = null,

        pub const http_query = .{
            .next_token = "nextToken",
            .max_results = "maxResults",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .api_id = "apiId",
                .next_token = "nextToken",
                .max_results = "maxResults",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_data_sources) } {
            return .{ .service_metadata = service_metadata, .action = list_data_sources };
        }
    },
    Response: type = struct {
        data_sources: ?[]DataSource = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .data_sources = "dataSources",
                .next_token = "nextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        BadRequest,
        InternalFailure,
        NotFound,
        Unauthorized,
    },
} = .{};
pub const list_functions: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/v1/apis/{apiId}/functions",
        .success_code = 200,
    };

    action_name: []const u8 = "ListFunctions",
    Request: type = struct {
        api_id: []const u8,
        next_token: ?[]const u8 = null,
        max_results: ?i64 = null,

        pub const http_query = .{
            .next_token = "nextToken",
            .max_results = "maxResults",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .api_id = "apiId",
                .next_token = "nextToken",
                .max_results = "maxResults",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_functions) } {
            return .{ .service_metadata = service_metadata, .action = list_functions };
        }
    },
    Response: type = struct {
        functions: ?[]FunctionConfiguration = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .functions = "functions",
                .next_token = "nextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        BadRequest,
        InternalFailure,
        NotFound,
        Unauthorized,
    },
} = .{};
pub const list_graphql_apis: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/v1/apis",
        .success_code = 200,
    };

    action_name: []const u8 = "ListGraphqlApis",
    Request: type = struct {
        next_token: ?[]const u8 = null,
        max_results: ?i64 = null,

        pub const http_query = .{
            .next_token = "nextToken",
            .max_results = "maxResults",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .next_token = "nextToken",
                .max_results = "maxResults",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_graphql_apis) } {
            return .{ .service_metadata = service_metadata, .action = list_graphql_apis };
        }
    },
    Response: type = struct {
        graphql_apis: ?[]GraphqlApi = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .graphql_apis = "graphqlApis",
                .next_token = "nextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        BadRequest,
        InternalFailure,
        Unauthorized,
    },
} = .{};
pub const list_resolvers: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/v1/apis/{apiId}/types/{typeName}/resolvers",
        .success_code = 200,
    };

    action_name: []const u8 = "ListResolvers",
    Request: type = struct {
        api_id: []const u8,
        type_name: []const u8,
        next_token: ?[]const u8 = null,
        max_results: ?i64 = null,

        pub const http_query = .{
            .next_token = "nextToken",
            .max_results = "maxResults",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .api_id = "apiId",
                .type_name = "typeName",
                .next_token = "nextToken",
                .max_results = "maxResults",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_resolvers) } {
            return .{ .service_metadata = service_metadata, .action = list_resolvers };
        }
    },
    Response: type = struct {
        resolvers: ?[]Resolver = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .resolvers = "resolvers",
                .next_token = "nextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        BadRequest,
        InternalFailure,
        NotFound,
        Unauthorized,
    },
} = .{};
pub const list_resolvers_by_function: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/v1/apis/{apiId}/functions/{functionId}/resolvers",
        .success_code = 200,
    };

    action_name: []const u8 = "ListResolversByFunction",
    Request: type = struct {
        api_id: []const u8,
        function_id: []const u8,
        next_token: ?[]const u8 = null,
        max_results: ?i64 = null,

        pub const http_query = .{
            .next_token = "nextToken",
            .max_results = "maxResults",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .api_id = "apiId",
                .function_id = "functionId",
                .next_token = "nextToken",
                .max_results = "maxResults",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_resolvers_by_function) } {
            return .{ .service_metadata = service_metadata, .action = list_resolvers_by_function };
        }
    },
    Response: type = struct {
        resolvers: ?[]Resolver = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .resolvers = "resolvers",
                .next_token = "nextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        BadRequest,
        InternalFailure,
        NotFound,
        Unauthorized,
    },
} = .{};
pub const list_tags_for_resource: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/v1/tags/{resourceArn}",
        .success_code = 200,
    };

    action_name: []const u8 = "ListTagsForResource",
    Request: type = struct {
        resource_arn: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .resource_arn = "resourceArn",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_tags_for_resource) } {
            return .{ .service_metadata = service_metadata, .action = list_tags_for_resource };
        }
    },
    Response: type = struct {
        tags: ?[]struct {
            key: ?[]const u8 = null,
            value: ?[]const u8 = null,
        } = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .tags = "tags",
            };
            return @field(mappings, field_name);
        }

        pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
            if (std.mem.eql(u8, "tags", field_name))
                return try serializeMap(self.tags, self.fieldNameFor("tags"), options, out_stream);
            return false;
        }
    },
    ServiceError: type = error{
        AccessDenied,
        BadRequest,
        InternalFailure,
        LimitExceeded,
        NotFound,
        Unauthorized,
    },
} = .{};
pub const list_types: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/v1/apis/{apiId}/types",
        .success_code = 200,
    };

    action_name: []const u8 = "ListTypes",
    Request: type = struct {
        api_id: []const u8,
        format: []const u8,
        next_token: ?[]const u8 = null,
        max_results: ?i64 = null,

        pub const http_query = .{
            .format = "format",
            .next_token = "nextToken",
            .max_results = "maxResults",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .api_id = "apiId",
                .format = "format",
                .next_token = "nextToken",
                .max_results = "maxResults",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_types) } {
            return .{ .service_metadata = service_metadata, .action = list_types };
        }
    },
    Response: type = struct {
        types: ?[]Type = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .types = "types",
                .next_token = "nextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        BadRequest,
        ConcurrentModification,
        InternalFailure,
        NotFound,
        Unauthorized,
    },
} = .{};
pub const start_schema_creation: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/v1/apis/{apiId}/schemacreation",
        .success_code = 200,
    };

    action_name: []const u8 = "StartSchemaCreation",
    Request: type = struct {
        api_id: []const u8,
        definition: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .api_id = "apiId",
                .definition = "definition",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(start_schema_creation) } {
            return .{ .service_metadata = service_metadata, .action = start_schema_creation };
        }
    },
    Response: type = struct {
        status: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .status = "status",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        BadRequest,
        ConcurrentModification,
        InternalFailure,
        NotFound,
        Unauthorized,
    },
} = .{};
pub const tag_resource: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/v1/tags/{resourceArn}",
        .success_code = 200,
    };

    action_name: []const u8 = "TagResource",
    Request: type = struct {
        resource_arn: []const u8,
        tags: []struct {
            key: ?[]const u8 = null,
            value: ?[]const u8 = null,
        },

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .resource_arn = "resourceArn",
                .tags = "tags",
            };
            return @field(mappings, field_name);
        }

        pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
            if (std.mem.eql(u8, "tags", field_name))
                return try serializeMap(self.tags, self.fieldNameFor("tags"), options, out_stream);
            return false;
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(tag_resource) } {
            return .{ .service_metadata = service_metadata, .action = tag_resource };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        BadRequest,
        InternalFailure,
        LimitExceeded,
        NotFound,
        Unauthorized,
    },
} = .{};
pub const untag_resource: struct {
    pub const http_config = .{
        .method = "DELETE",
        .uri = "/v1/tags/{resourceArn}",
        .success_code = 200,
    };

    action_name: []const u8 = "UntagResource",
    Request: type = struct {
        resource_arn: []const u8,
        tag_keys: [][]const u8,

        pub const http_query = .{
            .tag_keys = "tagKeys",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .resource_arn = "resourceArn",
                .tag_keys = "tagKeys",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(untag_resource) } {
            return .{ .service_metadata = service_metadata, .action = untag_resource };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        BadRequest,
        InternalFailure,
        LimitExceeded,
        NotFound,
        Unauthorized,
    },
} = .{};
pub const update_api_cache: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/v1/apis/{apiId}/ApiCaches/update",
        .success_code = 200,
    };

    action_name: []const u8 = "UpdateApiCache",
    Request: type = struct {
        api_id: []const u8,
        ttl: i64,
        api_caching_behavior: []const u8,
        type: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .api_id = "apiId",
                .ttl = "ttl",
                .api_caching_behavior = "apiCachingBehavior",
                .type = "type",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(update_api_cache) } {
            return .{ .service_metadata = service_metadata, .action = update_api_cache };
        }
    },
    Response: type = struct {
        api_cache: ?ApiCache = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .api_cache = "apiCache",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        BadRequest,
        ConcurrentModification,
        InternalFailure,
        NotFound,
        Unauthorized,
    },
} = .{};
pub const update_api_key: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/v1/apis/{apiId}/apikeys/{id}",
        .success_code = 200,
    };

    action_name: []const u8 = "UpdateApiKey",
    Request: type = struct {
        api_id: []const u8,
        id: []const u8,
        description: ?[]const u8 = null,
        expires: ?i64 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .api_id = "apiId",
                .id = "id",
                .description = "description",
                .expires = "expires",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(update_api_key) } {
            return .{ .service_metadata = service_metadata, .action = update_api_key };
        }
    },
    Response: type = struct {
        api_key: ?ApiKey = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .api_key = "apiKey",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        ApiKeyValidityOutOfBounds,
        BadRequest,
        InternalFailure,
        LimitExceeded,
        NotFound,
        Unauthorized,
    },
} = .{};
pub const update_data_source: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/v1/apis/{apiId}/datasources/{name}",
        .success_code = 200,
    };

    action_name: []const u8 = "UpdateDataSource",
    Request: type = struct {
        api_id: []const u8,
        name: []const u8,
        description: ?[]const u8 = null,
        type: []const u8,
        service_role_arn: ?[]const u8 = null,
        dynamodb_config: ?DynamodbDataSourceConfig = null,
        lambda_config: ?LambdaDataSourceConfig = null,
        elasticsearch_config: ?ElasticsearchDataSourceConfig = null,
        http_config: ?HttpDataSourceConfig = null,
        relational_database_config: ?RelationalDatabaseDataSourceConfig = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .api_id = "apiId",
                .name = "name",
                .description = "description",
                .type = "type",
                .service_role_arn = "serviceRoleArn",
                .dynamodb_config = "dynamodbConfig",
                .lambda_config = "lambdaConfig",
                .elasticsearch_config = "elasticsearchConfig",
                .http_config = "httpConfig",
                .relational_database_config = "relationalDatabaseConfig",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(update_data_source) } {
            return .{ .service_metadata = service_metadata, .action = update_data_source };
        }
    },
    Response: type = struct {
        data_source: ?DataSource = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .data_source = "dataSource",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        BadRequest,
        ConcurrentModification,
        InternalFailure,
        NotFound,
        Unauthorized,
    },
} = .{};
pub const update_function: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/v1/apis/{apiId}/functions/{functionId}",
        .success_code = 200,
    };

    action_name: []const u8 = "UpdateFunction",
    Request: type = struct {
        api_id: []const u8,
        name: []const u8,
        description: ?[]const u8 = null,
        function_id: []const u8,
        data_source_name: []const u8,
        request_mapping_template: ?[]const u8 = null,
        response_mapping_template: ?[]const u8 = null,
        function_version: []const u8,
        sync_config: ?SyncConfig = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .api_id = "apiId",
                .name = "name",
                .description = "description",
                .function_id = "functionId",
                .data_source_name = "dataSourceName",
                .request_mapping_template = "requestMappingTemplate",
                .response_mapping_template = "responseMappingTemplate",
                .function_version = "functionVersion",
                .sync_config = "syncConfig",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(update_function) } {
            return .{ .service_metadata = service_metadata, .action = update_function };
        }
    },
    Response: type = struct {
        function_configuration: ?FunctionConfiguration = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .function_configuration = "functionConfiguration",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        ConcurrentModification,
        InternalFailure,
        NotFound,
        Unauthorized,
    },
} = .{};
pub const update_graphql_api: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/v1/apis/{apiId}",
        .success_code = 200,
    };

    action_name: []const u8 = "UpdateGraphqlApi",
    Request: type = struct {
        api_id: []const u8,
        name: []const u8,
        log_config: ?LogConfig = null,
        authentication_type: ?[]const u8 = null,
        user_pool_config: ?UserPoolConfig = null,
        open_id_connect_config: ?OpenIDConnectConfig = null,
        additional_authentication_providers: ?[]AdditionalAuthenticationProvider = null,
        xray_enabled: ?bool = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .api_id = "apiId",
                .name = "name",
                .log_config = "logConfig",
                .authentication_type = "authenticationType",
                .user_pool_config = "userPoolConfig",
                .open_id_connect_config = "openIDConnectConfig",
                .additional_authentication_providers = "additionalAuthenticationProviders",
                .xray_enabled = "xrayEnabled",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(update_graphql_api) } {
            return .{ .service_metadata = service_metadata, .action = update_graphql_api };
        }
    },
    Response: type = struct {
        graphql_api: ?GraphqlApi = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .graphql_api = "graphqlApi",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        BadRequest,
        ConcurrentModification,
        InternalFailure,
        NotFound,
        Unauthorized,
    },
} = .{};
pub const update_resolver: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/v1/apis/{apiId}/types/{typeName}/resolvers/{fieldName}",
        .success_code = 200,
    };

    action_name: []const u8 = "UpdateResolver",
    Request: type = struct {
        api_id: []const u8,
        type_name: []const u8,
        field_name: []const u8,
        data_source_name: ?[]const u8 = null,
        request_mapping_template: ?[]const u8 = null,
        response_mapping_template: ?[]const u8 = null,
        kind: ?[]const u8 = null,
        pipeline_config: ?PipelineConfig = null,
        sync_config: ?SyncConfig = null,
        caching_config: ?CachingConfig = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .api_id = "apiId",
                .type_name = "typeName",
                .field_name = "fieldName",
                .data_source_name = "dataSourceName",
                .request_mapping_template = "requestMappingTemplate",
                .response_mapping_template = "responseMappingTemplate",
                .kind = "kind",
                .pipeline_config = "pipelineConfig",
                .sync_config = "syncConfig",
                .caching_config = "cachingConfig",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(update_resolver) } {
            return .{ .service_metadata = service_metadata, .action = update_resolver };
        }
    },
    Response: type = struct {
        resolver: ?Resolver = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .resolver = "resolver",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        ConcurrentModification,
        InternalFailure,
        NotFound,
        Unauthorized,
    },
} = .{};
pub const update_type: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/v1/apis/{apiId}/types/{typeName}",
        .success_code = 200,
    };

    action_name: []const u8 = "UpdateType",
    Request: type = struct {
        api_id: []const u8,
        type_name: []const u8,
        definition: ?[]const u8 = null,
        format: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .api_id = "apiId",
                .type_name = "typeName",
                .definition = "definition",
                .format = "format",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(update_type) } {
            return .{ .service_metadata = service_metadata, .action = update_type };
        }
    },
    Response: type = struct {
        type: ?Type = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .type = "type",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        BadRequest,
        ConcurrentModification,
        InternalFailure,
        NotFound,
        Unauthorized,
    },
} = .{};

pub const Type = struct {
    name: ?[]const u8 = null,
    description: ?[]const u8 = null,
    arn: ?[]const u8 = null,
    definition: ?[]const u8 = null,
    format: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .name = "name",
            .description = "description",
            .arn = "arn",
            .definition = "definition",
            .format = "format",
        };
        return @field(mappings, field_name);
    }
};

pub const Resolver = struct {
    type_name: ?[]const u8 = null,
    field_name: ?[]const u8 = null,
    data_source_name: ?[]const u8 = null,
    resolver_arn: ?[]const u8 = null,
    request_mapping_template: ?[]const u8 = null,
    response_mapping_template: ?[]const u8 = null,
    kind: ?[]const u8 = null,
    pipeline_config: ?PipelineConfig = null,
    sync_config: ?SyncConfig = null,
    caching_config: ?CachingConfig = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .type_name = "typeName",
            .field_name = "fieldName",
            .data_source_name = "dataSourceName",
            .resolver_arn = "resolverArn",
            .request_mapping_template = "requestMappingTemplate",
            .response_mapping_template = "responseMappingTemplate",
            .kind = "kind",
            .pipeline_config = "pipelineConfig",
            .sync_config = "syncConfig",
            .caching_config = "cachingConfig",
        };
        return @field(mappings, field_name);
    }
};

pub const CachingConfig = struct {
    ttl: ?i64 = null,
    caching_keys: ?[][]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .ttl = "ttl",
            .caching_keys = "cachingKeys",
        };
        return @field(mappings, field_name);
    }
};

pub const SyncConfig = struct {
    conflict_handler: ?[]const u8 = null,
    conflict_detection: ?[]const u8 = null,
    lambda_conflict_handler_config: ?LambdaConflictHandlerConfig = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .conflict_handler = "conflictHandler",
            .conflict_detection = "conflictDetection",
            .lambda_conflict_handler_config = "lambdaConflictHandlerConfig",
        };
        return @field(mappings, field_name);
    }
};

pub const LambdaConflictHandlerConfig = struct {
    lambda_conflict_handler_arn: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .lambda_conflict_handler_arn = "lambdaConflictHandlerArn",
        };
        return @field(mappings, field_name);
    }
};

pub const PipelineConfig = struct {
    functions: ?[][]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .functions = "functions",
        };
        return @field(mappings, field_name);
    }
};

pub const GraphqlApi = struct {
    name: ?[]const u8 = null,
    api_id: ?[]const u8 = null,
    authentication_type: ?[]const u8 = null,
    log_config: ?LogConfig = null,
    user_pool_config: ?UserPoolConfig = null,
    open_id_connect_config: ?OpenIDConnectConfig = null,
    arn: ?[]const u8 = null,
    uris: ?[]struct {
        key: ?[]const u8 = null,
        value: ?[]const u8 = null,
    } = null,
    tags: ?[]struct {
        key: ?[]const u8 = null,
        value: ?[]const u8 = null,
    } = null,
    additional_authentication_providers: ?[]AdditionalAuthenticationProvider = null,
    xray_enabled: ?bool = null,
    waf_web_acl_arn: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .name = "name",
            .api_id = "apiId",
            .authentication_type = "authenticationType",
            .log_config = "logConfig",
            .user_pool_config = "userPoolConfig",
            .open_id_connect_config = "openIDConnectConfig",
            .arn = "arn",
            .uris = "uris",
            .tags = "tags",
            .additional_authentication_providers = "additionalAuthenticationProviders",
            .xray_enabled = "xrayEnabled",
            .waf_web_acl_arn = "wafWebAclArn",
        };
        return @field(mappings, field_name);
    }

    pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
        if (std.mem.eql(u8, "uris", field_name))
            return try serializeMap(self.uris, self.fieldNameFor("uris"), options, out_stream);
        if (std.mem.eql(u8, "tags", field_name))
            return try serializeMap(self.tags, self.fieldNameFor("tags"), options, out_stream);
        return false;
    }
};

pub const AdditionalAuthenticationProvider = struct {
    authentication_type: ?[]const u8 = null,
    open_id_connect_config: ?OpenIDConnectConfig = null,
    user_pool_config: ?CognitoUserPoolConfig = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .authentication_type = "authenticationType",
            .open_id_connect_config = "openIDConnectConfig",
            .user_pool_config = "userPoolConfig",
        };
        return @field(mappings, field_name);
    }
};

pub const CognitoUserPoolConfig = struct {
    user_pool_id: []const u8,
    aws_region: []const u8,
    app_id_client_regex: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .user_pool_id = "userPoolId",
            .aws_region = "awsRegion",
            .app_id_client_regex = "appIdClientRegex",
        };
        return @field(mappings, field_name);
    }
};

pub const OpenIDConnectConfig = struct {
    issuer: []const u8,
    client_id: ?[]const u8 = null,
    iat_ttl: ?i64 = null,
    auth_ttl: ?i64 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .issuer = "issuer",
            .client_id = "clientId",
            .iat_ttl = "iatTTL",
            .auth_ttl = "authTTL",
        };
        return @field(mappings, field_name);
    }
};

pub const UserPoolConfig = struct {
    user_pool_id: []const u8,
    aws_region: []const u8,
    default_action: []const u8,
    app_id_client_regex: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .user_pool_id = "userPoolId",
            .aws_region = "awsRegion",
            .default_action = "defaultAction",
            .app_id_client_regex = "appIdClientRegex",
        };
        return @field(mappings, field_name);
    }
};

pub const LogConfig = struct {
    field_log_level: []const u8,
    cloud_watch_logs_role_arn: []const u8,
    exclude_verbose_content: ?bool = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .field_log_level = "fieldLogLevel",
            .cloud_watch_logs_role_arn = "cloudWatchLogsRoleArn",
            .exclude_verbose_content = "excludeVerboseContent",
        };
        return @field(mappings, field_name);
    }
};

pub const FunctionConfiguration = struct {
    function_id: ?[]const u8 = null,
    function_arn: ?[]const u8 = null,
    name: ?[]const u8 = null,
    description: ?[]const u8 = null,
    data_source_name: ?[]const u8 = null,
    request_mapping_template: ?[]const u8 = null,
    response_mapping_template: ?[]const u8 = null,
    function_version: ?[]const u8 = null,
    sync_config: ?SyncConfig = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .function_id = "functionId",
            .function_arn = "functionArn",
            .name = "name",
            .description = "description",
            .data_source_name = "dataSourceName",
            .request_mapping_template = "requestMappingTemplate",
            .response_mapping_template = "responseMappingTemplate",
            .function_version = "functionVersion",
            .sync_config = "syncConfig",
        };
        return @field(mappings, field_name);
    }
};

pub const DataSource = struct {
    data_source_arn: ?[]const u8 = null,
    name: ?[]const u8 = null,
    description: ?[]const u8 = null,
    type: ?[]const u8 = null,
    service_role_arn: ?[]const u8 = null,
    dynamodb_config: ?DynamodbDataSourceConfig = null,
    lambda_config: ?LambdaDataSourceConfig = null,
    elasticsearch_config: ?ElasticsearchDataSourceConfig = null,
    http_config: ?HttpDataSourceConfig = null,
    relational_database_config: ?RelationalDatabaseDataSourceConfig = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .data_source_arn = "dataSourceArn",
            .name = "name",
            .description = "description",
            .type = "type",
            .service_role_arn = "serviceRoleArn",
            .dynamodb_config = "dynamodbConfig",
            .lambda_config = "lambdaConfig",
            .elasticsearch_config = "elasticsearchConfig",
            .http_config = "httpConfig",
            .relational_database_config = "relationalDatabaseConfig",
        };
        return @field(mappings, field_name);
    }
};

pub const RelationalDatabaseDataSourceConfig = struct {
    relational_database_source_type: ?[]const u8 = null,
    rds_http_endpoint_config: ?RdsHttpEndpointConfig = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .relational_database_source_type = "relationalDatabaseSourceType",
            .rds_http_endpoint_config = "rdsHttpEndpointConfig",
        };
        return @field(mappings, field_name);
    }
};

pub const RdsHttpEndpointConfig = struct {
    aws_region: ?[]const u8 = null,
    db_cluster_identifier: ?[]const u8 = null,
    database_name: ?[]const u8 = null,
    schema: ?[]const u8 = null,
    aws_secret_store_arn: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .aws_region = "awsRegion",
            .db_cluster_identifier = "dbClusterIdentifier",
            .database_name = "databaseName",
            .schema = "schema",
            .aws_secret_store_arn = "awsSecretStoreArn",
        };
        return @field(mappings, field_name);
    }
};

pub const HttpDataSourceConfig = struct {
    endpoint: ?[]const u8 = null,
    authorization_config: ?AuthorizationConfig = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .endpoint = "endpoint",
            .authorization_config = "authorizationConfig",
        };
        return @field(mappings, field_name);
    }
};

pub const AuthorizationConfig = struct {
    authorization_type: []const u8,
    aws_iam_config: ?AwsIamConfig = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .authorization_type = "authorizationType",
            .aws_iam_config = "awsIamConfig",
        };
        return @field(mappings, field_name);
    }
};

pub const AwsIamConfig = struct {
    signing_region: ?[]const u8 = null,
    signing_service_name: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .signing_region = "signingRegion",
            .signing_service_name = "signingServiceName",
        };
        return @field(mappings, field_name);
    }
};

pub const ElasticsearchDataSourceConfig = struct {
    endpoint: []const u8,
    aws_region: []const u8,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .endpoint = "endpoint",
            .aws_region = "awsRegion",
        };
        return @field(mappings, field_name);
    }
};

pub const LambdaDataSourceConfig = struct {
    lambda_function_arn: []const u8,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .lambda_function_arn = "lambdaFunctionArn",
        };
        return @field(mappings, field_name);
    }
};

pub const DynamodbDataSourceConfig = struct {
    table_name: []const u8,
    aws_region: []const u8,
    use_caller_credentials: ?bool = null,
    delta_sync_config: ?DeltaSyncConfig = null,
    versioned: ?bool = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .table_name = "tableName",
            .aws_region = "awsRegion",
            .use_caller_credentials = "useCallerCredentials",
            .delta_sync_config = "deltaSyncConfig",
            .versioned = "versioned",
        };
        return @field(mappings, field_name);
    }
};

pub const DeltaSyncConfig = struct {
    base_table_ttl: ?i64 = null,
    delta_sync_table_name: ?[]const u8 = null,
    delta_sync_table_ttl: ?i64 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .base_table_ttl = "baseTableTTL",
            .delta_sync_table_name = "deltaSyncTableName",
            .delta_sync_table_ttl = "deltaSyncTableTTL",
        };
        return @field(mappings, field_name);
    }
};

pub const ApiKey = struct {
    id: ?[]const u8 = null,
    description: ?[]const u8 = null,
    expires: ?i64 = null,
    deletes: ?i64 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .id = "id",
            .description = "description",
            .expires = "expires",
            .deletes = "deletes",
        };
        return @field(mappings, field_name);
    }
};

pub const ApiCache = struct {
    ttl: ?i64 = null,
    api_caching_behavior: ?[]const u8 = null,
    transit_encryption_enabled: ?bool = null,
    at_rest_encryption_enabled: ?bool = null,
    type: ?[]const u8 = null,
    status: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .ttl = "ttl",
            .api_caching_behavior = "apiCachingBehavior",
            .transit_encryption_enabled = "transitEncryptionEnabled",
            .at_rest_encryption_enabled = "atRestEncryptionEnabled",
            .type = "type",
            .status = "status",
        };
        return @field(mappings, field_name);
    }
};
