const std = @import("std");
const serializeMap = @import("json.zig").serializeMap;
const smithy = @import("smithy");

const Self = @This();
pub const version: []const u8 = "2016-08-10";
pub const sdk_id: []const u8 = "Batch";
pub const arn_namespace: []const u8 = "batch";
pub const endpoint_prefix: []const u8 = "batch";
pub const sigv4_name: []const u8 = "batch";
pub const name: []const u8 = "AWSBatchV20160810";
pub const aws_protocol: smithy.AwsProtocol = smithy.AwsProtocol.rest_json_1;

pub const service_metadata: struct {
    version: []const u8 = "2016-08-10",
    sdk_id: []const u8 = "Batch",
    arn_namespace: []const u8 = "batch",
    endpoint_prefix: []const u8 = "batch",
    sigv4_name: []const u8 = "batch",
    name: []const u8 = "AWSBatchV20160810",
    aws_protocol: smithy.AwsProtocol = smithy.AwsProtocol.rest_json_1,
} = .{};
pub const cancel_job: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/v1/canceljob",
        .success_code = 200,
    };

    action_name: []const u8 = "CancelJob",
    Request: type = struct {
        job_id: []const u8,
        reason: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .job_id = "jobId",
                .reason = "reason",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(cancel_job) } {
            return .{ .service_metadata = service_metadata, .action = cancel_job };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        Client,
        Server,
    },
} = .{};
pub const create_compute_environment: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/v1/createcomputeenvironment",
        .success_code = 200,
    };

    action_name: []const u8 = "CreateComputeEnvironment",
    Request: type = struct {
        compute_environment_name: []const u8,
        type: []const u8,
        state: ?[]const u8 = null,
        compute_resources: ?ComputeResource = null,
        service_role: ?[]const u8 = null,
        tags: ?[]struct {
            key: ?[]const u8 = null,
            value: ?[]const u8 = null,
        } = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .compute_environment_name = "computeEnvironmentName",
                .type = "type",
                .state = "state",
                .compute_resources = "computeResources",
                .service_role = "serviceRole",
                .tags = "tags",
            };
            return @field(mappings, field_name);
        }

        pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
            if (std.mem.eql(u8, "tags", field_name))
                return try serializeMap(self.tags, self.fieldNameFor("tags"), options, out_stream);
            return false;
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(create_compute_environment) } {
            return .{ .service_metadata = service_metadata, .action = create_compute_environment };
        }
    },
    Response: type = struct {
        compute_environment_name: ?[]const u8 = null,
        compute_environment_arn: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .compute_environment_name = "computeEnvironmentName",
                .compute_environment_arn = "computeEnvironmentArn",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        Client,
        Server,
    },
} = .{};
pub const create_job_queue: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/v1/createjobqueue",
        .success_code = 200,
    };

    action_name: []const u8 = "CreateJobQueue",
    Request: type = struct {
        job_queue_name: []const u8,
        state: ?[]const u8 = null,
        priority: i64,
        compute_environment_order: []ComputeEnvironmentOrder,
        tags: ?[]struct {
            key: ?[]const u8 = null,
            value: ?[]const u8 = null,
        } = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .job_queue_name = "jobQueueName",
                .state = "state",
                .priority = "priority",
                .compute_environment_order = "computeEnvironmentOrder",
                .tags = "tags",
            };
            return @field(mappings, field_name);
        }

        pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
            if (std.mem.eql(u8, "tags", field_name))
                return try serializeMap(self.tags, self.fieldNameFor("tags"), options, out_stream);
            return false;
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(create_job_queue) } {
            return .{ .service_metadata = service_metadata, .action = create_job_queue };
        }
    },
    Response: type = struct {
        job_queue_name: []const u8,
        job_queue_arn: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .job_queue_name = "jobQueueName",
                .job_queue_arn = "jobQueueArn",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        Client,
        Server,
    },
} = .{};
pub const delete_compute_environment: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/v1/deletecomputeenvironment",
        .success_code = 200,
    };

    action_name: []const u8 = "DeleteComputeEnvironment",
    Request: type = struct {
        compute_environment: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .compute_environment = "computeEnvironment",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(delete_compute_environment) } {
            return .{ .service_metadata = service_metadata, .action = delete_compute_environment };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        Client,
        Server,
    },
} = .{};
pub const delete_job_queue: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/v1/deletejobqueue",
        .success_code = 200,
    };

    action_name: []const u8 = "DeleteJobQueue",
    Request: type = struct {
        job_queue: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .job_queue = "jobQueue",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(delete_job_queue) } {
            return .{ .service_metadata = service_metadata, .action = delete_job_queue };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        Client,
        Server,
    },
} = .{};
pub const deregister_job_definition: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/v1/deregisterjobdefinition",
        .success_code = 200,
    };

    action_name: []const u8 = "DeregisterJobDefinition",
    Request: type = struct {
        job_definition: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .job_definition = "jobDefinition",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(deregister_job_definition) } {
            return .{ .service_metadata = service_metadata, .action = deregister_job_definition };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        Client,
        Server,
    },
} = .{};
pub const describe_compute_environments: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/v1/describecomputeenvironments",
        .success_code = 200,
    };

    action_name: []const u8 = "DescribeComputeEnvironments",
    Request: type = struct {
        compute_environments: ?[][]const u8 = null,
        max_results: ?i64 = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .compute_environments = "computeEnvironments",
                .max_results = "maxResults",
                .next_token = "nextToken",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(describe_compute_environments) } {
            return .{ .service_metadata = service_metadata, .action = describe_compute_environments };
        }
    },
    Response: type = struct {
        compute_environments: ?[]struct {
            compute_environment_name: []const u8,
            compute_environment_arn: []const u8,
            ecs_cluster_arn: []const u8,
            tags: ?[]struct {
                key: ?[]const u8 = null,
                value: ?[]const u8 = null,
            } = null,
            type: ?[]const u8 = null,
            state: ?[]const u8 = null,
            status: ?[]const u8 = null,
            status_reason: ?[]const u8 = null,
            compute_resources: ?ComputeResource = null,
            service_role: ?[]const u8 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .compute_environment_name = "computeEnvironmentName",
                    .compute_environment_arn = "computeEnvironmentArn",
                    .ecs_cluster_arn = "ecsClusterArn",
                    .tags = "tags",
                    .type = "type",
                    .state = "state",
                    .status = "status",
                    .status_reason = "statusReason",
                    .compute_resources = "computeResources",
                    .service_role = "serviceRole",
                };
                return @field(mappings, field_name);
            }

            pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
                if (std.mem.eql(u8, "tags", field_name))
                    return try serializeMap(self.tags, self.fieldNameFor("tags"), options, out_stream);
                return false;
            }
        } = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .compute_environments = "computeEnvironments",
                .next_token = "nextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        Client,
        Server,
    },
} = .{};
pub const describe_job_definitions: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/v1/describejobdefinitions",
        .success_code = 200,
    };

    action_name: []const u8 = "DescribeJobDefinitions",
    Request: type = struct {
        job_definitions: ?[][]const u8 = null,
        max_results: ?i64 = null,
        job_definition_name: ?[]const u8 = null,
        status: ?[]const u8 = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .job_definitions = "jobDefinitions",
                .max_results = "maxResults",
                .job_definition_name = "jobDefinitionName",
                .status = "status",
                .next_token = "nextToken",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(describe_job_definitions) } {
            return .{ .service_metadata = service_metadata, .action = describe_job_definitions };
        }
    },
    Response: type = struct {
        job_definitions: ?[]struct {
            job_definition_name: []const u8,
            job_definition_arn: []const u8,
            revision: i64,
            status: ?[]const u8 = null,
            type: []const u8,
            parameters: ?[]struct {
                key: ?[]const u8 = null,
                value: ?[]const u8 = null,
            } = null,
            retry_strategy: ?RetryStrategy = null,
            container_properties: ?ContainerProperties = null,
            timeout: ?JobTimeout = null,
            node_properties: ?NodeProperties = null,
            tags: ?[]struct {
                key: ?[]const u8 = null,
                value: ?[]const u8 = null,
            } = null,
            propagate_tags: ?bool = null,
            platform_capabilities: ?[][]const u8 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .job_definition_name = "jobDefinitionName",
                    .job_definition_arn = "jobDefinitionArn",
                    .revision = "revision",
                    .status = "status",
                    .type = "type",
                    .parameters = "parameters",
                    .retry_strategy = "retryStrategy",
                    .container_properties = "containerProperties",
                    .timeout = "timeout",
                    .node_properties = "nodeProperties",
                    .tags = "tags",
                    .propagate_tags = "propagateTags",
                    .platform_capabilities = "platformCapabilities",
                };
                return @field(mappings, field_name);
            }

            pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
                if (std.mem.eql(u8, "parameters", field_name))
                    return try serializeMap(self.parameters, self.fieldNameFor("parameters"), options, out_stream);
                if (std.mem.eql(u8, "tags", field_name))
                    return try serializeMap(self.tags, self.fieldNameFor("tags"), options, out_stream);
                return false;
            }
        } = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .job_definitions = "jobDefinitions",
                .next_token = "nextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        Client,
        Server,
    },
} = .{};
pub const describe_job_queues: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/v1/describejobqueues",
        .success_code = 200,
    };

    action_name: []const u8 = "DescribeJobQueues",
    Request: type = struct {
        job_queues: ?[][]const u8 = null,
        max_results: ?i64 = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .job_queues = "jobQueues",
                .max_results = "maxResults",
                .next_token = "nextToken",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(describe_job_queues) } {
            return .{ .service_metadata = service_metadata, .action = describe_job_queues };
        }
    },
    Response: type = struct {
        job_queues: ?[]struct {
            job_queue_name: []const u8,
            job_queue_arn: []const u8,
            state: []const u8,
            status: ?[]const u8 = null,
            status_reason: ?[]const u8 = null,
            priority: i64,
            compute_environment_order: []ComputeEnvironmentOrder,
            tags: ?[]struct {
                key: ?[]const u8 = null,
                value: ?[]const u8 = null,
            } = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .job_queue_name = "jobQueueName",
                    .job_queue_arn = "jobQueueArn",
                    .state = "state",
                    .status = "status",
                    .status_reason = "statusReason",
                    .priority = "priority",
                    .compute_environment_order = "computeEnvironmentOrder",
                    .tags = "tags",
                };
                return @field(mappings, field_name);
            }

            pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
                if (std.mem.eql(u8, "tags", field_name))
                    return try serializeMap(self.tags, self.fieldNameFor("tags"), options, out_stream);
                return false;
            }
        } = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .job_queues = "jobQueues",
                .next_token = "nextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        Client,
        Server,
    },
} = .{};
pub const describe_jobs: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/v1/describejobs",
        .success_code = 200,
    };

    action_name: []const u8 = "DescribeJobs",
    Request: type = struct {
        jobs: [][]const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .jobs = "jobs",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(describe_jobs) } {
            return .{ .service_metadata = service_metadata, .action = describe_jobs };
        }
    },
    Response: type = struct {
        jobs: ?[]struct {
            job_arn: ?[]const u8 = null,
            job_name: []const u8,
            job_id: []const u8,
            job_queue: []const u8,
            status: []const u8,
            attempts: ?[]struct {
                container: ?struct {
                    container_instance_arn: ?[]const u8 = null,
                    task_arn: ?[]const u8 = null,
                    exit_code: ?i64 = null,
                    reason: ?[]const u8 = null,
                    log_stream_name: ?[]const u8 = null,
                    network_interfaces: ?[]NetworkInterface = null,

                    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                        const mappings = .{
                            .container_instance_arn = "containerInstanceArn",
                            .task_arn = "taskArn",
                            .exit_code = "exitCode",
                            .reason = "reason",
                            .log_stream_name = "logStreamName",
                            .network_interfaces = "networkInterfaces",
                        };
                        return @field(mappings, field_name);
                    }
                } = null,
                started_at: ?i64 = null,
                stopped_at: ?i64 = null,
                status_reason: ?[]const u8 = null,

                pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                    const mappings = .{
                        .container = "container",
                        .started_at = "startedAt",
                        .stopped_at = "stoppedAt",
                        .status_reason = "statusReason",
                    };
                    return @field(mappings, field_name);
                }
            } = null,
            status_reason: ?[]const u8 = null,
            created_at: ?i64 = null,
            retry_strategy: ?RetryStrategy = null,
            started_at: i64,
            stopped_at: ?i64 = null,
            depends_on: ?[]JobDependency = null,
            job_definition: []const u8,
            parameters: ?[]struct {
                key: ?[]const u8 = null,
                value: ?[]const u8 = null,
            } = null,
            container: ?struct {
                image: ?[]const u8 = null,
                vcpus: ?i64 = null,
                memory: ?i64 = null,
                command: ?[][]const u8 = null,
                job_role_arn: ?[]const u8 = null,
                execution_role_arn: ?[]const u8 = null,
                volumes: ?[]Volume = null,
                environment: ?[]KeyValuePair = null,
                mount_points: ?[]MountPoint = null,
                readonly_root_filesystem: ?bool = null,
                ulimits: ?[]Ulimit = null,
                privileged: ?bool = null,
                user: ?[]const u8 = null,
                exit_code: ?i64 = null,
                reason: ?[]const u8 = null,
                container_instance_arn: ?[]const u8 = null,
                task_arn: ?[]const u8 = null,
                log_stream_name: ?[]const u8 = null,
                instance_type: ?[]const u8 = null,
                network_interfaces: ?[]NetworkInterface = null,
                resource_requirements: ?[]ResourceRequirement = null,
                linux_parameters: ?LinuxParameters = null,
                log_configuration: ?LogConfiguration = null,
                secrets: ?[]Secret = null,
                network_configuration: ?NetworkConfiguration = null,
                fargate_platform_configuration: ?FargatePlatformConfiguration = null,

                pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                    const mappings = .{
                        .image = "image",
                        .vcpus = "vcpus",
                        .memory = "memory",
                        .command = "command",
                        .job_role_arn = "jobRoleArn",
                        .execution_role_arn = "executionRoleArn",
                        .volumes = "volumes",
                        .environment = "environment",
                        .mount_points = "mountPoints",
                        .readonly_root_filesystem = "readonlyRootFilesystem",
                        .ulimits = "ulimits",
                        .privileged = "privileged",
                        .user = "user",
                        .exit_code = "exitCode",
                        .reason = "reason",
                        .container_instance_arn = "containerInstanceArn",
                        .task_arn = "taskArn",
                        .log_stream_name = "logStreamName",
                        .instance_type = "instanceType",
                        .network_interfaces = "networkInterfaces",
                        .resource_requirements = "resourceRequirements",
                        .linux_parameters = "linuxParameters",
                        .log_configuration = "logConfiguration",
                        .secrets = "secrets",
                        .network_configuration = "networkConfiguration",
                        .fargate_platform_configuration = "fargatePlatformConfiguration",
                    };
                    return @field(mappings, field_name);
                }
            } = null,
            node_details: ?struct {
                node_index: ?i64 = null,
                is_main_node: ?bool = null,

                pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                    const mappings = .{
                        .node_index = "nodeIndex",
                        .is_main_node = "isMainNode",
                    };
                    return @field(mappings, field_name);
                }
            } = null,
            node_properties: ?NodeProperties = null,
            array_properties: ?struct {
                status_summary: ?[]struct {
                    key: ?[]const u8 = null,
                    value: ?i64 = null,
                } = null,
                size: ?i64 = null,
                index: ?i64 = null,

                pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                    const mappings = .{
                        .status_summary = "statusSummary",
                        .size = "size",
                        .index = "index",
                    };
                    return @field(mappings, field_name);
                }

                pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
                    if (std.mem.eql(u8, "status_summary", field_name))
                        return try serializeMap(self.status_summary, self.fieldNameFor("status_summary"), options, out_stream);
                    return false;
                }
            } = null,
            timeout: ?JobTimeout = null,
            tags: ?[]struct {
                key: ?[]const u8 = null,
                value: ?[]const u8 = null,
            } = null,
            propagate_tags: ?bool = null,
            platform_capabilities: ?[][]const u8 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .job_arn = "jobArn",
                    .job_name = "jobName",
                    .job_id = "jobId",
                    .job_queue = "jobQueue",
                    .status = "status",
                    .attempts = "attempts",
                    .status_reason = "statusReason",
                    .created_at = "createdAt",
                    .retry_strategy = "retryStrategy",
                    .started_at = "startedAt",
                    .stopped_at = "stoppedAt",
                    .depends_on = "dependsOn",
                    .job_definition = "jobDefinition",
                    .parameters = "parameters",
                    .container = "container",
                    .node_details = "nodeDetails",
                    .node_properties = "nodeProperties",
                    .array_properties = "arrayProperties",
                    .timeout = "timeout",
                    .tags = "tags",
                    .propagate_tags = "propagateTags",
                    .platform_capabilities = "platformCapabilities",
                };
                return @field(mappings, field_name);
            }

            pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
                if (std.mem.eql(u8, "parameters", field_name))
                    return try serializeMap(self.parameters, self.fieldNameFor("parameters"), options, out_stream);
                if (std.mem.eql(u8, "tags", field_name))
                    return try serializeMap(self.tags, self.fieldNameFor("tags"), options, out_stream);
                return false;
            }
        } = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .jobs = "jobs",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        Client,
        Server,
    },
} = .{};
pub const list_jobs: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/v1/listjobs",
        .success_code = 200,
    };

    action_name: []const u8 = "ListJobs",
    Request: type = struct {
        job_queue: ?[]const u8 = null,
        array_job_id: ?[]const u8 = null,
        multi_node_job_id: ?[]const u8 = null,
        job_status: ?[]const u8 = null,
        max_results: ?i64 = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .job_queue = "jobQueue",
                .array_job_id = "arrayJobId",
                .multi_node_job_id = "multiNodeJobId",
                .job_status = "jobStatus",
                .max_results = "maxResults",
                .next_token = "nextToken",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_jobs) } {
            return .{ .service_metadata = service_metadata, .action = list_jobs };
        }
    },
    Response: type = struct {
        job_summary_list: []struct {
            job_arn: ?[]const u8 = null,
            job_id: []const u8,
            job_name: []const u8,
            created_at: ?i64 = null,
            status: ?[]const u8 = null,
            status_reason: ?[]const u8 = null,
            started_at: ?i64 = null,
            stopped_at: ?i64 = null,
            container: ?struct {
                exit_code: ?i64 = null,
                reason: ?[]const u8 = null,

                pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                    const mappings = .{
                        .exit_code = "exitCode",
                        .reason = "reason",
                    };
                    return @field(mappings, field_name);
                }
            } = null,
            array_properties: ?struct {
                size: ?i64 = null,
                index: ?i64 = null,

                pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                    const mappings = .{
                        .size = "size",
                        .index = "index",
                    };
                    return @field(mappings, field_name);
                }
            } = null,
            node_properties: ?struct {
                is_main_node: ?bool = null,
                num_nodes: ?i64 = null,
                node_index: ?i64 = null,

                pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                    const mappings = .{
                        .is_main_node = "isMainNode",
                        .num_nodes = "numNodes",
                        .node_index = "nodeIndex",
                    };
                    return @field(mappings, field_name);
                }
            } = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .job_arn = "jobArn",
                    .job_id = "jobId",
                    .job_name = "jobName",
                    .created_at = "createdAt",
                    .status = "status",
                    .status_reason = "statusReason",
                    .started_at = "startedAt",
                    .stopped_at = "stoppedAt",
                    .container = "container",
                    .array_properties = "arrayProperties",
                    .node_properties = "nodeProperties",
                };
                return @field(mappings, field_name);
            }
        },
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .job_summary_list = "jobSummaryList",
                .next_token = "nextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        Client,
        Server,
    },
} = .{};
pub const list_tags_for_resource: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/v1/tags/{resourceArn}",
        .success_code = 200,
    };

    action_name: []const u8 = "ListTagsForResource",
    Request: type = struct {
        resource_arn: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .resource_arn = "resourceArn",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_tags_for_resource) } {
            return .{ .service_metadata = service_metadata, .action = list_tags_for_resource };
        }
    },
    Response: type = struct {
        tags: ?[]struct {
            key: ?[]const u8 = null,
            value: ?[]const u8 = null,
        } = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .tags = "tags",
            };
            return @field(mappings, field_name);
        }

        pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
            if (std.mem.eql(u8, "tags", field_name))
                return try serializeMap(self.tags, self.fieldNameFor("tags"), options, out_stream);
            return false;
        }
    },
    ServiceError: type = error{
        Client,
        Server,
    },
} = .{};
pub const register_job_definition: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/v1/registerjobdefinition",
        .success_code = 200,
    };

    action_name: []const u8 = "RegisterJobDefinition",
    Request: type = struct {
        job_definition_name: []const u8,
        type: []const u8,
        parameters: ?[]struct {
            key: ?[]const u8 = null,
            value: ?[]const u8 = null,
        } = null,
        container_properties: ?ContainerProperties = null,
        node_properties: ?NodeProperties = null,
        retry_strategy: ?RetryStrategy = null,
        propagate_tags: ?bool = null,
        timeout: ?JobTimeout = null,
        tags: ?[]struct {
            key: ?[]const u8 = null,
            value: ?[]const u8 = null,
        } = null,
        platform_capabilities: ?[][]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .job_definition_name = "jobDefinitionName",
                .type = "type",
                .parameters = "parameters",
                .container_properties = "containerProperties",
                .node_properties = "nodeProperties",
                .retry_strategy = "retryStrategy",
                .propagate_tags = "propagateTags",
                .timeout = "timeout",
                .tags = "tags",
                .platform_capabilities = "platformCapabilities",
            };
            return @field(mappings, field_name);
        }

        pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
            if (std.mem.eql(u8, "parameters", field_name))
                return try serializeMap(self.parameters, self.fieldNameFor("parameters"), options, out_stream);
            if (std.mem.eql(u8, "tags", field_name))
                return try serializeMap(self.tags, self.fieldNameFor("tags"), options, out_stream);
            return false;
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(register_job_definition) } {
            return .{ .service_metadata = service_metadata, .action = register_job_definition };
        }
    },
    Response: type = struct {
        job_definition_name: []const u8,
        job_definition_arn: []const u8,
        revision: i64,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .job_definition_name = "jobDefinitionName",
                .job_definition_arn = "jobDefinitionArn",
                .revision = "revision",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        Client,
        Server,
    },
} = .{};
pub const submit_job: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/v1/submitjob",
        .success_code = 200,
    };

    action_name: []const u8 = "SubmitJob",
    Request: type = struct {
        job_name: []const u8,
        job_queue: []const u8,
        array_properties: ?struct {
            size: ?i64 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .size = "size",
                };
                return @field(mappings, field_name);
            }
        } = null,
        depends_on: ?[]JobDependency = null,
        job_definition: []const u8,
        parameters: ?[]struct {
            key: ?[]const u8 = null,
            value: ?[]const u8 = null,
        } = null,
        container_overrides: ?ContainerOverrides = null,
        node_overrides: ?struct {
            num_nodes: ?i64 = null,
            node_property_overrides: ?[]struct {
                target_nodes: []const u8,
                container_overrides: ?ContainerOverrides = null,

                pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                    const mappings = .{
                        .target_nodes = "targetNodes",
                        .container_overrides = "containerOverrides",
                    };
                    return @field(mappings, field_name);
                }
            } = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .num_nodes = "numNodes",
                    .node_property_overrides = "nodePropertyOverrides",
                };
                return @field(mappings, field_name);
            }
        } = null,
        retry_strategy: ?RetryStrategy = null,
        propagate_tags: ?bool = null,
        timeout: ?JobTimeout = null,
        tags: ?[]struct {
            key: ?[]const u8 = null,
            value: ?[]const u8 = null,
        } = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .job_name = "jobName",
                .job_queue = "jobQueue",
                .array_properties = "arrayProperties",
                .depends_on = "dependsOn",
                .job_definition = "jobDefinition",
                .parameters = "parameters",
                .container_overrides = "containerOverrides",
                .node_overrides = "nodeOverrides",
                .retry_strategy = "retryStrategy",
                .propagate_tags = "propagateTags",
                .timeout = "timeout",
                .tags = "tags",
            };
            return @field(mappings, field_name);
        }

        pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
            if (std.mem.eql(u8, "parameters", field_name))
                return try serializeMap(self.parameters, self.fieldNameFor("parameters"), options, out_stream);
            if (std.mem.eql(u8, "tags", field_name))
                return try serializeMap(self.tags, self.fieldNameFor("tags"), options, out_stream);
            return false;
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(submit_job) } {
            return .{ .service_metadata = service_metadata, .action = submit_job };
        }
    },
    Response: type = struct {
        job_arn: ?[]const u8 = null,
        job_name: []const u8,
        job_id: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .job_arn = "jobArn",
                .job_name = "jobName",
                .job_id = "jobId",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        Client,
        Server,
    },
} = .{};
pub const tag_resource: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/v1/tags/{resourceArn}",
        .success_code = 200,
    };

    action_name: []const u8 = "TagResource",
    Request: type = struct {
        resource_arn: []const u8,
        tags: []struct {
            key: ?[]const u8 = null,
            value: ?[]const u8 = null,
        },

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .resource_arn = "resourceArn",
                .tags = "tags",
            };
            return @field(mappings, field_name);
        }

        pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
            if (std.mem.eql(u8, "tags", field_name))
                return try serializeMap(self.tags, self.fieldNameFor("tags"), options, out_stream);
            return false;
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(tag_resource) } {
            return .{ .service_metadata = service_metadata, .action = tag_resource };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        Client,
        Server,
    },
} = .{};
pub const terminate_job: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/v1/terminatejob",
        .success_code = 200,
    };

    action_name: []const u8 = "TerminateJob",
    Request: type = struct {
        job_id: []const u8,
        reason: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .job_id = "jobId",
                .reason = "reason",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(terminate_job) } {
            return .{ .service_metadata = service_metadata, .action = terminate_job };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        Client,
        Server,
    },
} = .{};
pub const untag_resource: struct {
    pub const http_config = .{
        .method = "DELETE",
        .uri = "/v1/tags/{resourceArn}",
        .success_code = 200,
    };

    action_name: []const u8 = "UntagResource",
    Request: type = struct {
        resource_arn: []const u8,
        tag_keys: [][]const u8,

        pub const http_query = .{
            .tag_keys = "tagKeys",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .resource_arn = "resourceArn",
                .tag_keys = "tagKeys",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(untag_resource) } {
            return .{ .service_metadata = service_metadata, .action = untag_resource };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        Client,
        Server,
    },
} = .{};
pub const update_compute_environment: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/v1/updatecomputeenvironment",
        .success_code = 200,
    };

    action_name: []const u8 = "UpdateComputeEnvironment",
    Request: type = struct {
        compute_environment: []const u8,
        state: ?[]const u8 = null,
        compute_resources: ?struct {
            minv_cpus: ?i64 = null,
            maxv_cpus: ?i64 = null,
            desiredv_cpus: ?i64 = null,
            subnets: ?[][]const u8 = null,
            security_group_ids: ?[][]const u8 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .minv_cpus = "minvCpus",
                    .maxv_cpus = "maxvCpus",
                    .desiredv_cpus = "desiredvCpus",
                    .subnets = "subnets",
                    .security_group_ids = "securityGroupIds",
                };
                return @field(mappings, field_name);
            }
        } = null,
        service_role: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .compute_environment = "computeEnvironment",
                .state = "state",
                .compute_resources = "computeResources",
                .service_role = "serviceRole",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(update_compute_environment) } {
            return .{ .service_metadata = service_metadata, .action = update_compute_environment };
        }
    },
    Response: type = struct {
        compute_environment_name: ?[]const u8 = null,
        compute_environment_arn: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .compute_environment_name = "computeEnvironmentName",
                .compute_environment_arn = "computeEnvironmentArn",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        Client,
        Server,
    },
} = .{};
pub const update_job_queue: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/v1/updatejobqueue",
        .success_code = 200,
    };

    action_name: []const u8 = "UpdateJobQueue",
    Request: type = struct {
        job_queue: []const u8,
        state: ?[]const u8 = null,
        priority: ?i64 = null,
        compute_environment_order: ?[]ComputeEnvironmentOrder = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .job_queue = "jobQueue",
                .state = "state",
                .priority = "priority",
                .compute_environment_order = "computeEnvironmentOrder",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(update_job_queue) } {
            return .{ .service_metadata = service_metadata, .action = update_job_queue };
        }
    },
    Response: type = struct {
        job_queue_name: ?[]const u8 = null,
        job_queue_arn: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .job_queue_name = "jobQueueName",
                .job_queue_arn = "jobQueueArn",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        Client,
        Server,
    },
} = .{};

pub const ComputeEnvironmentOrder = struct {
    order: i64,
    compute_environment: []const u8,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .order = "order",
            .compute_environment = "computeEnvironment",
        };
        return @field(mappings, field_name);
    }
};

pub const JobTimeout = struct {
    attempt_duration_seconds: ?i64 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .attempt_duration_seconds = "attemptDurationSeconds",
        };
        return @field(mappings, field_name);
    }
};

pub const RetryStrategy = struct {
    attempts: ?i64 = null,
    evaluate_on_exit: ?[]EvaluateOnExit = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .attempts = "attempts",
            .evaluate_on_exit = "evaluateOnExit",
        };
        return @field(mappings, field_name);
    }
};

pub const EvaluateOnExit = struct {
    on_status_reason: ?[]const u8 = null,
    on_reason: ?[]const u8 = null,
    on_exit_code: ?[]const u8 = null,
    action: []const u8,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .on_status_reason = "onStatusReason",
            .on_reason = "onReason",
            .on_exit_code = "onExitCode",
            .action = "action",
        };
        return @field(mappings, field_name);
    }
};

pub const ContainerOverrides = struct {
    vcpus: ?i64 = null,
    memory: ?i64 = null,
    command: ?[][]const u8 = null,
    instance_type: ?[]const u8 = null,
    environment: ?[]KeyValuePair = null,
    resource_requirements: ?[]ResourceRequirement = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .vcpus = "vcpus",
            .memory = "memory",
            .command = "command",
            .instance_type = "instanceType",
            .environment = "environment",
            .resource_requirements = "resourceRequirements",
        };
        return @field(mappings, field_name);
    }
};

pub const ResourceRequirement = struct {
    value: []const u8,
    type: []const u8,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .value = "value",
            .type = "type",
        };
        return @field(mappings, field_name);
    }
};

pub const KeyValuePair = struct {
    name: ?[]const u8 = null,
    value: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .name = "name",
            .value = "value",
        };
        return @field(mappings, field_name);
    }
};

pub const JobDependency = struct {
    job_id: ?[]const u8 = null,
    type: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .job_id = "jobId",
            .type = "type",
        };
        return @field(mappings, field_name);
    }
};

pub const NodeProperties = struct {
    num_nodes: i64,
    main_node: i64,
    node_range_properties: []NodeRangeProperty,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .num_nodes = "numNodes",
            .main_node = "mainNode",
            .node_range_properties = "nodeRangeProperties",
        };
        return @field(mappings, field_name);
    }
};

pub const NodeRangeProperty = struct {
    target_nodes: []const u8,
    container: ?ContainerProperties = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .target_nodes = "targetNodes",
            .container = "container",
        };
        return @field(mappings, field_name);
    }
};

pub const ContainerProperties = struct {
    image: ?[]const u8 = null,
    vcpus: ?i64 = null,
    memory: ?i64 = null,
    command: ?[][]const u8 = null,
    job_role_arn: ?[]const u8 = null,
    execution_role_arn: ?[]const u8 = null,
    volumes: ?[]Volume = null,
    environment: ?[]KeyValuePair = null,
    mount_points: ?[]MountPoint = null,
    readonly_root_filesystem: ?bool = null,
    privileged: ?bool = null,
    ulimits: ?[]Ulimit = null,
    user: ?[]const u8 = null,
    instance_type: ?[]const u8 = null,
    resource_requirements: ?[]ResourceRequirement = null,
    linux_parameters: ?LinuxParameters = null,
    log_configuration: ?LogConfiguration = null,
    secrets: ?[]Secret = null,
    network_configuration: ?NetworkConfiguration = null,
    fargate_platform_configuration: ?FargatePlatformConfiguration = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .image = "image",
            .vcpus = "vcpus",
            .memory = "memory",
            .command = "command",
            .job_role_arn = "jobRoleArn",
            .execution_role_arn = "executionRoleArn",
            .volumes = "volumes",
            .environment = "environment",
            .mount_points = "mountPoints",
            .readonly_root_filesystem = "readonlyRootFilesystem",
            .privileged = "privileged",
            .ulimits = "ulimits",
            .user = "user",
            .instance_type = "instanceType",
            .resource_requirements = "resourceRequirements",
            .linux_parameters = "linuxParameters",
            .log_configuration = "logConfiguration",
            .secrets = "secrets",
            .network_configuration = "networkConfiguration",
            .fargate_platform_configuration = "fargatePlatformConfiguration",
        };
        return @field(mappings, field_name);
    }
};

pub const FargatePlatformConfiguration = struct {
    platform_version: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .platform_version = "platformVersion",
        };
        return @field(mappings, field_name);
    }
};

pub const NetworkConfiguration = struct {
    assign_public_ip: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .assign_public_ip = "assignPublicIp",
        };
        return @field(mappings, field_name);
    }
};

pub const Secret = struct {
    name: []const u8,
    value_from: []const u8,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .name = "name",
            .value_from = "valueFrom",
        };
        return @field(mappings, field_name);
    }
};

pub const LogConfiguration = struct {
    log_driver: []const u8,
    options: ?[]struct {
        key: ?[]const u8 = null,
        value: ?[]const u8 = null,
    } = null,
    secret_options: ?[]Secret = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .log_driver = "logDriver",
            .options = "options",
            .secret_options = "secretOptions",
        };
        return @field(mappings, field_name);
    }

    pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
        if (std.mem.eql(u8, "options", field_name))
            return try serializeMap(self.options, self.fieldNameFor("options"), options, out_stream);
        return false;
    }
};

pub const LinuxParameters = struct {
    devices: ?[]Device = null,
    init_process_enabled: ?bool = null,
    shared_memory_size: ?i64 = null,
    tmpfs: ?[]Tmpfs = null,
    max_swap: ?i64 = null,
    swappiness: ?i64 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .devices = "devices",
            .init_process_enabled = "initProcessEnabled",
            .shared_memory_size = "sharedMemorySize",
            .tmpfs = "tmpfs",
            .max_swap = "maxSwap",
            .swappiness = "swappiness",
        };
        return @field(mappings, field_name);
    }
};

pub const Tmpfs = struct {
    container_path: []const u8,
    size: i64,
    mount_options: ?[][]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .container_path = "containerPath",
            .size = "size",
            .mount_options = "mountOptions",
        };
        return @field(mappings, field_name);
    }
};

pub const Device = struct {
    host_path: []const u8,
    container_path: ?[]const u8 = null,
    permissions: ?[][]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .host_path = "hostPath",
            .container_path = "containerPath",
            .permissions = "permissions",
        };
        return @field(mappings, field_name);
    }
};

pub const Ulimit = struct {
    hard_limit: i64,
    name: []const u8,
    soft_limit: i64,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .hard_limit = "hardLimit",
            .name = "name",
            .soft_limit = "softLimit",
        };
        return @field(mappings, field_name);
    }
};

pub const MountPoint = struct {
    container_path: ?[]const u8 = null,
    read_only: ?bool = null,
    source_volume: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .container_path = "containerPath",
            .read_only = "readOnly",
            .source_volume = "sourceVolume",
        };
        return @field(mappings, field_name);
    }
};

pub const Volume = struct {
    host: ?Host = null,
    name: ?[]const u8 = null,
    efs_volume_configuration: ?EFSVolumeConfiguration = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .host = "host",
            .name = "name",
            .efs_volume_configuration = "efsVolumeConfiguration",
        };
        return @field(mappings, field_name);
    }
};

pub const EFSVolumeConfiguration = struct {
    file_system_id: []const u8,
    root_directory: ?[]const u8 = null,
    transit_encryption: ?[]const u8 = null,
    transit_encryption_port: ?i64 = null,
    authorization_config: ?EFSAuthorizationConfig = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .file_system_id = "fileSystemId",
            .root_directory = "rootDirectory",
            .transit_encryption = "transitEncryption",
            .transit_encryption_port = "transitEncryptionPort",
            .authorization_config = "authorizationConfig",
        };
        return @field(mappings, field_name);
    }
};

pub const EFSAuthorizationConfig = struct {
    access_point_id: ?[]const u8 = null,
    iam: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .access_point_id = "accessPointId",
            .iam = "iam",
        };
        return @field(mappings, field_name);
    }
};

pub const Host = struct {
    source_path: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .source_path = "sourcePath",
        };
        return @field(mappings, field_name);
    }
};

pub const NetworkInterface = struct {
    attachment_id: ?[]const u8 = null,
    ipv6_address: ?[]const u8 = null,
    private_ipv4_address: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .attachment_id = "attachmentId",
            .ipv6_address = "ipv6Address",
            .private_ipv4_address = "privateIpv4Address",
        };
        return @field(mappings, field_name);
    }
};

pub const ComputeResource = struct {
    type: []const u8,
    allocation_strategy: ?[]const u8 = null,
    minv_cpus: ?i64 = null,
    maxv_cpus: i64,
    desiredv_cpus: ?i64 = null,
    instance_types: ?[][]const u8 = null,
    image_id: ?[]const u8 = null,
    subnets: [][]const u8,
    security_group_ids: ?[][]const u8 = null,
    ec2_key_pair: ?[]const u8 = null,
    instance_role: ?[]const u8 = null,
    tags: ?[]struct {
        key: ?[]const u8 = null,
        value: ?[]const u8 = null,
    } = null,
    placement_group: ?[]const u8 = null,
    bid_percentage: ?i64 = null,
    spot_iam_fleet_role: ?[]const u8 = null,
    launch_template: ?LaunchTemplateSpecification = null,
    ec2_configuration: ?[]Ec2Configuration = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .type = "type",
            .allocation_strategy = "allocationStrategy",
            .minv_cpus = "minvCpus",
            .maxv_cpus = "maxvCpus",
            .desiredv_cpus = "desiredvCpus",
            .instance_types = "instanceTypes",
            .image_id = "imageId",
            .subnets = "subnets",
            .security_group_ids = "securityGroupIds",
            .ec2_key_pair = "ec2KeyPair",
            .instance_role = "instanceRole",
            .tags = "tags",
            .placement_group = "placementGroup",
            .bid_percentage = "bidPercentage",
            .spot_iam_fleet_role = "spotIamFleetRole",
            .launch_template = "launchTemplate",
            .ec2_configuration = "ec2Configuration",
        };
        return @field(mappings, field_name);
    }

    pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
        if (std.mem.eql(u8, "tags", field_name))
            return try serializeMap(self.tags, self.fieldNameFor("tags"), options, out_stream);
        return false;
    }
};

pub const Ec2Configuration = struct {
    image_type: []const u8,
    image_id_override: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .image_type = "imageType",
            .image_id_override = "imageIdOverride",
        };
        return @field(mappings, field_name);
    }
};

pub const LaunchTemplateSpecification = struct {
    launch_template_id: ?[]const u8 = null,
    launch_template_name: ?[]const u8 = null,
    version: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .launch_template_id = "launchTemplateId",
            .launch_template_name = "launchTemplateName",
            .version = "version",
        };
        return @field(mappings, field_name);
    }
};
