const std = @import("std");
const serializeMap = @import("json.zig").serializeMap;
const smithy = @import("smithy");

const Self = @This();
pub const version: []const u8 = "2013-11-01";
pub const sdk_id: []const u8 = "CloudTrail";
pub const arn_namespace: []const u8 = "cloudtrail";
pub const endpoint_prefix: []const u8 = "cloudtrail";
pub const sigv4_name: []const u8 = "cloudtrail";
pub const name: []const u8 = "CloudTrail_20131101";
pub const aws_protocol: smithy.AwsProtocol = smithy.AwsProtocol.json_1_1;

pub const service_metadata: struct {
    version: []const u8 = "2013-11-01",
    sdk_id: []const u8 = "CloudTrail",
    arn_namespace: []const u8 = "cloudtrail",
    endpoint_prefix: []const u8 = "cloudtrail",
    sigv4_name: []const u8 = "cloudtrail",
    name: []const u8 = "CloudTrail_20131101",
    aws_protocol: smithy.AwsProtocol = smithy.AwsProtocol.json_1_1,
} = .{};
pub const add_tags: struct {
    action_name: []const u8 = "AddTags",
    Request: type = struct {
        resource_id: []const u8,
        tags_list: ?[]Tag = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .resource_id = "ResourceId",
                .tags_list = "TagsList",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(add_tags) } {
            return .{ .service_metadata = service_metadata, .action = add_tags };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        CloudTrailARNInvalid,
        InvalidTagParameter,
        InvalidTrailName,
        NotOrganizationMasterAccount,
        OperationNotPermitted,
        ResourceNotFound,
        ResourceTypeNotSupported,
        TagsLimitExceeded,
        UnsupportedOperation,
    },
} = .{};
pub const create_trail: struct {
    action_name: []const u8 = "CreateTrail",
    Request: type = struct {
        name: []const u8,
        s3_bucket_name: []const u8,
        s3_key_prefix: ?[]const u8 = null,
        sns_topic_name: ?[]const u8 = null,
        include_global_service_events: ?bool = null,
        is_multi_region_trail: ?bool = null,
        enable_log_file_validation: ?bool = null,
        cloud_watch_logs_log_group_arn: ?[]const u8 = null,
        cloud_watch_logs_role_arn: ?[]const u8 = null,
        kms_key_id: ?[]const u8 = null,
        is_organization_trail: ?bool = null,
        tags_list: ?[]Tag = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .name = "Name",
                .s3_bucket_name = "S3BucketName",
                .s3_key_prefix = "S3KeyPrefix",
                .sns_topic_name = "SnsTopicName",
                .include_global_service_events = "IncludeGlobalServiceEvents",
                .is_multi_region_trail = "IsMultiRegionTrail",
                .enable_log_file_validation = "EnableLogFileValidation",
                .cloud_watch_logs_log_group_arn = "CloudWatchLogsLogGroupArn",
                .cloud_watch_logs_role_arn = "CloudWatchLogsRoleArn",
                .kms_key_id = "KmsKeyId",
                .is_organization_trail = "IsOrganizationTrail",
                .tags_list = "TagsList",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(create_trail) } {
            return .{ .service_metadata = service_metadata, .action = create_trail };
        }
    },
    Response: type = struct {
        name: ?[]const u8 = null,
        s3_bucket_name: ?[]const u8 = null,
        s3_key_prefix: ?[]const u8 = null,
        sns_topic_name: ?[]const u8 = null,
        sns_topic_arn: ?[]const u8 = null,
        include_global_service_events: ?bool = null,
        is_multi_region_trail: ?bool = null,
        trail_arn: ?[]const u8 = null,
        log_file_validation_enabled: ?bool = null,
        cloud_watch_logs_log_group_arn: ?[]const u8 = null,
        cloud_watch_logs_role_arn: ?[]const u8 = null,
        kms_key_id: ?[]const u8 = null,
        is_organization_trail: ?bool = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .name = "Name",
                .s3_bucket_name = "S3BucketName",
                .s3_key_prefix = "S3KeyPrefix",
                .sns_topic_name = "SnsTopicName",
                .sns_topic_arn = "SnsTopicARN",
                .include_global_service_events = "IncludeGlobalServiceEvents",
                .is_multi_region_trail = "IsMultiRegionTrail",
                .trail_arn = "TrailARN",
                .log_file_validation_enabled = "LogFileValidationEnabled",
                .cloud_watch_logs_log_group_arn = "CloudWatchLogsLogGroupArn",
                .cloud_watch_logs_role_arn = "CloudWatchLogsRoleArn",
                .kms_key_id = "KmsKeyId",
                .is_organization_trail = "IsOrganizationTrail",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        CloudTrailAccessNotEnabled,
        CloudTrailInvalidClientTokenId,
        CloudWatchLogsDeliveryUnavailable,
        InsufficientDependencyServiceAccessPermission,
        InsufficientEncryptionPolicy,
        InsufficientS3BucketPolicy,
        InsufficientSnsTopicPolicy,
        InvalidCloudWatchLogsLogGroupArn,
        InvalidCloudWatchLogsRoleArn,
        InvalidKmsKeyId,
        InvalidParameterCombination,
        InvalidS3BucketName,
        InvalidS3Prefix,
        InvalidSnsTopicName,
        InvalidTagParameter,
        InvalidTrailName,
        Kms,
        KmsKeyDisabled,
        KmsKeyNotFound,
        MaximumNumberOfTrailsExceeded,
        NotOrganizationMasterAccount,
        OperationNotPermitted,
        OrganizationNotInAllFeaturesMode,
        OrganizationsNotInUse,
        S3BucketDoesNotExist,
        TrailAlreadyExists,
        TrailNotProvided,
        UnsupportedOperation,
    },
} = .{};
pub const delete_trail: struct {
    action_name: []const u8 = "DeleteTrail",
    Request: type = struct {
        name: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .name = "Name",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(delete_trail) } {
            return .{ .service_metadata = service_metadata, .action = delete_trail };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        Conflict,
        InsufficientDependencyServiceAccessPermission,
        InvalidHomeRegion,
        InvalidTrailName,
        NotOrganizationMasterAccount,
        OperationNotPermitted,
        TrailNotFound,
        UnsupportedOperation,
    },
} = .{};
pub const describe_trails: struct {
    action_name: []const u8 = "DescribeTrails",
    Request: type = struct {
        trail_name_list: ?[][]const u8 = null,
        include_shadow_trails: ?bool = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .trail_name_list = "trailNameList",
                .include_shadow_trails = "includeShadowTrails",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(describe_trails) } {
            return .{ .service_metadata = service_metadata, .action = describe_trails };
        }
    },
    Response: type = struct {
        trail_list: ?[]Trail = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .trail_list = "trailList",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InvalidTrailName,
        OperationNotPermitted,
        UnsupportedOperation,
    },
} = .{};
pub const get_event_selectors: struct {
    action_name: []const u8 = "GetEventSelectors",
    Request: type = struct {
        trail_name: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .trail_name = "TrailName",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(get_event_selectors) } {
            return .{ .service_metadata = service_metadata, .action = get_event_selectors };
        }
    },
    Response: type = struct {
        trail_arn: ?[]const u8 = null,
        event_selectors: ?[]EventSelector = null,
        advanced_event_selectors: ?[]AdvancedEventSelector = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .trail_arn = "TrailARN",
                .event_selectors = "EventSelectors",
                .advanced_event_selectors = "AdvancedEventSelectors",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InvalidTrailName,
        OperationNotPermitted,
        TrailNotFound,
        UnsupportedOperation,
    },
} = .{};
pub const get_insight_selectors: struct {
    action_name: []const u8 = "GetInsightSelectors",
    Request: type = struct {
        trail_name: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .trail_name = "TrailName",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(get_insight_selectors) } {
            return .{ .service_metadata = service_metadata, .action = get_insight_selectors };
        }
    },
    Response: type = struct {
        trail_arn: ?[]const u8 = null,
        insight_selectors: ?[]InsightSelector = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .trail_arn = "TrailARN",
                .insight_selectors = "InsightSelectors",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InsightNotEnabled,
        InvalidTrailName,
        OperationNotPermitted,
        TrailNotFound,
        UnsupportedOperation,
    },
} = .{};
pub const get_trail: struct {
    action_name: []const u8 = "GetTrail",
    Request: type = struct {
        name: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .name = "Name",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(get_trail) } {
            return .{ .service_metadata = service_metadata, .action = get_trail };
        }
    },
    Response: type = struct {
        trail: ?Trail = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .trail = "Trail",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InvalidTrailName,
        OperationNotPermitted,
        TrailNotFound,
        UnsupportedOperation,
    },
} = .{};
pub const get_trail_status: struct {
    action_name: []const u8 = "GetTrailStatus",
    Request: type = struct {
        name: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .name = "Name",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(get_trail_status) } {
            return .{ .service_metadata = service_metadata, .action = get_trail_status };
        }
    },
    Response: type = struct {
        is_logging: ?bool = null,
        latest_delivery_error: ?[]const u8 = null,
        latest_notification_error: ?[]const u8 = null,
        latest_delivery_time: ?i64 = null,
        latest_notification_time: ?i64 = null,
        start_logging_time: ?i64 = null,
        stop_logging_time: ?i64 = null,
        latest_cloud_watch_logs_delivery_error: ?[]const u8 = null,
        latest_cloud_watch_logs_delivery_time: ?i64 = null,
        latest_digest_delivery_time: ?i64 = null,
        latest_digest_delivery_error: ?[]const u8 = null,
        latest_delivery_attempt_time: ?[]const u8 = null,
        latest_notification_attempt_time: ?[]const u8 = null,
        latest_notification_attempt_succeeded: ?[]const u8 = null,
        latest_delivery_attempt_succeeded: ?[]const u8 = null,
        time_logging_started: ?[]const u8 = null,
        time_logging_stopped: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .is_logging = "IsLogging",
                .latest_delivery_error = "LatestDeliveryError",
                .latest_notification_error = "LatestNotificationError",
                .latest_delivery_time = "LatestDeliveryTime",
                .latest_notification_time = "LatestNotificationTime",
                .start_logging_time = "StartLoggingTime",
                .stop_logging_time = "StopLoggingTime",
                .latest_cloud_watch_logs_delivery_error = "LatestCloudWatchLogsDeliveryError",
                .latest_cloud_watch_logs_delivery_time = "LatestCloudWatchLogsDeliveryTime",
                .latest_digest_delivery_time = "LatestDigestDeliveryTime",
                .latest_digest_delivery_error = "LatestDigestDeliveryError",
                .latest_delivery_attempt_time = "LatestDeliveryAttemptTime",
                .latest_notification_attempt_time = "LatestNotificationAttemptTime",
                .latest_notification_attempt_succeeded = "LatestNotificationAttemptSucceeded",
                .latest_delivery_attempt_succeeded = "LatestDeliveryAttemptSucceeded",
                .time_logging_started = "TimeLoggingStarted",
                .time_logging_stopped = "TimeLoggingStopped",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InvalidTrailName,
        OperationNotPermitted,
        TrailNotFound,
        UnsupportedOperation,
    },
} = .{};
pub const list_public_keys: struct {
    action_name: []const u8 = "ListPublicKeys",
    Request: type = struct {
        start_time: ?i64 = null,
        end_time: ?i64 = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .start_time = "StartTime",
                .end_time = "EndTime",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_public_keys) } {
            return .{ .service_metadata = service_metadata, .action = list_public_keys };
        }
    },
    Response: type = struct {
        public_key_list: ?[]struct {
            value: ?[]const u8 = null,
            validity_start_time: ?i64 = null,
            validity_end_time: ?i64 = null,
            fingerprint: ?[]const u8 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .value = "Value",
                    .validity_start_time = "ValidityStartTime",
                    .validity_end_time = "ValidityEndTime",
                    .fingerprint = "Fingerprint",
                };
                return @field(mappings, field_name);
            }
        } = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .public_key_list = "PublicKeyList",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InvalidTimeRange,
        InvalidToken,
        OperationNotPermitted,
        UnsupportedOperation,
    },
} = .{};
pub const list_tags: struct {
    action_name: []const u8 = "ListTags",
    Request: type = struct {
        resource_id_list: [][]const u8,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .resource_id_list = "ResourceIdList",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_tags) } {
            return .{ .service_metadata = service_metadata, .action = list_tags };
        }
    },
    Response: type = struct {
        resource_tag_list: ?[]struct {
            resource_id: ?[]const u8 = null,
            tags_list: ?[]Tag = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .resource_id = "ResourceId",
                    .tags_list = "TagsList",
                };
                return @field(mappings, field_name);
            }
        } = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .resource_tag_list = "ResourceTagList",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        CloudTrailARNInvalid,
        InvalidToken,
        InvalidTrailName,
        OperationNotPermitted,
        ResourceNotFound,
        ResourceTypeNotSupported,
        UnsupportedOperation,
    },
} = .{};
pub const list_trails: struct {
    action_name: []const u8 = "ListTrails",
    Request: type = struct {
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_trails) } {
            return .{ .service_metadata = service_metadata, .action = list_trails };
        }
    },
    Response: type = struct {
        trails: ?[]struct {
            trail_arn: ?[]const u8 = null,
            name: ?[]const u8 = null,
            home_region: ?[]const u8 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .trail_arn = "TrailARN",
                    .name = "Name",
                    .home_region = "HomeRegion",
                };
                return @field(mappings, field_name);
            }
        } = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .trails = "Trails",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        OperationNotPermitted,
        UnsupportedOperation,
    },
} = .{};
pub const lookup_events: struct {
    action_name: []const u8 = "LookupEvents",
    Request: type = struct {
        lookup_attributes: ?[]struct {
            attribute_key: []const u8,
            attribute_value: []const u8,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .attribute_key = "AttributeKey",
                    .attribute_value = "AttributeValue",
                };
                return @field(mappings, field_name);
            }
        } = null,
        start_time: ?i64 = null,
        end_time: ?i64 = null,
        event_category: ?[]const u8 = null,
        max_results: ?i64 = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .lookup_attributes = "LookupAttributes",
                .start_time = "StartTime",
                .end_time = "EndTime",
                .event_category = "EventCategory",
                .max_results = "MaxResults",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(lookup_events) } {
            return .{ .service_metadata = service_metadata, .action = lookup_events };
        }
    },
    Response: type = struct {
        events: ?[]struct {
            event_id: ?[]const u8 = null,
            event_name: ?[]const u8 = null,
            read_only: ?[]const u8 = null,
            access_key_id: ?[]const u8 = null,
            event_time: ?i64 = null,
            event_source: ?[]const u8 = null,
            username: ?[]const u8 = null,
            resources: ?[]struct {
                resource_type: ?[]const u8 = null,
                resource_name: ?[]const u8 = null,

                pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                    const mappings = .{
                        .resource_type = "ResourceType",
                        .resource_name = "ResourceName",
                    };
                    return @field(mappings, field_name);
                }
            } = null,
            cloud_trail_event: ?[]const u8 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .event_id = "EventId",
                    .event_name = "EventName",
                    .read_only = "ReadOnly",
                    .access_key_id = "AccessKeyId",
                    .event_time = "EventTime",
                    .event_source = "EventSource",
                    .username = "Username",
                    .resources = "Resources",
                    .cloud_trail_event = "CloudTrailEvent",
                };
                return @field(mappings, field_name);
            }
        } = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .events = "Events",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InvalidEventCategory,
        InvalidLookupAttributes,
        InvalidMaxResults,
        InvalidNextToken,
        InvalidTimeRange,
        OperationNotPermitted,
        UnsupportedOperation,
    },
} = .{};
pub const put_event_selectors: struct {
    action_name: []const u8 = "PutEventSelectors",
    Request: type = struct {
        trail_name: []const u8,
        event_selectors: ?[]EventSelector = null,
        advanced_event_selectors: ?[]AdvancedEventSelector = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .trail_name = "TrailName",
                .event_selectors = "EventSelectors",
                .advanced_event_selectors = "AdvancedEventSelectors",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(put_event_selectors) } {
            return .{ .service_metadata = service_metadata, .action = put_event_selectors };
        }
    },
    Response: type = struct {
        trail_arn: ?[]const u8 = null,
        event_selectors: ?[]EventSelector = null,
        advanced_event_selectors: ?[]AdvancedEventSelector = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .trail_arn = "TrailARN",
                .event_selectors = "EventSelectors",
                .advanced_event_selectors = "AdvancedEventSelectors",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InsufficientDependencyServiceAccessPermission,
        InvalidEventSelectors,
        InvalidHomeRegion,
        InvalidTrailName,
        NotOrganizationMasterAccount,
        OperationNotPermitted,
        TrailNotFound,
        UnsupportedOperation,
    },
} = .{};
pub const put_insight_selectors: struct {
    action_name: []const u8 = "PutInsightSelectors",
    Request: type = struct {
        trail_name: []const u8,
        insight_selectors: []InsightSelector,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .trail_name = "TrailName",
                .insight_selectors = "InsightSelectors",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(put_insight_selectors) } {
            return .{ .service_metadata = service_metadata, .action = put_insight_selectors };
        }
    },
    Response: type = struct {
        trail_arn: ?[]const u8 = null,
        insight_selectors: ?[]InsightSelector = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .trail_arn = "TrailARN",
                .insight_selectors = "InsightSelectors",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InsufficientEncryptionPolicy,
        InsufficientS3BucketPolicy,
        InvalidHomeRegion,
        InvalidInsightSelectors,
        InvalidTrailName,
        Kms,
        NotOrganizationMasterAccount,
        OperationNotPermitted,
        S3BucketDoesNotExist,
        TrailNotFound,
        UnsupportedOperation,
    },
} = .{};
pub const remove_tags: struct {
    action_name: []const u8 = "RemoveTags",
    Request: type = struct {
        resource_id: []const u8,
        tags_list: ?[]Tag = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .resource_id = "ResourceId",
                .tags_list = "TagsList",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(remove_tags) } {
            return .{ .service_metadata = service_metadata, .action = remove_tags };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        CloudTrailARNInvalid,
        InvalidTagParameter,
        InvalidTrailName,
        NotOrganizationMasterAccount,
        OperationNotPermitted,
        ResourceNotFound,
        ResourceTypeNotSupported,
        UnsupportedOperation,
    },
} = .{};
pub const start_logging: struct {
    action_name: []const u8 = "StartLogging",
    Request: type = struct {
        name: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .name = "Name",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(start_logging) } {
            return .{ .service_metadata = service_metadata, .action = start_logging };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InsufficientDependencyServiceAccessPermission,
        InvalidHomeRegion,
        InvalidTrailName,
        NotOrganizationMasterAccount,
        OperationNotPermitted,
        TrailNotFound,
        UnsupportedOperation,
    },
} = .{};
pub const stop_logging: struct {
    action_name: []const u8 = "StopLogging",
    Request: type = struct {
        name: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .name = "Name",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(stop_logging) } {
            return .{ .service_metadata = service_metadata, .action = stop_logging };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InsufficientDependencyServiceAccessPermission,
        InvalidHomeRegion,
        InvalidTrailName,
        NotOrganizationMasterAccount,
        OperationNotPermitted,
        TrailNotFound,
        UnsupportedOperation,
    },
} = .{};
pub const update_trail: struct {
    action_name: []const u8 = "UpdateTrail",
    Request: type = struct {
        name: []const u8,
        s3_bucket_name: ?[]const u8 = null,
        s3_key_prefix: ?[]const u8 = null,
        sns_topic_name: ?[]const u8 = null,
        include_global_service_events: ?bool = null,
        is_multi_region_trail: ?bool = null,
        enable_log_file_validation: ?bool = null,
        cloud_watch_logs_log_group_arn: ?[]const u8 = null,
        cloud_watch_logs_role_arn: ?[]const u8 = null,
        kms_key_id: ?[]const u8 = null,
        is_organization_trail: ?bool = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .name = "Name",
                .s3_bucket_name = "S3BucketName",
                .s3_key_prefix = "S3KeyPrefix",
                .sns_topic_name = "SnsTopicName",
                .include_global_service_events = "IncludeGlobalServiceEvents",
                .is_multi_region_trail = "IsMultiRegionTrail",
                .enable_log_file_validation = "EnableLogFileValidation",
                .cloud_watch_logs_log_group_arn = "CloudWatchLogsLogGroupArn",
                .cloud_watch_logs_role_arn = "CloudWatchLogsRoleArn",
                .kms_key_id = "KmsKeyId",
                .is_organization_trail = "IsOrganizationTrail",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(update_trail) } {
            return .{ .service_metadata = service_metadata, .action = update_trail };
        }
    },
    Response: type = struct {
        name: ?[]const u8 = null,
        s3_bucket_name: ?[]const u8 = null,
        s3_key_prefix: ?[]const u8 = null,
        sns_topic_name: ?[]const u8 = null,
        sns_topic_arn: ?[]const u8 = null,
        include_global_service_events: ?bool = null,
        is_multi_region_trail: ?bool = null,
        trail_arn: ?[]const u8 = null,
        log_file_validation_enabled: ?bool = null,
        cloud_watch_logs_log_group_arn: ?[]const u8 = null,
        cloud_watch_logs_role_arn: ?[]const u8 = null,
        kms_key_id: ?[]const u8 = null,
        is_organization_trail: ?bool = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .name = "Name",
                .s3_bucket_name = "S3BucketName",
                .s3_key_prefix = "S3KeyPrefix",
                .sns_topic_name = "SnsTopicName",
                .sns_topic_arn = "SnsTopicARN",
                .include_global_service_events = "IncludeGlobalServiceEvents",
                .is_multi_region_trail = "IsMultiRegionTrail",
                .trail_arn = "TrailARN",
                .log_file_validation_enabled = "LogFileValidationEnabled",
                .cloud_watch_logs_log_group_arn = "CloudWatchLogsLogGroupArn",
                .cloud_watch_logs_role_arn = "CloudWatchLogsRoleArn",
                .kms_key_id = "KmsKeyId",
                .is_organization_trail = "IsOrganizationTrail",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        CloudTrailAccessNotEnabled,
        CloudTrailInvalidClientTokenId,
        CloudWatchLogsDeliveryUnavailable,
        InsufficientDependencyServiceAccessPermission,
        InsufficientEncryptionPolicy,
        InsufficientS3BucketPolicy,
        InsufficientSnsTopicPolicy,
        InvalidCloudWatchLogsLogGroupArn,
        InvalidCloudWatchLogsRoleArn,
        InvalidEventSelectors,
        InvalidHomeRegion,
        InvalidKmsKeyId,
        InvalidParameterCombination,
        InvalidS3BucketName,
        InvalidS3Prefix,
        InvalidSnsTopicName,
        InvalidTrailName,
        Kms,
        KmsKeyDisabled,
        KmsKeyNotFound,
        NotOrganizationMasterAccount,
        OperationNotPermitted,
        OrganizationNotInAllFeaturesMode,
        OrganizationsNotInUse,
        S3BucketDoesNotExist,
        TrailNotFound,
        TrailNotProvided,
        UnsupportedOperation,
    },
} = .{};

pub const Tag = struct {
    key: []const u8,
    value: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .key = "Key",
            .value = "Value",
        };
        return @field(mappings, field_name);
    }
};

pub const InsightSelector = struct {
    insight_type: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .insight_type = "InsightType",
        };
        return @field(mappings, field_name);
    }
};

pub const AdvancedEventSelector = struct {
    name: ?[]const u8 = null,
    field_selectors: []AdvancedFieldSelector,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .name = "Name",
            .field_selectors = "FieldSelectors",
        };
        return @field(mappings, field_name);
    }
};

pub const AdvancedFieldSelector = struct {
    field: []const u8,
    equals: ?[][]const u8 = null,
    starts_with: ?[][]const u8 = null,
    ends_with: ?[][]const u8 = null,
    not_equals: ?[][]const u8 = null,
    not_starts_with: ?[][]const u8 = null,
    not_ends_with: ?[][]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .field = "Field",
            .equals = "Equals",
            .starts_with = "StartsWith",
            .ends_with = "EndsWith",
            .not_equals = "NotEquals",
            .not_starts_with = "NotStartsWith",
            .not_ends_with = "NotEndsWith",
        };
        return @field(mappings, field_name);
    }
};

pub const EventSelector = struct {
    read_write_type: ?[]const u8 = null,
    include_management_events: ?bool = null,
    data_resources: ?[]DataResource = null,
    exclude_management_event_sources: ?[][]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .read_write_type = "ReadWriteType",
            .include_management_events = "IncludeManagementEvents",
            .data_resources = "DataResources",
            .exclude_management_event_sources = "ExcludeManagementEventSources",
        };
        return @field(mappings, field_name);
    }
};

pub const DataResource = struct {
    type: ?[]const u8 = null,
    values: ?[][]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .type = "Type",
            .values = "Values",
        };
        return @field(mappings, field_name);
    }
};

pub const Trail = struct {
    name: ?[]const u8 = null,
    s3_bucket_name: ?[]const u8 = null,
    s3_key_prefix: ?[]const u8 = null,
    sns_topic_name: ?[]const u8 = null,
    sns_topic_arn: ?[]const u8 = null,
    include_global_service_events: ?bool = null,
    is_multi_region_trail: ?bool = null,
    home_region: ?[]const u8 = null,
    trail_arn: ?[]const u8 = null,
    log_file_validation_enabled: ?bool = null,
    cloud_watch_logs_log_group_arn: ?[]const u8 = null,
    cloud_watch_logs_role_arn: ?[]const u8 = null,
    kms_key_id: ?[]const u8 = null,
    has_custom_event_selectors: ?bool = null,
    has_insight_selectors: ?bool = null,
    is_organization_trail: ?bool = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .name = "Name",
            .s3_bucket_name = "S3BucketName",
            .s3_key_prefix = "S3KeyPrefix",
            .sns_topic_name = "SnsTopicName",
            .sns_topic_arn = "SnsTopicARN",
            .include_global_service_events = "IncludeGlobalServiceEvents",
            .is_multi_region_trail = "IsMultiRegionTrail",
            .home_region = "HomeRegion",
            .trail_arn = "TrailARN",
            .log_file_validation_enabled = "LogFileValidationEnabled",
            .cloud_watch_logs_log_group_arn = "CloudWatchLogsLogGroupArn",
            .cloud_watch_logs_role_arn = "CloudWatchLogsRoleArn",
            .kms_key_id = "KmsKeyId",
            .has_custom_event_selectors = "HasCustomEventSelectors",
            .has_insight_selectors = "HasInsightSelectors",
            .is_organization_trail = "IsOrganizationTrail",
        };
        return @field(mappings, field_name);
    }
};
