const std = @import("std");
const serializeMap = @import("json.zig").serializeMap;
const smithy = @import("smithy");

const Self = @This();
pub const version: []const u8 = "2019-12-01";
pub const sdk_id: []const u8 = "CodeStar connections";
pub const arn_namespace: []const u8 = "codestar-connections";
pub const endpoint_prefix: []const u8 = "codestar-connections";
pub const sigv4_name: []const u8 = "codestar-connections";
pub const name: []const u8 = "CodeStar_connections_20191201";
pub const aws_protocol: smithy.AwsProtocol = smithy.AwsProtocol.json_1_0;

pub const service_metadata: struct {
    version: []const u8 = "2019-12-01",
    sdk_id: []const u8 = "CodeStar connections",
    arn_namespace: []const u8 = "codestar-connections",
    endpoint_prefix: []const u8 = "codestar-connections",
    sigv4_name: []const u8 = "codestar-connections",
    name: []const u8 = "CodeStar_connections_20191201",
    aws_protocol: smithy.AwsProtocol = smithy.AwsProtocol.json_1_0,
} = .{};
pub const create_connection: struct {
    action_name: []const u8 = "CreateConnection",
    Request: type = struct {
        provider_type: ?[]const u8 = null,
        connection_name: []const u8,
        tags: ?[]Tag = null,
        host_arn: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .provider_type = "ProviderType",
                .connection_name = "ConnectionName",
                .tags = "Tags",
                .host_arn = "HostArn",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(create_connection) } {
            return .{ .service_metadata = service_metadata, .action = create_connection };
        }
    },
    Response: type = struct {
        connection_arn: []const u8,
        tags: ?[]Tag = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .connection_arn = "ConnectionArn",
                .tags = "Tags",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        LimitExceeded,
        ResourceNotFound,
        ResourceUnavailable,
    },
} = .{};
pub const create_host: struct {
    action_name: []const u8 = "CreateHost",
    Request: type = struct {
        name: []const u8,
        provider_type: []const u8,
        provider_endpoint: []const u8,
        vpc_configuration: ?VpcConfiguration = null,
        tags: ?[]Tag = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .name = "Name",
                .provider_type = "ProviderType",
                .provider_endpoint = "ProviderEndpoint",
                .vpc_configuration = "VpcConfiguration",
                .tags = "Tags",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(create_host) } {
            return .{ .service_metadata = service_metadata, .action = create_host };
        }
    },
    Response: type = struct {
        host_arn: ?[]const u8 = null,
        tags: ?[]Tag = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .host_arn = "HostArn",
                .tags = "Tags",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        LimitExceeded,
    },
} = .{};
pub const delete_connection: struct {
    action_name: []const u8 = "DeleteConnection",
    Request: type = struct {
        connection_arn: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .connection_arn = "ConnectionArn",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(delete_connection) } {
            return .{ .service_metadata = service_metadata, .action = delete_connection };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        ResourceNotFound,
    },
} = .{};
pub const delete_host: struct {
    action_name: []const u8 = "DeleteHost",
    Request: type = struct {
        host_arn: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .host_arn = "HostArn",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(delete_host) } {
            return .{ .service_metadata = service_metadata, .action = delete_host };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        ResourceNotFound,
        ResourceUnavailable,
    },
} = .{};
pub const get_connection: struct {
    action_name: []const u8 = "GetConnection",
    Request: type = struct {
        connection_arn: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .connection_arn = "ConnectionArn",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(get_connection) } {
            return .{ .service_metadata = service_metadata, .action = get_connection };
        }
    },
    Response: type = struct {
        connection: ?Connection = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .connection = "Connection",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        ResourceNotFound,
        ResourceUnavailable,
    },
} = .{};
pub const get_host: struct {
    action_name: []const u8 = "GetHost",
    Request: type = struct {
        host_arn: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .host_arn = "HostArn",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(get_host) } {
            return .{ .service_metadata = service_metadata, .action = get_host };
        }
    },
    Response: type = struct {
        name: ?[]const u8 = null,
        status: ?[]const u8 = null,
        provider_type: ?[]const u8 = null,
        provider_endpoint: ?[]const u8 = null,
        vpc_configuration: ?VpcConfiguration = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .name = "Name",
                .status = "Status",
                .provider_type = "ProviderType",
                .provider_endpoint = "ProviderEndpoint",
                .vpc_configuration = "VpcConfiguration",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        ResourceNotFound,
        ResourceUnavailable,
    },
} = .{};
pub const list_connections: struct {
    action_name: []const u8 = "ListConnections",
    Request: type = struct {
        provider_type_filter: ?[]const u8 = null,
        host_arn_filter: ?[]const u8 = null,
        max_results: ?i64 = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .provider_type_filter = "ProviderTypeFilter",
                .host_arn_filter = "HostArnFilter",
                .max_results = "MaxResults",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_connections) } {
            return .{ .service_metadata = service_metadata, .action = list_connections };
        }
    },
    Response: type = struct {
        connections: ?[]Connection = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .connections = "Connections",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }
    },
} = .{};
pub const list_hosts: struct {
    action_name: []const u8 = "ListHosts",
    Request: type = struct {
        max_results: ?i64 = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .max_results = "MaxResults",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_hosts) } {
            return .{ .service_metadata = service_metadata, .action = list_hosts };
        }
    },
    Response: type = struct {
        hosts: ?[]struct {
            name: ?[]const u8 = null,
            host_arn: ?[]const u8 = null,
            provider_type: ?[]const u8 = null,
            provider_endpoint: ?[]const u8 = null,
            vpc_configuration: ?VpcConfiguration = null,
            status: ?[]const u8 = null,
            status_message: ?[]const u8 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .name = "Name",
                    .host_arn = "HostArn",
                    .provider_type = "ProviderType",
                    .provider_endpoint = "ProviderEndpoint",
                    .vpc_configuration = "VpcConfiguration",
                    .status = "Status",
                    .status_message = "StatusMessage",
                };
                return @field(mappings, field_name);
            }
        } = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .hosts = "Hosts",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }
    },
} = .{};
pub const list_tags_for_resource: struct {
    action_name: []const u8 = "ListTagsForResource",
    Request: type = struct {
        resource_arn: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .resource_arn = "ResourceArn",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_tags_for_resource) } {
            return .{ .service_metadata = service_metadata, .action = list_tags_for_resource };
        }
    },
    Response: type = struct {
        tags: ?[]Tag = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .tags = "Tags",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        ResourceNotFound,
    },
} = .{};
pub const tag_resource: struct {
    action_name: []const u8 = "TagResource",
    Request: type = struct {
        resource_arn: []const u8,
        tags: []Tag,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .resource_arn = "ResourceArn",
                .tags = "Tags",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(tag_resource) } {
            return .{ .service_metadata = service_metadata, .action = tag_resource };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        LimitExceeded,
        ResourceNotFound,
    },
} = .{};
pub const untag_resource: struct {
    action_name: []const u8 = "UntagResource",
    Request: type = struct {
        resource_arn: []const u8,
        tag_keys: [][]const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .resource_arn = "ResourceArn",
                .tag_keys = "TagKeys",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(untag_resource) } {
            return .{ .service_metadata = service_metadata, .action = untag_resource };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        ResourceNotFound,
    },
} = .{};
pub const update_host: struct {
    action_name: []const u8 = "UpdateHost",
    Request: type = struct {
        host_arn: []const u8,
        provider_endpoint: ?[]const u8 = null,
        vpc_configuration: ?VpcConfiguration = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .host_arn = "HostArn",
                .provider_endpoint = "ProviderEndpoint",
                .vpc_configuration = "VpcConfiguration",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(update_host) } {
            return .{ .service_metadata = service_metadata, .action = update_host };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        Conflict,
        ResourceNotFound,
        ResourceUnavailable,
        UnsupportedOperation,
    },
} = .{};

pub const VpcConfiguration = struct {
    vpc_id: []const u8,
    subnet_ids: [][]const u8,
    security_group_ids: [][]const u8,
    tls_certificate: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .vpc_id = "VpcId",
            .subnet_ids = "SubnetIds",
            .security_group_ids = "SecurityGroupIds",
            .tls_certificate = "TlsCertificate",
        };
        return @field(mappings, field_name);
    }
};

pub const Tag = struct {
    key: []const u8,
    value: []const u8,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .key = "Key",
            .value = "Value",
        };
        return @field(mappings, field_name);
    }
};

pub const Connection = struct {
    connection_name: ?[]const u8 = null,
    connection_arn: ?[]const u8 = null,
    provider_type: ?[]const u8 = null,
    owner_account_id: ?[]const u8 = null,
    connection_status: ?[]const u8 = null,
    host_arn: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .connection_name = "ConnectionName",
            .connection_arn = "ConnectionArn",
            .provider_type = "ProviderType",
            .owner_account_id = "OwnerAccountId",
            .connection_status = "ConnectionStatus",
            .host_arn = "HostArn",
        };
        return @field(mappings, field_name);
    }
};
