const std = @import("std");
const serializeMap = @import("json.zig").serializeMap;
const smithy = @import("smithy");

const Self = @This();
pub const version: []const u8 = "2017-01-06";
pub const sdk_id: []const u8 = "Cost and Usage Report Service";
pub const arn_namespace: []const u8 = "cur";
pub const endpoint_prefix: []const u8 = "cur";
pub const sigv4_name: []const u8 = "cur";
pub const name: []const u8 = "AWSOrigamiServiceGatewayService";
pub const aws_protocol: smithy.AwsProtocol = smithy.AwsProtocol.json_1_1;

pub const service_metadata: struct {
    version: []const u8 = "2017-01-06",
    sdk_id: []const u8 = "Cost and Usage Report Service",
    arn_namespace: []const u8 = "cur",
    endpoint_prefix: []const u8 = "cur",
    sigv4_name: []const u8 = "cur",
    name: []const u8 = "AWSOrigamiServiceGatewayService",
    aws_protocol: smithy.AwsProtocol = smithy.AwsProtocol.json_1_1,
} = .{};
pub const delete_report_definition: struct {
    action_name: []const u8 = "DeleteReportDefinition",
    Request: type = struct {
        report_name: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .report_name = "ReportName",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(delete_report_definition) } {
            return .{ .service_metadata = service_metadata, .action = delete_report_definition };
        }
    },
    Response: type = struct {
        response_message: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .response_message = "ResponseMessage",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalError,
        Validation,
    },
} = .{};
pub const describe_report_definitions: struct {
    action_name: []const u8 = "DescribeReportDefinitions",
    Request: type = struct {
        max_results: ?i64 = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .max_results = "MaxResults",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(describe_report_definitions) } {
            return .{ .service_metadata = service_metadata, .action = describe_report_definitions };
        }
    },
    Response: type = struct {
        report_definitions: ?[]ReportDefinition = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .report_definitions = "ReportDefinitions",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalError,
    },
} = .{};
pub const modify_report_definition: struct {
    action_name: []const u8 = "ModifyReportDefinition",
    Request: type = struct {
        report_name: []const u8,
        report_definition: ReportDefinition,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .report_name = "ReportName",
                .report_definition = "ReportDefinition",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(modify_report_definition) } {
            return .{ .service_metadata = service_metadata, .action = modify_report_definition };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalError,
        Validation,
    },
} = .{};
pub const put_report_definition: struct {
    action_name: []const u8 = "PutReportDefinition",
    Request: type = struct {
        report_definition: ReportDefinition,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .report_definition = "ReportDefinition",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(put_report_definition) } {
            return .{ .service_metadata = service_metadata, .action = put_report_definition };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        DuplicateReportName,
        InternalError,
        ReportLimitReached,
        Validation,
    },
} = .{};

pub const ReportDefinition = struct {
    report_name: []const u8,
    time_unit: []const u8,
    format: []const u8,
    compression: []const u8,
    additional_schema_elements: [][]const u8,
    s3_bucket: []const u8,
    s3_prefix: []const u8,
    s3_region: []const u8,
    additional_artifacts: ?[][]const u8 = null,
    refresh_closed_reports: ?bool = null,
    report_versioning: ?[]const u8 = null,
    billing_view_arn: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .report_name = "ReportName",
            .time_unit = "TimeUnit",
            .format = "Format",
            .compression = "Compression",
            .additional_schema_elements = "AdditionalSchemaElements",
            .s3_bucket = "S3Bucket",
            .s3_prefix = "S3Prefix",
            .s3_region = "S3Region",
            .additional_artifacts = "AdditionalArtifacts",
            .refresh_closed_reports = "RefreshClosedReports",
            .report_versioning = "ReportVersioning",
            .billing_view_arn = "BillingViewArn",
        };
        return @field(mappings, field_name);
    }
};
