const std = @import("std");
const serializeMap = @import("json.zig").serializeMap;
const smithy = @import("smithy");

const Self = @This();
pub const version: []const u8 = "2020-08-15";
pub const sdk_id: []const u8 = "Customer Profiles";
pub const arn_namespace: []const u8 = "profile";
pub const endpoint_prefix: []const u8 = "profile";
pub const sigv4_name: []const u8 = "profile";
pub const name: []const u8 = "CustomerProfiles_20200815";
pub const aws_protocol: smithy.AwsProtocol = smithy.AwsProtocol.rest_json_1;

pub const service_metadata: struct {
    version: []const u8 = "2020-08-15",
    sdk_id: []const u8 = "Customer Profiles",
    arn_namespace: []const u8 = "profile",
    endpoint_prefix: []const u8 = "profile",
    sigv4_name: []const u8 = "profile",
    name: []const u8 = "CustomerProfiles_20200815",
    aws_protocol: smithy.AwsProtocol = smithy.AwsProtocol.rest_json_1,
} = .{};
pub const add_profile_key: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/domains/{DomainName}/profiles/keys",
        .success_code = 200,
    };

    action_name: []const u8 = "AddProfileKey",
    Request: type = struct {
        profile_id: []const u8,
        key_name: []const u8,
        values: [][]const u8,
        domain_name: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .profile_id = "ProfileId",
                .key_name = "KeyName",
                .values = "Values",
                .domain_name = "DomainName",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(add_profile_key) } {
            return .{ .service_metadata = service_metadata, .action = add_profile_key };
        }
    },
    Response: type = struct {
        key_name: ?[]const u8 = null,
        values: ?[][]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .key_name = "KeyName",
                .values = "Values",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        BadRequest,
        InternalServer,
        ResourceNotFound,
        Throttling,
    },
} = .{};
pub const create_domain: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/domains/{DomainName}",
        .success_code = 200,
    };

    action_name: []const u8 = "CreateDomain",
    Request: type = struct {
        domain_name: []const u8,
        default_expiration_days: i64,
        default_encryption_key: ?[]const u8 = null,
        dead_letter_queue_url: ?[]const u8 = null,
        matching: ?MatchingRequest = null,
        tags: ?[]struct {
            key: ?[]const u8 = null,
            value: ?[]const u8 = null,
        } = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .domain_name = "DomainName",
                .default_expiration_days = "DefaultExpirationDays",
                .default_encryption_key = "DefaultEncryptionKey",
                .dead_letter_queue_url = "DeadLetterQueueUrl",
                .matching = "Matching",
                .tags = "Tags",
            };
            return @field(mappings, field_name);
        }

        pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
            if (std.mem.eql(u8, "tags", field_name))
                return try serializeMap(self.tags, self.fieldNameFor("tags"), options, out_stream);
            return false;
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(create_domain) } {
            return .{ .service_metadata = service_metadata, .action = create_domain };
        }
    },
    Response: type = struct {
        domain_name: []const u8,
        default_expiration_days: i64,
        default_encryption_key: ?[]const u8 = null,
        dead_letter_queue_url: ?[]const u8 = null,
        matching: ?MatchingResponse = null,
        created_at: i64,
        last_updated_at: i64,
        tags: ?[]struct {
            key: ?[]const u8 = null,
            value: ?[]const u8 = null,
        } = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .domain_name = "DomainName",
                .default_expiration_days = "DefaultExpirationDays",
                .default_encryption_key = "DefaultEncryptionKey",
                .dead_letter_queue_url = "DeadLetterQueueUrl",
                .matching = "Matching",
                .created_at = "CreatedAt",
                .last_updated_at = "LastUpdatedAt",
                .tags = "Tags",
            };
            return @field(mappings, field_name);
        }

        pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
            if (std.mem.eql(u8, "tags", field_name))
                return try serializeMap(self.tags, self.fieldNameFor("tags"), options, out_stream);
            return false;
        }
    },
    ServiceError: type = error{
        AccessDenied,
        BadRequest,
        InternalServer,
        ResourceNotFound,
        Throttling,
    },
} = .{};
pub const create_profile: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/domains/{DomainName}/profiles",
        .success_code = 200,
    };

    action_name: []const u8 = "CreateProfile",
    Request: type = struct {
        domain_name: []const u8,
        account_number: ?[]const u8 = null,
        additional_information: ?[]const u8 = null,
        party_type: ?[]const u8 = null,
        business_name: ?[]const u8 = null,
        first_name: ?[]const u8 = null,
        middle_name: ?[]const u8 = null,
        last_name: ?[]const u8 = null,
        birth_date: ?[]const u8 = null,
        gender: ?[]const u8 = null,
        phone_number: ?[]const u8 = null,
        mobile_phone_number: ?[]const u8 = null,
        home_phone_number: ?[]const u8 = null,
        business_phone_number: ?[]const u8 = null,
        email_address: ?[]const u8 = null,
        personal_email_address: ?[]const u8 = null,
        business_email_address: ?[]const u8 = null,
        address: ?Address = null,
        shipping_address: ?Address = null,
        mailing_address: ?Address = null,
        billing_address: ?Address = null,
        attributes: ?[]struct {
            key: ?[]const u8 = null,
            value: ?[]const u8 = null,
        } = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .domain_name = "DomainName",
                .account_number = "AccountNumber",
                .additional_information = "AdditionalInformation",
                .party_type = "PartyType",
                .business_name = "BusinessName",
                .first_name = "FirstName",
                .middle_name = "MiddleName",
                .last_name = "LastName",
                .birth_date = "BirthDate",
                .gender = "Gender",
                .phone_number = "PhoneNumber",
                .mobile_phone_number = "MobilePhoneNumber",
                .home_phone_number = "HomePhoneNumber",
                .business_phone_number = "BusinessPhoneNumber",
                .email_address = "EmailAddress",
                .personal_email_address = "PersonalEmailAddress",
                .business_email_address = "BusinessEmailAddress",
                .address = "Address",
                .shipping_address = "ShippingAddress",
                .mailing_address = "MailingAddress",
                .billing_address = "BillingAddress",
                .attributes = "Attributes",
            };
            return @field(mappings, field_name);
        }

        pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
            if (std.mem.eql(u8, "attributes", field_name))
                return try serializeMap(self.attributes, self.fieldNameFor("attributes"), options, out_stream);
            return false;
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(create_profile) } {
            return .{ .service_metadata = service_metadata, .action = create_profile };
        }
    },
    Response: type = struct {
        profile_id: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .profile_id = "ProfileId",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        BadRequest,
        InternalServer,
        ResourceNotFound,
        Throttling,
    },
} = .{};
pub const delete_domain: struct {
    pub const http_config = .{
        .method = "DELETE",
        .uri = "/domains/{DomainName}",
        .success_code = 200,
    };

    action_name: []const u8 = "DeleteDomain",
    Request: type = struct {
        domain_name: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .domain_name = "DomainName",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(delete_domain) } {
            return .{ .service_metadata = service_metadata, .action = delete_domain };
        }
    },
    Response: type = struct {
        message: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .message = "Message",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        BadRequest,
        InternalServer,
        ResourceNotFound,
        Throttling,
    },
} = .{};
pub const delete_integration: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/domains/{DomainName}/integrations/delete",
        .success_code = 200,
    };

    action_name: []const u8 = "DeleteIntegration",
    Request: type = struct {
        domain_name: []const u8,
        uri: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .domain_name = "DomainName",
                .uri = "Uri",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(delete_integration) } {
            return .{ .service_metadata = service_metadata, .action = delete_integration };
        }
    },
    Response: type = struct {
        message: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .message = "Message",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        BadRequest,
        InternalServer,
        ResourceNotFound,
        Throttling,
    },
} = .{};
pub const delete_profile: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/domains/{DomainName}/profiles/delete",
        .success_code = 200,
    };

    action_name: []const u8 = "DeleteProfile",
    Request: type = struct {
        profile_id: []const u8,
        domain_name: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .profile_id = "ProfileId",
                .domain_name = "DomainName",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(delete_profile) } {
            return .{ .service_metadata = service_metadata, .action = delete_profile };
        }
    },
    Response: type = struct {
        message: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .message = "Message",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        BadRequest,
        InternalServer,
        ResourceNotFound,
        Throttling,
    },
} = .{};
pub const delete_profile_key: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/domains/{DomainName}/profiles/keys/delete",
        .success_code = 200,
    };

    action_name: []const u8 = "DeleteProfileKey",
    Request: type = struct {
        profile_id: []const u8,
        key_name: []const u8,
        values: [][]const u8,
        domain_name: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .profile_id = "ProfileId",
                .key_name = "KeyName",
                .values = "Values",
                .domain_name = "DomainName",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(delete_profile_key) } {
            return .{ .service_metadata = service_metadata, .action = delete_profile_key };
        }
    },
    Response: type = struct {
        message: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .message = "Message",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        BadRequest,
        InternalServer,
        ResourceNotFound,
        Throttling,
    },
} = .{};
pub const delete_profile_object: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/domains/{DomainName}/profiles/objects/delete",
        .success_code = 200,
    };

    action_name: []const u8 = "DeleteProfileObject",
    Request: type = struct {
        profile_id: []const u8,
        profile_object_unique_key: []const u8,
        object_type_name: []const u8,
        domain_name: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .profile_id = "ProfileId",
                .profile_object_unique_key = "ProfileObjectUniqueKey",
                .object_type_name = "ObjectTypeName",
                .domain_name = "DomainName",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(delete_profile_object) } {
            return .{ .service_metadata = service_metadata, .action = delete_profile_object };
        }
    },
    Response: type = struct {
        message: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .message = "Message",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        BadRequest,
        InternalServer,
        ResourceNotFound,
        Throttling,
    },
} = .{};
pub const delete_profile_object_type: struct {
    pub const http_config = .{
        .method = "DELETE",
        .uri = "/domains/{DomainName}/object-types/{ObjectTypeName}",
        .success_code = 200,
    };

    action_name: []const u8 = "DeleteProfileObjectType",
    Request: type = struct {
        domain_name: []const u8,
        object_type_name: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .domain_name = "DomainName",
                .object_type_name = "ObjectTypeName",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(delete_profile_object_type) } {
            return .{ .service_metadata = service_metadata, .action = delete_profile_object_type };
        }
    },
    Response: type = struct {
        message: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .message = "Message",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        BadRequest,
        InternalServer,
        ResourceNotFound,
        Throttling,
    },
} = .{};
pub const get_domain: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/domains/{DomainName}",
        .success_code = 200,
    };

    action_name: []const u8 = "GetDomain",
    Request: type = struct {
        domain_name: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .domain_name = "DomainName",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(get_domain) } {
            return .{ .service_metadata = service_metadata, .action = get_domain };
        }
    },
    Response: type = struct {
        domain_name: []const u8,
        default_expiration_days: ?i64 = null,
        default_encryption_key: ?[]const u8 = null,
        dead_letter_queue_url: ?[]const u8 = null,
        stats: ?struct {
            profile_count: ?i64 = null,
            metering_profile_count: ?i64 = null,
            object_count: ?i64 = null,
            total_size: ?i64 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .profile_count = "ProfileCount",
                    .metering_profile_count = "MeteringProfileCount",
                    .object_count = "ObjectCount",
                    .total_size = "TotalSize",
                };
                return @field(mappings, field_name);
            }
        } = null,
        matching: ?MatchingResponse = null,
        created_at: i64,
        last_updated_at: i64,
        tags: ?[]struct {
            key: ?[]const u8 = null,
            value: ?[]const u8 = null,
        } = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .domain_name = "DomainName",
                .default_expiration_days = "DefaultExpirationDays",
                .default_encryption_key = "DefaultEncryptionKey",
                .dead_letter_queue_url = "DeadLetterQueueUrl",
                .stats = "Stats",
                .matching = "Matching",
                .created_at = "CreatedAt",
                .last_updated_at = "LastUpdatedAt",
                .tags = "Tags",
            };
            return @field(mappings, field_name);
        }

        pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
            if (std.mem.eql(u8, "tags", field_name))
                return try serializeMap(self.tags, self.fieldNameFor("tags"), options, out_stream);
            return false;
        }
    },
    ServiceError: type = error{
        AccessDenied,
        BadRequest,
        InternalServer,
        ResourceNotFound,
        Throttling,
    },
} = .{};
pub const get_integration: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/domains/{DomainName}/integrations",
        .success_code = 200,
    };

    action_name: []const u8 = "GetIntegration",
    Request: type = struct {
        domain_name: []const u8,
        uri: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .domain_name = "DomainName",
                .uri = "Uri",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(get_integration) } {
            return .{ .service_metadata = service_metadata, .action = get_integration };
        }
    },
    Response: type = struct {
        domain_name: []const u8,
        uri: []const u8,
        object_type_name: []const u8,
        created_at: i64,
        last_updated_at: i64,
        tags: ?[]struct {
            key: ?[]const u8 = null,
            value: ?[]const u8 = null,
        } = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .domain_name = "DomainName",
                .uri = "Uri",
                .object_type_name = "ObjectTypeName",
                .created_at = "CreatedAt",
                .last_updated_at = "LastUpdatedAt",
                .tags = "Tags",
            };
            return @field(mappings, field_name);
        }

        pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
            if (std.mem.eql(u8, "tags", field_name))
                return try serializeMap(self.tags, self.fieldNameFor("tags"), options, out_stream);
            return false;
        }
    },
    ServiceError: type = error{
        AccessDenied,
        BadRequest,
        InternalServer,
        ResourceNotFound,
        Throttling,
    },
} = .{};
pub const get_matches: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/domains/{DomainName}/matches",
        .success_code = 200,
    };

    action_name: []const u8 = "GetMatches",
    Request: type = struct {
        next_token: ?[]const u8 = null,
        max_results: ?i64 = null,
        domain_name: []const u8,

        pub const http_query = .{
            .next_token = "next-token",
            .max_results = "max-results",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .next_token = "NextToken",
                .max_results = "MaxResults",
                .domain_name = "DomainName",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(get_matches) } {
            return .{ .service_metadata = service_metadata, .action = get_matches };
        }
    },
    Response: type = struct {
        next_token: ?[]const u8 = null,
        match_generation_date: ?i64 = null,
        potential_matches: ?i64 = null,
        matches: ?[]struct {
            match_id: ?[]const u8 = null,
            profile_ids: ?[][]const u8 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .match_id = "MatchId",
                    .profile_ids = "ProfileIds",
                };
                return @field(mappings, field_name);
            }
        } = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .next_token = "NextToken",
                .match_generation_date = "MatchGenerationDate",
                .potential_matches = "PotentialMatches",
                .matches = "Matches",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        BadRequest,
        InternalServer,
        ResourceNotFound,
        Throttling,
    },
} = .{};
pub const get_profile_object_type: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/domains/{DomainName}/object-types/{ObjectTypeName}",
        .success_code = 200,
    };

    action_name: []const u8 = "GetProfileObjectType",
    Request: type = struct {
        domain_name: []const u8,
        object_type_name: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .domain_name = "DomainName",
                .object_type_name = "ObjectTypeName",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(get_profile_object_type) } {
            return .{ .service_metadata = service_metadata, .action = get_profile_object_type };
        }
    },
    Response: type = struct {
        object_type_name: []const u8,
        description: []const u8,
        template_id: ?[]const u8 = null,
        expiration_days: ?i64 = null,
        encryption_key: ?[]const u8 = null,
        allow_profile_creation: ?bool = null,
        fields: ?[]struct {
            key: ?[]const u8 = null,
            value: ?ObjectTypeField = null,
        } = null,
        keys: ?[]struct {
            key: ?[]const u8 = null,
            value: ?[]ObjectTypeKey = null,
        } = null,
        created_at: ?i64 = null,
        last_updated_at: ?i64 = null,
        tags: ?[]struct {
            key: ?[]const u8 = null,
            value: ?[]const u8 = null,
        } = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .object_type_name = "ObjectTypeName",
                .description = "Description",
                .template_id = "TemplateId",
                .expiration_days = "ExpirationDays",
                .encryption_key = "EncryptionKey",
                .allow_profile_creation = "AllowProfileCreation",
                .fields = "Fields",
                .keys = "Keys",
                .created_at = "CreatedAt",
                .last_updated_at = "LastUpdatedAt",
                .tags = "Tags",
            };
            return @field(mappings, field_name);
        }

        pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
            if (std.mem.eql(u8, "fields", field_name))
                return try serializeMap(self.fields, self.fieldNameFor("fields"), options, out_stream);
            if (std.mem.eql(u8, "keys", field_name))
                return try serializeMap(self.keys, self.fieldNameFor("keys"), options, out_stream);
            if (std.mem.eql(u8, "tags", field_name))
                return try serializeMap(self.tags, self.fieldNameFor("tags"), options, out_stream);
            return false;
        }
    },
    ServiceError: type = error{
        AccessDenied,
        BadRequest,
        InternalServer,
        ResourceNotFound,
        Throttling,
    },
} = .{};
pub const get_profile_object_type_template: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/templates/{TemplateId}",
        .success_code = 200,
    };

    action_name: []const u8 = "GetProfileObjectTypeTemplate",
    Request: type = struct {
        template_id: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .template_id = "TemplateId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(get_profile_object_type_template) } {
            return .{ .service_metadata = service_metadata, .action = get_profile_object_type_template };
        }
    },
    Response: type = struct {
        template_id: ?[]const u8 = null,
        source_name: ?[]const u8 = null,
        source_object: ?[]const u8 = null,
        allow_profile_creation: ?bool = null,
        fields: ?[]struct {
            key: ?[]const u8 = null,
            value: ?ObjectTypeField = null,
        } = null,
        keys: ?[]struct {
            key: ?[]const u8 = null,
            value: ?[]ObjectTypeKey = null,
        } = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .template_id = "TemplateId",
                .source_name = "SourceName",
                .source_object = "SourceObject",
                .allow_profile_creation = "AllowProfileCreation",
                .fields = "Fields",
                .keys = "Keys",
            };
            return @field(mappings, field_name);
        }

        pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
            if (std.mem.eql(u8, "fields", field_name))
                return try serializeMap(self.fields, self.fieldNameFor("fields"), options, out_stream);
            if (std.mem.eql(u8, "keys", field_name))
                return try serializeMap(self.keys, self.fieldNameFor("keys"), options, out_stream);
            return false;
        }
    },
    ServiceError: type = error{
        AccessDenied,
        BadRequest,
        InternalServer,
        ResourceNotFound,
        Throttling,
    },
} = .{};
pub const list_account_integrations: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/integrations",
        .success_code = 200,
    };

    action_name: []const u8 = "ListAccountIntegrations",
    Request: type = struct {
        uri: []const u8,
        next_token: ?[]const u8 = null,
        max_results: ?i64 = null,

        pub const http_query = .{
            .next_token = "next-token",
            .max_results = "max-results",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .uri = "Uri",
                .next_token = "NextToken",
                .max_results = "MaxResults",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_account_integrations) } {
            return .{ .service_metadata = service_metadata, .action = list_account_integrations };
        }
    },
    Response: type = struct {
        items: ?[]ListIntegrationItem = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .items = "Items",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        BadRequest,
        InternalServer,
        ResourceNotFound,
        Throttling,
    },
} = .{};
pub const list_domains: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/domains",
        .success_code = 200,
    };

    action_name: []const u8 = "ListDomains",
    Request: type = struct {
        next_token: ?[]const u8 = null,
        max_results: ?i64 = null,

        pub const http_query = .{
            .next_token = "next-token",
            .max_results = "max-results",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .next_token = "NextToken",
                .max_results = "MaxResults",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_domains) } {
            return .{ .service_metadata = service_metadata, .action = list_domains };
        }
    },
    Response: type = struct {
        items: ?[]struct {
            domain_name: []const u8,
            created_at: i64,
            last_updated_at: i64,
            tags: ?[]struct {
                key: ?[]const u8 = null,
                value: ?[]const u8 = null,
            } = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .domain_name = "DomainName",
                    .created_at = "CreatedAt",
                    .last_updated_at = "LastUpdatedAt",
                    .tags = "Tags",
                };
                return @field(mappings, field_name);
            }

            pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
                if (std.mem.eql(u8, "tags", field_name))
                    return try serializeMap(self.tags, self.fieldNameFor("tags"), options, out_stream);
                return false;
            }
        } = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .items = "Items",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        BadRequest,
        InternalServer,
        ResourceNotFound,
        Throttling,
    },
} = .{};
pub const list_integrations: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/domains/{DomainName}/integrations",
        .success_code = 200,
    };

    action_name: []const u8 = "ListIntegrations",
    Request: type = struct {
        domain_name: []const u8,
        next_token: ?[]const u8 = null,
        max_results: ?i64 = null,

        pub const http_query = .{
            .next_token = "next-token",
            .max_results = "max-results",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .domain_name = "DomainName",
                .next_token = "NextToken",
                .max_results = "MaxResults",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_integrations) } {
            return .{ .service_metadata = service_metadata, .action = list_integrations };
        }
    },
    Response: type = struct {
        items: ?[]ListIntegrationItem = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .items = "Items",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        BadRequest,
        InternalServer,
        ResourceNotFound,
        Throttling,
    },
} = .{};
pub const list_profile_objects: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/domains/{DomainName}/profiles/objects",
        .success_code = 200,
    };

    action_name: []const u8 = "ListProfileObjects",
    Request: type = struct {
        next_token: ?[]const u8 = null,
        max_results: ?i64 = null,
        domain_name: []const u8,
        object_type_name: []const u8,
        profile_id: []const u8,

        pub const http_query = .{
            .next_token = "next-token",
            .max_results = "max-results",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .next_token = "NextToken",
                .max_results = "MaxResults",
                .domain_name = "DomainName",
                .object_type_name = "ObjectTypeName",
                .profile_id = "ProfileId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_profile_objects) } {
            return .{ .service_metadata = service_metadata, .action = list_profile_objects };
        }
    },
    Response: type = struct {
        items: ?[]struct {
            object_type_name: ?[]const u8 = null,
            profile_object_unique_key: ?[]const u8 = null,
            object: ?[]const u8 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .object_type_name = "ObjectTypeName",
                    .profile_object_unique_key = "ProfileObjectUniqueKey",
                    .object = "Object",
                };
                return @field(mappings, field_name);
            }
        } = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .items = "Items",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        BadRequest,
        InternalServer,
        ResourceNotFound,
        Throttling,
    },
} = .{};
pub const list_profile_object_types: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/domains/{DomainName}/object-types",
        .success_code = 200,
    };

    action_name: []const u8 = "ListProfileObjectTypes",
    Request: type = struct {
        domain_name: []const u8,
        next_token: ?[]const u8 = null,
        max_results: ?i64 = null,

        pub const http_query = .{
            .next_token = "next-token",
            .max_results = "max-results",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .domain_name = "DomainName",
                .next_token = "NextToken",
                .max_results = "MaxResults",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_profile_object_types) } {
            return .{ .service_metadata = service_metadata, .action = list_profile_object_types };
        }
    },
    Response: type = struct {
        items: ?[]struct {
            object_type_name: []const u8,
            description: []const u8,
            created_at: ?i64 = null,
            last_updated_at: ?i64 = null,
            tags: ?[]struct {
                key: ?[]const u8 = null,
                value: ?[]const u8 = null,
            } = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .object_type_name = "ObjectTypeName",
                    .description = "Description",
                    .created_at = "CreatedAt",
                    .last_updated_at = "LastUpdatedAt",
                    .tags = "Tags",
                };
                return @field(mappings, field_name);
            }

            pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
                if (std.mem.eql(u8, "tags", field_name))
                    return try serializeMap(self.tags, self.fieldNameFor("tags"), options, out_stream);
                return false;
            }
        } = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .items = "Items",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        BadRequest,
        InternalServer,
        ResourceNotFound,
        Throttling,
    },
} = .{};
pub const list_profile_object_type_templates: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/templates",
        .success_code = 200,
    };

    action_name: []const u8 = "ListProfileObjectTypeTemplates",
    Request: type = struct {
        next_token: ?[]const u8 = null,
        max_results: ?i64 = null,

        pub const http_query = .{
            .next_token = "next-token",
            .max_results = "max-results",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .next_token = "NextToken",
                .max_results = "MaxResults",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_profile_object_type_templates) } {
            return .{ .service_metadata = service_metadata, .action = list_profile_object_type_templates };
        }
    },
    Response: type = struct {
        items: ?[]struct {
            template_id: ?[]const u8 = null,
            source_name: ?[]const u8 = null,
            source_object: ?[]const u8 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .template_id = "TemplateId",
                    .source_name = "SourceName",
                    .source_object = "SourceObject",
                };
                return @field(mappings, field_name);
            }
        } = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .items = "Items",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        BadRequest,
        InternalServer,
        ResourceNotFound,
        Throttling,
    },
} = .{};
pub const list_tags_for_resource: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/tags/{resourceArn}",
        .success_code = 200,
    };

    action_name: []const u8 = "ListTagsForResource",
    Request: type = struct {
        resource_arn: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .resource_arn = "resourceArn",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_tags_for_resource) } {
            return .{ .service_metadata = service_metadata, .action = list_tags_for_resource };
        }
    },
    Response: type = struct {
        tags: ?[]struct {
            key: ?[]const u8 = null,
            value: ?[]const u8 = null,
        } = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .tags = "tags",
            };
            return @field(mappings, field_name);
        }

        pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
            if (std.mem.eql(u8, "tags", field_name))
                return try serializeMap(self.tags, self.fieldNameFor("tags"), options, out_stream);
            return false;
        }
    },
    ServiceError: type = error{
        BadRequest,
        InternalServer,
        ResourceNotFound,
    },
} = .{};
pub const merge_profiles: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/domains/{DomainName}/profiles/objects/merge",
        .success_code = 200,
    };

    action_name: []const u8 = "MergeProfiles",
    Request: type = struct {
        domain_name: []const u8,
        main_profile_id: []const u8,
        profile_ids_to_be_merged: [][]const u8,
        field_source_profile_ids: ?struct {
            account_number: ?[]const u8 = null,
            additional_information: ?[]const u8 = null,
            party_type: ?[]const u8 = null,
            business_name: ?[]const u8 = null,
            first_name: ?[]const u8 = null,
            middle_name: ?[]const u8 = null,
            last_name: ?[]const u8 = null,
            birth_date: ?[]const u8 = null,
            gender: ?[]const u8 = null,
            phone_number: ?[]const u8 = null,
            mobile_phone_number: ?[]const u8 = null,
            home_phone_number: ?[]const u8 = null,
            business_phone_number: ?[]const u8 = null,
            email_address: ?[]const u8 = null,
            personal_email_address: ?[]const u8 = null,
            business_email_address: ?[]const u8 = null,
            address: ?[]const u8 = null,
            shipping_address: ?[]const u8 = null,
            mailing_address: ?[]const u8 = null,
            billing_address: ?[]const u8 = null,
            attributes: ?[]struct {
                key: ?[]const u8 = null,
                value: ?[]const u8 = null,
            } = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .account_number = "AccountNumber",
                    .additional_information = "AdditionalInformation",
                    .party_type = "PartyType",
                    .business_name = "BusinessName",
                    .first_name = "FirstName",
                    .middle_name = "MiddleName",
                    .last_name = "LastName",
                    .birth_date = "BirthDate",
                    .gender = "Gender",
                    .phone_number = "PhoneNumber",
                    .mobile_phone_number = "MobilePhoneNumber",
                    .home_phone_number = "HomePhoneNumber",
                    .business_phone_number = "BusinessPhoneNumber",
                    .email_address = "EmailAddress",
                    .personal_email_address = "PersonalEmailAddress",
                    .business_email_address = "BusinessEmailAddress",
                    .address = "Address",
                    .shipping_address = "ShippingAddress",
                    .mailing_address = "MailingAddress",
                    .billing_address = "BillingAddress",
                    .attributes = "Attributes",
                };
                return @field(mappings, field_name);
            }

            pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
                if (std.mem.eql(u8, "attributes", field_name))
                    return try serializeMap(self.attributes, self.fieldNameFor("attributes"), options, out_stream);
                return false;
            }
        } = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .domain_name = "DomainName",
                .main_profile_id = "MainProfileId",
                .profile_ids_to_be_merged = "ProfileIdsToBeMerged",
                .field_source_profile_ids = "FieldSourceProfileIds",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(merge_profiles) } {
            return .{ .service_metadata = service_metadata, .action = merge_profiles };
        }
    },
    Response: type = struct {
        message: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .message = "Message",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        BadRequest,
        InternalServer,
        ResourceNotFound,
        Throttling,
    },
} = .{};
pub const put_integration: struct {
    pub const http_config = .{
        .method = "PUT",
        .uri = "/domains/{DomainName}/integrations",
        .success_code = 200,
    };

    action_name: []const u8 = "PutIntegration",
    Request: type = struct {
        domain_name: []const u8,
        uri: ?[]const u8 = null,
        object_type_name: []const u8,
        tags: ?[]struct {
            key: ?[]const u8 = null,
            value: ?[]const u8 = null,
        } = null,
        flow_definition: ?struct {
            description: ?[]const u8 = null,
            flow_name: []const u8,
            kms_arn: []const u8,
            source_flow_config: struct {
                connector_profile_name: ?[]const u8 = null,
                connector_type: []const u8,
                incremental_pull_config: ?struct {
                    datetime_type_field_name: ?[]const u8 = null,

                    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                        const mappings = .{
                            .datetime_type_field_name = "DatetimeTypeFieldName",
                        };
                        return @field(mappings, field_name);
                    }
                } = null,
                source_connector_properties: struct {
                    marketo: ?struct {
                        object: []const u8,

                        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                            const mappings = .{
                                .object = "Object",
                            };
                            return @field(mappings, field_name);
                        }
                    } = null,
                    s3: ?struct {
                        bucket_name: []const u8,
                        bucket_prefix: ?[]const u8 = null,

                        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                            const mappings = .{
                                .bucket_name = "BucketName",
                                .bucket_prefix = "BucketPrefix",
                            };
                            return @field(mappings, field_name);
                        }
                    } = null,
                    salesforce: ?struct {
                        object: []const u8,
                        enable_dynamic_field_update: ?bool = null,
                        include_deleted_records: ?bool = null,

                        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                            const mappings = .{
                                .object = "Object",
                                .enable_dynamic_field_update = "EnableDynamicFieldUpdate",
                                .include_deleted_records = "IncludeDeletedRecords",
                            };
                            return @field(mappings, field_name);
                        }
                    } = null,
                    service_now: ?struct {
                        object: []const u8,

                        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                            const mappings = .{
                                .object = "Object",
                            };
                            return @field(mappings, field_name);
                        }
                    } = null,
                    zendesk: ?struct {
                        object: []const u8,

                        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                            const mappings = .{
                                .object = "Object",
                            };
                            return @field(mappings, field_name);
                        }
                    } = null,

                    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                        const mappings = .{
                            .marketo = "Marketo",
                            .s3 = "S3",
                            .salesforce = "Salesforce",
                            .service_now = "ServiceNow",
                            .zendesk = "Zendesk",
                        };
                        return @field(mappings, field_name);
                    }
                },

                pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                    const mappings = .{
                        .connector_profile_name = "ConnectorProfileName",
                        .connector_type = "ConnectorType",
                        .incremental_pull_config = "IncrementalPullConfig",
                        .source_connector_properties = "SourceConnectorProperties",
                    };
                    return @field(mappings, field_name);
                }
            },
            tasks: []struct {
                connector_operator: ?struct {
                    marketo: ?[]const u8 = null,
                    s3: ?[]const u8 = null,
                    salesforce: ?[]const u8 = null,
                    service_now: ?[]const u8 = null,
                    zendesk: ?[]const u8 = null,

                    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                        const mappings = .{
                            .marketo = "Marketo",
                            .s3 = "S3",
                            .salesforce = "Salesforce",
                            .service_now = "ServiceNow",
                            .zendesk = "Zendesk",
                        };
                        return @field(mappings, field_name);
                    }
                } = null,
                destination_field: ?[]const u8 = null,
                source_fields: [][]const u8,
                task_properties: ?[]struct {
                    key: ?[]const u8 = null,
                    value: ?[]const u8 = null,
                } = null,
                task_type: []const u8,

                pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                    const mappings = .{
                        .connector_operator = "ConnectorOperator",
                        .destination_field = "DestinationField",
                        .source_fields = "SourceFields",
                        .task_properties = "TaskProperties",
                        .task_type = "TaskType",
                    };
                    return @field(mappings, field_name);
                }

                pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
                    if (std.mem.eql(u8, "task_properties", field_name))
                        return try serializeMap(self.task_properties, self.fieldNameFor("task_properties"), options, out_stream);
                    return false;
                }
            },
            trigger_config: struct {
                trigger_type: []const u8,
                trigger_properties: ?struct {
                    scheduled: ?struct {
                        schedule_expression: []const u8,
                        data_pull_mode: ?[]const u8 = null,
                        schedule_start_time: ?i64 = null,
                        schedule_end_time: ?i64 = null,
                        timezone: ?[]const u8 = null,
                        schedule_offset: ?i64 = null,
                        first_execution_from: ?i64 = null,

                        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                            const mappings = .{
                                .schedule_expression = "ScheduleExpression",
                                .data_pull_mode = "DataPullMode",
                                .schedule_start_time = "ScheduleStartTime",
                                .schedule_end_time = "ScheduleEndTime",
                                .timezone = "Timezone",
                                .schedule_offset = "ScheduleOffset",
                                .first_execution_from = "FirstExecutionFrom",
                            };
                            return @field(mappings, field_name);
                        }
                    } = null,

                    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                        const mappings = .{
                            .scheduled = "Scheduled",
                        };
                        return @field(mappings, field_name);
                    }
                } = null,

                pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                    const mappings = .{
                        .trigger_type = "TriggerType",
                        .trigger_properties = "TriggerProperties",
                    };
                    return @field(mappings, field_name);
                }
            },

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .description = "Description",
                    .flow_name = "FlowName",
                    .kms_arn = "KmsArn",
                    .source_flow_config = "SourceFlowConfig",
                    .tasks = "Tasks",
                    .trigger_config = "TriggerConfig",
                };
                return @field(mappings, field_name);
            }
        } = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .domain_name = "DomainName",
                .uri = "Uri",
                .object_type_name = "ObjectTypeName",
                .tags = "Tags",
                .flow_definition = "FlowDefinition",
            };
            return @field(mappings, field_name);
        }

        pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
            if (std.mem.eql(u8, "tags", field_name))
                return try serializeMap(self.tags, self.fieldNameFor("tags"), options, out_stream);
            return false;
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(put_integration) } {
            return .{ .service_metadata = service_metadata, .action = put_integration };
        }
    },
    Response: type = struct {
        domain_name: []const u8,
        uri: []const u8,
        object_type_name: []const u8,
        created_at: i64,
        last_updated_at: i64,
        tags: ?[]struct {
            key: ?[]const u8 = null,
            value: ?[]const u8 = null,
        } = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .domain_name = "DomainName",
                .uri = "Uri",
                .object_type_name = "ObjectTypeName",
                .created_at = "CreatedAt",
                .last_updated_at = "LastUpdatedAt",
                .tags = "Tags",
            };
            return @field(mappings, field_name);
        }

        pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
            if (std.mem.eql(u8, "tags", field_name))
                return try serializeMap(self.tags, self.fieldNameFor("tags"), options, out_stream);
            return false;
        }
    },
    ServiceError: type = error{
        AccessDenied,
        BadRequest,
        InternalServer,
        ResourceNotFound,
        Throttling,
    },
} = .{};
pub const put_profile_object: struct {
    pub const http_config = .{
        .method = "PUT",
        .uri = "/domains/{DomainName}/profiles/objects",
        .success_code = 200,
    };

    action_name: []const u8 = "PutProfileObject",
    Request: type = struct {
        object_type_name: []const u8,
        object: []const u8,
        domain_name: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .object_type_name = "ObjectTypeName",
                .object = "Object",
                .domain_name = "DomainName",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(put_profile_object) } {
            return .{ .service_metadata = service_metadata, .action = put_profile_object };
        }
    },
    Response: type = struct {
        profile_object_unique_key: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .profile_object_unique_key = "ProfileObjectUniqueKey",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        BadRequest,
        InternalServer,
        ResourceNotFound,
        Throttling,
    },
} = .{};
pub const put_profile_object_type: struct {
    pub const http_config = .{
        .method = "PUT",
        .uri = "/domains/{DomainName}/object-types/{ObjectTypeName}",
        .success_code = 200,
    };

    action_name: []const u8 = "PutProfileObjectType",
    Request: type = struct {
        domain_name: []const u8,
        object_type_name: []const u8,
        description: []const u8,
        template_id: ?[]const u8 = null,
        expiration_days: ?i64 = null,
        encryption_key: ?[]const u8 = null,
        allow_profile_creation: ?bool = null,
        fields: ?[]struct {
            key: ?[]const u8 = null,
            value: ?ObjectTypeField = null,
        } = null,
        keys: ?[]struct {
            key: ?[]const u8 = null,
            value: ?[]ObjectTypeKey = null,
        } = null,
        tags: ?[]struct {
            key: ?[]const u8 = null,
            value: ?[]const u8 = null,
        } = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .domain_name = "DomainName",
                .object_type_name = "ObjectTypeName",
                .description = "Description",
                .template_id = "TemplateId",
                .expiration_days = "ExpirationDays",
                .encryption_key = "EncryptionKey",
                .allow_profile_creation = "AllowProfileCreation",
                .fields = "Fields",
                .keys = "Keys",
                .tags = "Tags",
            };
            return @field(mappings, field_name);
        }

        pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
            if (std.mem.eql(u8, "fields", field_name))
                return try serializeMap(self.fields, self.fieldNameFor("fields"), options, out_stream);
            if (std.mem.eql(u8, "keys", field_name))
                return try serializeMap(self.keys, self.fieldNameFor("keys"), options, out_stream);
            if (std.mem.eql(u8, "tags", field_name))
                return try serializeMap(self.tags, self.fieldNameFor("tags"), options, out_stream);
            return false;
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(put_profile_object_type) } {
            return .{ .service_metadata = service_metadata, .action = put_profile_object_type };
        }
    },
    Response: type = struct {
        object_type_name: []const u8,
        description: []const u8,
        template_id: ?[]const u8 = null,
        expiration_days: ?i64 = null,
        encryption_key: ?[]const u8 = null,
        allow_profile_creation: ?bool = null,
        fields: ?[]struct {
            key: ?[]const u8 = null,
            value: ?ObjectTypeField = null,
        } = null,
        keys: ?[]struct {
            key: ?[]const u8 = null,
            value: ?[]ObjectTypeKey = null,
        } = null,
        created_at: ?i64 = null,
        last_updated_at: ?i64 = null,
        tags: ?[]struct {
            key: ?[]const u8 = null,
            value: ?[]const u8 = null,
        } = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .object_type_name = "ObjectTypeName",
                .description = "Description",
                .template_id = "TemplateId",
                .expiration_days = "ExpirationDays",
                .encryption_key = "EncryptionKey",
                .allow_profile_creation = "AllowProfileCreation",
                .fields = "Fields",
                .keys = "Keys",
                .created_at = "CreatedAt",
                .last_updated_at = "LastUpdatedAt",
                .tags = "Tags",
            };
            return @field(mappings, field_name);
        }

        pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
            if (std.mem.eql(u8, "fields", field_name))
                return try serializeMap(self.fields, self.fieldNameFor("fields"), options, out_stream);
            if (std.mem.eql(u8, "keys", field_name))
                return try serializeMap(self.keys, self.fieldNameFor("keys"), options, out_stream);
            if (std.mem.eql(u8, "tags", field_name))
                return try serializeMap(self.tags, self.fieldNameFor("tags"), options, out_stream);
            return false;
        }
    },
    ServiceError: type = error{
        AccessDenied,
        BadRequest,
        InternalServer,
        ResourceNotFound,
        Throttling,
    },
} = .{};
pub const search_profiles: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/domains/{DomainName}/profiles/search",
        .success_code = 200,
    };

    action_name: []const u8 = "SearchProfiles",
    Request: type = struct {
        next_token: ?[]const u8 = null,
        max_results: ?i64 = null,
        domain_name: []const u8,
        key_name: []const u8,
        values: [][]const u8,

        pub const http_query = .{
            .next_token = "next-token",
            .max_results = "max-results",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .next_token = "NextToken",
                .max_results = "MaxResults",
                .domain_name = "DomainName",
                .key_name = "KeyName",
                .values = "Values",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(search_profiles) } {
            return .{ .service_metadata = service_metadata, .action = search_profiles };
        }
    },
    Response: type = struct {
        items: ?[]struct {
            profile_id: ?[]const u8 = null,
            account_number: ?[]const u8 = null,
            additional_information: ?[]const u8 = null,
            party_type: ?[]const u8 = null,
            business_name: ?[]const u8 = null,
            first_name: ?[]const u8 = null,
            middle_name: ?[]const u8 = null,
            last_name: ?[]const u8 = null,
            birth_date: ?[]const u8 = null,
            gender: ?[]const u8 = null,
            phone_number: ?[]const u8 = null,
            mobile_phone_number: ?[]const u8 = null,
            home_phone_number: ?[]const u8 = null,
            business_phone_number: ?[]const u8 = null,
            email_address: ?[]const u8 = null,
            personal_email_address: ?[]const u8 = null,
            business_email_address: ?[]const u8 = null,
            address: ?Address = null,
            shipping_address: ?Address = null,
            mailing_address: ?Address = null,
            billing_address: ?Address = null,
            attributes: ?[]struct {
                key: ?[]const u8 = null,
                value: ?[]const u8 = null,
            } = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .profile_id = "ProfileId",
                    .account_number = "AccountNumber",
                    .additional_information = "AdditionalInformation",
                    .party_type = "PartyType",
                    .business_name = "BusinessName",
                    .first_name = "FirstName",
                    .middle_name = "MiddleName",
                    .last_name = "LastName",
                    .birth_date = "BirthDate",
                    .gender = "Gender",
                    .phone_number = "PhoneNumber",
                    .mobile_phone_number = "MobilePhoneNumber",
                    .home_phone_number = "HomePhoneNumber",
                    .business_phone_number = "BusinessPhoneNumber",
                    .email_address = "EmailAddress",
                    .personal_email_address = "PersonalEmailAddress",
                    .business_email_address = "BusinessEmailAddress",
                    .address = "Address",
                    .shipping_address = "ShippingAddress",
                    .mailing_address = "MailingAddress",
                    .billing_address = "BillingAddress",
                    .attributes = "Attributes",
                };
                return @field(mappings, field_name);
            }

            pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
                if (std.mem.eql(u8, "attributes", field_name))
                    return try serializeMap(self.attributes, self.fieldNameFor("attributes"), options, out_stream);
                return false;
            }
        } = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .items = "Items",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        BadRequest,
        InternalServer,
        ResourceNotFound,
        Throttling,
    },
} = .{};
pub const tag_resource: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/tags/{resourceArn}",
        .success_code = 200,
    };

    action_name: []const u8 = "TagResource",
    Request: type = struct {
        resource_arn: []const u8,
        tags: []struct {
            key: ?[]const u8 = null,
            value: ?[]const u8 = null,
        },

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .resource_arn = "resourceArn",
                .tags = "tags",
            };
            return @field(mappings, field_name);
        }

        pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
            if (std.mem.eql(u8, "tags", field_name))
                return try serializeMap(self.tags, self.fieldNameFor("tags"), options, out_stream);
            return false;
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(tag_resource) } {
            return .{ .service_metadata = service_metadata, .action = tag_resource };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        BadRequest,
        InternalServer,
        ResourceNotFound,
    },
} = .{};
pub const untag_resource: struct {
    pub const http_config = .{
        .method = "DELETE",
        .uri = "/tags/{resourceArn}",
        .success_code = 200,
    };

    action_name: []const u8 = "UntagResource",
    Request: type = struct {
        resource_arn: []const u8,
        tag_keys: [][]const u8,

        pub const http_query = .{
            .tag_keys = "tagKeys",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .resource_arn = "resourceArn",
                .tag_keys = "tagKeys",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(untag_resource) } {
            return .{ .service_metadata = service_metadata, .action = untag_resource };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        BadRequest,
        InternalServer,
        ResourceNotFound,
    },
} = .{};
pub const update_domain: struct {
    pub const http_config = .{
        .method = "PUT",
        .uri = "/domains/{DomainName}",
        .success_code = 200,
    };

    action_name: []const u8 = "UpdateDomain",
    Request: type = struct {
        domain_name: []const u8,
        default_expiration_days: ?i64 = null,
        default_encryption_key: ?[]const u8 = null,
        dead_letter_queue_url: ?[]const u8 = null,
        matching: ?MatchingRequest = null,
        tags: ?[]struct {
            key: ?[]const u8 = null,
            value: ?[]const u8 = null,
        } = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .domain_name = "DomainName",
                .default_expiration_days = "DefaultExpirationDays",
                .default_encryption_key = "DefaultEncryptionKey",
                .dead_letter_queue_url = "DeadLetterQueueUrl",
                .matching = "Matching",
                .tags = "Tags",
            };
            return @field(mappings, field_name);
        }

        pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
            if (std.mem.eql(u8, "tags", field_name))
                return try serializeMap(self.tags, self.fieldNameFor("tags"), options, out_stream);
            return false;
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(update_domain) } {
            return .{ .service_metadata = service_metadata, .action = update_domain };
        }
    },
    Response: type = struct {
        domain_name: []const u8,
        default_expiration_days: ?i64 = null,
        default_encryption_key: ?[]const u8 = null,
        dead_letter_queue_url: ?[]const u8 = null,
        matching: ?MatchingResponse = null,
        created_at: i64,
        last_updated_at: i64,
        tags: ?[]struct {
            key: ?[]const u8 = null,
            value: ?[]const u8 = null,
        } = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .domain_name = "DomainName",
                .default_expiration_days = "DefaultExpirationDays",
                .default_encryption_key = "DefaultEncryptionKey",
                .dead_letter_queue_url = "DeadLetterQueueUrl",
                .matching = "Matching",
                .created_at = "CreatedAt",
                .last_updated_at = "LastUpdatedAt",
                .tags = "Tags",
            };
            return @field(mappings, field_name);
        }

        pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
            if (std.mem.eql(u8, "tags", field_name))
                return try serializeMap(self.tags, self.fieldNameFor("tags"), options, out_stream);
            return false;
        }
    },
    ServiceError: type = error{
        AccessDenied,
        BadRequest,
        InternalServer,
        ResourceNotFound,
        Throttling,
    },
} = .{};
pub const update_profile: struct {
    pub const http_config = .{
        .method = "PUT",
        .uri = "/domains/{DomainName}/profiles",
        .success_code = 200,
    };

    action_name: []const u8 = "UpdateProfile",
    Request: type = struct {
        domain_name: []const u8,
        profile_id: []const u8,
        additional_information: ?[]const u8 = null,
        account_number: ?[]const u8 = null,
        party_type: ?[]const u8 = null,
        business_name: ?[]const u8 = null,
        first_name: ?[]const u8 = null,
        middle_name: ?[]const u8 = null,
        last_name: ?[]const u8 = null,
        birth_date: ?[]const u8 = null,
        gender: ?[]const u8 = null,
        phone_number: ?[]const u8 = null,
        mobile_phone_number: ?[]const u8 = null,
        home_phone_number: ?[]const u8 = null,
        business_phone_number: ?[]const u8 = null,
        email_address: ?[]const u8 = null,
        personal_email_address: ?[]const u8 = null,
        business_email_address: ?[]const u8 = null,
        address: ?UpdateAddress = null,
        shipping_address: ?UpdateAddress = null,
        mailing_address: ?UpdateAddress = null,
        billing_address: ?UpdateAddress = null,
        attributes: ?[]struct {
            key: ?[]const u8 = null,
            value: ?[]const u8 = null,
        } = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .domain_name = "DomainName",
                .profile_id = "ProfileId",
                .additional_information = "AdditionalInformation",
                .account_number = "AccountNumber",
                .party_type = "PartyType",
                .business_name = "BusinessName",
                .first_name = "FirstName",
                .middle_name = "MiddleName",
                .last_name = "LastName",
                .birth_date = "BirthDate",
                .gender = "Gender",
                .phone_number = "PhoneNumber",
                .mobile_phone_number = "MobilePhoneNumber",
                .home_phone_number = "HomePhoneNumber",
                .business_phone_number = "BusinessPhoneNumber",
                .email_address = "EmailAddress",
                .personal_email_address = "PersonalEmailAddress",
                .business_email_address = "BusinessEmailAddress",
                .address = "Address",
                .shipping_address = "ShippingAddress",
                .mailing_address = "MailingAddress",
                .billing_address = "BillingAddress",
                .attributes = "Attributes",
            };
            return @field(mappings, field_name);
        }

        pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
            if (std.mem.eql(u8, "attributes", field_name))
                return try serializeMap(self.attributes, self.fieldNameFor("attributes"), options, out_stream);
            return false;
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(update_profile) } {
            return .{ .service_metadata = service_metadata, .action = update_profile };
        }
    },
    Response: type = struct {
        profile_id: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .profile_id = "ProfileId",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        BadRequest,
        InternalServer,
        ResourceNotFound,
        Throttling,
    },
} = .{};

pub const UpdateAddress = struct {
    address1: ?[]const u8 = null,
    address2: ?[]const u8 = null,
    address3: ?[]const u8 = null,
    address4: ?[]const u8 = null,
    city: ?[]const u8 = null,
    county: ?[]const u8 = null,
    state: ?[]const u8 = null,
    province: ?[]const u8 = null,
    country: ?[]const u8 = null,
    postal_code: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .address1 = "Address1",
            .address2 = "Address2",
            .address3 = "Address3",
            .address4 = "Address4",
            .city = "City",
            .county = "County",
            .state = "State",
            .province = "Province",
            .country = "Country",
            .postal_code = "PostalCode",
        };
        return @field(mappings, field_name);
    }
};

pub const MatchingResponse = struct {
    enabled: ?bool = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .enabled = "Enabled",
        };
        return @field(mappings, field_name);
    }
};

pub const MatchingRequest = struct {
    enabled: bool,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .enabled = "Enabled",
        };
        return @field(mappings, field_name);
    }
};

pub const Address = struct {
    address1: ?[]const u8 = null,
    address2: ?[]const u8 = null,
    address3: ?[]const u8 = null,
    address4: ?[]const u8 = null,
    city: ?[]const u8 = null,
    county: ?[]const u8 = null,
    state: ?[]const u8 = null,
    province: ?[]const u8 = null,
    country: ?[]const u8 = null,
    postal_code: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .address1 = "Address1",
            .address2 = "Address2",
            .address3 = "Address3",
            .address4 = "Address4",
            .city = "City",
            .county = "County",
            .state = "State",
            .province = "Province",
            .country = "Country",
            .postal_code = "PostalCode",
        };
        return @field(mappings, field_name);
    }
};

pub const ObjectTypeKey = struct {
    standard_identifiers: ?[][]const u8 = null,
    field_names: ?[][]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .standard_identifiers = "StandardIdentifiers",
            .field_names = "FieldNames",
        };
        return @field(mappings, field_name);
    }
};

pub const ObjectTypeField = struct {
    source: ?[]const u8 = null,
    target: ?[]const u8 = null,
    content_type: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .source = "Source",
            .target = "Target",
            .content_type = "ContentType",
        };
        return @field(mappings, field_name);
    }
};

pub const ListIntegrationItem = struct {
    domain_name: []const u8,
    uri: []const u8,
    object_type_name: []const u8,
    created_at: i64,
    last_updated_at: i64,
    tags: ?[]struct {
        key: ?[]const u8 = null,
        value: ?[]const u8 = null,
    } = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .domain_name = "DomainName",
            .uri = "Uri",
            .object_type_name = "ObjectTypeName",
            .created_at = "CreatedAt",
            .last_updated_at = "LastUpdatedAt",
            .tags = "Tags",
        };
        return @field(mappings, field_name);
    }

    pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
        if (std.mem.eql(u8, "tags", field_name))
            return try serializeMap(self.tags, self.fieldNameFor("tags"), options, out_stream);
        return false;
    }
};
