const std = @import("std");
const serializeMap = @import("json.zig").serializeMap;
const smithy = @import("smithy");

const Self = @This();
pub const version: []const u8 = "2019-12-02";
pub const sdk_id: []const u8 = "imagebuilder";
pub const arn_namespace: []const u8 = "imagebuilder";
pub const endpoint_prefix: []const u8 = "imagebuilder";
pub const sigv4_name: []const u8 = "imagebuilder";
pub const name: []const u8 = "imagebuilder";
pub const aws_protocol: smithy.AwsProtocol = smithy.AwsProtocol.rest_json_1;

pub const service_metadata: struct {
    version: []const u8 = "2019-12-02",
    sdk_id: []const u8 = "imagebuilder",
    arn_namespace: []const u8 = "imagebuilder",
    endpoint_prefix: []const u8 = "imagebuilder",
    sigv4_name: []const u8 = "imagebuilder",
    name: []const u8 = "imagebuilder",
    aws_protocol: smithy.AwsProtocol = smithy.AwsProtocol.rest_json_1,
} = .{};
pub const cancel_image_creation: struct {
    pub const http_config = .{
        .method = "PUT",
        .uri = "/CancelImageCreation",
        .success_code = 200,
    };

    action_name: []const u8 = "CancelImageCreation",
    Request: type = struct {
        image_build_version_arn: []const u8,
        client_token: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .image_build_version_arn = "imageBuildVersionArn",
                .client_token = "clientToken",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(cancel_image_creation) } {
            return .{ .service_metadata = service_metadata, .action = cancel_image_creation };
        }
    },
    Response: type = struct {
        request_id: ?[]const u8 = null,
        client_token: ?[]const u8 = null,
        image_build_version_arn: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .request_id = "requestId",
                .client_token = "clientToken",
                .image_build_version_arn = "imageBuildVersionArn",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        CallRateLimitExceeded,
        Client,
        Forbidden,
        IdempotentParameterMismatch,
        InvalidRequest,
        ResourceInUse,
        Service,
        ServiceUnavailable,
    },
} = .{};
pub const create_component: struct {
    pub const http_config = .{
        .method = "PUT",
        .uri = "/CreateComponent",
        .success_code = 200,
    };

    action_name: []const u8 = "CreateComponent",
    Request: type = struct {
        name: []const u8,
        semantic_version: []const u8,
        description: ?[]const u8 = null,
        change_description: ?[]const u8 = null,
        platform: []const u8,
        supported_os_versions: ?[][]const u8 = null,
        data: ?[]const u8 = null,
        uri: ?[]const u8 = null,
        kms_key_id: ?[]const u8 = null,
        tags: ?[]struct {
            key: ?[]const u8 = null,
            value: ?[]const u8 = null,
        } = null,
        client_token: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .name = "name",
                .semantic_version = "semanticVersion",
                .description = "description",
                .change_description = "changeDescription",
                .platform = "platform",
                .supported_os_versions = "supportedOsVersions",
                .data = "data",
                .uri = "uri",
                .kms_key_id = "kmsKeyId",
                .tags = "tags",
                .client_token = "clientToken",
            };
            return @field(mappings, field_name);
        }

        pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
            if (std.mem.eql(u8, "tags", field_name))
                return try serializeMap(self.tags, self.fieldNameFor("tags"), options, out_stream);
            return false;
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(create_component) } {
            return .{ .service_metadata = service_metadata, .action = create_component };
        }
    },
    Response: type = struct {
        request_id: ?[]const u8 = null,
        client_token: ?[]const u8 = null,
        component_build_version_arn: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .request_id = "requestId",
                .client_token = "clientToken",
                .component_build_version_arn = "componentBuildVersionArn",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        CallRateLimitExceeded,
        Client,
        Forbidden,
        IdempotentParameterMismatch,
        InvalidParameterCombination,
        InvalidRequest,
        InvalidVersionNumber,
        ResourceInUse,
        Service,
        ServiceQuotaExceeded,
        ServiceUnavailable,
    },
} = .{};
pub const create_container_recipe: struct {
    pub const http_config = .{
        .method = "PUT",
        .uri = "/CreateContainerRecipe",
        .success_code = 200,
    };

    action_name: []const u8 = "CreateContainerRecipe",
    Request: type = struct {
        container_type: []const u8,
        name: []const u8,
        description: ?[]const u8 = null,
        semantic_version: []const u8,
        components: []ComponentConfiguration,
        instance_configuration: ?InstanceConfiguration = null,
        dockerfile_template_data: ?[]const u8 = null,
        dockerfile_template_uri: ?[]const u8 = null,
        platform_override: ?[]const u8 = null,
        image_os_version_override: ?[]const u8 = null,
        parent_image: []const u8,
        tags: ?[]struct {
            key: ?[]const u8 = null,
            value: ?[]const u8 = null,
        } = null,
        working_directory: ?[]const u8 = null,
        target_repository: TargetContainerRepository,
        kms_key_id: ?[]const u8 = null,
        client_token: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .container_type = "containerType",
                .name = "name",
                .description = "description",
                .semantic_version = "semanticVersion",
                .components = "components",
                .instance_configuration = "instanceConfiguration",
                .dockerfile_template_data = "dockerfileTemplateData",
                .dockerfile_template_uri = "dockerfileTemplateUri",
                .platform_override = "platformOverride",
                .image_os_version_override = "imageOsVersionOverride",
                .parent_image = "parentImage",
                .tags = "tags",
                .working_directory = "workingDirectory",
                .target_repository = "targetRepository",
                .kms_key_id = "kmsKeyId",
                .client_token = "clientToken",
            };
            return @field(mappings, field_name);
        }

        pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
            if (std.mem.eql(u8, "tags", field_name))
                return try serializeMap(self.tags, self.fieldNameFor("tags"), options, out_stream);
            return false;
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(create_container_recipe) } {
            return .{ .service_metadata = service_metadata, .action = create_container_recipe };
        }
    },
    Response: type = struct {
        request_id: ?[]const u8 = null,
        client_token: ?[]const u8 = null,
        container_recipe_arn: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .request_id = "requestId",
                .client_token = "clientToken",
                .container_recipe_arn = "containerRecipeArn",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        CallRateLimitExceeded,
        Client,
        Forbidden,
        IdempotentParameterMismatch,
        InvalidRequest,
        InvalidVersionNumber,
        ResourceAlreadyExists,
        ResourceInUse,
        Service,
        ServiceQuotaExceeded,
        ServiceUnavailable,
    },
} = .{};
pub const create_distribution_configuration: struct {
    pub const http_config = .{
        .method = "PUT",
        .uri = "/CreateDistributionConfiguration",
        .success_code = 200,
    };

    action_name: []const u8 = "CreateDistributionConfiguration",
    Request: type = struct {
        name: []const u8,
        description: ?[]const u8 = null,
        distributions: []Distribution,
        tags: ?[]struct {
            key: ?[]const u8 = null,
            value: ?[]const u8 = null,
        } = null,
        client_token: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .name = "name",
                .description = "description",
                .distributions = "distributions",
                .tags = "tags",
                .client_token = "clientToken",
            };
            return @field(mappings, field_name);
        }

        pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
            if (std.mem.eql(u8, "tags", field_name))
                return try serializeMap(self.tags, self.fieldNameFor("tags"), options, out_stream);
            return false;
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(create_distribution_configuration) } {
            return .{ .service_metadata = service_metadata, .action = create_distribution_configuration };
        }
    },
    Response: type = struct {
        request_id: ?[]const u8 = null,
        client_token: ?[]const u8 = null,
        distribution_configuration_arn: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .request_id = "requestId",
                .client_token = "clientToken",
                .distribution_configuration_arn = "distributionConfigurationArn",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        CallRateLimitExceeded,
        Client,
        Forbidden,
        IdempotentParameterMismatch,
        InvalidParameterCombination,
        InvalidRequest,
        ResourceAlreadyExists,
        ResourceInUse,
        Service,
        ServiceQuotaExceeded,
        ServiceUnavailable,
    },
} = .{};
pub const create_image: struct {
    pub const http_config = .{
        .method = "PUT",
        .uri = "/CreateImage",
        .success_code = 200,
    };

    action_name: []const u8 = "CreateImage",
    Request: type = struct {
        image_recipe_arn: ?[]const u8 = null,
        container_recipe_arn: ?[]const u8 = null,
        distribution_configuration_arn: ?[]const u8 = null,
        infrastructure_configuration_arn: []const u8,
        image_tests_configuration: ?ImageTestsConfiguration = null,
        enhanced_image_metadata_enabled: ?bool = null,
        tags: ?[]struct {
            key: ?[]const u8 = null,
            value: ?[]const u8 = null,
        } = null,
        client_token: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .image_recipe_arn = "imageRecipeArn",
                .container_recipe_arn = "containerRecipeArn",
                .distribution_configuration_arn = "distributionConfigurationArn",
                .infrastructure_configuration_arn = "infrastructureConfigurationArn",
                .image_tests_configuration = "imageTestsConfiguration",
                .enhanced_image_metadata_enabled = "enhancedImageMetadataEnabled",
                .tags = "tags",
                .client_token = "clientToken",
            };
            return @field(mappings, field_name);
        }

        pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
            if (std.mem.eql(u8, "tags", field_name))
                return try serializeMap(self.tags, self.fieldNameFor("tags"), options, out_stream);
            return false;
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(create_image) } {
            return .{ .service_metadata = service_metadata, .action = create_image };
        }
    },
    Response: type = struct {
        request_id: ?[]const u8 = null,
        client_token: ?[]const u8 = null,
        image_build_version_arn: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .request_id = "requestId",
                .client_token = "clientToken",
                .image_build_version_arn = "imageBuildVersionArn",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        CallRateLimitExceeded,
        Client,
        Forbidden,
        IdempotentParameterMismatch,
        InvalidRequest,
        ResourceInUse,
        Service,
        ServiceQuotaExceeded,
        ServiceUnavailable,
    },
} = .{};
pub const create_image_pipeline: struct {
    pub const http_config = .{
        .method = "PUT",
        .uri = "/CreateImagePipeline",
        .success_code = 200,
    };

    action_name: []const u8 = "CreateImagePipeline",
    Request: type = struct {
        name: []const u8,
        description: ?[]const u8 = null,
        image_recipe_arn: ?[]const u8 = null,
        container_recipe_arn: ?[]const u8 = null,
        infrastructure_configuration_arn: []const u8,
        distribution_configuration_arn: ?[]const u8 = null,
        image_tests_configuration: ?ImageTestsConfiguration = null,
        enhanced_image_metadata_enabled: ?bool = null,
        schedule: ?Schedule = null,
        status: ?[]const u8 = null,
        tags: ?[]struct {
            key: ?[]const u8 = null,
            value: ?[]const u8 = null,
        } = null,
        client_token: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .name = "name",
                .description = "description",
                .image_recipe_arn = "imageRecipeArn",
                .container_recipe_arn = "containerRecipeArn",
                .infrastructure_configuration_arn = "infrastructureConfigurationArn",
                .distribution_configuration_arn = "distributionConfigurationArn",
                .image_tests_configuration = "imageTestsConfiguration",
                .enhanced_image_metadata_enabled = "enhancedImageMetadataEnabled",
                .schedule = "schedule",
                .status = "status",
                .tags = "tags",
                .client_token = "clientToken",
            };
            return @field(mappings, field_name);
        }

        pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
            if (std.mem.eql(u8, "tags", field_name))
                return try serializeMap(self.tags, self.fieldNameFor("tags"), options, out_stream);
            return false;
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(create_image_pipeline) } {
            return .{ .service_metadata = service_metadata, .action = create_image_pipeline };
        }
    },
    Response: type = struct {
        request_id: ?[]const u8 = null,
        client_token: ?[]const u8 = null,
        image_pipeline_arn: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .request_id = "requestId",
                .client_token = "clientToken",
                .image_pipeline_arn = "imagePipelineArn",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        CallRateLimitExceeded,
        Client,
        Forbidden,
        IdempotentParameterMismatch,
        InvalidRequest,
        ResourceAlreadyExists,
        ResourceInUse,
        Service,
        ServiceQuotaExceeded,
        ServiceUnavailable,
    },
} = .{};
pub const create_image_recipe: struct {
    pub const http_config = .{
        .method = "PUT",
        .uri = "/CreateImageRecipe",
        .success_code = 200,
    };

    action_name: []const u8 = "CreateImageRecipe",
    Request: type = struct {
        name: []const u8,
        description: ?[]const u8 = null,
        semantic_version: []const u8,
        components: []ComponentConfiguration,
        parent_image: []const u8,
        block_device_mappings: ?[]InstanceBlockDeviceMapping = null,
        tags: ?[]struct {
            key: ?[]const u8 = null,
            value: ?[]const u8 = null,
        } = null,
        working_directory: ?[]const u8 = null,
        client_token: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .name = "name",
                .description = "description",
                .semantic_version = "semanticVersion",
                .components = "components",
                .parent_image = "parentImage",
                .block_device_mappings = "blockDeviceMappings",
                .tags = "tags",
                .working_directory = "workingDirectory",
                .client_token = "clientToken",
            };
            return @field(mappings, field_name);
        }

        pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
            if (std.mem.eql(u8, "tags", field_name))
                return try serializeMap(self.tags, self.fieldNameFor("tags"), options, out_stream);
            return false;
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(create_image_recipe) } {
            return .{ .service_metadata = service_metadata, .action = create_image_recipe };
        }
    },
    Response: type = struct {
        request_id: ?[]const u8 = null,
        client_token: ?[]const u8 = null,
        image_recipe_arn: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .request_id = "requestId",
                .client_token = "clientToken",
                .image_recipe_arn = "imageRecipeArn",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        CallRateLimitExceeded,
        Client,
        Forbidden,
        IdempotentParameterMismatch,
        InvalidRequest,
        InvalidVersionNumber,
        ResourceAlreadyExists,
        ResourceInUse,
        Service,
        ServiceQuotaExceeded,
        ServiceUnavailable,
    },
} = .{};
pub const create_infrastructure_configuration: struct {
    pub const http_config = .{
        .method = "PUT",
        .uri = "/CreateInfrastructureConfiguration",
        .success_code = 200,
    };

    action_name: []const u8 = "CreateInfrastructureConfiguration",
    Request: type = struct {
        name: []const u8,
        description: ?[]const u8 = null,
        instance_types: ?[][]const u8 = null,
        instance_profile_name: []const u8,
        security_group_ids: ?[][]const u8 = null,
        subnet_id: ?[]const u8 = null,
        logging: ?Logging = null,
        key_pair: ?[]const u8 = null,
        terminate_instance_on_failure: ?bool = null,
        sns_topic_arn: ?[]const u8 = null,
        resource_tags: ?[]struct {
            key: ?[]const u8 = null,
            value: ?[]const u8 = null,
        } = null,
        tags: ?[]struct {
            key: ?[]const u8 = null,
            value: ?[]const u8 = null,
        } = null,
        client_token: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .name = "name",
                .description = "description",
                .instance_types = "instanceTypes",
                .instance_profile_name = "instanceProfileName",
                .security_group_ids = "securityGroupIds",
                .subnet_id = "subnetId",
                .logging = "logging",
                .key_pair = "keyPair",
                .terminate_instance_on_failure = "terminateInstanceOnFailure",
                .sns_topic_arn = "snsTopicArn",
                .resource_tags = "resourceTags",
                .tags = "tags",
                .client_token = "clientToken",
            };
            return @field(mappings, field_name);
        }

        pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
            if (std.mem.eql(u8, "resource_tags", field_name))
                return try serializeMap(self.resource_tags, self.fieldNameFor("resource_tags"), options, out_stream);
            if (std.mem.eql(u8, "tags", field_name))
                return try serializeMap(self.tags, self.fieldNameFor("tags"), options, out_stream);
            return false;
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(create_infrastructure_configuration) } {
            return .{ .service_metadata = service_metadata, .action = create_infrastructure_configuration };
        }
    },
    Response: type = struct {
        request_id: ?[]const u8 = null,
        client_token: ?[]const u8 = null,
        infrastructure_configuration_arn: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .request_id = "requestId",
                .client_token = "clientToken",
                .infrastructure_configuration_arn = "infrastructureConfigurationArn",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        CallRateLimitExceeded,
        Client,
        Forbidden,
        IdempotentParameterMismatch,
        InvalidRequest,
        ResourceAlreadyExists,
        ResourceInUse,
        Service,
        ServiceQuotaExceeded,
        ServiceUnavailable,
    },
} = .{};
pub const delete_component: struct {
    pub const http_config = .{
        .method = "DELETE",
        .uri = "/DeleteComponent",
        .success_code = 200,
    };

    action_name: []const u8 = "DeleteComponent",
    Request: type = struct {
        component_build_version_arn: []const u8,

        pub const http_query = .{
            .component_build_version_arn = "componentBuildVersionArn",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .component_build_version_arn = "componentBuildVersionArn",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(delete_component) } {
            return .{ .service_metadata = service_metadata, .action = delete_component };
        }
    },
    Response: type = struct {
        request_id: ?[]const u8 = null,
        component_build_version_arn: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .request_id = "requestId",
                .component_build_version_arn = "componentBuildVersionArn",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        CallRateLimitExceeded,
        Client,
        Forbidden,
        InvalidRequest,
        ResourceDependency,
        Service,
        ServiceUnavailable,
    },
} = .{};
pub const delete_container_recipe: struct {
    pub const http_config = .{
        .method = "DELETE",
        .uri = "/DeleteContainerRecipe",
        .success_code = 200,
    };

    action_name: []const u8 = "DeleteContainerRecipe",
    Request: type = struct {
        container_recipe_arn: []const u8,

        pub const http_query = .{
            .container_recipe_arn = "containerRecipeArn",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .container_recipe_arn = "containerRecipeArn",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(delete_container_recipe) } {
            return .{ .service_metadata = service_metadata, .action = delete_container_recipe };
        }
    },
    Response: type = struct {
        request_id: ?[]const u8 = null,
        container_recipe_arn: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .request_id = "requestId",
                .container_recipe_arn = "containerRecipeArn",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        CallRateLimitExceeded,
        Client,
        Forbidden,
        InvalidRequest,
        ResourceDependency,
        Service,
        ServiceUnavailable,
    },
} = .{};
pub const delete_distribution_configuration: struct {
    pub const http_config = .{
        .method = "DELETE",
        .uri = "/DeleteDistributionConfiguration",
        .success_code = 200,
    };

    action_name: []const u8 = "DeleteDistributionConfiguration",
    Request: type = struct {
        distribution_configuration_arn: []const u8,

        pub const http_query = .{
            .distribution_configuration_arn = "distributionConfigurationArn",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .distribution_configuration_arn = "distributionConfigurationArn",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(delete_distribution_configuration) } {
            return .{ .service_metadata = service_metadata, .action = delete_distribution_configuration };
        }
    },
    Response: type = struct {
        request_id: ?[]const u8 = null,
        distribution_configuration_arn: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .request_id = "requestId",
                .distribution_configuration_arn = "distributionConfigurationArn",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        CallRateLimitExceeded,
        Client,
        Forbidden,
        InvalidRequest,
        ResourceDependency,
        Service,
        ServiceUnavailable,
    },
} = .{};
pub const delete_image: struct {
    pub const http_config = .{
        .method = "DELETE",
        .uri = "/DeleteImage",
        .success_code = 200,
    };

    action_name: []const u8 = "DeleteImage",
    Request: type = struct {
        image_build_version_arn: []const u8,

        pub const http_query = .{
            .image_build_version_arn = "imageBuildVersionArn",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .image_build_version_arn = "imageBuildVersionArn",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(delete_image) } {
            return .{ .service_metadata = service_metadata, .action = delete_image };
        }
    },
    Response: type = struct {
        request_id: ?[]const u8 = null,
        image_build_version_arn: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .request_id = "requestId",
                .image_build_version_arn = "imageBuildVersionArn",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        CallRateLimitExceeded,
        Client,
        Forbidden,
        InvalidRequest,
        ResourceDependency,
        Service,
        ServiceUnavailable,
    },
} = .{};
pub const delete_image_pipeline: struct {
    pub const http_config = .{
        .method = "DELETE",
        .uri = "/DeleteImagePipeline",
        .success_code = 200,
    };

    action_name: []const u8 = "DeleteImagePipeline",
    Request: type = struct {
        image_pipeline_arn: []const u8,

        pub const http_query = .{
            .image_pipeline_arn = "imagePipelineArn",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .image_pipeline_arn = "imagePipelineArn",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(delete_image_pipeline) } {
            return .{ .service_metadata = service_metadata, .action = delete_image_pipeline };
        }
    },
    Response: type = struct {
        request_id: ?[]const u8 = null,
        image_pipeline_arn: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .request_id = "requestId",
                .image_pipeline_arn = "imagePipelineArn",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        CallRateLimitExceeded,
        Client,
        Forbidden,
        InvalidRequest,
        ResourceDependency,
        Service,
        ServiceUnavailable,
    },
} = .{};
pub const delete_image_recipe: struct {
    pub const http_config = .{
        .method = "DELETE",
        .uri = "/DeleteImageRecipe",
        .success_code = 200,
    };

    action_name: []const u8 = "DeleteImageRecipe",
    Request: type = struct {
        image_recipe_arn: []const u8,

        pub const http_query = .{
            .image_recipe_arn = "imageRecipeArn",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .image_recipe_arn = "imageRecipeArn",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(delete_image_recipe) } {
            return .{ .service_metadata = service_metadata, .action = delete_image_recipe };
        }
    },
    Response: type = struct {
        request_id: ?[]const u8 = null,
        image_recipe_arn: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .request_id = "requestId",
                .image_recipe_arn = "imageRecipeArn",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        CallRateLimitExceeded,
        Client,
        Forbidden,
        InvalidRequest,
        ResourceDependency,
        Service,
        ServiceUnavailable,
    },
} = .{};
pub const delete_infrastructure_configuration: struct {
    pub const http_config = .{
        .method = "DELETE",
        .uri = "/DeleteInfrastructureConfiguration",
        .success_code = 200,
    };

    action_name: []const u8 = "DeleteInfrastructureConfiguration",
    Request: type = struct {
        infrastructure_configuration_arn: []const u8,

        pub const http_query = .{
            .infrastructure_configuration_arn = "infrastructureConfigurationArn",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .infrastructure_configuration_arn = "infrastructureConfigurationArn",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(delete_infrastructure_configuration) } {
            return .{ .service_metadata = service_metadata, .action = delete_infrastructure_configuration };
        }
    },
    Response: type = struct {
        request_id: ?[]const u8 = null,
        infrastructure_configuration_arn: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .request_id = "requestId",
                .infrastructure_configuration_arn = "infrastructureConfigurationArn",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        CallRateLimitExceeded,
        Client,
        Forbidden,
        InvalidRequest,
        ResourceDependency,
        Service,
        ServiceUnavailable,
    },
} = .{};
pub const get_component: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/GetComponent",
        .success_code = 200,
    };

    action_name: []const u8 = "GetComponent",
    Request: type = struct {
        component_build_version_arn: []const u8,

        pub const http_query = .{
            .component_build_version_arn = "componentBuildVersionArn",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .component_build_version_arn = "componentBuildVersionArn",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(get_component) } {
            return .{ .service_metadata = service_metadata, .action = get_component };
        }
    },
    Response: type = struct {
        request_id: ?[]const u8 = null,
        component: ?struct {
            arn: ?[]const u8 = null,
            name: ?[]const u8 = null,
            version: ?[]const u8 = null,
            description: ?[]const u8 = null,
            change_description: ?[]const u8 = null,
            type: ?[]const u8 = null,
            platform: ?[]const u8 = null,
            supported_os_versions: ?[][]const u8 = null,
            owner: ?[]const u8 = null,
            data: ?[]const u8 = null,
            kms_key_id: ?[]const u8 = null,
            encrypted: ?bool = null,
            date_created: ?[]const u8 = null,
            tags: ?[]struct {
                key: ?[]const u8 = null,
                value: ?[]const u8 = null,
            } = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .arn = "arn",
                    .name = "name",
                    .version = "version",
                    .description = "description",
                    .change_description = "changeDescription",
                    .type = "type",
                    .platform = "platform",
                    .supported_os_versions = "supportedOsVersions",
                    .owner = "owner",
                    .data = "data",
                    .kms_key_id = "kmsKeyId",
                    .encrypted = "encrypted",
                    .date_created = "dateCreated",
                    .tags = "tags",
                };
                return @field(mappings, field_name);
            }

            pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
                if (std.mem.eql(u8, "tags", field_name))
                    return try serializeMap(self.tags, self.fieldNameFor("tags"), options, out_stream);
                return false;
            }
        } = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .request_id = "requestId",
                .component = "component",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        CallRateLimitExceeded,
        Client,
        Forbidden,
        InvalidRequest,
        Service,
        ServiceUnavailable,
    },
} = .{};
pub const get_component_policy: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/GetComponentPolicy",
        .success_code = 200,
    };

    action_name: []const u8 = "GetComponentPolicy",
    Request: type = struct {
        component_arn: []const u8,

        pub const http_query = .{
            .component_arn = "componentArn",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .component_arn = "componentArn",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(get_component_policy) } {
            return .{ .service_metadata = service_metadata, .action = get_component_policy };
        }
    },
    Response: type = struct {
        request_id: ?[]const u8 = null,
        policy: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .request_id = "requestId",
                .policy = "policy",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        CallRateLimitExceeded,
        Forbidden,
        InvalidRequest,
        ResourceNotFound,
        Service,
        ServiceUnavailable,
    },
} = .{};
pub const get_container_recipe: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/GetContainerRecipe",
        .success_code = 200,
    };

    action_name: []const u8 = "GetContainerRecipe",
    Request: type = struct {
        container_recipe_arn: []const u8,

        pub const http_query = .{
            .container_recipe_arn = "containerRecipeArn",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .container_recipe_arn = "containerRecipeArn",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(get_container_recipe) } {
            return .{ .service_metadata = service_metadata, .action = get_container_recipe };
        }
    },
    Response: type = struct {
        request_id: ?[]const u8 = null,
        container_recipe: ?ContainerRecipe = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .request_id = "requestId",
                .container_recipe = "containerRecipe",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        CallRateLimitExceeded,
        Client,
        Forbidden,
        InvalidRequest,
        Service,
        ServiceUnavailable,
    },
} = .{};
pub const get_container_recipe_policy: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/GetContainerRecipePolicy",
        .success_code = 200,
    };

    action_name: []const u8 = "GetContainerRecipePolicy",
    Request: type = struct {
        container_recipe_arn: []const u8,

        pub const http_query = .{
            .container_recipe_arn = "containerRecipeArn",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .container_recipe_arn = "containerRecipeArn",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(get_container_recipe_policy) } {
            return .{ .service_metadata = service_metadata, .action = get_container_recipe_policy };
        }
    },
    Response: type = struct {
        request_id: ?[]const u8 = null,
        policy: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .request_id = "requestId",
                .policy = "policy",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        CallRateLimitExceeded,
        Forbidden,
        InvalidRequest,
        ResourceNotFound,
        Service,
        ServiceUnavailable,
    },
} = .{};
pub const get_distribution_configuration: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/GetDistributionConfiguration",
        .success_code = 200,
    };

    action_name: []const u8 = "GetDistributionConfiguration",
    Request: type = struct {
        distribution_configuration_arn: []const u8,

        pub const http_query = .{
            .distribution_configuration_arn = "distributionConfigurationArn",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .distribution_configuration_arn = "distributionConfigurationArn",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(get_distribution_configuration) } {
            return .{ .service_metadata = service_metadata, .action = get_distribution_configuration };
        }
    },
    Response: type = struct {
        request_id: ?[]const u8 = null,
        distribution_configuration: ?DistributionConfiguration = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .request_id = "requestId",
                .distribution_configuration = "distributionConfiguration",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        CallRateLimitExceeded,
        Client,
        Forbidden,
        InvalidRequest,
        Service,
        ServiceUnavailable,
    },
} = .{};
pub const get_image: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/GetImage",
        .success_code = 200,
    };

    action_name: []const u8 = "GetImage",
    Request: type = struct {
        image_build_version_arn: []const u8,

        pub const http_query = .{
            .image_build_version_arn = "imageBuildVersionArn",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .image_build_version_arn = "imageBuildVersionArn",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(get_image) } {
            return .{ .service_metadata = service_metadata, .action = get_image };
        }
    },
    Response: type = struct {
        request_id: ?[]const u8 = null,
        image: ?struct {
            arn: ?[]const u8 = null,
            type: ?[]const u8 = null,
            name: ?[]const u8 = null,
            version: ?[]const u8 = null,
            platform: ?[]const u8 = null,
            enhanced_image_metadata_enabled: ?bool = null,
            os_version: ?[]const u8 = null,
            state: ?ImageState = null,
            image_recipe: ?ImageRecipe = null,
            container_recipe: ?ContainerRecipe = null,
            source_pipeline_name: ?[]const u8 = null,
            source_pipeline_arn: ?[]const u8 = null,
            infrastructure_configuration: ?InfrastructureConfiguration = null,
            distribution_configuration: ?DistributionConfiguration = null,
            image_tests_configuration: ?ImageTestsConfiguration = null,
            date_created: ?[]const u8 = null,
            output_resources: ?OutputResources = null,
            tags: ?[]struct {
                key: ?[]const u8 = null,
                value: ?[]const u8 = null,
            } = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .arn = "arn",
                    .type = "type",
                    .name = "name",
                    .version = "version",
                    .platform = "platform",
                    .enhanced_image_metadata_enabled = "enhancedImageMetadataEnabled",
                    .os_version = "osVersion",
                    .state = "state",
                    .image_recipe = "imageRecipe",
                    .container_recipe = "containerRecipe",
                    .source_pipeline_name = "sourcePipelineName",
                    .source_pipeline_arn = "sourcePipelineArn",
                    .infrastructure_configuration = "infrastructureConfiguration",
                    .distribution_configuration = "distributionConfiguration",
                    .image_tests_configuration = "imageTestsConfiguration",
                    .date_created = "dateCreated",
                    .output_resources = "outputResources",
                    .tags = "tags",
                };
                return @field(mappings, field_name);
            }

            pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
                if (std.mem.eql(u8, "tags", field_name))
                    return try serializeMap(self.tags, self.fieldNameFor("tags"), options, out_stream);
                return false;
            }
        } = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .request_id = "requestId",
                .image = "image",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        CallRateLimitExceeded,
        Client,
        Forbidden,
        InvalidRequest,
        Service,
        ServiceUnavailable,
    },
} = .{};
pub const get_image_pipeline: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/GetImagePipeline",
        .success_code = 200,
    };

    action_name: []const u8 = "GetImagePipeline",
    Request: type = struct {
        image_pipeline_arn: []const u8,

        pub const http_query = .{
            .image_pipeline_arn = "imagePipelineArn",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .image_pipeline_arn = "imagePipelineArn",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(get_image_pipeline) } {
            return .{ .service_metadata = service_metadata, .action = get_image_pipeline };
        }
    },
    Response: type = struct {
        request_id: ?[]const u8 = null,
        image_pipeline: ?ImagePipeline = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .request_id = "requestId",
                .image_pipeline = "imagePipeline",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        CallRateLimitExceeded,
        Client,
        Forbidden,
        InvalidRequest,
        Service,
        ServiceUnavailable,
    },
} = .{};
pub const get_image_policy: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/GetImagePolicy",
        .success_code = 200,
    };

    action_name: []const u8 = "GetImagePolicy",
    Request: type = struct {
        image_arn: []const u8,

        pub const http_query = .{
            .image_arn = "imageArn",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .image_arn = "imageArn",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(get_image_policy) } {
            return .{ .service_metadata = service_metadata, .action = get_image_policy };
        }
    },
    Response: type = struct {
        request_id: ?[]const u8 = null,
        policy: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .request_id = "requestId",
                .policy = "policy",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        CallRateLimitExceeded,
        Forbidden,
        InvalidRequest,
        ResourceNotFound,
        Service,
        ServiceUnavailable,
    },
} = .{};
pub const get_image_recipe: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/GetImageRecipe",
        .success_code = 200,
    };

    action_name: []const u8 = "GetImageRecipe",
    Request: type = struct {
        image_recipe_arn: []const u8,

        pub const http_query = .{
            .image_recipe_arn = "imageRecipeArn",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .image_recipe_arn = "imageRecipeArn",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(get_image_recipe) } {
            return .{ .service_metadata = service_metadata, .action = get_image_recipe };
        }
    },
    Response: type = struct {
        request_id: ?[]const u8 = null,
        image_recipe: ?ImageRecipe = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .request_id = "requestId",
                .image_recipe = "imageRecipe",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        CallRateLimitExceeded,
        Client,
        Forbidden,
        InvalidRequest,
        Service,
        ServiceUnavailable,
    },
} = .{};
pub const get_image_recipe_policy: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/GetImageRecipePolicy",
        .success_code = 200,
    };

    action_name: []const u8 = "GetImageRecipePolicy",
    Request: type = struct {
        image_recipe_arn: []const u8,

        pub const http_query = .{
            .image_recipe_arn = "imageRecipeArn",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .image_recipe_arn = "imageRecipeArn",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(get_image_recipe_policy) } {
            return .{ .service_metadata = service_metadata, .action = get_image_recipe_policy };
        }
    },
    Response: type = struct {
        request_id: ?[]const u8 = null,
        policy: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .request_id = "requestId",
                .policy = "policy",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        CallRateLimitExceeded,
        Forbidden,
        InvalidRequest,
        ResourceNotFound,
        Service,
        ServiceUnavailable,
    },
} = .{};
pub const get_infrastructure_configuration: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/GetInfrastructureConfiguration",
        .success_code = 200,
    };

    action_name: []const u8 = "GetInfrastructureConfiguration",
    Request: type = struct {
        infrastructure_configuration_arn: []const u8,

        pub const http_query = .{
            .infrastructure_configuration_arn = "infrastructureConfigurationArn",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .infrastructure_configuration_arn = "infrastructureConfigurationArn",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(get_infrastructure_configuration) } {
            return .{ .service_metadata = service_metadata, .action = get_infrastructure_configuration };
        }
    },
    Response: type = struct {
        request_id: ?[]const u8 = null,
        infrastructure_configuration: ?InfrastructureConfiguration = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .request_id = "requestId",
                .infrastructure_configuration = "infrastructureConfiguration",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        CallRateLimitExceeded,
        Client,
        Forbidden,
        InvalidRequest,
        Service,
        ServiceUnavailable,
    },
} = .{};
pub const import_component: struct {
    pub const http_config = .{
        .method = "PUT",
        .uri = "/ImportComponent",
        .success_code = 200,
    };

    action_name: []const u8 = "ImportComponent",
    Request: type = struct {
        name: []const u8,
        semantic_version: []const u8,
        description: ?[]const u8 = null,
        change_description: ?[]const u8 = null,
        type: []const u8,
        format: []const u8,
        platform: []const u8,
        data: ?[]const u8 = null,
        uri: ?[]const u8 = null,
        kms_key_id: ?[]const u8 = null,
        tags: ?[]struct {
            key: ?[]const u8 = null,
            value: ?[]const u8 = null,
        } = null,
        client_token: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .name = "name",
                .semantic_version = "semanticVersion",
                .description = "description",
                .change_description = "changeDescription",
                .type = "type",
                .format = "format",
                .platform = "platform",
                .data = "data",
                .uri = "uri",
                .kms_key_id = "kmsKeyId",
                .tags = "tags",
                .client_token = "clientToken",
            };
            return @field(mappings, field_name);
        }

        pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
            if (std.mem.eql(u8, "tags", field_name))
                return try serializeMap(self.tags, self.fieldNameFor("tags"), options, out_stream);
            return false;
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(import_component) } {
            return .{ .service_metadata = service_metadata, .action = import_component };
        }
    },
    Response: type = struct {
        request_id: ?[]const u8 = null,
        client_token: ?[]const u8 = null,
        component_build_version_arn: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .request_id = "requestId",
                .client_token = "clientToken",
                .component_build_version_arn = "componentBuildVersionArn",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        CallRateLimitExceeded,
        Client,
        Forbidden,
        IdempotentParameterMismatch,
        InvalidParameterCombination,
        InvalidRequest,
        InvalidVersionNumber,
        ResourceInUse,
        Service,
        ServiceUnavailable,
    },
} = .{};
pub const list_component_build_versions: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/ListComponentBuildVersions",
        .success_code = 200,
    };

    action_name: []const u8 = "ListComponentBuildVersions",
    Request: type = struct {
        component_version_arn: []const u8,
        max_results: ?i64 = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .component_version_arn = "componentVersionArn",
                .max_results = "maxResults",
                .next_token = "nextToken",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_component_build_versions) } {
            return .{ .service_metadata = service_metadata, .action = list_component_build_versions };
        }
    },
    Response: type = struct {
        request_id: ?[]const u8 = null,
        component_summary_list: ?[]struct {
            arn: ?[]const u8 = null,
            name: ?[]const u8 = null,
            version: ?[]const u8 = null,
            platform: ?[]const u8 = null,
            supported_os_versions: ?[][]const u8 = null,
            type: ?[]const u8 = null,
            owner: ?[]const u8 = null,
            description: ?[]const u8 = null,
            change_description: ?[]const u8 = null,
            date_created: ?[]const u8 = null,
            tags: ?[]struct {
                key: ?[]const u8 = null,
                value: ?[]const u8 = null,
            } = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .arn = "arn",
                    .name = "name",
                    .version = "version",
                    .platform = "platform",
                    .supported_os_versions = "supportedOsVersions",
                    .type = "type",
                    .owner = "owner",
                    .description = "description",
                    .change_description = "changeDescription",
                    .date_created = "dateCreated",
                    .tags = "tags",
                };
                return @field(mappings, field_name);
            }

            pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
                if (std.mem.eql(u8, "tags", field_name))
                    return try serializeMap(self.tags, self.fieldNameFor("tags"), options, out_stream);
                return false;
            }
        } = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .request_id = "requestId",
                .component_summary_list = "componentSummaryList",
                .next_token = "nextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        CallRateLimitExceeded,
        Client,
        Forbidden,
        InvalidPaginationToken,
        InvalidRequest,
        Service,
        ServiceUnavailable,
    },
} = .{};
pub const list_components: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/ListComponents",
        .success_code = 200,
    };

    action_name: []const u8 = "ListComponents",
    Request: type = struct {
        owner: ?[]const u8 = null,
        filters: ?[]Filter = null,
        by_name: ?bool = null,
        max_results: ?i64 = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .owner = "owner",
                .filters = "filters",
                .by_name = "byName",
                .max_results = "maxResults",
                .next_token = "nextToken",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_components) } {
            return .{ .service_metadata = service_metadata, .action = list_components };
        }
    },
    Response: type = struct {
        request_id: ?[]const u8 = null,
        component_version_list: ?[]struct {
            arn: ?[]const u8 = null,
            name: ?[]const u8 = null,
            version: ?[]const u8 = null,
            description: ?[]const u8 = null,
            platform: ?[]const u8 = null,
            supported_os_versions: ?[][]const u8 = null,
            type: ?[]const u8 = null,
            owner: ?[]const u8 = null,
            date_created: ?[]const u8 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .arn = "arn",
                    .name = "name",
                    .version = "version",
                    .description = "description",
                    .platform = "platform",
                    .supported_os_versions = "supportedOsVersions",
                    .type = "type",
                    .owner = "owner",
                    .date_created = "dateCreated",
                };
                return @field(mappings, field_name);
            }
        } = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .request_id = "requestId",
                .component_version_list = "componentVersionList",
                .next_token = "nextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        CallRateLimitExceeded,
        Client,
        Forbidden,
        InvalidPaginationToken,
        InvalidRequest,
        Service,
        ServiceUnavailable,
    },
} = .{};
pub const list_container_recipes: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/ListContainerRecipes",
        .success_code = 200,
    };

    action_name: []const u8 = "ListContainerRecipes",
    Request: type = struct {
        owner: ?[]const u8 = null,
        filters: ?[]Filter = null,
        max_results: ?i64 = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .owner = "owner",
                .filters = "filters",
                .max_results = "maxResults",
                .next_token = "nextToken",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_container_recipes) } {
            return .{ .service_metadata = service_metadata, .action = list_container_recipes };
        }
    },
    Response: type = struct {
        request_id: ?[]const u8 = null,
        container_recipe_summary_list: ?[]struct {
            arn: ?[]const u8 = null,
            container_type: ?[]const u8 = null,
            name: ?[]const u8 = null,
            platform: ?[]const u8 = null,
            owner: ?[]const u8 = null,
            parent_image: ?[]const u8 = null,
            date_created: ?[]const u8 = null,
            tags: ?[]struct {
                key: ?[]const u8 = null,
                value: ?[]const u8 = null,
            } = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .arn = "arn",
                    .container_type = "containerType",
                    .name = "name",
                    .platform = "platform",
                    .owner = "owner",
                    .parent_image = "parentImage",
                    .date_created = "dateCreated",
                    .tags = "tags",
                };
                return @field(mappings, field_name);
            }

            pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
                if (std.mem.eql(u8, "tags", field_name))
                    return try serializeMap(self.tags, self.fieldNameFor("tags"), options, out_stream);
                return false;
            }
        } = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .request_id = "requestId",
                .container_recipe_summary_list = "containerRecipeSummaryList",
                .next_token = "nextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        CallRateLimitExceeded,
        Client,
        Forbidden,
        InvalidPaginationToken,
        InvalidRequest,
        Service,
        ServiceUnavailable,
    },
} = .{};
pub const list_distribution_configurations: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/ListDistributionConfigurations",
        .success_code = 200,
    };

    action_name: []const u8 = "ListDistributionConfigurations",
    Request: type = struct {
        filters: ?[]Filter = null,
        max_results: ?i64 = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .filters = "filters",
                .max_results = "maxResults",
                .next_token = "nextToken",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_distribution_configurations) } {
            return .{ .service_metadata = service_metadata, .action = list_distribution_configurations };
        }
    },
    Response: type = struct {
        request_id: ?[]const u8 = null,
        distribution_configuration_summary_list: ?[]struct {
            arn: ?[]const u8 = null,
            name: ?[]const u8 = null,
            description: ?[]const u8 = null,
            date_created: ?[]const u8 = null,
            date_updated: ?[]const u8 = null,
            tags: ?[]struct {
                key: ?[]const u8 = null,
                value: ?[]const u8 = null,
            } = null,
            regions: ?[][]const u8 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .arn = "arn",
                    .name = "name",
                    .description = "description",
                    .date_created = "dateCreated",
                    .date_updated = "dateUpdated",
                    .tags = "tags",
                    .regions = "regions",
                };
                return @field(mappings, field_name);
            }

            pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
                if (std.mem.eql(u8, "tags", field_name))
                    return try serializeMap(self.tags, self.fieldNameFor("tags"), options, out_stream);
                return false;
            }
        } = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .request_id = "requestId",
                .distribution_configuration_summary_list = "distributionConfigurationSummaryList",
                .next_token = "nextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        CallRateLimitExceeded,
        Client,
        Forbidden,
        InvalidPaginationToken,
        InvalidRequest,
        Service,
        ServiceUnavailable,
    },
} = .{};
pub const list_image_build_versions: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/ListImageBuildVersions",
        .success_code = 200,
    };

    action_name: []const u8 = "ListImageBuildVersions",
    Request: type = struct {
        image_version_arn: []const u8,
        filters: ?[]Filter = null,
        max_results: ?i64 = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .image_version_arn = "imageVersionArn",
                .filters = "filters",
                .max_results = "maxResults",
                .next_token = "nextToken",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_image_build_versions) } {
            return .{ .service_metadata = service_metadata, .action = list_image_build_versions };
        }
    },
    Response: type = struct {
        request_id: ?[]const u8 = null,
        image_summary_list: ?[]ImageSummary = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .request_id = "requestId",
                .image_summary_list = "imageSummaryList",
                .next_token = "nextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        CallRateLimitExceeded,
        Client,
        Forbidden,
        InvalidPaginationToken,
        InvalidRequest,
        Service,
        ServiceUnavailable,
    },
} = .{};
pub const list_image_packages: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/ListImagePackages",
        .success_code = 200,
    };

    action_name: []const u8 = "ListImagePackages",
    Request: type = struct {
        image_build_version_arn: []const u8,
        max_results: ?i64 = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .image_build_version_arn = "imageBuildVersionArn",
                .max_results = "maxResults",
                .next_token = "nextToken",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_image_packages) } {
            return .{ .service_metadata = service_metadata, .action = list_image_packages };
        }
    },
    Response: type = struct {
        request_id: ?[]const u8 = null,
        image_package_list: ?[]struct {
            package_name: ?[]const u8 = null,
            package_version: ?[]const u8 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .package_name = "packageName",
                    .package_version = "packageVersion",
                };
                return @field(mappings, field_name);
            }
        } = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .request_id = "requestId",
                .image_package_list = "imagePackageList",
                .next_token = "nextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        CallRateLimitExceeded,
        Client,
        Forbidden,
        InvalidPaginationToken,
        InvalidRequest,
        ResourceNotFound,
        Service,
        ServiceUnavailable,
    },
} = .{};
pub const list_image_pipeline_images: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/ListImagePipelineImages",
        .success_code = 200,
    };

    action_name: []const u8 = "ListImagePipelineImages",
    Request: type = struct {
        image_pipeline_arn: []const u8,
        filters: ?[]Filter = null,
        max_results: ?i64 = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .image_pipeline_arn = "imagePipelineArn",
                .filters = "filters",
                .max_results = "maxResults",
                .next_token = "nextToken",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_image_pipeline_images) } {
            return .{ .service_metadata = service_metadata, .action = list_image_pipeline_images };
        }
    },
    Response: type = struct {
        request_id: ?[]const u8 = null,
        image_summary_list: ?[]ImageSummary = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .request_id = "requestId",
                .image_summary_list = "imageSummaryList",
                .next_token = "nextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        CallRateLimitExceeded,
        Client,
        Forbidden,
        InvalidPaginationToken,
        InvalidRequest,
        ResourceNotFound,
        Service,
        ServiceUnavailable,
    },
} = .{};
pub const list_image_pipelines: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/ListImagePipelines",
        .success_code = 200,
    };

    action_name: []const u8 = "ListImagePipelines",
    Request: type = struct {
        filters: ?[]Filter = null,
        max_results: ?i64 = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .filters = "filters",
                .max_results = "maxResults",
                .next_token = "nextToken",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_image_pipelines) } {
            return .{ .service_metadata = service_metadata, .action = list_image_pipelines };
        }
    },
    Response: type = struct {
        request_id: ?[]const u8 = null,
        image_pipeline_list: ?[]ImagePipeline = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .request_id = "requestId",
                .image_pipeline_list = "imagePipelineList",
                .next_token = "nextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        CallRateLimitExceeded,
        Client,
        Forbidden,
        InvalidPaginationToken,
        InvalidRequest,
        Service,
        ServiceUnavailable,
    },
} = .{};
pub const list_image_recipes: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/ListImageRecipes",
        .success_code = 200,
    };

    action_name: []const u8 = "ListImageRecipes",
    Request: type = struct {
        owner: ?[]const u8 = null,
        filters: ?[]Filter = null,
        max_results: ?i64 = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .owner = "owner",
                .filters = "filters",
                .max_results = "maxResults",
                .next_token = "nextToken",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_image_recipes) } {
            return .{ .service_metadata = service_metadata, .action = list_image_recipes };
        }
    },
    Response: type = struct {
        request_id: ?[]const u8 = null,
        image_recipe_summary_list: ?[]struct {
            arn: ?[]const u8 = null,
            name: ?[]const u8 = null,
            platform: ?[]const u8 = null,
            owner: ?[]const u8 = null,
            parent_image: ?[]const u8 = null,
            date_created: ?[]const u8 = null,
            tags: ?[]struct {
                key: ?[]const u8 = null,
                value: ?[]const u8 = null,
            } = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .arn = "arn",
                    .name = "name",
                    .platform = "platform",
                    .owner = "owner",
                    .parent_image = "parentImage",
                    .date_created = "dateCreated",
                    .tags = "tags",
                };
                return @field(mappings, field_name);
            }

            pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
                if (std.mem.eql(u8, "tags", field_name))
                    return try serializeMap(self.tags, self.fieldNameFor("tags"), options, out_stream);
                return false;
            }
        } = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .request_id = "requestId",
                .image_recipe_summary_list = "imageRecipeSummaryList",
                .next_token = "nextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        CallRateLimitExceeded,
        Client,
        Forbidden,
        InvalidPaginationToken,
        InvalidRequest,
        Service,
        ServiceUnavailable,
    },
} = .{};
pub const list_images: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/ListImages",
        .success_code = 200,
    };

    action_name: []const u8 = "ListImages",
    Request: type = struct {
        owner: ?[]const u8 = null,
        filters: ?[]Filter = null,
        by_name: ?bool = null,
        max_results: ?i64 = null,
        next_token: ?[]const u8 = null,
        include_deprecated: ?bool = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .owner = "owner",
                .filters = "filters",
                .by_name = "byName",
                .max_results = "maxResults",
                .next_token = "nextToken",
                .include_deprecated = "includeDeprecated",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_images) } {
            return .{ .service_metadata = service_metadata, .action = list_images };
        }
    },
    Response: type = struct {
        request_id: ?[]const u8 = null,
        image_version_list: ?[]struct {
            arn: ?[]const u8 = null,
            name: ?[]const u8 = null,
            type: ?[]const u8 = null,
            version: ?[]const u8 = null,
            platform: ?[]const u8 = null,
            os_version: ?[]const u8 = null,
            owner: ?[]const u8 = null,
            date_created: ?[]const u8 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .arn = "arn",
                    .name = "name",
                    .type = "type",
                    .version = "version",
                    .platform = "platform",
                    .os_version = "osVersion",
                    .owner = "owner",
                    .date_created = "dateCreated",
                };
                return @field(mappings, field_name);
            }
        } = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .request_id = "requestId",
                .image_version_list = "imageVersionList",
                .next_token = "nextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        CallRateLimitExceeded,
        Client,
        Forbidden,
        InvalidPaginationToken,
        InvalidRequest,
        Service,
        ServiceUnavailable,
    },
} = .{};
pub const list_infrastructure_configurations: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/ListInfrastructureConfigurations",
        .success_code = 200,
    };

    action_name: []const u8 = "ListInfrastructureConfigurations",
    Request: type = struct {
        filters: ?[]Filter = null,
        max_results: ?i64 = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .filters = "filters",
                .max_results = "maxResults",
                .next_token = "nextToken",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_infrastructure_configurations) } {
            return .{ .service_metadata = service_metadata, .action = list_infrastructure_configurations };
        }
    },
    Response: type = struct {
        request_id: ?[]const u8 = null,
        infrastructure_configuration_summary_list: ?[]struct {
            arn: ?[]const u8 = null,
            name: ?[]const u8 = null,
            description: ?[]const u8 = null,
            date_created: ?[]const u8 = null,
            date_updated: ?[]const u8 = null,
            resource_tags: ?[]struct {
                key: ?[]const u8 = null,
                value: ?[]const u8 = null,
            } = null,
            tags: ?[]struct {
                key: ?[]const u8 = null,
                value: ?[]const u8 = null,
            } = null,
            instance_types: ?[][]const u8 = null,
            instance_profile_name: ?[]const u8 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .arn = "arn",
                    .name = "name",
                    .description = "description",
                    .date_created = "dateCreated",
                    .date_updated = "dateUpdated",
                    .resource_tags = "resourceTags",
                    .tags = "tags",
                    .instance_types = "instanceTypes",
                    .instance_profile_name = "instanceProfileName",
                };
                return @field(mappings, field_name);
            }

            pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
                if (std.mem.eql(u8, "resource_tags", field_name))
                    return try serializeMap(self.resource_tags, self.fieldNameFor("resource_tags"), options, out_stream);
                if (std.mem.eql(u8, "tags", field_name))
                    return try serializeMap(self.tags, self.fieldNameFor("tags"), options, out_stream);
                return false;
            }
        } = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .request_id = "requestId",
                .infrastructure_configuration_summary_list = "infrastructureConfigurationSummaryList",
                .next_token = "nextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        CallRateLimitExceeded,
        Client,
        Forbidden,
        InvalidPaginationToken,
        InvalidRequest,
        Service,
        ServiceUnavailable,
    },
} = .{};
pub const list_tags_for_resource: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/tags/{resourceArn}",
        .success_code = 200,
    };

    action_name: []const u8 = "ListTagsForResource",
    Request: type = struct {
        resource_arn: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .resource_arn = "resourceArn",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_tags_for_resource) } {
            return .{ .service_metadata = service_metadata, .action = list_tags_for_resource };
        }
    },
    Response: type = struct {
        tags: ?[]struct {
            key: ?[]const u8 = null,
            value: ?[]const u8 = null,
        } = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .tags = "tags",
            };
            return @field(mappings, field_name);
        }

        pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
            if (std.mem.eql(u8, "tags", field_name))
                return try serializeMap(self.tags, self.fieldNameFor("tags"), options, out_stream);
            return false;
        }
    },
    ServiceError: type = error{
        InvalidParameter,
        ResourceNotFound,
        Service,
    },
} = .{};
pub const put_component_policy: struct {
    pub const http_config = .{
        .method = "PUT",
        .uri = "/PutComponentPolicy",
        .success_code = 200,
    };

    action_name: []const u8 = "PutComponentPolicy",
    Request: type = struct {
        component_arn: []const u8,
        policy: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .component_arn = "componentArn",
                .policy = "policy",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(put_component_policy) } {
            return .{ .service_metadata = service_metadata, .action = put_component_policy };
        }
    },
    Response: type = struct {
        request_id: ?[]const u8 = null,
        component_arn: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .request_id = "requestId",
                .component_arn = "componentArn",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        CallRateLimitExceeded,
        Client,
        Forbidden,
        InvalidParameterValue,
        InvalidRequest,
        ResourceNotFound,
        Service,
        ServiceUnavailable,
    },
} = .{};
pub const put_container_recipe_policy: struct {
    pub const http_config = .{
        .method = "PUT",
        .uri = "/PutContainerRecipePolicy",
        .success_code = 200,
    };

    action_name: []const u8 = "PutContainerRecipePolicy",
    Request: type = struct {
        container_recipe_arn: []const u8,
        policy: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .container_recipe_arn = "containerRecipeArn",
                .policy = "policy",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(put_container_recipe_policy) } {
            return .{ .service_metadata = service_metadata, .action = put_container_recipe_policy };
        }
    },
    Response: type = struct {
        request_id: ?[]const u8 = null,
        container_recipe_arn: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .request_id = "requestId",
                .container_recipe_arn = "containerRecipeArn",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        CallRateLimitExceeded,
        Client,
        Forbidden,
        InvalidParameterValue,
        InvalidRequest,
        ResourceNotFound,
        Service,
        ServiceUnavailable,
    },
} = .{};
pub const put_image_policy: struct {
    pub const http_config = .{
        .method = "PUT",
        .uri = "/PutImagePolicy",
        .success_code = 200,
    };

    action_name: []const u8 = "PutImagePolicy",
    Request: type = struct {
        image_arn: []const u8,
        policy: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .image_arn = "imageArn",
                .policy = "policy",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(put_image_policy) } {
            return .{ .service_metadata = service_metadata, .action = put_image_policy };
        }
    },
    Response: type = struct {
        request_id: ?[]const u8 = null,
        image_arn: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .request_id = "requestId",
                .image_arn = "imageArn",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        CallRateLimitExceeded,
        Client,
        Forbidden,
        InvalidParameterValue,
        InvalidRequest,
        ResourceNotFound,
        Service,
        ServiceUnavailable,
    },
} = .{};
pub const put_image_recipe_policy: struct {
    pub const http_config = .{
        .method = "PUT",
        .uri = "/PutImageRecipePolicy",
        .success_code = 200,
    };

    action_name: []const u8 = "PutImageRecipePolicy",
    Request: type = struct {
        image_recipe_arn: []const u8,
        policy: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .image_recipe_arn = "imageRecipeArn",
                .policy = "policy",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(put_image_recipe_policy) } {
            return .{ .service_metadata = service_metadata, .action = put_image_recipe_policy };
        }
    },
    Response: type = struct {
        request_id: ?[]const u8 = null,
        image_recipe_arn: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .request_id = "requestId",
                .image_recipe_arn = "imageRecipeArn",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        CallRateLimitExceeded,
        Client,
        Forbidden,
        InvalidParameterValue,
        InvalidRequest,
        ResourceNotFound,
        Service,
        ServiceUnavailable,
    },
} = .{};
pub const start_image_pipeline_execution: struct {
    pub const http_config = .{
        .method = "PUT",
        .uri = "/StartImagePipelineExecution",
        .success_code = 200,
    };

    action_name: []const u8 = "StartImagePipelineExecution",
    Request: type = struct {
        image_pipeline_arn: []const u8,
        client_token: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .image_pipeline_arn = "imagePipelineArn",
                .client_token = "clientToken",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(start_image_pipeline_execution) } {
            return .{ .service_metadata = service_metadata, .action = start_image_pipeline_execution };
        }
    },
    Response: type = struct {
        request_id: ?[]const u8 = null,
        client_token: ?[]const u8 = null,
        image_build_version_arn: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .request_id = "requestId",
                .client_token = "clientToken",
                .image_build_version_arn = "imageBuildVersionArn",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        CallRateLimitExceeded,
        Client,
        Forbidden,
        IdempotentParameterMismatch,
        InvalidRequest,
        ResourceInUse,
        ResourceNotFound,
        Service,
        ServiceUnavailable,
    },
} = .{};
pub const tag_resource: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/tags/{resourceArn}",
        .success_code = 200,
    };

    action_name: []const u8 = "TagResource",
    Request: type = struct {
        resource_arn: []const u8,
        tags: []struct {
            key: ?[]const u8 = null,
            value: ?[]const u8 = null,
        },

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .resource_arn = "resourceArn",
                .tags = "tags",
            };
            return @field(mappings, field_name);
        }

        pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
            if (std.mem.eql(u8, "tags", field_name))
                return try serializeMap(self.tags, self.fieldNameFor("tags"), options, out_stream);
            return false;
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(tag_resource) } {
            return .{ .service_metadata = service_metadata, .action = tag_resource };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InvalidParameter,
        ResourceNotFound,
        Service,
    },
} = .{};
pub const untag_resource: struct {
    pub const http_config = .{
        .method = "DELETE",
        .uri = "/tags/{resourceArn}",
        .success_code = 200,
    };

    action_name: []const u8 = "UntagResource",
    Request: type = struct {
        resource_arn: []const u8,
        tag_keys: [][]const u8,

        pub const http_query = .{
            .tag_keys = "tagKeys",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .resource_arn = "resourceArn",
                .tag_keys = "tagKeys",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(untag_resource) } {
            return .{ .service_metadata = service_metadata, .action = untag_resource };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InvalidParameter,
        ResourceNotFound,
        Service,
    },
} = .{};
pub const update_distribution_configuration: struct {
    pub const http_config = .{
        .method = "PUT",
        .uri = "/UpdateDistributionConfiguration",
        .success_code = 200,
    };

    action_name: []const u8 = "UpdateDistributionConfiguration",
    Request: type = struct {
        distribution_configuration_arn: []const u8,
        description: ?[]const u8 = null,
        distributions: []Distribution,
        client_token: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .distribution_configuration_arn = "distributionConfigurationArn",
                .description = "description",
                .distributions = "distributions",
                .client_token = "clientToken",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(update_distribution_configuration) } {
            return .{ .service_metadata = service_metadata, .action = update_distribution_configuration };
        }
    },
    Response: type = struct {
        request_id: ?[]const u8 = null,
        client_token: ?[]const u8 = null,
        distribution_configuration_arn: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .request_id = "requestId",
                .client_token = "clientToken",
                .distribution_configuration_arn = "distributionConfigurationArn",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        CallRateLimitExceeded,
        Client,
        Forbidden,
        IdempotentParameterMismatch,
        InvalidParameterCombination,
        InvalidRequest,
        ResourceInUse,
        Service,
        ServiceUnavailable,
    },
} = .{};
pub const update_image_pipeline: struct {
    pub const http_config = .{
        .method = "PUT",
        .uri = "/UpdateImagePipeline",
        .success_code = 200,
    };

    action_name: []const u8 = "UpdateImagePipeline",
    Request: type = struct {
        image_pipeline_arn: []const u8,
        description: ?[]const u8 = null,
        image_recipe_arn: ?[]const u8 = null,
        container_recipe_arn: ?[]const u8 = null,
        infrastructure_configuration_arn: []const u8,
        distribution_configuration_arn: ?[]const u8 = null,
        image_tests_configuration: ?ImageTestsConfiguration = null,
        enhanced_image_metadata_enabled: ?bool = null,
        schedule: ?Schedule = null,
        status: ?[]const u8 = null,
        client_token: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .image_pipeline_arn = "imagePipelineArn",
                .description = "description",
                .image_recipe_arn = "imageRecipeArn",
                .container_recipe_arn = "containerRecipeArn",
                .infrastructure_configuration_arn = "infrastructureConfigurationArn",
                .distribution_configuration_arn = "distributionConfigurationArn",
                .image_tests_configuration = "imageTestsConfiguration",
                .enhanced_image_metadata_enabled = "enhancedImageMetadataEnabled",
                .schedule = "schedule",
                .status = "status",
                .client_token = "clientToken",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(update_image_pipeline) } {
            return .{ .service_metadata = service_metadata, .action = update_image_pipeline };
        }
    },
    Response: type = struct {
        request_id: ?[]const u8 = null,
        client_token: ?[]const u8 = null,
        image_pipeline_arn: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .request_id = "requestId",
                .client_token = "clientToken",
                .image_pipeline_arn = "imagePipelineArn",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        CallRateLimitExceeded,
        Client,
        Forbidden,
        IdempotentParameterMismatch,
        InvalidRequest,
        ResourceInUse,
        Service,
        ServiceUnavailable,
    },
} = .{};
pub const update_infrastructure_configuration: struct {
    pub const http_config = .{
        .method = "PUT",
        .uri = "/UpdateInfrastructureConfiguration",
        .success_code = 200,
    };

    action_name: []const u8 = "UpdateInfrastructureConfiguration",
    Request: type = struct {
        infrastructure_configuration_arn: []const u8,
        description: ?[]const u8 = null,
        instance_types: ?[][]const u8 = null,
        instance_profile_name: []const u8,
        security_group_ids: ?[][]const u8 = null,
        subnet_id: ?[]const u8 = null,
        logging: ?Logging = null,
        key_pair: ?[]const u8 = null,
        terminate_instance_on_failure: ?bool = null,
        sns_topic_arn: ?[]const u8 = null,
        client_token: []const u8,
        resource_tags: ?[]struct {
            key: ?[]const u8 = null,
            value: ?[]const u8 = null,
        } = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .infrastructure_configuration_arn = "infrastructureConfigurationArn",
                .description = "description",
                .instance_types = "instanceTypes",
                .instance_profile_name = "instanceProfileName",
                .security_group_ids = "securityGroupIds",
                .subnet_id = "subnetId",
                .logging = "logging",
                .key_pair = "keyPair",
                .terminate_instance_on_failure = "terminateInstanceOnFailure",
                .sns_topic_arn = "snsTopicArn",
                .client_token = "clientToken",
                .resource_tags = "resourceTags",
            };
            return @field(mappings, field_name);
        }

        pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
            if (std.mem.eql(u8, "resource_tags", field_name))
                return try serializeMap(self.resource_tags, self.fieldNameFor("resource_tags"), options, out_stream);
            return false;
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(update_infrastructure_configuration) } {
            return .{ .service_metadata = service_metadata, .action = update_infrastructure_configuration };
        }
    },
    Response: type = struct {
        request_id: ?[]const u8 = null,
        client_token: ?[]const u8 = null,
        infrastructure_configuration_arn: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .request_id = "requestId",
                .client_token = "clientToken",
                .infrastructure_configuration_arn = "infrastructureConfigurationArn",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        CallRateLimitExceeded,
        Client,
        Forbidden,
        IdempotentParameterMismatch,
        InvalidRequest,
        ResourceInUse,
        Service,
        ServiceUnavailable,
    },
} = .{};

pub const Logging = struct {
    s3_logs: ?S3Logs = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .s3_logs = "s3Logs",
        };
        return @field(mappings, field_name);
    }
};

pub const S3Logs = struct {
    s3_bucket_name: ?[]const u8 = null,
    s3_key_prefix: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .s3_bucket_name = "s3BucketName",
            .s3_key_prefix = "s3KeyPrefix",
        };
        return @field(mappings, field_name);
    }
};

pub const Schedule = struct {
    schedule_expression: ?[]const u8 = null,
    timezone: ?[]const u8 = null,
    pipeline_execution_start_condition: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .schedule_expression = "scheduleExpression",
            .timezone = "timezone",
            .pipeline_execution_start_condition = "pipelineExecutionStartCondition",
        };
        return @field(mappings, field_name);
    }
};

pub const ImageTestsConfiguration = struct {
    image_tests_enabled: ?bool = null,
    timeout_minutes: ?i64 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .image_tests_enabled = "imageTestsEnabled",
            .timeout_minutes = "timeoutMinutes",
        };
        return @field(mappings, field_name);
    }
};

pub const Distribution = struct {
    region: []const u8,
    ami_distribution_configuration: ?AmiDistributionConfiguration = null,
    container_distribution_configuration: ?ContainerDistributionConfiguration = null,
    license_configuration_arns: ?[][]const u8 = null,
    launch_template_configurations: ?[]LaunchTemplateConfiguration = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .region = "region",
            .ami_distribution_configuration = "amiDistributionConfiguration",
            .container_distribution_configuration = "containerDistributionConfiguration",
            .license_configuration_arns = "licenseConfigurationArns",
            .launch_template_configurations = "launchTemplateConfigurations",
        };
        return @field(mappings, field_name);
    }
};

pub const LaunchTemplateConfiguration = struct {
    launch_template_id: []const u8,
    account_id: ?[]const u8 = null,
    set_default_version: ?bool = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .launch_template_id = "launchTemplateId",
            .account_id = "accountId",
            .set_default_version = "setDefaultVersion",
        };
        return @field(mappings, field_name);
    }
};

pub const ContainerDistributionConfiguration = struct {
    description: ?[]const u8 = null,
    container_tags: ?[][]const u8 = null,
    target_repository: TargetContainerRepository,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .description = "description",
            .container_tags = "containerTags",
            .target_repository = "targetRepository",
        };
        return @field(mappings, field_name);
    }
};

pub const TargetContainerRepository = struct {
    service: []const u8,
    repository_name: []const u8,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .service = "service",
            .repository_name = "repositoryName",
        };
        return @field(mappings, field_name);
    }
};

pub const AmiDistributionConfiguration = struct {
    name: ?[]const u8 = null,
    description: ?[]const u8 = null,
    target_account_ids: ?[][]const u8 = null,
    ami_tags: ?[]struct {
        key: ?[]const u8 = null,
        value: ?[]const u8 = null,
    } = null,
    kms_key_id: ?[]const u8 = null,
    launch_permission: ?LaunchPermissionConfiguration = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .name = "name",
            .description = "description",
            .target_account_ids = "targetAccountIds",
            .ami_tags = "amiTags",
            .kms_key_id = "kmsKeyId",
            .launch_permission = "launchPermission",
        };
        return @field(mappings, field_name);
    }

    pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
        if (std.mem.eql(u8, "ami_tags", field_name))
            return try serializeMap(self.ami_tags, self.fieldNameFor("ami_tags"), options, out_stream);
        return false;
    }
};

pub const LaunchPermissionConfiguration = struct {
    user_ids: ?[][]const u8 = null,
    user_groups: ?[][]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .user_ids = "userIds",
            .user_groups = "userGroups",
        };
        return @field(mappings, field_name);
    }
};

pub const Filter = struct {
    name: ?[]const u8 = null,
    values: ?[][]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .name = "name",
            .values = "values",
        };
        return @field(mappings, field_name);
    }
};

pub const ImagePipeline = struct {
    arn: ?[]const u8 = null,
    name: ?[]const u8 = null,
    description: ?[]const u8 = null,
    platform: ?[]const u8 = null,
    enhanced_image_metadata_enabled: ?bool = null,
    image_recipe_arn: ?[]const u8 = null,
    container_recipe_arn: ?[]const u8 = null,
    infrastructure_configuration_arn: ?[]const u8 = null,
    distribution_configuration_arn: ?[]const u8 = null,
    image_tests_configuration: ?ImageTestsConfiguration = null,
    schedule: ?Schedule = null,
    status: ?[]const u8 = null,
    date_created: ?[]const u8 = null,
    date_updated: ?[]const u8 = null,
    date_last_run: ?[]const u8 = null,
    date_next_run: ?[]const u8 = null,
    tags: ?[]struct {
        key: ?[]const u8 = null,
        value: ?[]const u8 = null,
    } = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .arn = "arn",
            .name = "name",
            .description = "description",
            .platform = "platform",
            .enhanced_image_metadata_enabled = "enhancedImageMetadataEnabled",
            .image_recipe_arn = "imageRecipeArn",
            .container_recipe_arn = "containerRecipeArn",
            .infrastructure_configuration_arn = "infrastructureConfigurationArn",
            .distribution_configuration_arn = "distributionConfigurationArn",
            .image_tests_configuration = "imageTestsConfiguration",
            .schedule = "schedule",
            .status = "status",
            .date_created = "dateCreated",
            .date_updated = "dateUpdated",
            .date_last_run = "dateLastRun",
            .date_next_run = "dateNextRun",
            .tags = "tags",
        };
        return @field(mappings, field_name);
    }

    pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
        if (std.mem.eql(u8, "tags", field_name))
            return try serializeMap(self.tags, self.fieldNameFor("tags"), options, out_stream);
        return false;
    }
};

pub const ImageSummary = struct {
    arn: ?[]const u8 = null,
    name: ?[]const u8 = null,
    type: ?[]const u8 = null,
    version: ?[]const u8 = null,
    platform: ?[]const u8 = null,
    os_version: ?[]const u8 = null,
    state: ?ImageState = null,
    owner: ?[]const u8 = null,
    date_created: ?[]const u8 = null,
    output_resources: ?OutputResources = null,
    tags: ?[]struct {
        key: ?[]const u8 = null,
        value: ?[]const u8 = null,
    } = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .arn = "arn",
            .name = "name",
            .type = "type",
            .version = "version",
            .platform = "platform",
            .os_version = "osVersion",
            .state = "state",
            .owner = "owner",
            .date_created = "dateCreated",
            .output_resources = "outputResources",
            .tags = "tags",
        };
        return @field(mappings, field_name);
    }

    pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
        if (std.mem.eql(u8, "tags", field_name))
            return try serializeMap(self.tags, self.fieldNameFor("tags"), options, out_stream);
        return false;
    }
};

pub const OutputResources = struct {
    amis: ?[]Ami = null,
    containers: ?[]Container = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .amis = "amis",
            .containers = "containers",
        };
        return @field(mappings, field_name);
    }
};

pub const Container = struct {
    region: ?[]const u8 = null,
    image_uris: ?[][]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .region = "region",
            .image_uris = "imageUris",
        };
        return @field(mappings, field_name);
    }
};

pub const Ami = struct {
    region: ?[]const u8 = null,
    image: ?[]const u8 = null,
    name: ?[]const u8 = null,
    description: ?[]const u8 = null,
    state: ?ImageState = null,
    account_id: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .region = "region",
            .image = "image",
            .name = "name",
            .description = "description",
            .state = "state",
            .account_id = "accountId",
        };
        return @field(mappings, field_name);
    }
};

pub const ImageState = struct {
    status: ?[]const u8 = null,
    reason: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .status = "status",
            .reason = "reason",
        };
        return @field(mappings, field_name);
    }
};

pub const InfrastructureConfiguration = struct {
    arn: ?[]const u8 = null,
    name: ?[]const u8 = null,
    description: ?[]const u8 = null,
    instance_types: ?[][]const u8 = null,
    instance_profile_name: ?[]const u8 = null,
    security_group_ids: ?[][]const u8 = null,
    subnet_id: ?[]const u8 = null,
    logging: ?Logging = null,
    key_pair: ?[]const u8 = null,
    terminate_instance_on_failure: ?bool = null,
    sns_topic_arn: ?[]const u8 = null,
    date_created: ?[]const u8 = null,
    date_updated: ?[]const u8 = null,
    resource_tags: ?[]struct {
        key: ?[]const u8 = null,
        value: ?[]const u8 = null,
    } = null,
    tags: ?[]struct {
        key: ?[]const u8 = null,
        value: ?[]const u8 = null,
    } = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .arn = "arn",
            .name = "name",
            .description = "description",
            .instance_types = "instanceTypes",
            .instance_profile_name = "instanceProfileName",
            .security_group_ids = "securityGroupIds",
            .subnet_id = "subnetId",
            .logging = "logging",
            .key_pair = "keyPair",
            .terminate_instance_on_failure = "terminateInstanceOnFailure",
            .sns_topic_arn = "snsTopicArn",
            .date_created = "dateCreated",
            .date_updated = "dateUpdated",
            .resource_tags = "resourceTags",
            .tags = "tags",
        };
        return @field(mappings, field_name);
    }

    pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
        if (std.mem.eql(u8, "resource_tags", field_name))
            return try serializeMap(self.resource_tags, self.fieldNameFor("resource_tags"), options, out_stream);
        if (std.mem.eql(u8, "tags", field_name))
            return try serializeMap(self.tags, self.fieldNameFor("tags"), options, out_stream);
        return false;
    }
};

pub const ImageRecipe = struct {
    arn: ?[]const u8 = null,
    type: ?[]const u8 = null,
    name: ?[]const u8 = null,
    description: ?[]const u8 = null,
    platform: ?[]const u8 = null,
    owner: ?[]const u8 = null,
    version: ?[]const u8 = null,
    components: ?[]ComponentConfiguration = null,
    parent_image: ?[]const u8 = null,
    block_device_mappings: ?[]InstanceBlockDeviceMapping = null,
    date_created: ?[]const u8 = null,
    tags: ?[]struct {
        key: ?[]const u8 = null,
        value: ?[]const u8 = null,
    } = null,
    working_directory: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .arn = "arn",
            .type = "type",
            .name = "name",
            .description = "description",
            .platform = "platform",
            .owner = "owner",
            .version = "version",
            .components = "components",
            .parent_image = "parentImage",
            .block_device_mappings = "blockDeviceMappings",
            .date_created = "dateCreated",
            .tags = "tags",
            .working_directory = "workingDirectory",
        };
        return @field(mappings, field_name);
    }

    pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
        if (std.mem.eql(u8, "tags", field_name))
            return try serializeMap(self.tags, self.fieldNameFor("tags"), options, out_stream);
        return false;
    }
};

pub const InstanceBlockDeviceMapping = struct {
    device_name: ?[]const u8 = null,
    ebs: ?EbsInstanceBlockDeviceSpecification = null,
    virtual_name: ?[]const u8 = null,
    no_device: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .device_name = "deviceName",
            .ebs = "ebs",
            .virtual_name = "virtualName",
            .no_device = "noDevice",
        };
        return @field(mappings, field_name);
    }
};

pub const EbsInstanceBlockDeviceSpecification = struct {
    encrypted: ?bool = null,
    delete_on_termination: ?bool = null,
    iops: ?i64 = null,
    kms_key_id: ?[]const u8 = null,
    snapshot_id: ?[]const u8 = null,
    volume_size: ?i64 = null,
    volume_type: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .encrypted = "encrypted",
            .delete_on_termination = "deleteOnTermination",
            .iops = "iops",
            .kms_key_id = "kmsKeyId",
            .snapshot_id = "snapshotId",
            .volume_size = "volumeSize",
            .volume_type = "volumeType",
        };
        return @field(mappings, field_name);
    }
};

pub const ComponentConfiguration = struct {
    component_arn: []const u8,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .component_arn = "componentArn",
        };
        return @field(mappings, field_name);
    }
};

pub const DistributionConfiguration = struct {
    arn: ?[]const u8 = null,
    name: ?[]const u8 = null,
    description: ?[]const u8 = null,
    distributions: ?[]Distribution = null,
    timeout_minutes: i64,
    date_created: ?[]const u8 = null,
    date_updated: ?[]const u8 = null,
    tags: ?[]struct {
        key: ?[]const u8 = null,
        value: ?[]const u8 = null,
    } = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .arn = "arn",
            .name = "name",
            .description = "description",
            .distributions = "distributions",
            .timeout_minutes = "timeoutMinutes",
            .date_created = "dateCreated",
            .date_updated = "dateUpdated",
            .tags = "tags",
        };
        return @field(mappings, field_name);
    }

    pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
        if (std.mem.eql(u8, "tags", field_name))
            return try serializeMap(self.tags, self.fieldNameFor("tags"), options, out_stream);
        return false;
    }
};

pub const ContainerRecipe = struct {
    arn: ?[]const u8 = null,
    container_type: ?[]const u8 = null,
    name: ?[]const u8 = null,
    description: ?[]const u8 = null,
    platform: ?[]const u8 = null,
    owner: ?[]const u8 = null,
    version: ?[]const u8 = null,
    components: ?[]ComponentConfiguration = null,
    instance_configuration: ?InstanceConfiguration = null,
    dockerfile_template_data: ?[]const u8 = null,
    kms_key_id: ?[]const u8 = null,
    encrypted: ?bool = null,
    parent_image: ?[]const u8 = null,
    date_created: ?[]const u8 = null,
    tags: ?[]struct {
        key: ?[]const u8 = null,
        value: ?[]const u8 = null,
    } = null,
    working_directory: ?[]const u8 = null,
    target_repository: ?TargetContainerRepository = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .arn = "arn",
            .container_type = "containerType",
            .name = "name",
            .description = "description",
            .platform = "platform",
            .owner = "owner",
            .version = "version",
            .components = "components",
            .instance_configuration = "instanceConfiguration",
            .dockerfile_template_data = "dockerfileTemplateData",
            .kms_key_id = "kmsKeyId",
            .encrypted = "encrypted",
            .parent_image = "parentImage",
            .date_created = "dateCreated",
            .tags = "tags",
            .working_directory = "workingDirectory",
            .target_repository = "targetRepository",
        };
        return @field(mappings, field_name);
    }

    pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
        if (std.mem.eql(u8, "tags", field_name))
            return try serializeMap(self.tags, self.fieldNameFor("tags"), options, out_stream);
        return false;
    }
};

pub const InstanceConfiguration = struct {
    image: ?[]const u8 = null,
    block_device_mappings: ?[]InstanceBlockDeviceMapping = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .image = "image",
            .block_device_mappings = "blockDeviceMappings",
        };
        return @field(mappings, field_name);
    }
};
