const std = @import("std");
const serializeMap = @import("json.zig").serializeMap;
const smithy = @import("smithy");

const Self = @This();
pub const version: []const u8 = "2020-11-22";
pub const sdk_id: []const u8 = "IoT Wireless";
pub const arn_namespace: []const u8 = "iotwireless";
pub const endpoint_prefix: []const u8 = "api.iotwireless";
pub const sigv4_name: []const u8 = "iotwireless";
pub const name: []const u8 = "iotwireless";
pub const aws_protocol: smithy.AwsProtocol = smithy.AwsProtocol.rest_json_1;

pub const service_metadata: struct {
    version: []const u8 = "2020-11-22",
    sdk_id: []const u8 = "IoT Wireless",
    arn_namespace: []const u8 = "iotwireless",
    endpoint_prefix: []const u8 = "api.iotwireless",
    sigv4_name: []const u8 = "iotwireless",
    name: []const u8 = "iotwireless",
    aws_protocol: smithy.AwsProtocol = smithy.AwsProtocol.rest_json_1,
} = .{};
pub const associate_aws_account_with_partner_account: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/partner-accounts",
        .success_code = 200,
    };

    action_name: []const u8 = "AssociateAwsAccountWithPartnerAccount",
    Request: type = struct {
        sidewalk: SidewalkAccountInfo,
        client_request_token: ?[]const u8 = null,
        tags: ?[]Tag = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .sidewalk = "Sidewalk",
                .client_request_token = "ClientRequestToken",
                .tags = "Tags",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(associate_aws_account_with_partner_account) } {
            return .{ .service_metadata = service_metadata, .action = associate_aws_account_with_partner_account };
        }
    },
    Response: type = struct {
        sidewalk: ?SidewalkAccountInfo = null,
        arn: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .sidewalk = "Sidewalk",
                .arn = "Arn",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        Conflict,
        InternalServer,
        ResourceNotFound,
        Throttling,
        Validation,
    },
} = .{};
pub const associate_wireless_device_with_thing: struct {
    pub const http_config = .{
        .method = "PUT",
        .uri = "/wireless-devices/{Id}/thing",
        .success_code = 204,
    };

    action_name: []const u8 = "AssociateWirelessDeviceWithThing",
    Request: type = struct {
        id: []const u8,
        thing_arn: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .id = "Id",
                .thing_arn = "ThingArn",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(associate_wireless_device_with_thing) } {
            return .{ .service_metadata = service_metadata, .action = associate_wireless_device_with_thing };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        Conflict,
        InternalServer,
        ResourceNotFound,
        Throttling,
        Validation,
    },
} = .{};
pub const associate_wireless_gateway_with_certificate: struct {
    pub const http_config = .{
        .method = "PUT",
        .uri = "/wireless-gateways/{Id}/certificate",
        .success_code = 200,
    };

    action_name: []const u8 = "AssociateWirelessGatewayWithCertificate",
    Request: type = struct {
        id: []const u8,
        iot_certificate_id: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .id = "Id",
                .iot_certificate_id = "IotCertificateId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(associate_wireless_gateway_with_certificate) } {
            return .{ .service_metadata = service_metadata, .action = associate_wireless_gateway_with_certificate };
        }
    },
    Response: type = struct {
        iot_certificate_id: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .iot_certificate_id = "IotCertificateId",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        Conflict,
        InternalServer,
        ResourceNotFound,
        Throttling,
        Validation,
    },
} = .{};
pub const associate_wireless_gateway_with_thing: struct {
    pub const http_config = .{
        .method = "PUT",
        .uri = "/wireless-gateways/{Id}/thing",
        .success_code = 204,
    };

    action_name: []const u8 = "AssociateWirelessGatewayWithThing",
    Request: type = struct {
        id: []const u8,
        thing_arn: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .id = "Id",
                .thing_arn = "ThingArn",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(associate_wireless_gateway_with_thing) } {
            return .{ .service_metadata = service_metadata, .action = associate_wireless_gateway_with_thing };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        Conflict,
        InternalServer,
        ResourceNotFound,
        Throttling,
        Validation,
    },
} = .{};
pub const create_destination: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/destinations",
        .success_code = 201,
    };

    action_name: []const u8 = "CreateDestination",
    Request: type = struct {
        name: []const u8,
        expression_type: []const u8,
        expression: []const u8,
        description: ?[]const u8 = null,
        role_arn: []const u8,
        tags: ?[]Tag = null,
        client_request_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .name = "Name",
                .expression_type = "ExpressionType",
                .expression = "Expression",
                .description = "Description",
                .role_arn = "RoleArn",
                .tags = "Tags",
                .client_request_token = "ClientRequestToken",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(create_destination) } {
            return .{ .service_metadata = service_metadata, .action = create_destination };
        }
    },
    Response: type = struct {
        arn: ?[]const u8 = null,
        name: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .arn = "Arn",
                .name = "Name",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        Conflict,
        InternalServer,
        ResourceNotFound,
        Throttling,
        Validation,
    },
} = .{};
pub const create_device_profile: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/device-profiles",
        .success_code = 201,
    };

    action_name: []const u8 = "CreateDeviceProfile",
    Request: type = struct {
        name: ?[]const u8 = null,
        lo_ra_wan: ?LoRaWANDeviceProfile = null,
        tags: ?[]Tag = null,
        client_request_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .name = "Name",
                .lo_ra_wan = "LoRaWAN",
                .tags = "Tags",
                .client_request_token = "ClientRequestToken",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(create_device_profile) } {
            return .{ .service_metadata = service_metadata, .action = create_device_profile };
        }
    },
    Response: type = struct {
        arn: ?[]const u8 = null,
        id: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .arn = "Arn",
                .id = "Id",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        Conflict,
        InternalServer,
        Throttling,
        Validation,
    },
} = .{};
pub const create_service_profile: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/service-profiles",
        .success_code = 201,
    };

    action_name: []const u8 = "CreateServiceProfile",
    Request: type = struct {
        name: ?[]const u8 = null,
        lo_ra_wan: ?struct {
            add_gw_metadata: ?bool = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .add_gw_metadata = "AddGwMetadata",
                };
                return @field(mappings, field_name);
            }
        } = null,
        tags: ?[]Tag = null,
        client_request_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .name = "Name",
                .lo_ra_wan = "LoRaWAN",
                .tags = "Tags",
                .client_request_token = "ClientRequestToken",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(create_service_profile) } {
            return .{ .service_metadata = service_metadata, .action = create_service_profile };
        }
    },
    Response: type = struct {
        arn: ?[]const u8 = null,
        id: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .arn = "Arn",
                .id = "Id",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        Conflict,
        InternalServer,
        Throttling,
        Validation,
    },
} = .{};
pub const create_wireless_device: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/wireless-devices",
        .success_code = 201,
    };

    action_name: []const u8 = "CreateWirelessDevice",
    Request: type = struct {
        type: []const u8,
        name: ?[]const u8 = null,
        description: ?[]const u8 = null,
        destination_name: []const u8,
        client_request_token: ?[]const u8 = null,
        lo_ra_wan: ?LoRaWANDevice = null,
        tags: ?[]Tag = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .type = "Type",
                .name = "Name",
                .description = "Description",
                .destination_name = "DestinationName",
                .client_request_token = "ClientRequestToken",
                .lo_ra_wan = "LoRaWAN",
                .tags = "Tags",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(create_wireless_device) } {
            return .{ .service_metadata = service_metadata, .action = create_wireless_device };
        }
    },
    Response: type = struct {
        arn: ?[]const u8 = null,
        id: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .arn = "Arn",
                .id = "Id",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        Conflict,
        InternalServer,
        ResourceNotFound,
        Throttling,
        Validation,
    },
} = .{};
pub const create_wireless_gateway: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/wireless-gateways",
        .success_code = 201,
    };

    action_name: []const u8 = "CreateWirelessGateway",
    Request: type = struct {
        name: ?[]const u8 = null,
        description: ?[]const u8 = null,
        lo_ra_wan: LoRaWANGateway,
        tags: ?[]Tag = null,
        client_request_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .name = "Name",
                .description = "Description",
                .lo_ra_wan = "LoRaWAN",
                .tags = "Tags",
                .client_request_token = "ClientRequestToken",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(create_wireless_gateway) } {
            return .{ .service_metadata = service_metadata, .action = create_wireless_gateway };
        }
    },
    Response: type = struct {
        arn: ?[]const u8 = null,
        id: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .arn = "Arn",
                .id = "Id",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        Conflict,
        InternalServer,
        Throttling,
        Validation,
    },
} = .{};
pub const create_wireless_gateway_task: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/wireless-gateways/{Id}/tasks",
        .success_code = 201,
    };

    action_name: []const u8 = "CreateWirelessGatewayTask",
    Request: type = struct {
        id: []const u8,
        wireless_gateway_task_definition_id: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .id = "Id",
                .wireless_gateway_task_definition_id = "WirelessGatewayTaskDefinitionId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(create_wireless_gateway_task) } {
            return .{ .service_metadata = service_metadata, .action = create_wireless_gateway_task };
        }
    },
    Response: type = struct {
        wireless_gateway_task_definition_id: ?[]const u8 = null,
        status: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .wireless_gateway_task_definition_id = "WirelessGatewayTaskDefinitionId",
                .status = "Status",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        Conflict,
        InternalServer,
        ResourceNotFound,
        Throttling,
        Validation,
    },
} = .{};
pub const create_wireless_gateway_task_definition: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/wireless-gateway-task-definitions",
        .success_code = 201,
    };

    action_name: []const u8 = "CreateWirelessGatewayTaskDefinition",
    Request: type = struct {
        auto_create_tasks: bool,
        name: ?[]const u8 = null,
        update: ?UpdateWirelessGatewayTaskCreate = null,
        client_request_token: ?[]const u8 = null,
        tags: ?[]Tag = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .auto_create_tasks = "AutoCreateTasks",
                .name = "Name",
                .update = "Update",
                .client_request_token = "ClientRequestToken",
                .tags = "Tags",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(create_wireless_gateway_task_definition) } {
            return .{ .service_metadata = service_metadata, .action = create_wireless_gateway_task_definition };
        }
    },
    Response: type = struct {
        id: ?[]const u8 = null,
        arn: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .id = "Id",
                .arn = "Arn",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        Conflict,
        InternalServer,
        ResourceNotFound,
        Throttling,
        Validation,
    },
} = .{};
pub const delete_destination: struct {
    pub const http_config = .{
        .method = "DELETE",
        .uri = "/destinations/{Name}",
        .success_code = 204,
    };

    action_name: []const u8 = "DeleteDestination",
    Request: type = struct {
        name: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .name = "Name",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(delete_destination) } {
            return .{ .service_metadata = service_metadata, .action = delete_destination };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        Conflict,
        InternalServer,
        ResourceNotFound,
        Throttling,
        Validation,
    },
} = .{};
pub const delete_device_profile: struct {
    pub const http_config = .{
        .method = "DELETE",
        .uri = "/device-profiles/{Id}",
        .success_code = 204,
    };

    action_name: []const u8 = "DeleteDeviceProfile",
    Request: type = struct {
        id: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .id = "Id",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(delete_device_profile) } {
            return .{ .service_metadata = service_metadata, .action = delete_device_profile };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        Conflict,
        InternalServer,
        ResourceNotFound,
        Throttling,
        Validation,
    },
} = .{};
pub const delete_service_profile: struct {
    pub const http_config = .{
        .method = "DELETE",
        .uri = "/service-profiles/{Id}",
        .success_code = 204,
    };

    action_name: []const u8 = "DeleteServiceProfile",
    Request: type = struct {
        id: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .id = "Id",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(delete_service_profile) } {
            return .{ .service_metadata = service_metadata, .action = delete_service_profile };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        Conflict,
        InternalServer,
        ResourceNotFound,
        Throttling,
        Validation,
    },
} = .{};
pub const delete_wireless_device: struct {
    pub const http_config = .{
        .method = "DELETE",
        .uri = "/wireless-devices/{Id}",
        .success_code = 204,
    };

    action_name: []const u8 = "DeleteWirelessDevice",
    Request: type = struct {
        id: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .id = "Id",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(delete_wireless_device) } {
            return .{ .service_metadata = service_metadata, .action = delete_wireless_device };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        InternalServer,
        ResourceNotFound,
        Throttling,
        Validation,
    },
} = .{};
pub const delete_wireless_gateway: struct {
    pub const http_config = .{
        .method = "DELETE",
        .uri = "/wireless-gateways/{Id}",
        .success_code = 204,
    };

    action_name: []const u8 = "DeleteWirelessGateway",
    Request: type = struct {
        id: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .id = "Id",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(delete_wireless_gateway) } {
            return .{ .service_metadata = service_metadata, .action = delete_wireless_gateway };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        InternalServer,
        ResourceNotFound,
        Throttling,
        Validation,
    },
} = .{};
pub const delete_wireless_gateway_task: struct {
    pub const http_config = .{
        .method = "DELETE",
        .uri = "/wireless-gateways/{Id}/tasks",
        .success_code = 204,
    };

    action_name: []const u8 = "DeleteWirelessGatewayTask",
    Request: type = struct {
        id: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .id = "Id",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(delete_wireless_gateway_task) } {
            return .{ .service_metadata = service_metadata, .action = delete_wireless_gateway_task };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        InternalServer,
        ResourceNotFound,
        Throttling,
        Validation,
    },
} = .{};
pub const delete_wireless_gateway_task_definition: struct {
    pub const http_config = .{
        .method = "DELETE",
        .uri = "/wireless-gateway-task-definitions/{Id}",
        .success_code = 204,
    };

    action_name: []const u8 = "DeleteWirelessGatewayTaskDefinition",
    Request: type = struct {
        id: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .id = "Id",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(delete_wireless_gateway_task_definition) } {
            return .{ .service_metadata = service_metadata, .action = delete_wireless_gateway_task_definition };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        InternalServer,
        ResourceNotFound,
        Throttling,
        Validation,
    },
} = .{};
pub const disassociate_aws_account_from_partner_account: struct {
    pub const http_config = .{
        .method = "DELETE",
        .uri = "/partner-accounts/{PartnerAccountId}",
        .success_code = 204,
    };

    action_name: []const u8 = "DisassociateAwsAccountFromPartnerAccount",
    Request: type = struct {
        partner_account_id: []const u8,
        partner_type: []const u8,

        pub const http_query = .{
            .partner_type = "partnerType",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .partner_account_id = "PartnerAccountId",
                .partner_type = "PartnerType",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(disassociate_aws_account_from_partner_account) } {
            return .{ .service_metadata = service_metadata, .action = disassociate_aws_account_from_partner_account };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalServer,
        ResourceNotFound,
        Throttling,
        Validation,
    },
} = .{};
pub const disassociate_wireless_device_from_thing: struct {
    pub const http_config = .{
        .method = "DELETE",
        .uri = "/wireless-devices/{Id}/thing",
        .success_code = 204,
    };

    action_name: []const u8 = "DisassociateWirelessDeviceFromThing",
    Request: type = struct {
        id: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .id = "Id",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(disassociate_wireless_device_from_thing) } {
            return .{ .service_metadata = service_metadata, .action = disassociate_wireless_device_from_thing };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        Conflict,
        InternalServer,
        ResourceNotFound,
        Throttling,
        Validation,
    },
} = .{};
pub const disassociate_wireless_gateway_from_certificate: struct {
    pub const http_config = .{
        .method = "DELETE",
        .uri = "/wireless-gateways/{Id}/certificate",
        .success_code = 204,
    };

    action_name: []const u8 = "DisassociateWirelessGatewayFromCertificate",
    Request: type = struct {
        id: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .id = "Id",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(disassociate_wireless_gateway_from_certificate) } {
            return .{ .service_metadata = service_metadata, .action = disassociate_wireless_gateway_from_certificate };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        InternalServer,
        ResourceNotFound,
        Throttling,
        Validation,
    },
} = .{};
pub const disassociate_wireless_gateway_from_thing: struct {
    pub const http_config = .{
        .method = "DELETE",
        .uri = "/wireless-gateways/{Id}/thing",
        .success_code = 204,
    };

    action_name: []const u8 = "DisassociateWirelessGatewayFromThing",
    Request: type = struct {
        id: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .id = "Id",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(disassociate_wireless_gateway_from_thing) } {
            return .{ .service_metadata = service_metadata, .action = disassociate_wireless_gateway_from_thing };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        Conflict,
        InternalServer,
        ResourceNotFound,
        Throttling,
        Validation,
    },
} = .{};
pub const get_destination: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/destinations/{Name}",
        .success_code = 200,
    };

    action_name: []const u8 = "GetDestination",
    Request: type = struct {
        name: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .name = "Name",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(get_destination) } {
            return .{ .service_metadata = service_metadata, .action = get_destination };
        }
    },
    Response: type = struct {
        arn: ?[]const u8 = null,
        name: ?[]const u8 = null,
        expression: ?[]const u8 = null,
        expression_type: ?[]const u8 = null,
        description: ?[]const u8 = null,
        role_arn: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .arn = "Arn",
                .name = "Name",
                .expression = "Expression",
                .expression_type = "ExpressionType",
                .description = "Description",
                .role_arn = "RoleArn",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        InternalServer,
        ResourceNotFound,
        Throttling,
        Validation,
    },
} = .{};
pub const get_device_profile: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/device-profiles/{Id}",
        .success_code = 200,
    };

    action_name: []const u8 = "GetDeviceProfile",
    Request: type = struct {
        id: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .id = "Id",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(get_device_profile) } {
            return .{ .service_metadata = service_metadata, .action = get_device_profile };
        }
    },
    Response: type = struct {
        arn: ?[]const u8 = null,
        name: ?[]const u8 = null,
        id: ?[]const u8 = null,
        lo_ra_wan: ?LoRaWANDeviceProfile = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .arn = "Arn",
                .name = "Name",
                .id = "Id",
                .lo_ra_wan = "LoRaWAN",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        InternalServer,
        ResourceNotFound,
        Throttling,
        Validation,
    },
} = .{};
pub const get_partner_account: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/partner-accounts/{PartnerAccountId}",
        .success_code = 200,
    };

    action_name: []const u8 = "GetPartnerAccount",
    Request: type = struct {
        partner_account_id: []const u8,
        partner_type: []const u8,

        pub const http_query = .{
            .partner_type = "partnerType",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .partner_account_id = "PartnerAccountId",
                .partner_type = "PartnerType",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(get_partner_account) } {
            return .{ .service_metadata = service_metadata, .action = get_partner_account };
        }
    },
    Response: type = struct {
        sidewalk: ?SidewalkAccountInfoWithFingerprint = null,
        account_linked: ?bool = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .sidewalk = "Sidewalk",
                .account_linked = "AccountLinked",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalServer,
        ResourceNotFound,
        Throttling,
        Validation,
    },
} = .{};
pub const get_service_endpoint: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/service-endpoint",
        .success_code = 200,
    };

    action_name: []const u8 = "GetServiceEndpoint",
    Request: type = struct {
        service_type: ?[]const u8 = null,

        pub const http_query = .{
            .service_type = "serviceType",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .service_type = "ServiceType",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(get_service_endpoint) } {
            return .{ .service_metadata = service_metadata, .action = get_service_endpoint };
        }
    },
    Response: type = struct {
        service_type: ?[]const u8 = null,
        service_endpoint: ?[]const u8 = null,
        server_trust: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .service_type = "ServiceType",
                .service_endpoint = "ServiceEndpoint",
                .server_trust = "ServerTrust",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        InternalServer,
        Throttling,
        Validation,
    },
} = .{};
pub const get_service_profile: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/service-profiles/{Id}",
        .success_code = 200,
    };

    action_name: []const u8 = "GetServiceProfile",
    Request: type = struct {
        id: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .id = "Id",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(get_service_profile) } {
            return .{ .service_metadata = service_metadata, .action = get_service_profile };
        }
    },
    Response: type = struct {
        arn: ?[]const u8 = null,
        name: ?[]const u8 = null,
        id: ?[]const u8 = null,
        lo_ra_wan: ?struct {
            ul_rate: ?i64 = null,
            ul_bucket_size: ?i64 = null,
            ul_rate_policy: ?[]const u8 = null,
            dl_rate: ?i64 = null,
            dl_bucket_size: ?i64 = null,
            dl_rate_policy: ?[]const u8 = null,
            add_gw_metadata: ?bool = null,
            dev_status_req_freq: ?i64 = null,
            report_dev_status_battery: ?bool = null,
            report_dev_status_margin: ?bool = null,
            dr_min: ?i64 = null,
            dr_max: ?i64 = null,
            channel_mask: ?[]const u8 = null,
            pr_allowed: ?bool = null,
            hr_allowed: ?bool = null,
            ra_allowed: ?bool = null,
            nwk_geo_loc: ?bool = null,
            target_per: ?i64 = null,
            min_gw_diversity: ?i64 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .ul_rate = "UlRate",
                    .ul_bucket_size = "UlBucketSize",
                    .ul_rate_policy = "UlRatePolicy",
                    .dl_rate = "DlRate",
                    .dl_bucket_size = "DlBucketSize",
                    .dl_rate_policy = "DlRatePolicy",
                    .add_gw_metadata = "AddGwMetadata",
                    .dev_status_req_freq = "DevStatusReqFreq",
                    .report_dev_status_battery = "ReportDevStatusBattery",
                    .report_dev_status_margin = "ReportDevStatusMargin",
                    .dr_min = "DrMin",
                    .dr_max = "DrMax",
                    .channel_mask = "ChannelMask",
                    .pr_allowed = "PrAllowed",
                    .hr_allowed = "HrAllowed",
                    .ra_allowed = "RaAllowed",
                    .nwk_geo_loc = "NwkGeoLoc",
                    .target_per = "TargetPer",
                    .min_gw_diversity = "MinGwDiversity",
                };
                return @field(mappings, field_name);
            }
        } = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .arn = "Arn",
                .name = "Name",
                .id = "Id",
                .lo_ra_wan = "LoRaWAN",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        InternalServer,
        ResourceNotFound,
        Throttling,
        Validation,
    },
} = .{};
pub const get_wireless_device: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/wireless-devices/{Identifier}",
        .success_code = 200,
    };

    action_name: []const u8 = "GetWirelessDevice",
    Request: type = struct {
        identifier: []const u8,
        identifier_type: []const u8,

        pub const http_query = .{
            .identifier_type = "identifierType",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .identifier = "Identifier",
                .identifier_type = "IdentifierType",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(get_wireless_device) } {
            return .{ .service_metadata = service_metadata, .action = get_wireless_device };
        }
    },
    Response: type = struct {
        type: ?[]const u8 = null,
        name: ?[]const u8 = null,
        description: ?[]const u8 = null,
        destination_name: ?[]const u8 = null,
        id: ?[]const u8 = null,
        arn: ?[]const u8 = null,
        thing_name: ?[]const u8 = null,
        thing_arn: ?[]const u8 = null,
        lo_ra_wan: ?LoRaWANDevice = null,
        sidewalk: ?struct {
            sidewalk_id: ?[]const u8 = null,
            sidewalk_manufacturing_sn: ?[]const u8 = null,
            device_certificates: ?[]CertificateList = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .sidewalk_id = "SidewalkId",
                    .sidewalk_manufacturing_sn = "SidewalkManufacturingSn",
                    .device_certificates = "DeviceCertificates",
                };
                return @field(mappings, field_name);
            }
        } = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .type = "Type",
                .name = "Name",
                .description = "Description",
                .destination_name = "DestinationName",
                .id = "Id",
                .arn = "Arn",
                .thing_name = "ThingName",
                .thing_arn = "ThingArn",
                .lo_ra_wan = "LoRaWAN",
                .sidewalk = "Sidewalk",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        InternalServer,
        ResourceNotFound,
        Throttling,
        Validation,
    },
} = .{};
pub const get_wireless_device_statistics: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/wireless-devices/{WirelessDeviceId}/statistics",
        .success_code = 200,
    };

    action_name: []const u8 = "GetWirelessDeviceStatistics",
    Request: type = struct {
        wireless_device_id: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .wireless_device_id = "WirelessDeviceId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(get_wireless_device_statistics) } {
            return .{ .service_metadata = service_metadata, .action = get_wireless_device_statistics };
        }
    },
    Response: type = struct {
        wireless_device_id: ?[]const u8 = null,
        last_uplink_received_at: ?[]const u8 = null,
        lo_ra_wan: ?struct {
            dev_eui: ?[]const u8 = null,
            f_port: ?i64 = null,
            data_rate: ?i64 = null,
            frequency: ?i64 = null,
            timestamp: ?[]const u8 = null,
            gateways: ?[]struct {
                gateway_eui: ?[]const u8 = null,
                snr: ?f64 = null,
                rssi: ?f64 = null,

                pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                    const mappings = .{
                        .gateway_eui = "GatewayEui",
                        .snr = "Snr",
                        .rssi = "Rssi",
                    };
                    return @field(mappings, field_name);
                }
            } = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .dev_eui = "DevEui",
                    .f_port = "FPort",
                    .data_rate = "DataRate",
                    .frequency = "Frequency",
                    .timestamp = "Timestamp",
                    .gateways = "Gateways",
                };
                return @field(mappings, field_name);
            }
        } = null,
        sidewalk: ?struct {
            rssi: ?i64 = null,
            battery_level: ?[]const u8 = null,
            event: ?[]const u8 = null,
            device_state: ?[]const u8 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .rssi = "Rssi",
                    .battery_level = "BatteryLevel",
                    .event = "Event",
                    .device_state = "DeviceState",
                };
                return @field(mappings, field_name);
            }
        } = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .wireless_device_id = "WirelessDeviceId",
                .last_uplink_received_at = "LastUplinkReceivedAt",
                .lo_ra_wan = "LoRaWAN",
                .sidewalk = "Sidewalk",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        InternalServer,
        ResourceNotFound,
        Throttling,
        Validation,
    },
} = .{};
pub const get_wireless_gateway: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/wireless-gateways/{Identifier}",
        .success_code = 200,
    };

    action_name: []const u8 = "GetWirelessGateway",
    Request: type = struct {
        identifier: []const u8,
        identifier_type: []const u8,

        pub const http_query = .{
            .identifier_type = "identifierType",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .identifier = "Identifier",
                .identifier_type = "IdentifierType",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(get_wireless_gateway) } {
            return .{ .service_metadata = service_metadata, .action = get_wireless_gateway };
        }
    },
    Response: type = struct {
        name: ?[]const u8 = null,
        id: ?[]const u8 = null,
        description: ?[]const u8 = null,
        lo_ra_wan: ?LoRaWANGateway = null,
        arn: ?[]const u8 = null,
        thing_name: ?[]const u8 = null,
        thing_arn: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .name = "Name",
                .id = "Id",
                .description = "Description",
                .lo_ra_wan = "LoRaWAN",
                .arn = "Arn",
                .thing_name = "ThingName",
                .thing_arn = "ThingArn",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        InternalServer,
        ResourceNotFound,
        Throttling,
        Validation,
    },
} = .{};
pub const get_wireless_gateway_certificate: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/wireless-gateways/{Id}/certificate",
        .success_code = 200,
    };

    action_name: []const u8 = "GetWirelessGatewayCertificate",
    Request: type = struct {
        id: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .id = "Id",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(get_wireless_gateway_certificate) } {
            return .{ .service_metadata = service_metadata, .action = get_wireless_gateway_certificate };
        }
    },
    Response: type = struct {
        iot_certificate_id: ?[]const u8 = null,
        lo_ra_wan_network_server_certificate_id: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .iot_certificate_id = "IotCertificateId",
                .lo_ra_wan_network_server_certificate_id = "LoRaWANNetworkServerCertificateId",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        InternalServer,
        ResourceNotFound,
        Throttling,
        Validation,
    },
} = .{};
pub const get_wireless_gateway_firmware_information: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/wireless-gateways/{Id}/firmware-information",
        .success_code = 200,
    };

    action_name: []const u8 = "GetWirelessGatewayFirmwareInformation",
    Request: type = struct {
        id: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .id = "Id",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(get_wireless_gateway_firmware_information) } {
            return .{ .service_metadata = service_metadata, .action = get_wireless_gateway_firmware_information };
        }
    },
    Response: type = struct {
        lo_ra_wan: ?struct {
            current_version: ?LoRaWANGatewayVersion = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .current_version = "CurrentVersion",
                };
                return @field(mappings, field_name);
            }
        } = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .lo_ra_wan = "LoRaWAN",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        InternalServer,
        ResourceNotFound,
        Throttling,
        Validation,
    },
} = .{};
pub const get_wireless_gateway_statistics: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/wireless-gateways/{WirelessGatewayId}/statistics",
        .success_code = 200,
    };

    action_name: []const u8 = "GetWirelessGatewayStatistics",
    Request: type = struct {
        wireless_gateway_id: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .wireless_gateway_id = "WirelessGatewayId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(get_wireless_gateway_statistics) } {
            return .{ .service_metadata = service_metadata, .action = get_wireless_gateway_statistics };
        }
    },
    Response: type = struct {
        wireless_gateway_id: ?[]const u8 = null,
        last_uplink_received_at: ?[]const u8 = null,
        connection_status: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .wireless_gateway_id = "WirelessGatewayId",
                .last_uplink_received_at = "LastUplinkReceivedAt",
                .connection_status = "ConnectionStatus",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        InternalServer,
        ResourceNotFound,
        Throttling,
        Validation,
    },
} = .{};
pub const get_wireless_gateway_task: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/wireless-gateways/{Id}/tasks",
        .success_code = 200,
    };

    action_name: []const u8 = "GetWirelessGatewayTask",
    Request: type = struct {
        id: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .id = "Id",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(get_wireless_gateway_task) } {
            return .{ .service_metadata = service_metadata, .action = get_wireless_gateway_task };
        }
    },
    Response: type = struct {
        wireless_gateway_id: ?[]const u8 = null,
        wireless_gateway_task_definition_id: ?[]const u8 = null,
        last_uplink_received_at: ?[]const u8 = null,
        task_created_at: ?[]const u8 = null,
        status: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .wireless_gateway_id = "WirelessGatewayId",
                .wireless_gateway_task_definition_id = "WirelessGatewayTaskDefinitionId",
                .last_uplink_received_at = "LastUplinkReceivedAt",
                .task_created_at = "TaskCreatedAt",
                .status = "Status",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        InternalServer,
        ResourceNotFound,
        Throttling,
        Validation,
    },
} = .{};
pub const get_wireless_gateway_task_definition: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/wireless-gateway-task-definitions/{Id}",
        .success_code = 200,
    };

    action_name: []const u8 = "GetWirelessGatewayTaskDefinition",
    Request: type = struct {
        id: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .id = "Id",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(get_wireless_gateway_task_definition) } {
            return .{ .service_metadata = service_metadata, .action = get_wireless_gateway_task_definition };
        }
    },
    Response: type = struct {
        auto_create_tasks: ?bool = null,
        name: ?[]const u8 = null,
        update: ?UpdateWirelessGatewayTaskCreate = null,
        arn: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .auto_create_tasks = "AutoCreateTasks",
                .name = "Name",
                .update = "Update",
                .arn = "Arn",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        InternalServer,
        ResourceNotFound,
        Throttling,
        Validation,
    },
} = .{};
pub const list_destinations: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/destinations",
        .success_code = 200,
    };

    action_name: []const u8 = "ListDestinations",
    Request: type = struct {
        max_results: ?i64 = null,
        next_token: ?[]const u8 = null,

        pub const http_query = .{
            .max_results = "maxResults",
            .next_token = "nextToken",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .max_results = "MaxResults",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_destinations) } {
            return .{ .service_metadata = service_metadata, .action = list_destinations };
        }
    },
    Response: type = struct {
        next_token: ?[]const u8 = null,
        destination_list: ?[]struct {
            arn: ?[]const u8 = null,
            name: ?[]const u8 = null,
            expression_type: ?[]const u8 = null,
            expression: ?[]const u8 = null,
            description: ?[]const u8 = null,
            role_arn: ?[]const u8 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .arn = "Arn",
                    .name = "Name",
                    .expression_type = "ExpressionType",
                    .expression = "Expression",
                    .description = "Description",
                    .role_arn = "RoleArn",
                };
                return @field(mappings, field_name);
            }
        } = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .next_token = "NextToken",
                .destination_list = "DestinationList",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        InternalServer,
        Throttling,
        Validation,
    },
} = .{};
pub const list_device_profiles: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/device-profiles",
        .success_code = 200,
    };

    action_name: []const u8 = "ListDeviceProfiles",
    Request: type = struct {
        next_token: ?[]const u8 = null,
        max_results: ?i64 = null,

        pub const http_query = .{
            .next_token = "nextToken",
            .max_results = "maxResults",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .next_token = "NextToken",
                .max_results = "MaxResults",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_device_profiles) } {
            return .{ .service_metadata = service_metadata, .action = list_device_profiles };
        }
    },
    Response: type = struct {
        next_token: ?[]const u8 = null,
        device_profile_list: ?[]struct {
            arn: ?[]const u8 = null,
            name: ?[]const u8 = null,
            id: ?[]const u8 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .arn = "Arn",
                    .name = "Name",
                    .id = "Id",
                };
                return @field(mappings, field_name);
            }
        } = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .next_token = "NextToken",
                .device_profile_list = "DeviceProfileList",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        InternalServer,
        Throttling,
        Validation,
    },
} = .{};
pub const list_partner_accounts: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/partner-accounts",
        .success_code = 200,
    };

    action_name: []const u8 = "ListPartnerAccounts",
    Request: type = struct {
        next_token: ?[]const u8 = null,
        max_results: ?i64 = null,

        pub const http_query = .{
            .next_token = "nextToken",
            .max_results = "maxResults",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .next_token = "NextToken",
                .max_results = "MaxResults",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_partner_accounts) } {
            return .{ .service_metadata = service_metadata, .action = list_partner_accounts };
        }
    },
    Response: type = struct {
        next_token: ?[]const u8 = null,
        sidewalk: ?[]SidewalkAccountInfoWithFingerprint = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .next_token = "NextToken",
                .sidewalk = "Sidewalk",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalServer,
        ResourceNotFound,
        Throttling,
        Validation,
    },
} = .{};
pub const list_service_profiles: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/service-profiles",
        .success_code = 200,
    };

    action_name: []const u8 = "ListServiceProfiles",
    Request: type = struct {
        next_token: ?[]const u8 = null,
        max_results: ?i64 = null,

        pub const http_query = .{
            .next_token = "nextToken",
            .max_results = "maxResults",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .next_token = "NextToken",
                .max_results = "MaxResults",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_service_profiles) } {
            return .{ .service_metadata = service_metadata, .action = list_service_profiles };
        }
    },
    Response: type = struct {
        next_token: ?[]const u8 = null,
        service_profile_list: ?[]struct {
            arn: ?[]const u8 = null,
            name: ?[]const u8 = null,
            id: ?[]const u8 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .arn = "Arn",
                    .name = "Name",
                    .id = "Id",
                };
                return @field(mappings, field_name);
            }
        } = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .next_token = "NextToken",
                .service_profile_list = "ServiceProfileList",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        InternalServer,
        Throttling,
        Validation,
    },
} = .{};
pub const list_tags_for_resource: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/tags",
        .success_code = 200,
    };

    action_name: []const u8 = "ListTagsForResource",
    Request: type = struct {
        resource_arn: []const u8,

        pub const http_query = .{
            .resource_arn = "resourceArn",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .resource_arn = "ResourceArn",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_tags_for_resource) } {
            return .{ .service_metadata = service_metadata, .action = list_tags_for_resource };
        }
    },
    Response: type = struct {
        tags: ?[]Tag = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .tags = "Tags",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        Conflict,
        InternalServer,
        ResourceNotFound,
        Throttling,
        Validation,
    },
} = .{};
pub const list_wireless_devices: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/wireless-devices",
        .success_code = 200,
    };

    action_name: []const u8 = "ListWirelessDevices",
    Request: type = struct {
        max_results: ?i64 = null,
        next_token: ?[]const u8 = null,
        destination_name: ?[]const u8 = null,
        device_profile_id: ?[]const u8 = null,
        service_profile_id: ?[]const u8 = null,
        wireless_device_type: ?[]const u8 = null,

        pub const http_query = .{
            .max_results = "maxResults",
            .next_token = "nextToken",
            .destination_name = "destinationName",
            .device_profile_id = "deviceProfileId",
            .service_profile_id = "serviceProfileId",
            .wireless_device_type = "wirelessDeviceType",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .max_results = "MaxResults",
                .next_token = "NextToken",
                .destination_name = "DestinationName",
                .device_profile_id = "DeviceProfileId",
                .service_profile_id = "ServiceProfileId",
                .wireless_device_type = "WirelessDeviceType",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_wireless_devices) } {
            return .{ .service_metadata = service_metadata, .action = list_wireless_devices };
        }
    },
    Response: type = struct {
        next_token: ?[]const u8 = null,
        wireless_device_list: ?[]struct {
            arn: ?[]const u8 = null,
            id: ?[]const u8 = null,
            type: ?[]const u8 = null,
            name: ?[]const u8 = null,
            destination_name: ?[]const u8 = null,
            last_uplink_received_at: ?[]const u8 = null,
            lo_ra_wan: ?struct {
                dev_eui: ?[]const u8 = null,

                pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                    const mappings = .{
                        .dev_eui = "DevEui",
                    };
                    return @field(mappings, field_name);
                }
            } = null,
            sidewalk: ?struct {
                amazon_id: ?[]const u8 = null,
                sidewalk_id: ?[]const u8 = null,
                sidewalk_manufacturing_sn: ?[]const u8 = null,
                device_certificates: ?[]CertificateList = null,

                pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                    const mappings = .{
                        .amazon_id = "AmazonId",
                        .sidewalk_id = "SidewalkId",
                        .sidewalk_manufacturing_sn = "SidewalkManufacturingSn",
                        .device_certificates = "DeviceCertificates",
                    };
                    return @field(mappings, field_name);
                }
            } = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .arn = "Arn",
                    .id = "Id",
                    .type = "Type",
                    .name = "Name",
                    .destination_name = "DestinationName",
                    .last_uplink_received_at = "LastUplinkReceivedAt",
                    .lo_ra_wan = "LoRaWAN",
                    .sidewalk = "Sidewalk",
                };
                return @field(mappings, field_name);
            }
        } = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .next_token = "NextToken",
                .wireless_device_list = "WirelessDeviceList",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        InternalServer,
        Throttling,
        Validation,
    },
} = .{};
pub const list_wireless_gateways: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/wireless-gateways",
        .success_code = 200,
    };

    action_name: []const u8 = "ListWirelessGateways",
    Request: type = struct {
        next_token: ?[]const u8 = null,
        max_results: ?i64 = null,

        pub const http_query = .{
            .next_token = "nextToken",
            .max_results = "maxResults",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .next_token = "NextToken",
                .max_results = "MaxResults",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_wireless_gateways) } {
            return .{ .service_metadata = service_metadata, .action = list_wireless_gateways };
        }
    },
    Response: type = struct {
        next_token: ?[]const u8 = null,
        wireless_gateway_list: ?[]struct {
            arn: ?[]const u8 = null,
            id: ?[]const u8 = null,
            name: ?[]const u8 = null,
            description: ?[]const u8 = null,
            lo_ra_wan: ?LoRaWANGateway = null,
            last_uplink_received_at: ?[]const u8 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .arn = "Arn",
                    .id = "Id",
                    .name = "Name",
                    .description = "Description",
                    .lo_ra_wan = "LoRaWAN",
                    .last_uplink_received_at = "LastUplinkReceivedAt",
                };
                return @field(mappings, field_name);
            }
        } = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .next_token = "NextToken",
                .wireless_gateway_list = "WirelessGatewayList",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        InternalServer,
        Throttling,
        Validation,
    },
} = .{};
pub const list_wireless_gateway_task_definitions: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/wireless-gateway-task-definitions",
        .success_code = 200,
    };

    action_name: []const u8 = "ListWirelessGatewayTaskDefinitions",
    Request: type = struct {
        max_results: ?i64 = null,
        next_token: ?[]const u8 = null,
        task_definition_type: ?[]const u8 = null,

        pub const http_query = .{
            .max_results = "maxResults",
            .next_token = "nextToken",
            .task_definition_type = "taskDefinitionType",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .max_results = "MaxResults",
                .next_token = "NextToken",
                .task_definition_type = "TaskDefinitionType",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_wireless_gateway_task_definitions) } {
            return .{ .service_metadata = service_metadata, .action = list_wireless_gateway_task_definitions };
        }
    },
    Response: type = struct {
        next_token: ?[]const u8 = null,
        task_definitions: ?[]struct {
            id: ?[]const u8 = null,
            lo_ra_wan: ?struct {
                current_version: ?LoRaWANGatewayVersion = null,
                update_version: ?LoRaWANGatewayVersion = null,

                pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                    const mappings = .{
                        .current_version = "CurrentVersion",
                        .update_version = "UpdateVersion",
                    };
                    return @field(mappings, field_name);
                }
            } = null,
            arn: ?[]const u8 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .id = "Id",
                    .lo_ra_wan = "LoRaWAN",
                    .arn = "Arn",
                };
                return @field(mappings, field_name);
            }
        } = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .next_token = "NextToken",
                .task_definitions = "TaskDefinitions",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        InternalServer,
        Throttling,
        Validation,
    },
} = .{};
pub const send_data_to_wireless_device: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/wireless-devices/{Id}/data",
        .success_code = 202,
    };

    action_name: []const u8 = "SendDataToWirelessDevice",
    Request: type = struct {
        id: []const u8,
        transmit_mode: i64,
        payload_data: []const u8,
        wireless_metadata: ?struct {
            lo_ra_wan: ?struct {
                f_port: ?i64 = null,

                pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                    const mappings = .{
                        .f_port = "FPort",
                    };
                    return @field(mappings, field_name);
                }
            } = null,
            sidewalk: ?struct {
                seq: ?i64 = null,
                message_type: ?[]const u8 = null,

                pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                    const mappings = .{
                        .seq = "Seq",
                        .message_type = "MessageType",
                    };
                    return @field(mappings, field_name);
                }
            } = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .lo_ra_wan = "LoRaWAN",
                    .sidewalk = "Sidewalk",
                };
                return @field(mappings, field_name);
            }
        } = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .id = "Id",
                .transmit_mode = "TransmitMode",
                .payload_data = "PayloadData",
                .wireless_metadata = "WirelessMetadata",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(send_data_to_wireless_device) } {
            return .{ .service_metadata = service_metadata, .action = send_data_to_wireless_device };
        }
    },
    Response: type = struct {
        message_id: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .message_id = "MessageId",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalServer,
        ResourceNotFound,
        Throttling,
        Validation,
    },
} = .{};
pub const tag_resource: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/tags",
        .success_code = 204,
    };

    action_name: []const u8 = "TagResource",
    Request: type = struct {
        resource_arn: []const u8,
        tags: []Tag,

        pub const http_query = .{
            .resource_arn = "resourceArn",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .resource_arn = "ResourceArn",
                .tags = "Tags",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(tag_resource) } {
            return .{ .service_metadata = service_metadata, .action = tag_resource };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        Conflict,
        InternalServer,
        ResourceNotFound,
        Throttling,
        TooManyTags,
        Validation,
    },
} = .{};
pub const test_wireless_device: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/wireless-devices/{Id}/test",
        .success_code = 200,
    };

    action_name: []const u8 = "TestWirelessDevice",
    Request: type = struct {
        id: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .id = "Id",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(test_wireless_device) } {
            return .{ .service_metadata = service_metadata, .action = test_wireless_device };
        }
    },
    Response: type = struct {
        result: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .result = "Result",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalServer,
        ResourceNotFound,
        Throttling,
        Validation,
    },
} = .{};
pub const untag_resource: struct {
    pub const http_config = .{
        .method = "DELETE",
        .uri = "/tags",
        .success_code = 204,
    };

    action_name: []const u8 = "UntagResource",
    Request: type = struct {
        resource_arn: []const u8,
        tag_keys: [][]const u8,

        pub const http_query = .{
            .resource_arn = "resourceArn",
            .tag_keys = "tagKeys",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .resource_arn = "ResourceArn",
                .tag_keys = "TagKeys",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(untag_resource) } {
            return .{ .service_metadata = service_metadata, .action = untag_resource };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        Conflict,
        InternalServer,
        ResourceNotFound,
        Throttling,
        Validation,
    },
} = .{};
pub const update_destination: struct {
    pub const http_config = .{
        .method = "PATCH",
        .uri = "/destinations/{Name}",
        .success_code = 204,
    };

    action_name: []const u8 = "UpdateDestination",
    Request: type = struct {
        name: []const u8,
        expression_type: ?[]const u8 = null,
        expression: ?[]const u8 = null,
        description: ?[]const u8 = null,
        role_arn: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .name = "Name",
                .expression_type = "ExpressionType",
                .expression = "Expression",
                .description = "Description",
                .role_arn = "RoleArn",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(update_destination) } {
            return .{ .service_metadata = service_metadata, .action = update_destination };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        InternalServer,
        ResourceNotFound,
        Throttling,
        Validation,
    },
} = .{};
pub const update_partner_account: struct {
    pub const http_config = .{
        .method = "PATCH",
        .uri = "/partner-accounts/{PartnerAccountId}",
        .success_code = 204,
    };

    action_name: []const u8 = "UpdatePartnerAccount",
    Request: type = struct {
        sidewalk: struct {
            app_server_private_key: ?[]const u8 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .app_server_private_key = "AppServerPrivateKey",
                };
                return @field(mappings, field_name);
            }
        },
        partner_account_id: []const u8,
        partner_type: []const u8,

        pub const http_query = .{
            .partner_type = "partnerType",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .sidewalk = "Sidewalk",
                .partner_account_id = "PartnerAccountId",
                .partner_type = "PartnerType",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(update_partner_account) } {
            return .{ .service_metadata = service_metadata, .action = update_partner_account };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalServer,
        ResourceNotFound,
        Throttling,
        Validation,
    },
} = .{};
pub const update_wireless_device: struct {
    pub const http_config = .{
        .method = "PATCH",
        .uri = "/wireless-devices/{Id}",
        .success_code = 204,
    };

    action_name: []const u8 = "UpdateWirelessDevice",
    Request: type = struct {
        id: []const u8,
        destination_name: ?[]const u8 = null,
        name: ?[]const u8 = null,
        description: ?[]const u8 = null,
        lo_ra_wan: ?struct {
            device_profile_id: ?[]const u8 = null,
            service_profile_id: ?[]const u8 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .device_profile_id = "DeviceProfileId",
                    .service_profile_id = "ServiceProfileId",
                };
                return @field(mappings, field_name);
            }
        } = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .id = "Id",
                .destination_name = "DestinationName",
                .name = "Name",
                .description = "Description",
                .lo_ra_wan = "LoRaWAN",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(update_wireless_device) } {
            return .{ .service_metadata = service_metadata, .action = update_wireless_device };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        InternalServer,
        ResourceNotFound,
        Throttling,
        Validation,
    },
} = .{};
pub const update_wireless_gateway: struct {
    pub const http_config = .{
        .method = "PATCH",
        .uri = "/wireless-gateways/{Id}",
        .success_code = 204,
    };

    action_name: []const u8 = "UpdateWirelessGateway",
    Request: type = struct {
        id: []const u8,
        name: ?[]const u8 = null,
        description: ?[]const u8 = null,
        join_eui_filters: ?[][][]const u8 = null,
        net_id_filters: ?[][]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .id = "Id",
                .name = "Name",
                .description = "Description",
                .join_eui_filters = "JoinEuiFilters",
                .net_id_filters = "NetIdFilters",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(update_wireless_gateway) } {
            return .{ .service_metadata = service_metadata, .action = update_wireless_gateway };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        InternalServer,
        ResourceNotFound,
        Throttling,
        Validation,
    },
} = .{};

pub const Tag = struct {
    key: []const u8,
    value: []const u8,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .key = "Key",
            .value = "Value",
        };
        return @field(mappings, field_name);
    }
};

pub const LoRaWANGatewayVersion = struct {
    package_version: ?[]const u8 = null,
    model: ?[]const u8 = null,
    station: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .package_version = "PackageVersion",
            .model = "Model",
            .station = "Station",
        };
        return @field(mappings, field_name);
    }
};

pub const LoRaWANGateway = struct {
    gateway_eui: ?[]const u8 = null,
    rf_region: ?[]const u8 = null,
    join_eui_filters: ?[][][]const u8 = null,
    net_id_filters: ?[][]const u8 = null,
    sub_bands: ?[]i64 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .gateway_eui = "GatewayEui",
            .rf_region = "RfRegion",
            .join_eui_filters = "JoinEuiFilters",
            .net_id_filters = "NetIdFilters",
            .sub_bands = "SubBands",
        };
        return @field(mappings, field_name);
    }
};

pub const CertificateList = struct {
    signing_alg: []const u8,
    value: []const u8,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .signing_alg = "SigningAlg",
            .value = "Value",
        };
        return @field(mappings, field_name);
    }
};

pub const SidewalkAccountInfoWithFingerprint = struct {
    amazon_id: ?[]const u8 = null,
    fingerprint: ?[]const u8 = null,
    arn: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .amazon_id = "AmazonId",
            .fingerprint = "Fingerprint",
            .arn = "Arn",
        };
        return @field(mappings, field_name);
    }
};

pub const UpdateWirelessGatewayTaskCreate = struct {
    update_data_source: ?[]const u8 = null,
    update_data_role: ?[]const u8 = null,
    lo_ra_wan: ?LoRaWANUpdateGatewayTaskCreate = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .update_data_source = "UpdateDataSource",
            .update_data_role = "UpdateDataRole",
            .lo_ra_wan = "LoRaWAN",
        };
        return @field(mappings, field_name);
    }
};

pub const LoRaWANUpdateGatewayTaskCreate = struct {
    update_signature: ?[]const u8 = null,
    sig_key_crc: ?i64 = null,
    current_version: ?LoRaWANGatewayVersion = null,
    update_version: ?LoRaWANGatewayVersion = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .update_signature = "UpdateSignature",
            .sig_key_crc = "SigKeyCrc",
            .current_version = "CurrentVersion",
            .update_version = "UpdateVersion",
        };
        return @field(mappings, field_name);
    }
};

pub const LoRaWANDevice = struct {
    dev_eui: ?[]const u8 = null,
    device_profile_id: ?[]const u8 = null,
    service_profile_id: ?[]const u8 = null,
    otaa_v1_1: ?OtaaV1_1 = null,
    otaa_v1_0_x: ?OtaaV1_0_x = null,
    abp_v1_1: ?AbpV1_1 = null,
    abp_v1_0_x: ?AbpV1_0_x = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .dev_eui = "DevEui",
            .device_profile_id = "DeviceProfileId",
            .service_profile_id = "ServiceProfileId",
            .otaa_v1_1 = "OtaaV1_1",
            .otaa_v1_0_x = "OtaaV1_0_x",
            .abp_v1_1 = "AbpV1_1",
            .abp_v1_0_x = "AbpV1_0_x",
        };
        return @field(mappings, field_name);
    }
};

pub const AbpV1_0_x = struct {
    dev_addr: ?[]const u8 = null,
    session_keys: ?SessionKeysAbpV1_0_x = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .dev_addr = "DevAddr",
            .session_keys = "SessionKeys",
        };
        return @field(mappings, field_name);
    }
};

pub const SessionKeysAbpV1_0_x = struct {
    nwk_s_key: ?[]const u8 = null,
    app_s_key: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .nwk_s_key = "NwkSKey",
            .app_s_key = "AppSKey",
        };
        return @field(mappings, field_name);
    }
};

pub const AbpV1_1 = struct {
    dev_addr: ?[]const u8 = null,
    session_keys: ?SessionKeysAbpV1_1 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .dev_addr = "DevAddr",
            .session_keys = "SessionKeys",
        };
        return @field(mappings, field_name);
    }
};

pub const SessionKeysAbpV1_1 = struct {
    f_nwk_s_int_key: ?[]const u8 = null,
    s_nwk_s_int_key: ?[]const u8 = null,
    nwk_s_enc_key: ?[]const u8 = null,
    app_s_key: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .f_nwk_s_int_key = "FNwkSIntKey",
            .s_nwk_s_int_key = "SNwkSIntKey",
            .nwk_s_enc_key = "NwkSEncKey",
            .app_s_key = "AppSKey",
        };
        return @field(mappings, field_name);
    }
};

pub const OtaaV1_0_x = struct {
    app_key: ?[]const u8 = null,
    app_eui: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .app_key = "AppKey",
            .app_eui = "AppEui",
        };
        return @field(mappings, field_name);
    }
};

pub const OtaaV1_1 = struct {
    app_key: ?[]const u8 = null,
    nwk_key: ?[]const u8 = null,
    join_eui: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .app_key = "AppKey",
            .nwk_key = "NwkKey",
            .join_eui = "JoinEui",
        };
        return @field(mappings, field_name);
    }
};

pub const LoRaWANDeviceProfile = struct {
    supports_classb: ?bool = null,
    class_b_timeout: ?i64 = null,
    ping_slot_period: ?i64 = null,
    ping_slot_dr: ?i64 = null,
    ping_slot_freq: ?i64 = null,
    supports_classc: ?bool = null,
    class_c_timeout: ?i64 = null,
    mac_version: ?[]const u8 = null,
    reg_params_revision: ?[]const u8 = null,
    rx_delay1: ?i64 = null,
    rx_dr_offset1: ?i64 = null,
    rx_data_rate2: ?i64 = null,
    rx_freq2: ?i64 = null,
    factory_preset_freqs_list: ?[]i64 = null,
    max_eirp: ?i64 = null,
    max_duty_cycle: ?i64 = null,
    rf_region: ?[]const u8 = null,
    supports_join: ?bool = null,
    supports32_bit_f_cnt: ?bool = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .supports_classb = "SupportsClassB",
            .class_b_timeout = "ClassBTimeout",
            .ping_slot_period = "PingSlotPeriod",
            .ping_slot_dr = "PingSlotDr",
            .ping_slot_freq = "PingSlotFreq",
            .supports_classc = "SupportsClassC",
            .class_c_timeout = "ClassCTimeout",
            .mac_version = "MacVersion",
            .reg_params_revision = "RegParamsRevision",
            .rx_delay1 = "RxDelay1",
            .rx_dr_offset1 = "RxDrOffset1",
            .rx_data_rate2 = "RxDataRate2",
            .rx_freq2 = "RxFreq2",
            .factory_preset_freqs_list = "FactoryPresetFreqsList",
            .max_eirp = "MaxEirp",
            .max_duty_cycle = "MaxDutyCycle",
            .rf_region = "RfRegion",
            .supports_join = "SupportsJoin",
            .supports32_bit_f_cnt = "Supports32BitFCnt",
        };
        return @field(mappings, field_name);
    }
};

pub const SidewalkAccountInfo = struct {
    amazon_id: ?[]const u8 = null,
    app_server_private_key: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .amazon_id = "AmazonId",
            .app_server_private_key = "AppServerPrivateKey",
        };
        return @field(mappings, field_name);
    }
};
