const std = @import("std");
const serializeMap = @import("json.zig").serializeMap;
const smithy = @import("smithy");

const Self = @This();
pub const version: []const u8 = "2020-08-07";
pub const sdk_id: []const u8 = "Lex Models V2";
pub const arn_namespace: []const u8 = "lex";
pub const endpoint_prefix: []const u8 = "models-v2-lex";
pub const sigv4_name: []const u8 = "lex";
pub const name: []const u8 = "LexModelBuildingServiceV2";
pub const aws_protocol: smithy.AwsProtocol = smithy.AwsProtocol.rest_json_1;

pub const service_metadata: struct {
    version: []const u8 = "2020-08-07",
    sdk_id: []const u8 = "Lex Models V2",
    arn_namespace: []const u8 = "lex",
    endpoint_prefix: []const u8 = "models-v2-lex",
    sigv4_name: []const u8 = "lex",
    name: []const u8 = "LexModelBuildingServiceV2",
    aws_protocol: smithy.AwsProtocol = smithy.AwsProtocol.rest_json_1,
} = .{};
pub const build_bot_locale: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/bots/{botId}/botversions/{botVersion}/botlocales/{localeId}",
        .success_code = 202,
    };

    action_name: []const u8 = "BuildBotLocale",
    Request: type = struct {
        bot_id: []const u8,
        bot_version: []const u8,
        locale_id: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .bot_id = "botId",
                .bot_version = "botVersion",
                .locale_id = "localeId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(build_bot_locale) } {
            return .{ .service_metadata = service_metadata, .action = build_bot_locale };
        }
    },
    Response: type = struct {
        bot_id: ?[]const u8 = null,
        bot_version: ?[]const u8 = null,
        locale_id: ?[]const u8 = null,
        bot_locale_status: ?[]const u8 = null,
        last_build_submitted_date_time: ?i64 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .bot_id = "botId",
                .bot_version = "botVersion",
                .locale_id = "localeId",
                .bot_locale_status = "botLocaleStatus",
                .last_build_submitted_date_time = "lastBuildSubmittedDateTime",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        Conflict,
        InternalServer,
        PreconditionFailed,
        ServiceQuotaExceeded,
        Throttling,
        Validation,
    },
} = .{};
pub const create_bot: struct {
    pub const http_config = .{
        .method = "PUT",
        .uri = "/bots",
        .success_code = 202,
    };

    action_name: []const u8 = "CreateBot",
    Request: type = struct {
        bot_name: []const u8,
        description: ?[]const u8 = null,
        role_arn: []const u8,
        data_privacy: DataPrivacy,
        idle_session_ttl_in_seconds: i64,
        bot_tags: ?[]struct {
            key: ?[]const u8 = null,
            value: ?[]const u8 = null,
        } = null,
        test_bot_alias_tags: ?[]struct {
            key: ?[]const u8 = null,
            value: ?[]const u8 = null,
        } = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .bot_name = "botName",
                .description = "description",
                .role_arn = "roleArn",
                .data_privacy = "dataPrivacy",
                .idle_session_ttl_in_seconds = "idleSessionTTLInSeconds",
                .bot_tags = "botTags",
                .test_bot_alias_tags = "testBotAliasTags",
            };
            return @field(mappings, field_name);
        }

        pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
            if (std.mem.eql(u8, "bot_tags", field_name))
                return try serializeMap(self.bot_tags, self.fieldNameFor("bot_tags"), options, out_stream);
            if (std.mem.eql(u8, "test_bot_alias_tags", field_name))
                return try serializeMap(self.test_bot_alias_tags, self.fieldNameFor("test_bot_alias_tags"), options, out_stream);
            return false;
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(create_bot) } {
            return .{ .service_metadata = service_metadata, .action = create_bot };
        }
    },
    Response: type = struct {
        bot_id: ?[]const u8 = null,
        bot_name: ?[]const u8 = null,
        description: ?[]const u8 = null,
        role_arn: ?[]const u8 = null,
        data_privacy: ?DataPrivacy = null,
        idle_session_ttl_in_seconds: ?i64 = null,
        bot_status: ?[]const u8 = null,
        creation_date_time: ?i64 = null,
        bot_tags: ?[]struct {
            key: ?[]const u8 = null,
            value: ?[]const u8 = null,
        } = null,
        test_bot_alias_tags: ?[]struct {
            key: ?[]const u8 = null,
            value: ?[]const u8 = null,
        } = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .bot_id = "botId",
                .bot_name = "botName",
                .description = "description",
                .role_arn = "roleArn",
                .data_privacy = "dataPrivacy",
                .idle_session_ttl_in_seconds = "idleSessionTTLInSeconds",
                .bot_status = "botStatus",
                .creation_date_time = "creationDateTime",
                .bot_tags = "botTags",
                .test_bot_alias_tags = "testBotAliasTags",
            };
            return @field(mappings, field_name);
        }

        pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
            if (std.mem.eql(u8, "bot_tags", field_name))
                return try serializeMap(self.bot_tags, self.fieldNameFor("bot_tags"), options, out_stream);
            if (std.mem.eql(u8, "test_bot_alias_tags", field_name))
                return try serializeMap(self.test_bot_alias_tags, self.fieldNameFor("test_bot_alias_tags"), options, out_stream);
            return false;
        }
    },
    ServiceError: type = error{
        Conflict,
        InternalServer,
        PreconditionFailed,
        ServiceQuotaExceeded,
        Throttling,
        Validation,
    },
} = .{};
pub const create_bot_alias: struct {
    pub const http_config = .{
        .method = "PUT",
        .uri = "/bots/{botId}/botaliases",
        .success_code = 202,
    };

    action_name: []const u8 = "CreateBotAlias",
    Request: type = struct {
        bot_alias_name: []const u8,
        description: ?[]const u8 = null,
        bot_version: ?[]const u8 = null,
        bot_alias_locale_settings: ?[]struct {
            key: ?[]const u8 = null,
            value: ?BotAliasLocaleSettings = null,
        } = null,
        conversation_log_settings: ?ConversationLogSettings = null,
        sentiment_analysis_settings: ?SentimentAnalysisSettings = null,
        bot_id: []const u8,
        tags: ?[]struct {
            key: ?[]const u8 = null,
            value: ?[]const u8 = null,
        } = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .bot_alias_name = "botAliasName",
                .description = "description",
                .bot_version = "botVersion",
                .bot_alias_locale_settings = "botAliasLocaleSettings",
                .conversation_log_settings = "conversationLogSettings",
                .sentiment_analysis_settings = "sentimentAnalysisSettings",
                .bot_id = "botId",
                .tags = "tags",
            };
            return @field(mappings, field_name);
        }

        pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
            if (std.mem.eql(u8, "bot_alias_locale_settings", field_name))
                return try serializeMap(self.bot_alias_locale_settings, self.fieldNameFor("bot_alias_locale_settings"), options, out_stream);
            if (std.mem.eql(u8, "tags", field_name))
                return try serializeMap(self.tags, self.fieldNameFor("tags"), options, out_stream);
            return false;
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(create_bot_alias) } {
            return .{ .service_metadata = service_metadata, .action = create_bot_alias };
        }
    },
    Response: type = struct {
        bot_alias_id: ?[]const u8 = null,
        bot_alias_name: ?[]const u8 = null,
        description: ?[]const u8 = null,
        bot_version: ?[]const u8 = null,
        bot_alias_locale_settings: ?[]struct {
            key: ?[]const u8 = null,
            value: ?BotAliasLocaleSettings = null,
        } = null,
        conversation_log_settings: ?ConversationLogSettings = null,
        sentiment_analysis_settings: ?SentimentAnalysisSettings = null,
        bot_alias_status: ?[]const u8 = null,
        bot_id: ?[]const u8 = null,
        creation_date_time: ?i64 = null,
        tags: ?[]struct {
            key: ?[]const u8 = null,
            value: ?[]const u8 = null,
        } = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .bot_alias_id = "botAliasId",
                .bot_alias_name = "botAliasName",
                .description = "description",
                .bot_version = "botVersion",
                .bot_alias_locale_settings = "botAliasLocaleSettings",
                .conversation_log_settings = "conversationLogSettings",
                .sentiment_analysis_settings = "sentimentAnalysisSettings",
                .bot_alias_status = "botAliasStatus",
                .bot_id = "botId",
                .creation_date_time = "creationDateTime",
                .tags = "tags",
            };
            return @field(mappings, field_name);
        }

        pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
            if (std.mem.eql(u8, "bot_alias_locale_settings", field_name))
                return try serializeMap(self.bot_alias_locale_settings, self.fieldNameFor("bot_alias_locale_settings"), options, out_stream);
            if (std.mem.eql(u8, "tags", field_name))
                return try serializeMap(self.tags, self.fieldNameFor("tags"), options, out_stream);
            return false;
        }
    },
    ServiceError: type = error{
        Conflict,
        InternalServer,
        PreconditionFailed,
        ServiceQuotaExceeded,
        Throttling,
        Validation,
    },
} = .{};
pub const create_bot_locale: struct {
    pub const http_config = .{
        .method = "PUT",
        .uri = "/bots/{botId}/botversions/{botVersion}/botlocales",
        .success_code = 202,
    };

    action_name: []const u8 = "CreateBotLocale",
    Request: type = struct {
        bot_id: []const u8,
        bot_version: []const u8,
        locale_id: []const u8,
        description: ?[]const u8 = null,
        nlu_intent_confidence_threshold: f64,
        voice_settings: ?VoiceSettings = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .bot_id = "botId",
                .bot_version = "botVersion",
                .locale_id = "localeId",
                .description = "description",
                .nlu_intent_confidence_threshold = "nluIntentConfidenceThreshold",
                .voice_settings = "voiceSettings",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(create_bot_locale) } {
            return .{ .service_metadata = service_metadata, .action = create_bot_locale };
        }
    },
    Response: type = struct {
        bot_id: ?[]const u8 = null,
        bot_version: ?[]const u8 = null,
        locale_name: ?[]const u8 = null,
        locale_id: ?[]const u8 = null,
        description: ?[]const u8 = null,
        nlu_intent_confidence_threshold: ?f64 = null,
        voice_settings: ?VoiceSettings = null,
        bot_locale_status: ?[]const u8 = null,
        creation_date_time: ?i64 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .bot_id = "botId",
                .bot_version = "botVersion",
                .locale_name = "localeName",
                .locale_id = "localeId",
                .description = "description",
                .nlu_intent_confidence_threshold = "nluIntentConfidenceThreshold",
                .voice_settings = "voiceSettings",
                .bot_locale_status = "botLocaleStatus",
                .creation_date_time = "creationDateTime",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        Conflict,
        InternalServer,
        PreconditionFailed,
        ServiceQuotaExceeded,
        Throttling,
        Validation,
    },
} = .{};
pub const create_bot_version: struct {
    pub const http_config = .{
        .method = "PUT",
        .uri = "/bots/{botId}/botversions",
        .success_code = 202,
    };

    action_name: []const u8 = "CreateBotVersion",
    Request: type = struct {
        bot_id: []const u8,
        description: ?[]const u8 = null,
        bot_version_locale_specification: []struct {
            key: ?[]const u8 = null,
            value: ?BotVersionLocaleDetails = null,
        },

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .bot_id = "botId",
                .description = "description",
                .bot_version_locale_specification = "botVersionLocaleSpecification",
            };
            return @field(mappings, field_name);
        }

        pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
            if (std.mem.eql(u8, "bot_version_locale_specification", field_name))
                return try serializeMap(self.bot_version_locale_specification, self.fieldNameFor("bot_version_locale_specification"), options, out_stream);
            return false;
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(create_bot_version) } {
            return .{ .service_metadata = service_metadata, .action = create_bot_version };
        }
    },
    Response: type = struct {
        bot_id: ?[]const u8 = null,
        description: ?[]const u8 = null,
        bot_version: ?[]const u8 = null,
        bot_version_locale_specification: ?[]struct {
            key: ?[]const u8 = null,
            value: ?BotVersionLocaleDetails = null,
        } = null,
        bot_status: ?[]const u8 = null,
        creation_date_time: ?i64 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .bot_id = "botId",
                .description = "description",
                .bot_version = "botVersion",
                .bot_version_locale_specification = "botVersionLocaleSpecification",
                .bot_status = "botStatus",
                .creation_date_time = "creationDateTime",
            };
            return @field(mappings, field_name);
        }

        pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
            if (std.mem.eql(u8, "bot_version_locale_specification", field_name))
                return try serializeMap(self.bot_version_locale_specification, self.fieldNameFor("bot_version_locale_specification"), options, out_stream);
            return false;
        }
    },
    ServiceError: type = error{
        Conflict,
        InternalServer,
        PreconditionFailed,
        ServiceQuotaExceeded,
        Throttling,
        Validation,
    },
} = .{};
pub const create_export: struct {
    pub const http_config = .{
        .method = "PUT",
        .uri = "/exports",
        .success_code = 202,
    };

    action_name: []const u8 = "CreateExport",
    Request: type = struct {
        resource_specification: ExportResourceSpecification,
        file_format: []const u8,
        file_password: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .resource_specification = "resourceSpecification",
                .file_format = "fileFormat",
                .file_password = "filePassword",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(create_export) } {
            return .{ .service_metadata = service_metadata, .action = create_export };
        }
    },
    Response: type = struct {
        export_id: ?[]const u8 = null,
        resource_specification: ?ExportResourceSpecification = null,
        file_format: ?[]const u8 = null,
        export_status: ?[]const u8 = null,
        creation_date_time: ?i64 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .export_id = "exportId",
                .resource_specification = "resourceSpecification",
                .file_format = "fileFormat",
                .export_status = "exportStatus",
                .creation_date_time = "creationDateTime",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        Conflict,
        InternalServer,
        ResourceNotFound,
        ServiceQuotaExceeded,
        Throttling,
        Validation,
    },
} = .{};
pub const create_intent: struct {
    pub const http_config = .{
        .method = "PUT",
        .uri = "/bots/{botId}/botversions/{botVersion}/botlocales/{localeId}/intents",
        .success_code = 200,
    };

    action_name: []const u8 = "CreateIntent",
    Request: type = struct {
        intent_name: []const u8,
        description: ?[]const u8 = null,
        parent_intent_signature: ?[]const u8 = null,
        sample_utterances: ?[]SampleUtterance = null,
        dialog_code_hook: ?DialogCodeHookSettings = null,
        fulfillment_code_hook: ?FulfillmentCodeHookSettings = null,
        intent_confirmation_setting: ?IntentConfirmationSetting = null,
        intent_closing_setting: ?IntentClosingSetting = null,
        input_contexts: ?[]InputContext = null,
        output_contexts: ?[]OutputContext = null,
        kendra_configuration: ?KendraConfiguration = null,
        bot_id: []const u8,
        bot_version: []const u8,
        locale_id: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .intent_name = "intentName",
                .description = "description",
                .parent_intent_signature = "parentIntentSignature",
                .sample_utterances = "sampleUtterances",
                .dialog_code_hook = "dialogCodeHook",
                .fulfillment_code_hook = "fulfillmentCodeHook",
                .intent_confirmation_setting = "intentConfirmationSetting",
                .intent_closing_setting = "intentClosingSetting",
                .input_contexts = "inputContexts",
                .output_contexts = "outputContexts",
                .kendra_configuration = "kendraConfiguration",
                .bot_id = "botId",
                .bot_version = "botVersion",
                .locale_id = "localeId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(create_intent) } {
            return .{ .service_metadata = service_metadata, .action = create_intent };
        }
    },
    Response: type = struct {
        intent_id: ?[]const u8 = null,
        intent_name: ?[]const u8 = null,
        description: ?[]const u8 = null,
        parent_intent_signature: ?[]const u8 = null,
        sample_utterances: ?[]SampleUtterance = null,
        dialog_code_hook: ?DialogCodeHookSettings = null,
        fulfillment_code_hook: ?FulfillmentCodeHookSettings = null,
        intent_confirmation_setting: ?IntentConfirmationSetting = null,
        intent_closing_setting: ?IntentClosingSetting = null,
        input_contexts: ?[]InputContext = null,
        output_contexts: ?[]OutputContext = null,
        kendra_configuration: ?KendraConfiguration = null,
        bot_id: ?[]const u8 = null,
        bot_version: ?[]const u8 = null,
        locale_id: ?[]const u8 = null,
        creation_date_time: ?i64 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .intent_id = "intentId",
                .intent_name = "intentName",
                .description = "description",
                .parent_intent_signature = "parentIntentSignature",
                .sample_utterances = "sampleUtterances",
                .dialog_code_hook = "dialogCodeHook",
                .fulfillment_code_hook = "fulfillmentCodeHook",
                .intent_confirmation_setting = "intentConfirmationSetting",
                .intent_closing_setting = "intentClosingSetting",
                .input_contexts = "inputContexts",
                .output_contexts = "outputContexts",
                .kendra_configuration = "kendraConfiguration",
                .bot_id = "botId",
                .bot_version = "botVersion",
                .locale_id = "localeId",
                .creation_date_time = "creationDateTime",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        Conflict,
        InternalServer,
        PreconditionFailed,
        ServiceQuotaExceeded,
        Throttling,
        Validation,
    },
} = .{};
pub const create_resource_policy: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/policy/{resourceArn}",
        .success_code = 200,
    };

    action_name: []const u8 = "CreateResourcePolicy",
    Request: type = struct {
        resource_arn: []const u8,
        policy: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .resource_arn = "resourceArn",
                .policy = "policy",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(create_resource_policy) } {
            return .{ .service_metadata = service_metadata, .action = create_resource_policy };
        }
    },
    Response: type = struct {
        resource_arn: ?[]const u8 = null,
        revision_id: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .resource_arn = "resourceArn",
                .revision_id = "revisionId",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalServer,
        PreconditionFailed,
        ResourceNotFound,
        ServiceQuotaExceeded,
        Throttling,
        Validation,
    },
} = .{};
pub const create_resource_policy_statement: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/policy/{resourceArn}/statements",
        .success_code = 200,
    };

    action_name: []const u8 = "CreateResourcePolicyStatement",
    Request: type = struct {
        resource_arn: []const u8,
        statement_id: []const u8,
        effect: []const u8,
        principal: []struct {
            service: ?[]const u8 = null,
            arn: ?[]const u8 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .service = "service",
                    .arn = "arn",
                };
                return @field(mappings, field_name);
            }
        },
        action: [][]const u8,
        condition: ?[]struct {
            key: ?[]const u8 = null,
            value: ?[]struct {
                key: ?[]const u8 = null,
                value: ?[]const u8 = null,
            } = null,


        pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
            if (std.mem.eql(u8, "value", field_name))
                return try serializeMap(self.value, self.fieldNameFor("value"), options, out_stream);
            return false;
        }
        } = null,
        expected_revision_id: ?[]const u8 = null,

        pub const http_query = .{
            .expected_revision_id = "expectedRevisionId",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .resource_arn = "resourceArn",
                .statement_id = "statementId",
                .effect = "effect",
                .principal = "principal",
                .action = "action",
                .condition = "condition",
                .expected_revision_id = "expectedRevisionId",
            };
            return @field(mappings, field_name);
        }

        pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
            if (std.mem.eql(u8, "condition", field_name))
                return try serializeMap(self.condition, self.fieldNameFor("condition"), options, out_stream);
            return false;
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(create_resource_policy_statement) } {
            return .{ .service_metadata = service_metadata, .action = create_resource_policy_statement };
        }
    },
    Response: type = struct {
        resource_arn: ?[]const u8 = null,
        revision_id: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .resource_arn = "resourceArn",
                .revision_id = "revisionId",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        Conflict,
        InternalServer,
        PreconditionFailed,
        ResourceNotFound,
        ServiceQuotaExceeded,
        Throttling,
        Validation,
    },
} = .{};
pub const create_slot: struct {
    pub const http_config = .{
        .method = "PUT",
        .uri = "/bots/{botId}/botversions/{botVersion}/botlocales/{localeId}/intents/{intentId}/slots",
        .success_code = 200,
    };

    action_name: []const u8 = "CreateSlot",
    Request: type = struct {
        slot_name: []const u8,
        description: ?[]const u8 = null,
        slot_type_id: []const u8,
        value_elicitation_setting: SlotValueElicitationSetting,
        obfuscation_setting: ?ObfuscationSetting = null,
        bot_id: []const u8,
        bot_version: []const u8,
        locale_id: []const u8,
        intent_id: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .slot_name = "slotName",
                .description = "description",
                .slot_type_id = "slotTypeId",
                .value_elicitation_setting = "valueElicitationSetting",
                .obfuscation_setting = "obfuscationSetting",
                .bot_id = "botId",
                .bot_version = "botVersion",
                .locale_id = "localeId",
                .intent_id = "intentId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(create_slot) } {
            return .{ .service_metadata = service_metadata, .action = create_slot };
        }
    },
    Response: type = struct {
        slot_id: ?[]const u8 = null,
        slot_name: ?[]const u8 = null,
        description: ?[]const u8 = null,
        slot_type_id: ?[]const u8 = null,
        value_elicitation_setting: ?SlotValueElicitationSetting = null,
        obfuscation_setting: ?ObfuscationSetting = null,
        bot_id: ?[]const u8 = null,
        bot_version: ?[]const u8 = null,
        locale_id: ?[]const u8 = null,
        intent_id: ?[]const u8 = null,
        creation_date_time: ?i64 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .slot_id = "slotId",
                .slot_name = "slotName",
                .description = "description",
                .slot_type_id = "slotTypeId",
                .value_elicitation_setting = "valueElicitationSetting",
                .obfuscation_setting = "obfuscationSetting",
                .bot_id = "botId",
                .bot_version = "botVersion",
                .locale_id = "localeId",
                .intent_id = "intentId",
                .creation_date_time = "creationDateTime",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        Conflict,
        InternalServer,
        PreconditionFailed,
        ServiceQuotaExceeded,
        Throttling,
        Validation,
    },
} = .{};
pub const create_slot_type: struct {
    pub const http_config = .{
        .method = "PUT",
        .uri = "/bots/{botId}/botversions/{botVersion}/botlocales/{localeId}/slottypes",
        .success_code = 200,
    };

    action_name: []const u8 = "CreateSlotType",
    Request: type = struct {
        slot_type_name: []const u8,
        description: ?[]const u8 = null,
        slot_type_values: ?[]SlotTypeValue = null,
        value_selection_setting: SlotValueSelectionSetting,
        parent_slot_type_signature: ?[]const u8 = null,
        bot_id: []const u8,
        bot_version: []const u8,
        locale_id: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .slot_type_name = "slotTypeName",
                .description = "description",
                .slot_type_values = "slotTypeValues",
                .value_selection_setting = "valueSelectionSetting",
                .parent_slot_type_signature = "parentSlotTypeSignature",
                .bot_id = "botId",
                .bot_version = "botVersion",
                .locale_id = "localeId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(create_slot_type) } {
            return .{ .service_metadata = service_metadata, .action = create_slot_type };
        }
    },
    Response: type = struct {
        slot_type_id: ?[]const u8 = null,
        slot_type_name: ?[]const u8 = null,
        description: ?[]const u8 = null,
        slot_type_values: ?[]SlotTypeValue = null,
        value_selection_setting: ?SlotValueSelectionSetting = null,
        parent_slot_type_signature: ?[]const u8 = null,
        bot_id: ?[]const u8 = null,
        bot_version: ?[]const u8 = null,
        locale_id: ?[]const u8 = null,
        creation_date_time: ?i64 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .slot_type_id = "slotTypeId",
                .slot_type_name = "slotTypeName",
                .description = "description",
                .slot_type_values = "slotTypeValues",
                .value_selection_setting = "valueSelectionSetting",
                .parent_slot_type_signature = "parentSlotTypeSignature",
                .bot_id = "botId",
                .bot_version = "botVersion",
                .locale_id = "localeId",
                .creation_date_time = "creationDateTime",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        Conflict,
        InternalServer,
        PreconditionFailed,
        ServiceQuotaExceeded,
        Throttling,
        Validation,
    },
} = .{};
pub const create_upload_url: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/createuploadurl",
        .success_code = 200,
    };

    action_name: []const u8 = "CreateUploadUrl",
    Request: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(create_upload_url) } {
            return .{ .service_metadata = service_metadata, .action = create_upload_url };
        }
    },
    Response: type = struct {
        import_id: ?[]const u8 = null,
        upload_url: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .import_id = "importId",
                .upload_url = "uploadUrl",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        Conflict,
        InternalServer,
        ResourceNotFound,
        Throttling,
        Validation,
    },
} = .{};
pub const delete_bot: struct {
    pub const http_config = .{
        .method = "DELETE",
        .uri = "/bots/{botId}",
        .success_code = 202,
    };

    action_name: []const u8 = "DeleteBot",
    Request: type = struct {
        bot_id: []const u8,
        skip_resource_in_use_check: ?bool = null,

        pub const http_query = .{
            .skip_resource_in_use_check = "skipResourceInUseCheck",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .bot_id = "botId",
                .skip_resource_in_use_check = "skipResourceInUseCheck",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(delete_bot) } {
            return .{ .service_metadata = service_metadata, .action = delete_bot };
        }
    },
    Response: type = struct {
        bot_id: ?[]const u8 = null,
        bot_status: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .bot_id = "botId",
                .bot_status = "botStatus",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        Conflict,
        InternalServer,
        PreconditionFailed,
        ServiceQuotaExceeded,
        Throttling,
        Validation,
    },
} = .{};
pub const delete_bot_alias: struct {
    pub const http_config = .{
        .method = "DELETE",
        .uri = "/bots/{botId}/botaliases/{botAliasId}",
        .success_code = 202,
    };

    action_name: []const u8 = "DeleteBotAlias",
    Request: type = struct {
        bot_alias_id: []const u8,
        bot_id: []const u8,
        skip_resource_in_use_check: ?bool = null,

        pub const http_query = .{
            .skip_resource_in_use_check = "skipResourceInUseCheck",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .bot_alias_id = "botAliasId",
                .bot_id = "botId",
                .skip_resource_in_use_check = "skipResourceInUseCheck",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(delete_bot_alias) } {
            return .{ .service_metadata = service_metadata, .action = delete_bot_alias };
        }
    },
    Response: type = struct {
        bot_alias_id: ?[]const u8 = null,
        bot_id: ?[]const u8 = null,
        bot_alias_status: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .bot_alias_id = "botAliasId",
                .bot_id = "botId",
                .bot_alias_status = "botAliasStatus",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        Conflict,
        InternalServer,
        PreconditionFailed,
        ServiceQuotaExceeded,
        Throttling,
        Validation,
    },
} = .{};
pub const delete_bot_locale: struct {
    pub const http_config = .{
        .method = "DELETE",
        .uri = "/bots/{botId}/botversions/{botVersion}/botlocales/{localeId}",
        .success_code = 202,
    };

    action_name: []const u8 = "DeleteBotLocale",
    Request: type = struct {
        bot_id: []const u8,
        bot_version: []const u8,
        locale_id: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .bot_id = "botId",
                .bot_version = "botVersion",
                .locale_id = "localeId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(delete_bot_locale) } {
            return .{ .service_metadata = service_metadata, .action = delete_bot_locale };
        }
    },
    Response: type = struct {
        bot_id: ?[]const u8 = null,
        bot_version: ?[]const u8 = null,
        locale_id: ?[]const u8 = null,
        bot_locale_status: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .bot_id = "botId",
                .bot_version = "botVersion",
                .locale_id = "localeId",
                .bot_locale_status = "botLocaleStatus",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        Conflict,
        InternalServer,
        PreconditionFailed,
        ServiceQuotaExceeded,
        Throttling,
        Validation,
    },
} = .{};
pub const delete_bot_version: struct {
    pub const http_config = .{
        .method = "DELETE",
        .uri = "/bots/{botId}/botversions/{botVersion}",
        .success_code = 202,
    };

    action_name: []const u8 = "DeleteBotVersion",
    Request: type = struct {
        bot_id: []const u8,
        bot_version: []const u8,
        skip_resource_in_use_check: ?bool = null,

        pub const http_query = .{
            .skip_resource_in_use_check = "skipResourceInUseCheck",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .bot_id = "botId",
                .bot_version = "botVersion",
                .skip_resource_in_use_check = "skipResourceInUseCheck",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(delete_bot_version) } {
            return .{ .service_metadata = service_metadata, .action = delete_bot_version };
        }
    },
    Response: type = struct {
        bot_id: ?[]const u8 = null,
        bot_version: ?[]const u8 = null,
        bot_status: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .bot_id = "botId",
                .bot_version = "botVersion",
                .bot_status = "botStatus",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        Conflict,
        InternalServer,
        PreconditionFailed,
        ServiceQuotaExceeded,
        Throttling,
        Validation,
    },
} = .{};
pub const delete_export: struct {
    pub const http_config = .{
        .method = "DELETE",
        .uri = "/exports/{exportId}",
        .success_code = 202,
    };

    action_name: []const u8 = "DeleteExport",
    Request: type = struct {
        export_id: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .export_id = "exportId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(delete_export) } {
            return .{ .service_metadata = service_metadata, .action = delete_export };
        }
    },
    Response: type = struct {
        export_id: ?[]const u8 = null,
        export_status: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .export_id = "exportId",
                .export_status = "exportStatus",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalServer,
        PreconditionFailed,
        ServiceQuotaExceeded,
        Throttling,
        Validation,
    },
} = .{};
pub const delete_import: struct {
    pub const http_config = .{
        .method = "DELETE",
        .uri = "/imports/{importId}",
        .success_code = 202,
    };

    action_name: []const u8 = "DeleteImport",
    Request: type = struct {
        import_id: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .import_id = "importId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(delete_import) } {
            return .{ .service_metadata = service_metadata, .action = delete_import };
        }
    },
    Response: type = struct {
        import_id: ?[]const u8 = null,
        import_status: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .import_id = "importId",
                .import_status = "importStatus",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalServer,
        PreconditionFailed,
        ServiceQuotaExceeded,
        Throttling,
        Validation,
    },
} = .{};
pub const delete_intent: struct {
    pub const http_config = .{
        .method = "DELETE",
        .uri = "/bots/{botId}/botversions/{botVersion}/botlocales/{localeId}/intents/{intentId}",
        .success_code = 204,
    };

    action_name: []const u8 = "DeleteIntent",
    Request: type = struct {
        intent_id: []const u8,
        bot_id: []const u8,
        bot_version: []const u8,
        locale_id: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .intent_id = "intentId",
                .bot_id = "botId",
                .bot_version = "botVersion",
                .locale_id = "localeId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(delete_intent) } {
            return .{ .service_metadata = service_metadata, .action = delete_intent };
        }
    },
    Response: type = struct {},
    ServiceError: type = error{
        Conflict,
        InternalServer,
        PreconditionFailed,
        ServiceQuotaExceeded,
        Throttling,
        Validation,
    },
} = .{};
pub const delete_resource_policy: struct {
    pub const http_config = .{
        .method = "DELETE",
        .uri = "/policy/{resourceArn}",
        .success_code = 204,
    };

    action_name: []const u8 = "DeleteResourcePolicy",
    Request: type = struct {
        resource_arn: []const u8,
        expected_revision_id: ?[]const u8 = null,

        pub const http_query = .{
            .expected_revision_id = "expectedRevisionId",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .resource_arn = "resourceArn",
                .expected_revision_id = "expectedRevisionId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(delete_resource_policy) } {
            return .{ .service_metadata = service_metadata, .action = delete_resource_policy };
        }
    },
    Response: type = struct {
        resource_arn: ?[]const u8 = null,
        revision_id: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .resource_arn = "resourceArn",
                .revision_id = "revisionId",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalServer,
        PreconditionFailed,
        ResourceNotFound,
        Throttling,
    },
} = .{};
pub const delete_resource_policy_statement: struct {
    pub const http_config = .{
        .method = "DELETE",
        .uri = "/policy/{resourceArn}/statements/{statementId}",
        .success_code = 204,
    };

    action_name: []const u8 = "DeleteResourcePolicyStatement",
    Request: type = struct {
        resource_arn: []const u8,
        statement_id: []const u8,
        expected_revision_id: ?[]const u8 = null,

        pub const http_query = .{
            .expected_revision_id = "expectedRevisionId",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .resource_arn = "resourceArn",
                .statement_id = "statementId",
                .expected_revision_id = "expectedRevisionId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(delete_resource_policy_statement) } {
            return .{ .service_metadata = service_metadata, .action = delete_resource_policy_statement };
        }
    },
    Response: type = struct {
        resource_arn: ?[]const u8 = null,
        revision_id: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .resource_arn = "resourceArn",
                .revision_id = "revisionId",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalServer,
        PreconditionFailed,
        ResourceNotFound,
        Throttling,
    },
} = .{};
pub const delete_slot: struct {
    pub const http_config = .{
        .method = "DELETE",
        .uri = "/bots/{botId}/botversions/{botVersion}/botlocales/{localeId}/intents/{intentId}/slots/{slotId}",
        .success_code = 204,
    };

    action_name: []const u8 = "DeleteSlot",
    Request: type = struct {
        slot_id: []const u8,
        bot_id: []const u8,
        bot_version: []const u8,
        locale_id: []const u8,
        intent_id: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .slot_id = "slotId",
                .bot_id = "botId",
                .bot_version = "botVersion",
                .locale_id = "localeId",
                .intent_id = "intentId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(delete_slot) } {
            return .{ .service_metadata = service_metadata, .action = delete_slot };
        }
    },
    Response: type = struct {},
    ServiceError: type = error{
        Conflict,
        InternalServer,
        PreconditionFailed,
        ServiceQuotaExceeded,
        Throttling,
        Validation,
    },
} = .{};
pub const delete_slot_type: struct {
    pub const http_config = .{
        .method = "DELETE",
        .uri = "/bots/{botId}/botversions/{botVersion}/botlocales/{localeId}/slottypes/{slotTypeId}",
        .success_code = 204,
    };

    action_name: []const u8 = "DeleteSlotType",
    Request: type = struct {
        slot_type_id: []const u8,
        bot_id: []const u8,
        bot_version: []const u8,
        locale_id: []const u8,
        skip_resource_in_use_check: ?bool = null,

        pub const http_query = .{
            .skip_resource_in_use_check = "skipResourceInUseCheck",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .slot_type_id = "slotTypeId",
                .bot_id = "botId",
                .bot_version = "botVersion",
                .locale_id = "localeId",
                .skip_resource_in_use_check = "skipResourceInUseCheck",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(delete_slot_type) } {
            return .{ .service_metadata = service_metadata, .action = delete_slot_type };
        }
    },
    Response: type = struct {},
    ServiceError: type = error{
        Conflict,
        InternalServer,
        PreconditionFailed,
        ServiceQuotaExceeded,
        Throttling,
        Validation,
    },
} = .{};
pub const describe_bot: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/bots/{botId}",
        .success_code = 200,
    };

    action_name: []const u8 = "DescribeBot",
    Request: type = struct {
        bot_id: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .bot_id = "botId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(describe_bot) } {
            return .{ .service_metadata = service_metadata, .action = describe_bot };
        }
    },
    Response: type = struct {
        bot_id: ?[]const u8 = null,
        bot_name: ?[]const u8 = null,
        description: ?[]const u8 = null,
        role_arn: ?[]const u8 = null,
        data_privacy: ?DataPrivacy = null,
        idle_session_ttl_in_seconds: ?i64 = null,
        bot_status: ?[]const u8 = null,
        creation_date_time: ?i64 = null,
        last_updated_date_time: ?i64 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .bot_id = "botId",
                .bot_name = "botName",
                .description = "description",
                .role_arn = "roleArn",
                .data_privacy = "dataPrivacy",
                .idle_session_ttl_in_seconds = "idleSessionTTLInSeconds",
                .bot_status = "botStatus",
                .creation_date_time = "creationDateTime",
                .last_updated_date_time = "lastUpdatedDateTime",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalServer,
        ResourceNotFound,
        ServiceQuotaExceeded,
        Throttling,
        Validation,
    },
} = .{};
pub const describe_bot_alias: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/bots/{botId}/botaliases/{botAliasId}",
        .success_code = 200,
    };

    action_name: []const u8 = "DescribeBotAlias",
    Request: type = struct {
        bot_alias_id: []const u8,
        bot_id: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .bot_alias_id = "botAliasId",
                .bot_id = "botId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(describe_bot_alias) } {
            return .{ .service_metadata = service_metadata, .action = describe_bot_alias };
        }
    },
    Response: type = struct {
        bot_alias_id: ?[]const u8 = null,
        bot_alias_name: ?[]const u8 = null,
        description: ?[]const u8 = null,
        bot_version: ?[]const u8 = null,
        bot_alias_locale_settings: ?[]struct {
            key: ?[]const u8 = null,
            value: ?BotAliasLocaleSettings = null,
        } = null,
        conversation_log_settings: ?ConversationLogSettings = null,
        sentiment_analysis_settings: ?SentimentAnalysisSettings = null,
        bot_alias_history_events: ?[]struct {
            bot_version: ?[]const u8 = null,
            start_date: ?i64 = null,
            end_date: ?i64 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .bot_version = "botVersion",
                    .start_date = "startDate",
                    .end_date = "endDate",
                };
                return @field(mappings, field_name);
            }
        } = null,
        bot_alias_status: ?[]const u8 = null,
        bot_id: ?[]const u8 = null,
        creation_date_time: ?i64 = null,
        last_updated_date_time: ?i64 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .bot_alias_id = "botAliasId",
                .bot_alias_name = "botAliasName",
                .description = "description",
                .bot_version = "botVersion",
                .bot_alias_locale_settings = "botAliasLocaleSettings",
                .conversation_log_settings = "conversationLogSettings",
                .sentiment_analysis_settings = "sentimentAnalysisSettings",
                .bot_alias_history_events = "botAliasHistoryEvents",
                .bot_alias_status = "botAliasStatus",
                .bot_id = "botId",
                .creation_date_time = "creationDateTime",
                .last_updated_date_time = "lastUpdatedDateTime",
            };
            return @field(mappings, field_name);
        }

        pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
            if (std.mem.eql(u8, "bot_alias_locale_settings", field_name))
                return try serializeMap(self.bot_alias_locale_settings, self.fieldNameFor("bot_alias_locale_settings"), options, out_stream);
            return false;
        }
    },
    ServiceError: type = error{
        InternalServer,
        ResourceNotFound,
        ServiceQuotaExceeded,
        Throttling,
        Validation,
    },
} = .{};
pub const describe_bot_locale: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/bots/{botId}/botversions/{botVersion}/botlocales/{localeId}",
        .success_code = 200,
    };

    action_name: []const u8 = "DescribeBotLocale",
    Request: type = struct {
        bot_id: []const u8,
        bot_version: []const u8,
        locale_id: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .bot_id = "botId",
                .bot_version = "botVersion",
                .locale_id = "localeId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(describe_bot_locale) } {
            return .{ .service_metadata = service_metadata, .action = describe_bot_locale };
        }
    },
    Response: type = struct {
        bot_id: ?[]const u8 = null,
        bot_version: ?[]const u8 = null,
        locale_id: ?[]const u8 = null,
        locale_name: ?[]const u8 = null,
        description: ?[]const u8 = null,
        nlu_intent_confidence_threshold: ?f64 = null,
        voice_settings: ?VoiceSettings = null,
        intents_count: ?i64 = null,
        slot_types_count: ?i64 = null,
        bot_locale_status: ?[]const u8 = null,
        failure_reasons: ?[][]const u8 = null,
        creation_date_time: ?i64 = null,
        last_updated_date_time: ?i64 = null,
        last_build_submitted_date_time: ?i64 = null,
        bot_locale_history_events: ?[]struct {
            event: []const u8,
            event_date: i64,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .event = "event",
                    .event_date = "eventDate",
                };
                return @field(mappings, field_name);
            }
        } = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .bot_id = "botId",
                .bot_version = "botVersion",
                .locale_id = "localeId",
                .locale_name = "localeName",
                .description = "description",
                .nlu_intent_confidence_threshold = "nluIntentConfidenceThreshold",
                .voice_settings = "voiceSettings",
                .intents_count = "intentsCount",
                .slot_types_count = "slotTypesCount",
                .bot_locale_status = "botLocaleStatus",
                .failure_reasons = "failureReasons",
                .creation_date_time = "creationDateTime",
                .last_updated_date_time = "lastUpdatedDateTime",
                .last_build_submitted_date_time = "lastBuildSubmittedDateTime",
                .bot_locale_history_events = "botLocaleHistoryEvents",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalServer,
        ResourceNotFound,
        ServiceQuotaExceeded,
        Throttling,
        Validation,
    },
} = .{};
pub const describe_bot_version: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/bots/{botId}/botversions/{botVersion}",
        .success_code = 200,
    };

    action_name: []const u8 = "DescribeBotVersion",
    Request: type = struct {
        bot_id: []const u8,
        bot_version: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .bot_id = "botId",
                .bot_version = "botVersion",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(describe_bot_version) } {
            return .{ .service_metadata = service_metadata, .action = describe_bot_version };
        }
    },
    Response: type = struct {
        bot_id: ?[]const u8 = null,
        bot_name: ?[]const u8 = null,
        bot_version: ?[]const u8 = null,
        description: ?[]const u8 = null,
        role_arn: ?[]const u8 = null,
        data_privacy: ?DataPrivacy = null,
        idle_session_ttl_in_seconds: ?i64 = null,
        bot_status: ?[]const u8 = null,
        failure_reasons: ?[][]const u8 = null,
        creation_date_time: ?i64 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .bot_id = "botId",
                .bot_name = "botName",
                .bot_version = "botVersion",
                .description = "description",
                .role_arn = "roleArn",
                .data_privacy = "dataPrivacy",
                .idle_session_ttl_in_seconds = "idleSessionTTLInSeconds",
                .bot_status = "botStatus",
                .failure_reasons = "failureReasons",
                .creation_date_time = "creationDateTime",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalServer,
        ResourceNotFound,
        ServiceQuotaExceeded,
        Throttling,
        Validation,
    },
} = .{};
pub const describe_export: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/exports/{exportId}",
        .success_code = 200,
    };

    action_name: []const u8 = "DescribeExport",
    Request: type = struct {
        export_id: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .export_id = "exportId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(describe_export) } {
            return .{ .service_metadata = service_metadata, .action = describe_export };
        }
    },
    Response: type = struct {
        export_id: ?[]const u8 = null,
        resource_specification: ?ExportResourceSpecification = null,
        file_format: ?[]const u8 = null,
        export_status: ?[]const u8 = null,
        failure_reasons: ?[][]const u8 = null,
        download_url: ?[]const u8 = null,
        creation_date_time: ?i64 = null,
        last_updated_date_time: ?i64 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .export_id = "exportId",
                .resource_specification = "resourceSpecification",
                .file_format = "fileFormat",
                .export_status = "exportStatus",
                .failure_reasons = "failureReasons",
                .download_url = "downloadUrl",
                .creation_date_time = "creationDateTime",
                .last_updated_date_time = "lastUpdatedDateTime",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalServer,
        ResourceNotFound,
        Throttling,
        Validation,
    },
} = .{};
pub const describe_import: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/imports/{importId}",
        .success_code = 200,
    };

    action_name: []const u8 = "DescribeImport",
    Request: type = struct {
        import_id: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .import_id = "importId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(describe_import) } {
            return .{ .service_metadata = service_metadata, .action = describe_import };
        }
    },
    Response: type = struct {
        import_id: ?[]const u8 = null,
        resource_specification: ?ImportResourceSpecification = null,
        imported_resource_id: ?[]const u8 = null,
        imported_resource_name: ?[]const u8 = null,
        merge_strategy: ?[]const u8 = null,
        import_status: ?[]const u8 = null,
        failure_reasons: ?[][]const u8 = null,
        creation_date_time: ?i64 = null,
        last_updated_date_time: ?i64 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .import_id = "importId",
                .resource_specification = "resourceSpecification",
                .imported_resource_id = "importedResourceId",
                .imported_resource_name = "importedResourceName",
                .merge_strategy = "mergeStrategy",
                .import_status = "importStatus",
                .failure_reasons = "failureReasons",
                .creation_date_time = "creationDateTime",
                .last_updated_date_time = "lastUpdatedDateTime",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalServer,
        ResourceNotFound,
        Throttling,
        Validation,
    },
} = .{};
pub const describe_intent: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/bots/{botId}/botversions/{botVersion}/botlocales/{localeId}/intents/{intentId}",
        .success_code = 200,
    };

    action_name: []const u8 = "DescribeIntent",
    Request: type = struct {
        intent_id: []const u8,
        bot_id: []const u8,
        bot_version: []const u8,
        locale_id: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .intent_id = "intentId",
                .bot_id = "botId",
                .bot_version = "botVersion",
                .locale_id = "localeId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(describe_intent) } {
            return .{ .service_metadata = service_metadata, .action = describe_intent };
        }
    },
    Response: type = struct {
        intent_id: ?[]const u8 = null,
        intent_name: ?[]const u8 = null,
        description: ?[]const u8 = null,
        parent_intent_signature: ?[]const u8 = null,
        sample_utterances: ?[]SampleUtterance = null,
        dialog_code_hook: ?DialogCodeHookSettings = null,
        fulfillment_code_hook: ?FulfillmentCodeHookSettings = null,
        slot_priorities: ?[]SlotPriority = null,
        intent_confirmation_setting: ?IntentConfirmationSetting = null,
        intent_closing_setting: ?IntentClosingSetting = null,
        input_contexts: ?[]InputContext = null,
        output_contexts: ?[]OutputContext = null,
        kendra_configuration: ?KendraConfiguration = null,
        bot_id: ?[]const u8 = null,
        bot_version: ?[]const u8 = null,
        locale_id: ?[]const u8 = null,
        creation_date_time: ?i64 = null,
        last_updated_date_time: ?i64 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .intent_id = "intentId",
                .intent_name = "intentName",
                .description = "description",
                .parent_intent_signature = "parentIntentSignature",
                .sample_utterances = "sampleUtterances",
                .dialog_code_hook = "dialogCodeHook",
                .fulfillment_code_hook = "fulfillmentCodeHook",
                .slot_priorities = "slotPriorities",
                .intent_confirmation_setting = "intentConfirmationSetting",
                .intent_closing_setting = "intentClosingSetting",
                .input_contexts = "inputContexts",
                .output_contexts = "outputContexts",
                .kendra_configuration = "kendraConfiguration",
                .bot_id = "botId",
                .bot_version = "botVersion",
                .locale_id = "localeId",
                .creation_date_time = "creationDateTime",
                .last_updated_date_time = "lastUpdatedDateTime",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalServer,
        ResourceNotFound,
        ServiceQuotaExceeded,
        Throttling,
        Validation,
    },
} = .{};
pub const describe_resource_policy: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/policy/{resourceArn}",
        .success_code = 200,
    };

    action_name: []const u8 = "DescribeResourcePolicy",
    Request: type = struct {
        resource_arn: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .resource_arn = "resourceArn",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(describe_resource_policy) } {
            return .{ .service_metadata = service_metadata, .action = describe_resource_policy };
        }
    },
    Response: type = struct {
        resource_arn: ?[]const u8 = null,
        policy: ?[]const u8 = null,
        revision_id: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .resource_arn = "resourceArn",
                .policy = "policy",
                .revision_id = "revisionId",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalServer,
        ResourceNotFound,
        Throttling,
    },
} = .{};
pub const describe_slot: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/bots/{botId}/botversions/{botVersion}/botlocales/{localeId}/intents/{intentId}/slots/{slotId}",
        .success_code = 200,
    };

    action_name: []const u8 = "DescribeSlot",
    Request: type = struct {
        slot_id: []const u8,
        bot_id: []const u8,
        bot_version: []const u8,
        locale_id: []const u8,
        intent_id: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .slot_id = "slotId",
                .bot_id = "botId",
                .bot_version = "botVersion",
                .locale_id = "localeId",
                .intent_id = "intentId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(describe_slot) } {
            return .{ .service_metadata = service_metadata, .action = describe_slot };
        }
    },
    Response: type = struct {
        slot_id: ?[]const u8 = null,
        slot_name: ?[]const u8 = null,
        description: ?[]const u8 = null,
        slot_type_id: ?[]const u8 = null,
        value_elicitation_setting: ?SlotValueElicitationSetting = null,
        obfuscation_setting: ?ObfuscationSetting = null,
        bot_id: ?[]const u8 = null,
        bot_version: ?[]const u8 = null,
        locale_id: ?[]const u8 = null,
        intent_id: ?[]const u8 = null,
        creation_date_time: ?i64 = null,
        last_updated_date_time: ?i64 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .slot_id = "slotId",
                .slot_name = "slotName",
                .description = "description",
                .slot_type_id = "slotTypeId",
                .value_elicitation_setting = "valueElicitationSetting",
                .obfuscation_setting = "obfuscationSetting",
                .bot_id = "botId",
                .bot_version = "botVersion",
                .locale_id = "localeId",
                .intent_id = "intentId",
                .creation_date_time = "creationDateTime",
                .last_updated_date_time = "lastUpdatedDateTime",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalServer,
        ResourceNotFound,
        ServiceQuotaExceeded,
        Throttling,
        Validation,
    },
} = .{};
pub const describe_slot_type: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/bots/{botId}/botversions/{botVersion}/botlocales/{localeId}/slottypes/{slotTypeId}",
        .success_code = 200,
    };

    action_name: []const u8 = "DescribeSlotType",
    Request: type = struct {
        slot_type_id: []const u8,
        bot_id: []const u8,
        bot_version: []const u8,
        locale_id: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .slot_type_id = "slotTypeId",
                .bot_id = "botId",
                .bot_version = "botVersion",
                .locale_id = "localeId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(describe_slot_type) } {
            return .{ .service_metadata = service_metadata, .action = describe_slot_type };
        }
    },
    Response: type = struct {
        slot_type_id: ?[]const u8 = null,
        slot_type_name: ?[]const u8 = null,
        description: ?[]const u8 = null,
        slot_type_values: ?[]SlotTypeValue = null,
        value_selection_setting: ?SlotValueSelectionSetting = null,
        parent_slot_type_signature: ?[]const u8 = null,
        bot_id: ?[]const u8 = null,
        bot_version: ?[]const u8 = null,
        locale_id: ?[]const u8 = null,
        creation_date_time: ?i64 = null,
        last_updated_date_time: ?i64 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .slot_type_id = "slotTypeId",
                .slot_type_name = "slotTypeName",
                .description = "description",
                .slot_type_values = "slotTypeValues",
                .value_selection_setting = "valueSelectionSetting",
                .parent_slot_type_signature = "parentSlotTypeSignature",
                .bot_id = "botId",
                .bot_version = "botVersion",
                .locale_id = "localeId",
                .creation_date_time = "creationDateTime",
                .last_updated_date_time = "lastUpdatedDateTime",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalServer,
        ResourceNotFound,
        ServiceQuotaExceeded,
        Throttling,
        Validation,
    },
} = .{};
pub const list_bot_aliases: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/bots/{botId}/botaliases",
        .success_code = 200,
    };

    action_name: []const u8 = "ListBotAliases",
    Request: type = struct {
        bot_id: []const u8,
        max_results: ?i64 = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .bot_id = "botId",
                .max_results = "maxResults",
                .next_token = "nextToken",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_bot_aliases) } {
            return .{ .service_metadata = service_metadata, .action = list_bot_aliases };
        }
    },
    Response: type = struct {
        bot_alias_summaries: ?[]struct {
            bot_alias_id: ?[]const u8 = null,
            bot_alias_name: ?[]const u8 = null,
            description: ?[]const u8 = null,
            bot_version: ?[]const u8 = null,
            bot_alias_status: ?[]const u8 = null,
            creation_date_time: ?i64 = null,
            last_updated_date_time: ?i64 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .bot_alias_id = "botAliasId",
                    .bot_alias_name = "botAliasName",
                    .description = "description",
                    .bot_version = "botVersion",
                    .bot_alias_status = "botAliasStatus",
                    .creation_date_time = "creationDateTime",
                    .last_updated_date_time = "lastUpdatedDateTime",
                };
                return @field(mappings, field_name);
            }
        } = null,
        next_token: ?[]const u8 = null,
        bot_id: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .bot_alias_summaries = "botAliasSummaries",
                .next_token = "nextToken",
                .bot_id = "botId",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalServer,
        ServiceQuotaExceeded,
        Throttling,
        Validation,
    },
} = .{};
pub const list_bot_locales: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/bots/{botId}/botversions/{botVersion}/botlocales",
        .success_code = 200,
    };

    action_name: []const u8 = "ListBotLocales",
    Request: type = struct {
        bot_id: []const u8,
        bot_version: []const u8,
        sort_by: ?struct {
            attribute: []const u8,
            order: []const u8,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .attribute = "attribute",
                    .order = "order",
                };
                return @field(mappings, field_name);
            }
        } = null,
        filters: ?[]struct {
            name: []const u8,
            values: [][]const u8,
            operator: []const u8,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .name = "name",
                    .values = "values",
                    .operator = "operator",
                };
                return @field(mappings, field_name);
            }
        } = null,
        max_results: ?i64 = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .bot_id = "botId",
                .bot_version = "botVersion",
                .sort_by = "sortBy",
                .filters = "filters",
                .max_results = "maxResults",
                .next_token = "nextToken",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_bot_locales) } {
            return .{ .service_metadata = service_metadata, .action = list_bot_locales };
        }
    },
    Response: type = struct {
        bot_id: ?[]const u8 = null,
        bot_version: ?[]const u8 = null,
        next_token: ?[]const u8 = null,
        bot_locale_summaries: ?[]struct {
            locale_id: ?[]const u8 = null,
            locale_name: ?[]const u8 = null,
            description: ?[]const u8 = null,
            bot_locale_status: ?[]const u8 = null,
            last_updated_date_time: ?i64 = null,
            last_build_submitted_date_time: ?i64 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .locale_id = "localeId",
                    .locale_name = "localeName",
                    .description = "description",
                    .bot_locale_status = "botLocaleStatus",
                    .last_updated_date_time = "lastUpdatedDateTime",
                    .last_build_submitted_date_time = "lastBuildSubmittedDateTime",
                };
                return @field(mappings, field_name);
            }
        } = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .bot_id = "botId",
                .bot_version = "botVersion",
                .next_token = "nextToken",
                .bot_locale_summaries = "botLocaleSummaries",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalServer,
        ServiceQuotaExceeded,
        Throttling,
        Validation,
    },
} = .{};
pub const list_bots: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/bots",
        .success_code = 200,
    };

    action_name: []const u8 = "ListBots",
    Request: type = struct {
        sort_by: ?struct {
            attribute: []const u8,
            order: []const u8,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .attribute = "attribute",
                    .order = "order",
                };
                return @field(mappings, field_name);
            }
        } = null,
        filters: ?[]struct {
            name: []const u8,
            values: [][]const u8,
            operator: []const u8,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .name = "name",
                    .values = "values",
                    .operator = "operator",
                };
                return @field(mappings, field_name);
            }
        } = null,
        max_results: ?i64 = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .sort_by = "sortBy",
                .filters = "filters",
                .max_results = "maxResults",
                .next_token = "nextToken",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_bots) } {
            return .{ .service_metadata = service_metadata, .action = list_bots };
        }
    },
    Response: type = struct {
        bot_summaries: ?[]struct {
            bot_id: ?[]const u8 = null,
            bot_name: ?[]const u8 = null,
            description: ?[]const u8 = null,
            bot_status: ?[]const u8 = null,
            latest_bot_version: ?[]const u8 = null,
            last_updated_date_time: ?i64 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .bot_id = "botId",
                    .bot_name = "botName",
                    .description = "description",
                    .bot_status = "botStatus",
                    .latest_bot_version = "latestBotVersion",
                    .last_updated_date_time = "lastUpdatedDateTime",
                };
                return @field(mappings, field_name);
            }
        } = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .bot_summaries = "botSummaries",
                .next_token = "nextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalServer,
        ServiceQuotaExceeded,
        Throttling,
        Validation,
    },
} = .{};
pub const list_bot_versions: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/bots/{botId}/botversions",
        .success_code = 200,
    };

    action_name: []const u8 = "ListBotVersions",
    Request: type = struct {
        bot_id: []const u8,
        sort_by: ?struct {
            attribute: []const u8,
            order: []const u8,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .attribute = "attribute",
                    .order = "order",
                };
                return @field(mappings, field_name);
            }
        } = null,
        max_results: ?i64 = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .bot_id = "botId",
                .sort_by = "sortBy",
                .max_results = "maxResults",
                .next_token = "nextToken",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_bot_versions) } {
            return .{ .service_metadata = service_metadata, .action = list_bot_versions };
        }
    },
    Response: type = struct {
        bot_id: ?[]const u8 = null,
        bot_version_summaries: ?[]struct {
            bot_name: ?[]const u8 = null,
            bot_version: ?[]const u8 = null,
            description: ?[]const u8 = null,
            bot_status: ?[]const u8 = null,
            creation_date_time: ?i64 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .bot_name = "botName",
                    .bot_version = "botVersion",
                    .description = "description",
                    .bot_status = "botStatus",
                    .creation_date_time = "creationDateTime",
                };
                return @field(mappings, field_name);
            }
        } = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .bot_id = "botId",
                .bot_version_summaries = "botVersionSummaries",
                .next_token = "nextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalServer,
        ServiceQuotaExceeded,
        Throttling,
        Validation,
    },
} = .{};
pub const list_built_in_intents: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/builtins/locales/{localeId}/intents",
        .success_code = 200,
    };

    action_name: []const u8 = "ListBuiltInIntents",
    Request: type = struct {
        locale_id: []const u8,
        sort_by: ?struct {
            attribute: []const u8,
            order: []const u8,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .attribute = "attribute",
                    .order = "order",
                };
                return @field(mappings, field_name);
            }
        } = null,
        max_results: ?i64 = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .locale_id = "localeId",
                .sort_by = "sortBy",
                .max_results = "maxResults",
                .next_token = "nextToken",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_built_in_intents) } {
            return .{ .service_metadata = service_metadata, .action = list_built_in_intents };
        }
    },
    Response: type = struct {
        built_in_intent_summaries: ?[]struct {
            intent_signature: ?[]const u8 = null,
            description: ?[]const u8 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .intent_signature = "intentSignature",
                    .description = "description",
                };
                return @field(mappings, field_name);
            }
        } = null,
        next_token: ?[]const u8 = null,
        locale_id: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .built_in_intent_summaries = "builtInIntentSummaries",
                .next_token = "nextToken",
                .locale_id = "localeId",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalServer,
        ServiceQuotaExceeded,
        Throttling,
        Validation,
    },
} = .{};
pub const list_built_in_slot_types: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/builtins/locales/{localeId}/slottypes",
        .success_code = 200,
    };

    action_name: []const u8 = "ListBuiltInSlotTypes",
    Request: type = struct {
        locale_id: []const u8,
        sort_by: ?struct {
            attribute: []const u8,
            order: []const u8,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .attribute = "attribute",
                    .order = "order",
                };
                return @field(mappings, field_name);
            }
        } = null,
        max_results: ?i64 = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .locale_id = "localeId",
                .sort_by = "sortBy",
                .max_results = "maxResults",
                .next_token = "nextToken",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_built_in_slot_types) } {
            return .{ .service_metadata = service_metadata, .action = list_built_in_slot_types };
        }
    },
    Response: type = struct {
        built_in_slot_type_summaries: ?[]struct {
            slot_type_signature: ?[]const u8 = null,
            description: ?[]const u8 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .slot_type_signature = "slotTypeSignature",
                    .description = "description",
                };
                return @field(mappings, field_name);
            }
        } = null,
        next_token: ?[]const u8 = null,
        locale_id: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .built_in_slot_type_summaries = "builtInSlotTypeSummaries",
                .next_token = "nextToken",
                .locale_id = "localeId",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalServer,
        ServiceQuotaExceeded,
        Throttling,
        Validation,
    },
} = .{};
pub const list_exports: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/exports",
        .success_code = 200,
    };

    action_name: []const u8 = "ListExports",
    Request: type = struct {
        bot_id: ?[]const u8 = null,
        bot_version: ?[]const u8 = null,
        sort_by: ?struct {
            attribute: []const u8,
            order: []const u8,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .attribute = "attribute",
                    .order = "order",
                };
                return @field(mappings, field_name);
            }
        } = null,
        filters: ?[]struct {
            name: []const u8,
            values: [][]const u8,
            operator: []const u8,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .name = "name",
                    .values = "values",
                    .operator = "operator",
                };
                return @field(mappings, field_name);
            }
        } = null,
        max_results: ?i64 = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .bot_id = "botId",
                .bot_version = "botVersion",
                .sort_by = "sortBy",
                .filters = "filters",
                .max_results = "maxResults",
                .next_token = "nextToken",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_exports) } {
            return .{ .service_metadata = service_metadata, .action = list_exports };
        }
    },
    Response: type = struct {
        bot_id: ?[]const u8 = null,
        bot_version: ?[]const u8 = null,
        export_summaries: ?[]struct {
            export_id: ?[]const u8 = null,
            resource_specification: ?ExportResourceSpecification = null,
            file_format: ?[]const u8 = null,
            export_status: ?[]const u8 = null,
            creation_date_time: ?i64 = null,
            last_updated_date_time: ?i64 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .export_id = "exportId",
                    .resource_specification = "resourceSpecification",
                    .file_format = "fileFormat",
                    .export_status = "exportStatus",
                    .creation_date_time = "creationDateTime",
                    .last_updated_date_time = "lastUpdatedDateTime",
                };
                return @field(mappings, field_name);
            }
        } = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .bot_id = "botId",
                .bot_version = "botVersion",
                .export_summaries = "exportSummaries",
                .next_token = "nextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalServer,
        Throttling,
        Validation,
    },
} = .{};
pub const list_imports: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/imports",
        .success_code = 200,
    };

    action_name: []const u8 = "ListImports",
    Request: type = struct {
        bot_id: ?[]const u8 = null,
        bot_version: ?[]const u8 = null,
        sort_by: ?struct {
            attribute: []const u8,
            order: []const u8,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .attribute = "attribute",
                    .order = "order",
                };
                return @field(mappings, field_name);
            }
        } = null,
        filters: ?[]struct {
            name: []const u8,
            values: [][]const u8,
            operator: []const u8,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .name = "name",
                    .values = "values",
                    .operator = "operator",
                };
                return @field(mappings, field_name);
            }
        } = null,
        max_results: ?i64 = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .bot_id = "botId",
                .bot_version = "botVersion",
                .sort_by = "sortBy",
                .filters = "filters",
                .max_results = "maxResults",
                .next_token = "nextToken",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_imports) } {
            return .{ .service_metadata = service_metadata, .action = list_imports };
        }
    },
    Response: type = struct {
        bot_id: ?[]const u8 = null,
        bot_version: ?[]const u8 = null,
        import_summaries: ?[]struct {
            import_id: ?[]const u8 = null,
            imported_resource_id: ?[]const u8 = null,
            imported_resource_name: ?[]const u8 = null,
            import_status: ?[]const u8 = null,
            merge_strategy: ?[]const u8 = null,
            creation_date_time: ?i64 = null,
            last_updated_date_time: ?i64 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .import_id = "importId",
                    .imported_resource_id = "importedResourceId",
                    .imported_resource_name = "importedResourceName",
                    .import_status = "importStatus",
                    .merge_strategy = "mergeStrategy",
                    .creation_date_time = "creationDateTime",
                    .last_updated_date_time = "lastUpdatedDateTime",
                };
                return @field(mappings, field_name);
            }
        } = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .bot_id = "botId",
                .bot_version = "botVersion",
                .import_summaries = "importSummaries",
                .next_token = "nextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalServer,
        Throttling,
        Validation,
    },
} = .{};
pub const list_intents: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/bots/{botId}/botversions/{botVersion}/botlocales/{localeId}/intents",
        .success_code = 200,
    };

    action_name: []const u8 = "ListIntents",
    Request: type = struct {
        bot_id: []const u8,
        bot_version: []const u8,
        locale_id: []const u8,
        sort_by: ?struct {
            attribute: []const u8,
            order: []const u8,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .attribute = "attribute",
                    .order = "order",
                };
                return @field(mappings, field_name);
            }
        } = null,
        filters: ?[]struct {
            name: []const u8,
            values: [][]const u8,
            operator: []const u8,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .name = "name",
                    .values = "values",
                    .operator = "operator",
                };
                return @field(mappings, field_name);
            }
        } = null,
        max_results: ?i64 = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .bot_id = "botId",
                .bot_version = "botVersion",
                .locale_id = "localeId",
                .sort_by = "sortBy",
                .filters = "filters",
                .max_results = "maxResults",
                .next_token = "nextToken",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_intents) } {
            return .{ .service_metadata = service_metadata, .action = list_intents };
        }
    },
    Response: type = struct {
        bot_id: ?[]const u8 = null,
        bot_version: ?[]const u8 = null,
        locale_id: ?[]const u8 = null,
        intent_summaries: ?[]struct {
            intent_id: ?[]const u8 = null,
            intent_name: ?[]const u8 = null,
            description: ?[]const u8 = null,
            parent_intent_signature: ?[]const u8 = null,
            input_contexts: ?[]InputContext = null,
            output_contexts: ?[]OutputContext = null,
            last_updated_date_time: ?i64 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .intent_id = "intentId",
                    .intent_name = "intentName",
                    .description = "description",
                    .parent_intent_signature = "parentIntentSignature",
                    .input_contexts = "inputContexts",
                    .output_contexts = "outputContexts",
                    .last_updated_date_time = "lastUpdatedDateTime",
                };
                return @field(mappings, field_name);
            }
        } = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .bot_id = "botId",
                .bot_version = "botVersion",
                .locale_id = "localeId",
                .intent_summaries = "intentSummaries",
                .next_token = "nextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalServer,
        ServiceQuotaExceeded,
        Throttling,
        Validation,
    },
} = .{};
pub const list_slots: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/bots/{botId}/botversions/{botVersion}/botlocales/{localeId}/intents/{intentId}/slots",
        .success_code = 200,
    };

    action_name: []const u8 = "ListSlots",
    Request: type = struct {
        bot_id: []const u8,
        bot_version: []const u8,
        locale_id: []const u8,
        intent_id: []const u8,
        sort_by: ?struct {
            attribute: []const u8,
            order: []const u8,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .attribute = "attribute",
                    .order = "order",
                };
                return @field(mappings, field_name);
            }
        } = null,
        filters: ?[]struct {
            name: []const u8,
            values: [][]const u8,
            operator: []const u8,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .name = "name",
                    .values = "values",
                    .operator = "operator",
                };
                return @field(mappings, field_name);
            }
        } = null,
        max_results: ?i64 = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .bot_id = "botId",
                .bot_version = "botVersion",
                .locale_id = "localeId",
                .intent_id = "intentId",
                .sort_by = "sortBy",
                .filters = "filters",
                .max_results = "maxResults",
                .next_token = "nextToken",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_slots) } {
            return .{ .service_metadata = service_metadata, .action = list_slots };
        }
    },
    Response: type = struct {
        bot_id: ?[]const u8 = null,
        bot_version: ?[]const u8 = null,
        locale_id: ?[]const u8 = null,
        intent_id: ?[]const u8 = null,
        slot_summaries: ?[]struct {
            slot_id: ?[]const u8 = null,
            slot_name: ?[]const u8 = null,
            description: ?[]const u8 = null,
            slot_constraint: ?[]const u8 = null,
            slot_type_id: ?[]const u8 = null,
            value_elicitation_prompt_specification: ?PromptSpecification = null,
            last_updated_date_time: ?i64 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .slot_id = "slotId",
                    .slot_name = "slotName",
                    .description = "description",
                    .slot_constraint = "slotConstraint",
                    .slot_type_id = "slotTypeId",
                    .value_elicitation_prompt_specification = "valueElicitationPromptSpecification",
                    .last_updated_date_time = "lastUpdatedDateTime",
                };
                return @field(mappings, field_name);
            }
        } = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .bot_id = "botId",
                .bot_version = "botVersion",
                .locale_id = "localeId",
                .intent_id = "intentId",
                .slot_summaries = "slotSummaries",
                .next_token = "nextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalServer,
        ServiceQuotaExceeded,
        Throttling,
        Validation,
    },
} = .{};
pub const list_slot_types: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/bots/{botId}/botversions/{botVersion}/botlocales/{localeId}/slottypes",
        .success_code = 200,
    };

    action_name: []const u8 = "ListSlotTypes",
    Request: type = struct {
        bot_id: []const u8,
        bot_version: []const u8,
        locale_id: []const u8,
        sort_by: ?struct {
            attribute: []const u8,
            order: []const u8,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .attribute = "attribute",
                    .order = "order",
                };
                return @field(mappings, field_name);
            }
        } = null,
        filters: ?[]struct {
            name: []const u8,
            values: [][]const u8,
            operator: []const u8,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .name = "name",
                    .values = "values",
                    .operator = "operator",
                };
                return @field(mappings, field_name);
            }
        } = null,
        max_results: ?i64 = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .bot_id = "botId",
                .bot_version = "botVersion",
                .locale_id = "localeId",
                .sort_by = "sortBy",
                .filters = "filters",
                .max_results = "maxResults",
                .next_token = "nextToken",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_slot_types) } {
            return .{ .service_metadata = service_metadata, .action = list_slot_types };
        }
    },
    Response: type = struct {
        bot_id: ?[]const u8 = null,
        bot_version: ?[]const u8 = null,
        locale_id: ?[]const u8 = null,
        slot_type_summaries: ?[]struct {
            slot_type_id: ?[]const u8 = null,
            slot_type_name: ?[]const u8 = null,
            description: ?[]const u8 = null,
            parent_slot_type_signature: ?[]const u8 = null,
            last_updated_date_time: ?i64 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .slot_type_id = "slotTypeId",
                    .slot_type_name = "slotTypeName",
                    .description = "description",
                    .parent_slot_type_signature = "parentSlotTypeSignature",
                    .last_updated_date_time = "lastUpdatedDateTime",
                };
                return @field(mappings, field_name);
            }
        } = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .bot_id = "botId",
                .bot_version = "botVersion",
                .locale_id = "localeId",
                .slot_type_summaries = "slotTypeSummaries",
                .next_token = "nextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalServer,
        ServiceQuotaExceeded,
        Throttling,
        Validation,
    },
} = .{};
pub const list_tags_for_resource: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/tags/{resourceARN}",
        .success_code = 200,
    };

    action_name: []const u8 = "ListTagsForResource",
    Request: type = struct {
        resource_arn: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .resource_arn = "resourceARN",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_tags_for_resource) } {
            return .{ .service_metadata = service_metadata, .action = list_tags_for_resource };
        }
    },
    Response: type = struct {
        tags: ?[]struct {
            key: ?[]const u8 = null,
            value: ?[]const u8 = null,
        } = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .tags = "tags",
            };
            return @field(mappings, field_name);
        }

        pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
            if (std.mem.eql(u8, "tags", field_name))
                return try serializeMap(self.tags, self.fieldNameFor("tags"), options, out_stream);
            return false;
        }
    },
    ServiceError: type = error{
        InternalServer,
        ResourceNotFound,
        Throttling,
        Validation,
    },
} = .{};
pub const start_import: struct {
    pub const http_config = .{
        .method = "PUT",
        .uri = "/imports",
        .success_code = 202,
    };

    action_name: []const u8 = "StartImport",
    Request: type = struct {
        import_id: []const u8,
        resource_specification: ImportResourceSpecification,
        merge_strategy: []const u8,
        file_password: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .import_id = "importId",
                .resource_specification = "resourceSpecification",
                .merge_strategy = "mergeStrategy",
                .file_password = "filePassword",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(start_import) } {
            return .{ .service_metadata = service_metadata, .action = start_import };
        }
    },
    Response: type = struct {
        import_id: ?[]const u8 = null,
        resource_specification: ?ImportResourceSpecification = null,
        merge_strategy: ?[]const u8 = null,
        import_status: ?[]const u8 = null,
        creation_date_time: ?i64 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .import_id = "importId",
                .resource_specification = "resourceSpecification",
                .merge_strategy = "mergeStrategy",
                .import_status = "importStatus",
                .creation_date_time = "creationDateTime",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        Conflict,
        InternalServer,
        ResourceNotFound,
        ServiceQuotaExceeded,
        Throttling,
        Validation,
    },
} = .{};
pub const tag_resource: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/tags/{resourceARN}",
        .success_code = 200,
    };

    action_name: []const u8 = "TagResource",
    Request: type = struct {
        resource_arn: []const u8,
        tags: []struct {
            key: ?[]const u8 = null,
            value: ?[]const u8 = null,
        },

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .resource_arn = "resourceARN",
                .tags = "tags",
            };
            return @field(mappings, field_name);
        }

        pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
            if (std.mem.eql(u8, "tags", field_name))
                return try serializeMap(self.tags, self.fieldNameFor("tags"), options, out_stream);
            return false;
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(tag_resource) } {
            return .{ .service_metadata = service_metadata, .action = tag_resource };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalServer,
        ResourceNotFound,
        Throttling,
        Validation,
    },
} = .{};
pub const untag_resource: struct {
    pub const http_config = .{
        .method = "DELETE",
        .uri = "/tags/{resourceARN}",
        .success_code = 200,
    };

    action_name: []const u8 = "UntagResource",
    Request: type = struct {
        resource_arn: []const u8,
        tag_keys: [][]const u8,

        pub const http_query = .{
            .tag_keys = "tagKeys",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .resource_arn = "resourceARN",
                .tag_keys = "tagKeys",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(untag_resource) } {
            return .{ .service_metadata = service_metadata, .action = untag_resource };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalServer,
        ResourceNotFound,
        Throttling,
        Validation,
    },
} = .{};
pub const update_bot: struct {
    pub const http_config = .{
        .method = "PUT",
        .uri = "/bots/{botId}",
        .success_code = 202,
    };

    action_name: []const u8 = "UpdateBot",
    Request: type = struct {
        bot_id: []const u8,
        bot_name: []const u8,
        description: ?[]const u8 = null,
        role_arn: []const u8,
        data_privacy: DataPrivacy,
        idle_session_ttl_in_seconds: i64,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .bot_id = "botId",
                .bot_name = "botName",
                .description = "description",
                .role_arn = "roleArn",
                .data_privacy = "dataPrivacy",
                .idle_session_ttl_in_seconds = "idleSessionTTLInSeconds",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(update_bot) } {
            return .{ .service_metadata = service_metadata, .action = update_bot };
        }
    },
    Response: type = struct {
        bot_id: ?[]const u8 = null,
        bot_name: ?[]const u8 = null,
        description: ?[]const u8 = null,
        role_arn: ?[]const u8 = null,
        data_privacy: ?DataPrivacy = null,
        idle_session_ttl_in_seconds: ?i64 = null,
        bot_status: ?[]const u8 = null,
        creation_date_time: ?i64 = null,
        last_updated_date_time: ?i64 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .bot_id = "botId",
                .bot_name = "botName",
                .description = "description",
                .role_arn = "roleArn",
                .data_privacy = "dataPrivacy",
                .idle_session_ttl_in_seconds = "idleSessionTTLInSeconds",
                .bot_status = "botStatus",
                .creation_date_time = "creationDateTime",
                .last_updated_date_time = "lastUpdatedDateTime",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        Conflict,
        InternalServer,
        PreconditionFailed,
        ServiceQuotaExceeded,
        Throttling,
        Validation,
    },
} = .{};
pub const update_bot_alias: struct {
    pub const http_config = .{
        .method = "PUT",
        .uri = "/bots/{botId}/botaliases/{botAliasId}",
        .success_code = 202,
    };

    action_name: []const u8 = "UpdateBotAlias",
    Request: type = struct {
        bot_alias_id: []const u8,
        bot_alias_name: []const u8,
        description: ?[]const u8 = null,
        bot_version: ?[]const u8 = null,
        bot_alias_locale_settings: ?[]struct {
            key: ?[]const u8 = null,
            value: ?BotAliasLocaleSettings = null,
        } = null,
        conversation_log_settings: ?ConversationLogSettings = null,
        sentiment_analysis_settings: ?SentimentAnalysisSettings = null,
        bot_id: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .bot_alias_id = "botAliasId",
                .bot_alias_name = "botAliasName",
                .description = "description",
                .bot_version = "botVersion",
                .bot_alias_locale_settings = "botAliasLocaleSettings",
                .conversation_log_settings = "conversationLogSettings",
                .sentiment_analysis_settings = "sentimentAnalysisSettings",
                .bot_id = "botId",
            };
            return @field(mappings, field_name);
        }

        pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
            if (std.mem.eql(u8, "bot_alias_locale_settings", field_name))
                return try serializeMap(self.bot_alias_locale_settings, self.fieldNameFor("bot_alias_locale_settings"), options, out_stream);
            return false;
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(update_bot_alias) } {
            return .{ .service_metadata = service_metadata, .action = update_bot_alias };
        }
    },
    Response: type = struct {
        bot_alias_id: ?[]const u8 = null,
        bot_alias_name: ?[]const u8 = null,
        description: ?[]const u8 = null,
        bot_version: ?[]const u8 = null,
        bot_alias_locale_settings: ?[]struct {
            key: ?[]const u8 = null,
            value: ?BotAliasLocaleSettings = null,
        } = null,
        conversation_log_settings: ?ConversationLogSettings = null,
        sentiment_analysis_settings: ?SentimentAnalysisSettings = null,
        bot_alias_status: ?[]const u8 = null,
        bot_id: ?[]const u8 = null,
        creation_date_time: ?i64 = null,
        last_updated_date_time: ?i64 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .bot_alias_id = "botAliasId",
                .bot_alias_name = "botAliasName",
                .description = "description",
                .bot_version = "botVersion",
                .bot_alias_locale_settings = "botAliasLocaleSettings",
                .conversation_log_settings = "conversationLogSettings",
                .sentiment_analysis_settings = "sentimentAnalysisSettings",
                .bot_alias_status = "botAliasStatus",
                .bot_id = "botId",
                .creation_date_time = "creationDateTime",
                .last_updated_date_time = "lastUpdatedDateTime",
            };
            return @field(mappings, field_name);
        }

        pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
            if (std.mem.eql(u8, "bot_alias_locale_settings", field_name))
                return try serializeMap(self.bot_alias_locale_settings, self.fieldNameFor("bot_alias_locale_settings"), options, out_stream);
            return false;
        }
    },
    ServiceError: type = error{
        Conflict,
        InternalServer,
        PreconditionFailed,
        ServiceQuotaExceeded,
        Throttling,
        Validation,
    },
} = .{};
pub const update_bot_locale: struct {
    pub const http_config = .{
        .method = "PUT",
        .uri = "/bots/{botId}/botversions/{botVersion}/botlocales/{localeId}",
        .success_code = 202,
    };

    action_name: []const u8 = "UpdateBotLocale",
    Request: type = struct {
        bot_id: []const u8,
        bot_version: []const u8,
        locale_id: []const u8,
        description: ?[]const u8 = null,
        nlu_intent_confidence_threshold: f64,
        voice_settings: ?VoiceSettings = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .bot_id = "botId",
                .bot_version = "botVersion",
                .locale_id = "localeId",
                .description = "description",
                .nlu_intent_confidence_threshold = "nluIntentConfidenceThreshold",
                .voice_settings = "voiceSettings",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(update_bot_locale) } {
            return .{ .service_metadata = service_metadata, .action = update_bot_locale };
        }
    },
    Response: type = struct {
        bot_id: ?[]const u8 = null,
        bot_version: ?[]const u8 = null,
        locale_id: ?[]const u8 = null,
        locale_name: ?[]const u8 = null,
        description: ?[]const u8 = null,
        nlu_intent_confidence_threshold: ?f64 = null,
        voice_settings: ?VoiceSettings = null,
        bot_locale_status: ?[]const u8 = null,
        failure_reasons: ?[][]const u8 = null,
        creation_date_time: ?i64 = null,
        last_updated_date_time: ?i64 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .bot_id = "botId",
                .bot_version = "botVersion",
                .locale_id = "localeId",
                .locale_name = "localeName",
                .description = "description",
                .nlu_intent_confidence_threshold = "nluIntentConfidenceThreshold",
                .voice_settings = "voiceSettings",
                .bot_locale_status = "botLocaleStatus",
                .failure_reasons = "failureReasons",
                .creation_date_time = "creationDateTime",
                .last_updated_date_time = "lastUpdatedDateTime",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        Conflict,
        InternalServer,
        PreconditionFailed,
        ServiceQuotaExceeded,
        Throttling,
        Validation,
    },
} = .{};
pub const update_export: struct {
    pub const http_config = .{
        .method = "PUT",
        .uri = "/exports/{exportId}",
        .success_code = 202,
    };

    action_name: []const u8 = "UpdateExport",
    Request: type = struct {
        export_id: []const u8,
        file_password: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .export_id = "exportId",
                .file_password = "filePassword",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(update_export) } {
            return .{ .service_metadata = service_metadata, .action = update_export };
        }
    },
    Response: type = struct {
        export_id: ?[]const u8 = null,
        resource_specification: ?ExportResourceSpecification = null,
        file_format: ?[]const u8 = null,
        export_status: ?[]const u8 = null,
        creation_date_time: ?i64 = null,
        last_updated_date_time: ?i64 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .export_id = "exportId",
                .resource_specification = "resourceSpecification",
                .file_format = "fileFormat",
                .export_status = "exportStatus",
                .creation_date_time = "creationDateTime",
                .last_updated_date_time = "lastUpdatedDateTime",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        Conflict,
        InternalServer,
        ResourceNotFound,
        ServiceQuotaExceeded,
        Throttling,
        Validation,
    },
} = .{};
pub const update_intent: struct {
    pub const http_config = .{
        .method = "PUT",
        .uri = "/bots/{botId}/botversions/{botVersion}/botlocales/{localeId}/intents/{intentId}",
        .success_code = 200,
    };

    action_name: []const u8 = "UpdateIntent",
    Request: type = struct {
        intent_id: []const u8,
        intent_name: []const u8,
        description: ?[]const u8 = null,
        parent_intent_signature: ?[]const u8 = null,
        sample_utterances: ?[]SampleUtterance = null,
        dialog_code_hook: ?DialogCodeHookSettings = null,
        fulfillment_code_hook: ?FulfillmentCodeHookSettings = null,
        slot_priorities: ?[]SlotPriority = null,
        intent_confirmation_setting: ?IntentConfirmationSetting = null,
        intent_closing_setting: ?IntentClosingSetting = null,
        input_contexts: ?[]InputContext = null,
        output_contexts: ?[]OutputContext = null,
        kendra_configuration: ?KendraConfiguration = null,
        bot_id: []const u8,
        bot_version: []const u8,
        locale_id: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .intent_id = "intentId",
                .intent_name = "intentName",
                .description = "description",
                .parent_intent_signature = "parentIntentSignature",
                .sample_utterances = "sampleUtterances",
                .dialog_code_hook = "dialogCodeHook",
                .fulfillment_code_hook = "fulfillmentCodeHook",
                .slot_priorities = "slotPriorities",
                .intent_confirmation_setting = "intentConfirmationSetting",
                .intent_closing_setting = "intentClosingSetting",
                .input_contexts = "inputContexts",
                .output_contexts = "outputContexts",
                .kendra_configuration = "kendraConfiguration",
                .bot_id = "botId",
                .bot_version = "botVersion",
                .locale_id = "localeId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(update_intent) } {
            return .{ .service_metadata = service_metadata, .action = update_intent };
        }
    },
    Response: type = struct {
        intent_id: ?[]const u8 = null,
        intent_name: ?[]const u8 = null,
        description: ?[]const u8 = null,
        parent_intent_signature: ?[]const u8 = null,
        sample_utterances: ?[]SampleUtterance = null,
        dialog_code_hook: ?DialogCodeHookSettings = null,
        fulfillment_code_hook: ?FulfillmentCodeHookSettings = null,
        slot_priorities: ?[]SlotPriority = null,
        intent_confirmation_setting: ?IntentConfirmationSetting = null,
        intent_closing_setting: ?IntentClosingSetting = null,
        input_contexts: ?[]InputContext = null,
        output_contexts: ?[]OutputContext = null,
        kendra_configuration: ?KendraConfiguration = null,
        bot_id: ?[]const u8 = null,
        bot_version: ?[]const u8 = null,
        locale_id: ?[]const u8 = null,
        creation_date_time: ?i64 = null,
        last_updated_date_time: ?i64 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .intent_id = "intentId",
                .intent_name = "intentName",
                .description = "description",
                .parent_intent_signature = "parentIntentSignature",
                .sample_utterances = "sampleUtterances",
                .dialog_code_hook = "dialogCodeHook",
                .fulfillment_code_hook = "fulfillmentCodeHook",
                .slot_priorities = "slotPriorities",
                .intent_confirmation_setting = "intentConfirmationSetting",
                .intent_closing_setting = "intentClosingSetting",
                .input_contexts = "inputContexts",
                .output_contexts = "outputContexts",
                .kendra_configuration = "kendraConfiguration",
                .bot_id = "botId",
                .bot_version = "botVersion",
                .locale_id = "localeId",
                .creation_date_time = "creationDateTime",
                .last_updated_date_time = "lastUpdatedDateTime",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        Conflict,
        InternalServer,
        PreconditionFailed,
        ServiceQuotaExceeded,
        Throttling,
        Validation,
    },
} = .{};
pub const update_resource_policy: struct {
    pub const http_config = .{
        .method = "PUT",
        .uri = "/policy/{resourceArn}",
        .success_code = 200,
    };

    action_name: []const u8 = "UpdateResourcePolicy",
    Request: type = struct {
        resource_arn: []const u8,
        policy: []const u8,
        expected_revision_id: ?[]const u8 = null,

        pub const http_query = .{
            .expected_revision_id = "expectedRevisionId",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .resource_arn = "resourceArn",
                .policy = "policy",
                .expected_revision_id = "expectedRevisionId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(update_resource_policy) } {
            return .{ .service_metadata = service_metadata, .action = update_resource_policy };
        }
    },
    Response: type = struct {
        resource_arn: ?[]const u8 = null,
        revision_id: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .resource_arn = "resourceArn",
                .revision_id = "revisionId",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalServer,
        PreconditionFailed,
        ResourceNotFound,
        ServiceQuotaExceeded,
        Throttling,
        Validation,
    },
} = .{};
pub const update_slot: struct {
    pub const http_config = .{
        .method = "PUT",
        .uri = "/bots/{botId}/botversions/{botVersion}/botlocales/{localeId}/intents/{intentId}/slots/{slotId}",
        .success_code = 200,
    };

    action_name: []const u8 = "UpdateSlot",
    Request: type = struct {
        slot_id: []const u8,
        slot_name: []const u8,
        description: ?[]const u8 = null,
        slot_type_id: []const u8,
        value_elicitation_setting: SlotValueElicitationSetting,
        obfuscation_setting: ?ObfuscationSetting = null,
        bot_id: []const u8,
        bot_version: []const u8,
        locale_id: []const u8,
        intent_id: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .slot_id = "slotId",
                .slot_name = "slotName",
                .description = "description",
                .slot_type_id = "slotTypeId",
                .value_elicitation_setting = "valueElicitationSetting",
                .obfuscation_setting = "obfuscationSetting",
                .bot_id = "botId",
                .bot_version = "botVersion",
                .locale_id = "localeId",
                .intent_id = "intentId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(update_slot) } {
            return .{ .service_metadata = service_metadata, .action = update_slot };
        }
    },
    Response: type = struct {
        slot_id: ?[]const u8 = null,
        slot_name: ?[]const u8 = null,
        description: ?[]const u8 = null,
        slot_type_id: ?[]const u8 = null,
        value_elicitation_setting: ?SlotValueElicitationSetting = null,
        obfuscation_setting: ?ObfuscationSetting = null,
        bot_id: ?[]const u8 = null,
        bot_version: ?[]const u8 = null,
        locale_id: ?[]const u8 = null,
        intent_id: ?[]const u8 = null,
        creation_date_time: ?i64 = null,
        last_updated_date_time: ?i64 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .slot_id = "slotId",
                .slot_name = "slotName",
                .description = "description",
                .slot_type_id = "slotTypeId",
                .value_elicitation_setting = "valueElicitationSetting",
                .obfuscation_setting = "obfuscationSetting",
                .bot_id = "botId",
                .bot_version = "botVersion",
                .locale_id = "localeId",
                .intent_id = "intentId",
                .creation_date_time = "creationDateTime",
                .last_updated_date_time = "lastUpdatedDateTime",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        Conflict,
        InternalServer,
        PreconditionFailed,
        ServiceQuotaExceeded,
        Throttling,
        Validation,
    },
} = .{};
pub const update_slot_type: struct {
    pub const http_config = .{
        .method = "PUT",
        .uri = "/bots/{botId}/botversions/{botVersion}/botlocales/{localeId}/slottypes/{slotTypeId}",
        .success_code = 202,
    };

    action_name: []const u8 = "UpdateSlotType",
    Request: type = struct {
        slot_type_id: []const u8,
        slot_type_name: []const u8,
        description: ?[]const u8 = null,
        slot_type_values: ?[]SlotTypeValue = null,
        value_selection_setting: SlotValueSelectionSetting,
        parent_slot_type_signature: ?[]const u8 = null,
        bot_id: []const u8,
        bot_version: []const u8,
        locale_id: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .slot_type_id = "slotTypeId",
                .slot_type_name = "slotTypeName",
                .description = "description",
                .slot_type_values = "slotTypeValues",
                .value_selection_setting = "valueSelectionSetting",
                .parent_slot_type_signature = "parentSlotTypeSignature",
                .bot_id = "botId",
                .bot_version = "botVersion",
                .locale_id = "localeId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(update_slot_type) } {
            return .{ .service_metadata = service_metadata, .action = update_slot_type };
        }
    },
    Response: type = struct {
        slot_type_id: ?[]const u8 = null,
        slot_type_name: ?[]const u8 = null,
        description: ?[]const u8 = null,
        slot_type_values: ?[]SlotTypeValue = null,
        value_selection_setting: ?SlotValueSelectionSetting = null,
        parent_slot_type_signature: ?[]const u8 = null,
        bot_id: ?[]const u8 = null,
        bot_version: ?[]const u8 = null,
        locale_id: ?[]const u8 = null,
        creation_date_time: ?i64 = null,
        last_updated_date_time: ?i64 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .slot_type_id = "slotTypeId",
                .slot_type_name = "slotTypeName",
                .description = "description",
                .slot_type_values = "slotTypeValues",
                .value_selection_setting = "valueSelectionSetting",
                .parent_slot_type_signature = "parentSlotTypeSignature",
                .bot_id = "botId",
                .bot_version = "botVersion",
                .locale_id = "localeId",
                .creation_date_time = "creationDateTime",
                .last_updated_date_time = "lastUpdatedDateTime",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        Conflict,
        InternalServer,
        PreconditionFailed,
        ServiceQuotaExceeded,
        Throttling,
        Validation,
    },
} = .{};

pub const SlotValueSelectionSetting = struct {
    resolution_strategy: []const u8,
    regex_filter: ?SlotValueRegexFilter = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .resolution_strategy = "resolutionStrategy",
            .regex_filter = "regexFilter",
        };
        return @field(mappings, field_name);
    }
};

pub const SlotValueRegexFilter = struct {
    pattern: []const u8,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .pattern = "pattern",
        };
        return @field(mappings, field_name);
    }
};

pub const SlotTypeValue = struct {
    sample_value: ?SampleValue = null,
    synonyms: ?[]SampleValue = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .sample_value = "sampleValue",
            .synonyms = "synonyms",
        };
        return @field(mappings, field_name);
    }
};

pub const SampleValue = struct {
    value: []const u8,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .value = "value",
        };
        return @field(mappings, field_name);
    }
};

pub const ObfuscationSetting = struct {
    obfuscation_setting_type: []const u8,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .obfuscation_setting_type = "obfuscationSettingType",
        };
        return @field(mappings, field_name);
    }
};

pub const SlotValueElicitationSetting = struct {
    default_value_specification: ?SlotDefaultValueSpecification = null,
    slot_constraint: []const u8,
    prompt_specification: ?PromptSpecification = null,
    sample_utterances: ?[]SampleUtterance = null,
    wait_and_continue_specification: ?WaitAndContinueSpecification = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .default_value_specification = "defaultValueSpecification",
            .slot_constraint = "slotConstraint",
            .prompt_specification = "promptSpecification",
            .sample_utterances = "sampleUtterances",
            .wait_and_continue_specification = "waitAndContinueSpecification",
        };
        return @field(mappings, field_name);
    }
};

pub const WaitAndContinueSpecification = struct {
    waiting_response: ResponseSpecification,
    continue_response: ResponseSpecification,
    still_waiting_response: ?StillWaitingResponseSpecification = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .waiting_response = "waitingResponse",
            .continue_response = "continueResponse",
            .still_waiting_response = "stillWaitingResponse",
        };
        return @field(mappings, field_name);
    }
};

pub const StillWaitingResponseSpecification = struct {
    message_groups: []MessageGroup,
    frequency_in_seconds: i64,
    timeout_in_seconds: i64,
    allow_interrupt: ?bool = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .message_groups = "messageGroups",
            .frequency_in_seconds = "frequencyInSeconds",
            .timeout_in_seconds = "timeoutInSeconds",
            .allow_interrupt = "allowInterrupt",
        };
        return @field(mappings, field_name);
    }
};

pub const MessageGroup = struct {
    message: Message,
    variations: ?[]Message = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .message = "message",
            .variations = "variations",
        };
        return @field(mappings, field_name);
    }
};

pub const Message = struct {
    plain_text_message: ?PlainTextMessage = null,
    custom_payload: ?CustomPayload = null,
    ssml_message: ?SSMLMessage = null,
    image_response_card: ?ImageResponseCard = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .plain_text_message = "plainTextMessage",
            .custom_payload = "customPayload",
            .ssml_message = "ssmlMessage",
            .image_response_card = "imageResponseCard",
        };
        return @field(mappings, field_name);
    }
};

pub const ImageResponseCard = struct {
    title: []const u8,
    subtitle: ?[]const u8 = null,
    image_url: ?[]const u8 = null,
    buttons: ?[]Button = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .title = "title",
            .subtitle = "subtitle",
            .image_url = "imageUrl",
            .buttons = "buttons",
        };
        return @field(mappings, field_name);
    }
};

pub const Button = struct {
    text: []const u8,
    value: []const u8,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .text = "text",
            .value = "value",
        };
        return @field(mappings, field_name);
    }
};

pub const SSMLMessage = struct {
    value: []const u8,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .value = "value",
        };
        return @field(mappings, field_name);
    }
};

pub const CustomPayload = struct {
    value: []const u8,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .value = "value",
        };
        return @field(mappings, field_name);
    }
};

pub const PlainTextMessage = struct {
    value: []const u8,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .value = "value",
        };
        return @field(mappings, field_name);
    }
};

pub const ResponseSpecification = struct {
    message_groups: []MessageGroup,
    allow_interrupt: ?bool = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .message_groups = "messageGroups",
            .allow_interrupt = "allowInterrupt",
        };
        return @field(mappings, field_name);
    }
};

pub const SampleUtterance = struct {
    utterance: []const u8,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .utterance = "utterance",
        };
        return @field(mappings, field_name);
    }
};

pub const PromptSpecification = struct {
    message_groups: []MessageGroup,
    max_retries: i64,
    allow_interrupt: ?bool = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .message_groups = "messageGroups",
            .max_retries = "maxRetries",
            .allow_interrupt = "allowInterrupt",
        };
        return @field(mappings, field_name);
    }
};

pub const SlotDefaultValueSpecification = struct {
    default_value_list: []SlotDefaultValue,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .default_value_list = "defaultValueList",
        };
        return @field(mappings, field_name);
    }
};

pub const SlotDefaultValue = struct {
    default_value: []const u8,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .default_value = "defaultValue",
        };
        return @field(mappings, field_name);
    }
};

pub const KendraConfiguration = struct {
    kendra_index: []const u8,
    query_filter_string_enabled: ?bool = null,
    query_filter_string: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .kendra_index = "kendraIndex",
            .query_filter_string_enabled = "queryFilterStringEnabled",
            .query_filter_string = "queryFilterString",
        };
        return @field(mappings, field_name);
    }
};

pub const OutputContext = struct {
    name: []const u8,
    time_to_live_in_seconds: i64,
    turns_to_live: i64,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .name = "name",
            .time_to_live_in_seconds = "timeToLiveInSeconds",
            .turns_to_live = "turnsToLive",
        };
        return @field(mappings, field_name);
    }
};

pub const InputContext = struct {
    name: []const u8,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .name = "name",
        };
        return @field(mappings, field_name);
    }
};

pub const IntentClosingSetting = struct {
    closing_response: ResponseSpecification,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .closing_response = "closingResponse",
        };
        return @field(mappings, field_name);
    }
};

pub const IntentConfirmationSetting = struct {
    prompt_specification: PromptSpecification,
    declination_response: ResponseSpecification,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .prompt_specification = "promptSpecification",
            .declination_response = "declinationResponse",
        };
        return @field(mappings, field_name);
    }
};

pub const SlotPriority = struct {
    priority: i64,
    slot_id: []const u8,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .priority = "priority",
            .slot_id = "slotId",
        };
        return @field(mappings, field_name);
    }
};

pub const FulfillmentCodeHookSettings = struct {
    enabled: bool,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .enabled = "enabled",
        };
        return @field(mappings, field_name);
    }
};

pub const DialogCodeHookSettings = struct {
    enabled: bool,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .enabled = "enabled",
        };
        return @field(mappings, field_name);
    }
};

pub const ExportResourceSpecification = struct {
    bot_export_specification: ?BotExportSpecification = null,
    bot_locale_export_specification: ?BotLocaleExportSpecification = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .bot_export_specification = "botExportSpecification",
            .bot_locale_export_specification = "botLocaleExportSpecification",
        };
        return @field(mappings, field_name);
    }
};

pub const BotLocaleExportSpecification = struct {
    bot_id: []const u8,
    bot_version: []const u8,
    locale_id: []const u8,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .bot_id = "botId",
            .bot_version = "botVersion",
            .locale_id = "localeId",
        };
        return @field(mappings, field_name);
    }
};

pub const BotExportSpecification = struct {
    bot_id: []const u8,
    bot_version: []const u8,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .bot_id = "botId",
            .bot_version = "botVersion",
        };
        return @field(mappings, field_name);
    }
};

pub const VoiceSettings = struct {
    voice_id: []const u8,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .voice_id = "voiceId",
        };
        return @field(mappings, field_name);
    }
};

pub const SentimentAnalysisSettings = struct {
    detect_sentiment: bool,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .detect_sentiment = "detectSentiment",
        };
        return @field(mappings, field_name);
    }
};

pub const ConversationLogSettings = struct {
    text_log_settings: ?[]TextLogSetting = null,
    audio_log_settings: ?[]AudioLogSetting = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .text_log_settings = "textLogSettings",
            .audio_log_settings = "audioLogSettings",
        };
        return @field(mappings, field_name);
    }
};

pub const AudioLogSetting = struct {
    enabled: bool,
    destination: AudioLogDestination,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .enabled = "enabled",
            .destination = "destination",
        };
        return @field(mappings, field_name);
    }
};

pub const AudioLogDestination = struct {
    s3_bucket: S3BucketLogDestination,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .s3_bucket = "s3Bucket",
        };
        return @field(mappings, field_name);
    }
};

pub const S3BucketLogDestination = struct {
    kms_key_arn: ?[]const u8 = null,
    s3_bucket_arn: []const u8,
    log_prefix: []const u8,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .kms_key_arn = "kmsKeyArn",
            .s3_bucket_arn = "s3BucketArn",
            .log_prefix = "logPrefix",
        };
        return @field(mappings, field_name);
    }
};

pub const TextLogSetting = struct {
    enabled: bool,
    destination: TextLogDestination,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .enabled = "enabled",
            .destination = "destination",
        };
        return @field(mappings, field_name);
    }
};

pub const TextLogDestination = struct {
    cloud_watch: CloudWatchLogGroupLogDestination,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .cloud_watch = "cloudWatch",
        };
        return @field(mappings, field_name);
    }
};

pub const CloudWatchLogGroupLogDestination = struct {
    cloud_watch_log_group_arn: []const u8,
    log_prefix: []const u8,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .cloud_watch_log_group_arn = "cloudWatchLogGroupArn",
            .log_prefix = "logPrefix",
        };
        return @field(mappings, field_name);
    }
};

pub const BotAliasLocaleSettings = struct {
    enabled: bool,
    code_hook_specification: ?CodeHookSpecification = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .enabled = "enabled",
            .code_hook_specification = "codeHookSpecification",
        };
        return @field(mappings, field_name);
    }
};

pub const CodeHookSpecification = struct {
    lambda_code_hook: LambdaCodeHook,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .lambda_code_hook = "lambdaCodeHook",
        };
        return @field(mappings, field_name);
    }
};

pub const LambdaCodeHook = struct {
    lambda_arn: []const u8,
    code_hook_interface_version: []const u8,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .lambda_arn = "lambdaARN",
            .code_hook_interface_version = "codeHookInterfaceVersion",
        };
        return @field(mappings, field_name);
    }
};

pub const DataPrivacy = struct {
    child_directed: bool,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .child_directed = "childDirected",
        };
        return @field(mappings, field_name);
    }
};

pub const ImportResourceSpecification = struct {
    bot_import_specification: ?BotImportSpecification = null,
    bot_locale_import_specification: ?BotLocaleImportSpecification = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .bot_import_specification = "botImportSpecification",
            .bot_locale_import_specification = "botLocaleImportSpecification",
        };
        return @field(mappings, field_name);
    }
};

pub const BotLocaleImportSpecification = struct {
    bot_id: []const u8,
    bot_version: []const u8,
    locale_id: []const u8,
    nlu_intent_confidence_threshold: ?f64 = null,
    voice_settings: ?VoiceSettings = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .bot_id = "botId",
            .bot_version = "botVersion",
            .locale_id = "localeId",
            .nlu_intent_confidence_threshold = "nluIntentConfidenceThreshold",
            .voice_settings = "voiceSettings",
        };
        return @field(mappings, field_name);
    }
};

pub const BotImportSpecification = struct {
    bot_name: []const u8,
    role_arn: []const u8,
    data_privacy: DataPrivacy,
    idle_session_ttl_in_seconds: ?i64 = null,
    bot_tags: ?[]struct {
        key: ?[]const u8 = null,
        value: ?[]const u8 = null,
    } = null,
    test_bot_alias_tags: ?[]struct {
        key: ?[]const u8 = null,
        value: ?[]const u8 = null,
    } = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .bot_name = "botName",
            .role_arn = "roleArn",
            .data_privacy = "dataPrivacy",
            .idle_session_ttl_in_seconds = "idleSessionTTLInSeconds",
            .bot_tags = "botTags",
            .test_bot_alias_tags = "testBotAliasTags",
        };
        return @field(mappings, field_name);
    }

    pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
        if (std.mem.eql(u8, "bot_tags", field_name))
            return try serializeMap(self.bot_tags, self.fieldNameFor("bot_tags"), options, out_stream);
        if (std.mem.eql(u8, "test_bot_alias_tags", field_name))
            return try serializeMap(self.test_bot_alias_tags, self.fieldNameFor("test_bot_alias_tags"), options, out_stream);
        return false;
    }
};

pub const BotVersionLocaleDetails = struct {
    source_bot_version: []const u8,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .source_bot_version = "sourceBotVersion",
        };
        return @field(mappings, field_name);
    }
};
