const std = @import("std");
const serializeMap = @import("json.zig").serializeMap;
const smithy = @import("smithy");

const Self = @This();
pub const version: []const u8 = "2020-12-15";
pub const sdk_id: []const u8 = "LookoutEquipment";
pub const arn_namespace: []const u8 = "lookoutequipment";
pub const endpoint_prefix: []const u8 = "lookoutequipment";
pub const sigv4_name: []const u8 = "lookoutequipment";
pub const name: []const u8 = "AWSLookoutEquipmentFrontendService";
pub const aws_protocol: smithy.AwsProtocol = smithy.AwsProtocol.json_1_0;

pub const service_metadata: struct {
    version: []const u8 = "2020-12-15",
    sdk_id: []const u8 = "LookoutEquipment",
    arn_namespace: []const u8 = "lookoutequipment",
    endpoint_prefix: []const u8 = "lookoutequipment",
    sigv4_name: []const u8 = "lookoutequipment",
    name: []const u8 = "AWSLookoutEquipmentFrontendService",
    aws_protocol: smithy.AwsProtocol = smithy.AwsProtocol.json_1_0,
} = .{};
pub const create_dataset: struct {
    action_name: []const u8 = "CreateDataset",
    Request: type = struct {
        dataset_name: []const u8,
        dataset_schema: DatasetSchema,
        server_side_kms_key_id: ?[]const u8 = null,
        client_token: []const u8,
        tags: ?[]Tag = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .dataset_name = "DatasetName",
                .dataset_schema = "DatasetSchema",
                .server_side_kms_key_id = "ServerSideKmsKeyId",
                .client_token = "ClientToken",
                .tags = "Tags",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(create_dataset) } {
            return .{ .service_metadata = service_metadata, .action = create_dataset };
        }
    },
    Response: type = struct {
        dataset_name: ?[]const u8 = null,
        dataset_arn: ?[]const u8 = null,
        status: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .dataset_name = "DatasetName",
                .dataset_arn = "DatasetArn",
                .status = "Status",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        Conflict,
        InternalServer,
        ServiceQuotaExceeded,
        Throttling,
        Validation,
    },
} = .{};
pub const create_inference_scheduler: struct {
    action_name: []const u8 = "CreateInferenceScheduler",
    Request: type = struct {
        model_name: []const u8,
        inference_scheduler_name: []const u8,
        data_delay_offset_in_minutes: ?i64 = null,
        data_upload_frequency: []const u8,
        data_input_configuration: InferenceInputConfiguration,
        data_output_configuration: InferenceOutputConfiguration,
        role_arn: []const u8,
        server_side_kms_key_id: ?[]const u8 = null,
        client_token: []const u8,
        tags: ?[]Tag = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .model_name = "ModelName",
                .inference_scheduler_name = "InferenceSchedulerName",
                .data_delay_offset_in_minutes = "DataDelayOffsetInMinutes",
                .data_upload_frequency = "DataUploadFrequency",
                .data_input_configuration = "DataInputConfiguration",
                .data_output_configuration = "DataOutputConfiguration",
                .role_arn = "RoleArn",
                .server_side_kms_key_id = "ServerSideKmsKeyId",
                .client_token = "ClientToken",
                .tags = "Tags",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(create_inference_scheduler) } {
            return .{ .service_metadata = service_metadata, .action = create_inference_scheduler };
        }
    },
    Response: type = struct {
        inference_scheduler_arn: ?[]const u8 = null,
        inference_scheduler_name: ?[]const u8 = null,
        status: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .inference_scheduler_arn = "InferenceSchedulerArn",
                .inference_scheduler_name = "InferenceSchedulerName",
                .status = "Status",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        Conflict,
        InternalServer,
        ResourceNotFound,
        ServiceQuotaExceeded,
        Throttling,
        Validation,
    },
} = .{};
pub const create_model: struct {
    action_name: []const u8 = "CreateModel",
    Request: type = struct {
        model_name: []const u8,
        dataset_name: []const u8,
        dataset_schema: ?DatasetSchema = null,
        labels_input_configuration: ?LabelsInputConfiguration = null,
        client_token: []const u8,
        training_data_start_time: ?i64 = null,
        training_data_end_time: ?i64 = null,
        evaluation_data_start_time: ?i64 = null,
        evaluation_data_end_time: ?i64 = null,
        role_arn: ?[]const u8 = null,
        data_pre_processing_configuration: ?DataPreProcessingConfiguration = null,
        server_side_kms_key_id: ?[]const u8 = null,
        tags: ?[]Tag = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .model_name = "ModelName",
                .dataset_name = "DatasetName",
                .dataset_schema = "DatasetSchema",
                .labels_input_configuration = "LabelsInputConfiguration",
                .client_token = "ClientToken",
                .training_data_start_time = "TrainingDataStartTime",
                .training_data_end_time = "TrainingDataEndTime",
                .evaluation_data_start_time = "EvaluationDataStartTime",
                .evaluation_data_end_time = "EvaluationDataEndTime",
                .role_arn = "RoleArn",
                .data_pre_processing_configuration = "DataPreProcessingConfiguration",
                .server_side_kms_key_id = "ServerSideKmsKeyId",
                .tags = "Tags",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(create_model) } {
            return .{ .service_metadata = service_metadata, .action = create_model };
        }
    },
    Response: type = struct {
        model_arn: ?[]const u8 = null,
        status: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .model_arn = "ModelArn",
                .status = "Status",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        Conflict,
        InternalServer,
        ResourceNotFound,
        ServiceQuotaExceeded,
        Throttling,
        Validation,
    },
} = .{};
pub const delete_dataset: struct {
    action_name: []const u8 = "DeleteDataset",
    Request: type = struct {
        dataset_name: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .dataset_name = "DatasetName",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(delete_dataset) } {
            return .{ .service_metadata = service_metadata, .action = delete_dataset };
        }
    },
    Response: type = struct {},
    ServiceError: type = error{
        AccessDenied,
        Conflict,
        InternalServer,
        ResourceNotFound,
        Throttling,
    },
} = .{};
pub const delete_inference_scheduler: struct {
    action_name: []const u8 = "DeleteInferenceScheduler",
    Request: type = struct {
        inference_scheduler_name: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .inference_scheduler_name = "InferenceSchedulerName",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(delete_inference_scheduler) } {
            return .{ .service_metadata = service_metadata, .action = delete_inference_scheduler };
        }
    },
    Response: type = struct {},
    ServiceError: type = error{
        AccessDenied,
        Conflict,
        InternalServer,
        ResourceNotFound,
        Throttling,
        Validation,
    },
} = .{};
pub const delete_model: struct {
    action_name: []const u8 = "DeleteModel",
    Request: type = struct {
        model_name: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .model_name = "ModelName",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(delete_model) } {
            return .{ .service_metadata = service_metadata, .action = delete_model };
        }
    },
    Response: type = struct {},
    ServiceError: type = error{
        AccessDenied,
        Conflict,
        InternalServer,
        ResourceNotFound,
        Throttling,
    },
} = .{};
pub const describe_data_ingestion_job: struct {
    action_name: []const u8 = "DescribeDataIngestionJob",
    Request: type = struct {
        job_id: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .job_id = "JobId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(describe_data_ingestion_job) } {
            return .{ .service_metadata = service_metadata, .action = describe_data_ingestion_job };
        }
    },
    Response: type = struct {
        job_id: ?[]const u8 = null,
        dataset_arn: ?[]const u8 = null,
        ingestion_input_configuration: ?IngestionInputConfiguration = null,
        role_arn: ?[]const u8 = null,
        created_at: ?i64 = null,
        status: ?[]const u8 = null,
        failed_reason: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .job_id = "JobId",
                .dataset_arn = "DatasetArn",
                .ingestion_input_configuration = "IngestionInputConfiguration",
                .role_arn = "RoleArn",
                .created_at = "CreatedAt",
                .status = "Status",
                .failed_reason = "FailedReason",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        InternalServer,
        ResourceNotFound,
        Throttling,
        Validation,
    },
} = .{};
pub const describe_dataset: struct {
    action_name: []const u8 = "DescribeDataset",
    Request: type = struct {
        dataset_name: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .dataset_name = "DatasetName",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(describe_dataset) } {
            return .{ .service_metadata = service_metadata, .action = describe_dataset };
        }
    },
    Response: type = struct {
        dataset_name: ?[]const u8 = null,
        dataset_arn: ?[]const u8 = null,
        created_at: ?i64 = null,
        last_updated_at: ?i64 = null,
        status: ?[]const u8 = null,
        schema: ?[]const u8 = null,
        server_side_kms_key_id: ?[]const u8 = null,
        ingestion_input_configuration: ?IngestionInputConfiguration = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .dataset_name = "DatasetName",
                .dataset_arn = "DatasetArn",
                .created_at = "CreatedAt",
                .last_updated_at = "LastUpdatedAt",
                .status = "Status",
                .schema = "Schema",
                .server_side_kms_key_id = "ServerSideKmsKeyId",
                .ingestion_input_configuration = "IngestionInputConfiguration",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        InternalServer,
        ResourceNotFound,
        Throttling,
        Validation,
    },
} = .{};
pub const describe_inference_scheduler: struct {
    action_name: []const u8 = "DescribeInferenceScheduler",
    Request: type = struct {
        inference_scheduler_name: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .inference_scheduler_name = "InferenceSchedulerName",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(describe_inference_scheduler) } {
            return .{ .service_metadata = service_metadata, .action = describe_inference_scheduler };
        }
    },
    Response: type = struct {
        model_arn: ?[]const u8 = null,
        model_name: ?[]const u8 = null,
        inference_scheduler_name: ?[]const u8 = null,
        inference_scheduler_arn: ?[]const u8 = null,
        status: ?[]const u8 = null,
        data_delay_offset_in_minutes: ?i64 = null,
        data_upload_frequency: ?[]const u8 = null,
        created_at: ?i64 = null,
        updated_at: ?i64 = null,
        data_input_configuration: ?InferenceInputConfiguration = null,
        data_output_configuration: ?InferenceOutputConfiguration = null,
        role_arn: ?[]const u8 = null,
        server_side_kms_key_id: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .model_arn = "ModelArn",
                .model_name = "ModelName",
                .inference_scheduler_name = "InferenceSchedulerName",
                .inference_scheduler_arn = "InferenceSchedulerArn",
                .status = "Status",
                .data_delay_offset_in_minutes = "DataDelayOffsetInMinutes",
                .data_upload_frequency = "DataUploadFrequency",
                .created_at = "CreatedAt",
                .updated_at = "UpdatedAt",
                .data_input_configuration = "DataInputConfiguration",
                .data_output_configuration = "DataOutputConfiguration",
                .role_arn = "RoleArn",
                .server_side_kms_key_id = "ServerSideKmsKeyId",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        InternalServer,
        ResourceNotFound,
        Throttling,
        Validation,
    },
} = .{};
pub const describe_model: struct {
    action_name: []const u8 = "DescribeModel",
    Request: type = struct {
        model_name: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .model_name = "ModelName",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(describe_model) } {
            return .{ .service_metadata = service_metadata, .action = describe_model };
        }
    },
    Response: type = struct {
        model_name: ?[]const u8 = null,
        model_arn: ?[]const u8 = null,
        dataset_name: ?[]const u8 = null,
        dataset_arn: ?[]const u8 = null,
        schema: ?[]const u8 = null,
        labels_input_configuration: ?LabelsInputConfiguration = null,
        training_data_start_time: ?i64 = null,
        training_data_end_time: ?i64 = null,
        evaluation_data_start_time: ?i64 = null,
        evaluation_data_end_time: ?i64 = null,
        role_arn: ?[]const u8 = null,
        data_pre_processing_configuration: ?DataPreProcessingConfiguration = null,
        status: ?[]const u8 = null,
        training_execution_start_time: ?i64 = null,
        training_execution_end_time: ?i64 = null,
        failed_reason: ?[]const u8 = null,
        model_metrics: ?[]const u8 = null,
        last_updated_time: ?i64 = null,
        created_at: ?i64 = null,
        server_side_kms_key_id: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .model_name = "ModelName",
                .model_arn = "ModelArn",
                .dataset_name = "DatasetName",
                .dataset_arn = "DatasetArn",
                .schema = "Schema",
                .labels_input_configuration = "LabelsInputConfiguration",
                .training_data_start_time = "TrainingDataStartTime",
                .training_data_end_time = "TrainingDataEndTime",
                .evaluation_data_start_time = "EvaluationDataStartTime",
                .evaluation_data_end_time = "EvaluationDataEndTime",
                .role_arn = "RoleArn",
                .data_pre_processing_configuration = "DataPreProcessingConfiguration",
                .status = "Status",
                .training_execution_start_time = "TrainingExecutionStartTime",
                .training_execution_end_time = "TrainingExecutionEndTime",
                .failed_reason = "FailedReason",
                .model_metrics = "ModelMetrics",
                .last_updated_time = "LastUpdatedTime",
                .created_at = "CreatedAt",
                .server_side_kms_key_id = "ServerSideKmsKeyId",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        InternalServer,
        ResourceNotFound,
        Throttling,
        Validation,
    },
} = .{};
pub const list_data_ingestion_jobs: struct {
    action_name: []const u8 = "ListDataIngestionJobs",
    Request: type = struct {
        dataset_name: ?[]const u8 = null,
        next_token: ?[]const u8 = null,
        max_results: ?i64 = null,
        status: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .dataset_name = "DatasetName",
                .next_token = "NextToken",
                .max_results = "MaxResults",
                .status = "Status",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_data_ingestion_jobs) } {
            return .{ .service_metadata = service_metadata, .action = list_data_ingestion_jobs };
        }
    },
    Response: type = struct {
        next_token: ?[]const u8 = null,
        data_ingestion_job_summaries: ?[]struct {
            job_id: ?[]const u8 = null,
            dataset_name: ?[]const u8 = null,
            dataset_arn: ?[]const u8 = null,
            ingestion_input_configuration: ?IngestionInputConfiguration = null,
            status: ?[]const u8 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .job_id = "JobId",
                    .dataset_name = "DatasetName",
                    .dataset_arn = "DatasetArn",
                    .ingestion_input_configuration = "IngestionInputConfiguration",
                    .status = "Status",
                };
                return @field(mappings, field_name);
            }
        } = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .next_token = "NextToken",
                .data_ingestion_job_summaries = "DataIngestionJobSummaries",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        InternalServer,
        Throttling,
        Validation,
    },
} = .{};
pub const list_datasets: struct {
    action_name: []const u8 = "ListDatasets",
    Request: type = struct {
        next_token: ?[]const u8 = null,
        max_results: ?i64 = null,
        dataset_name_begins_with: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .next_token = "NextToken",
                .max_results = "MaxResults",
                .dataset_name_begins_with = "DatasetNameBeginsWith",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_datasets) } {
            return .{ .service_metadata = service_metadata, .action = list_datasets };
        }
    },
    Response: type = struct {
        next_token: ?[]const u8 = null,
        dataset_summaries: ?[]struct {
            dataset_name: ?[]const u8 = null,
            dataset_arn: ?[]const u8 = null,
            status: ?[]const u8 = null,
            created_at: ?i64 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .dataset_name = "DatasetName",
                    .dataset_arn = "DatasetArn",
                    .status = "Status",
                    .created_at = "CreatedAt",
                };
                return @field(mappings, field_name);
            }
        } = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .next_token = "NextToken",
                .dataset_summaries = "DatasetSummaries",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        InternalServer,
        Throttling,
        Validation,
    },
} = .{};
pub const list_inference_executions: struct {
    action_name: []const u8 = "ListInferenceExecutions",
    Request: type = struct {
        next_token: ?[]const u8 = null,
        max_results: ?i64 = null,
        inference_scheduler_name: []const u8,
        data_start_time_after: ?i64 = null,
        data_end_time_before: ?i64 = null,
        status: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .next_token = "NextToken",
                .max_results = "MaxResults",
                .inference_scheduler_name = "InferenceSchedulerName",
                .data_start_time_after = "DataStartTimeAfter",
                .data_end_time_before = "DataEndTimeBefore",
                .status = "Status",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_inference_executions) } {
            return .{ .service_metadata = service_metadata, .action = list_inference_executions };
        }
    },
    Response: type = struct {
        next_token: ?[]const u8 = null,
        inference_execution_summaries: ?[]struct {
            model_name: ?[]const u8 = null,
            model_arn: ?[]const u8 = null,
            inference_scheduler_name: ?[]const u8 = null,
            inference_scheduler_arn: ?[]const u8 = null,
            scheduled_start_time: ?i64 = null,
            data_start_time: ?i64 = null,
            data_end_time: ?i64 = null,
            data_input_configuration: ?InferenceInputConfiguration = null,
            data_output_configuration: ?InferenceOutputConfiguration = null,
            customer_result_object: ?struct {
                bucket: []const u8,
                key: []const u8,

                pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                    const mappings = .{
                        .bucket = "Bucket",
                        .key = "Key",
                    };
                    return @field(mappings, field_name);
                }
            } = null,
            status: ?[]const u8 = null,
            failed_reason: ?[]const u8 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .model_name = "ModelName",
                    .model_arn = "ModelArn",
                    .inference_scheduler_name = "InferenceSchedulerName",
                    .inference_scheduler_arn = "InferenceSchedulerArn",
                    .scheduled_start_time = "ScheduledStartTime",
                    .data_start_time = "DataStartTime",
                    .data_end_time = "DataEndTime",
                    .data_input_configuration = "DataInputConfiguration",
                    .data_output_configuration = "DataOutputConfiguration",
                    .customer_result_object = "CustomerResultObject",
                    .status = "Status",
                    .failed_reason = "FailedReason",
                };
                return @field(mappings, field_name);
            }
        } = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .next_token = "NextToken",
                .inference_execution_summaries = "InferenceExecutionSummaries",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        InternalServer,
        ResourceNotFound,
        Throttling,
        Validation,
    },
} = .{};
pub const list_inference_schedulers: struct {
    action_name: []const u8 = "ListInferenceSchedulers",
    Request: type = struct {
        next_token: ?[]const u8 = null,
        max_results: ?i64 = null,
        inference_scheduler_name_begins_with: ?[]const u8 = null,
        model_name: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .next_token = "NextToken",
                .max_results = "MaxResults",
                .inference_scheduler_name_begins_with = "InferenceSchedulerNameBeginsWith",
                .model_name = "ModelName",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_inference_schedulers) } {
            return .{ .service_metadata = service_metadata, .action = list_inference_schedulers };
        }
    },
    Response: type = struct {
        next_token: ?[]const u8 = null,
        inference_scheduler_summaries: ?[]struct {
            model_name: ?[]const u8 = null,
            model_arn: ?[]const u8 = null,
            inference_scheduler_name: ?[]const u8 = null,
            inference_scheduler_arn: ?[]const u8 = null,
            status: ?[]const u8 = null,
            data_delay_offset_in_minutes: ?i64 = null,
            data_upload_frequency: ?[]const u8 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .model_name = "ModelName",
                    .model_arn = "ModelArn",
                    .inference_scheduler_name = "InferenceSchedulerName",
                    .inference_scheduler_arn = "InferenceSchedulerArn",
                    .status = "Status",
                    .data_delay_offset_in_minutes = "DataDelayOffsetInMinutes",
                    .data_upload_frequency = "DataUploadFrequency",
                };
                return @field(mappings, field_name);
            }
        } = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .next_token = "NextToken",
                .inference_scheduler_summaries = "InferenceSchedulerSummaries",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        InternalServer,
        Throttling,
        Validation,
    },
} = .{};
pub const list_models: struct {
    action_name: []const u8 = "ListModels",
    Request: type = struct {
        next_token: ?[]const u8 = null,
        max_results: ?i64 = null,
        status: ?[]const u8 = null,
        model_name_begins_with: ?[]const u8 = null,
        dataset_name_begins_with: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .next_token = "NextToken",
                .max_results = "MaxResults",
                .status = "Status",
                .model_name_begins_with = "ModelNameBeginsWith",
                .dataset_name_begins_with = "DatasetNameBeginsWith",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_models) } {
            return .{ .service_metadata = service_metadata, .action = list_models };
        }
    },
    Response: type = struct {
        next_token: ?[]const u8 = null,
        model_summaries: ?[]struct {
            model_name: ?[]const u8 = null,
            model_arn: ?[]const u8 = null,
            dataset_name: ?[]const u8 = null,
            dataset_arn: ?[]const u8 = null,
            status: ?[]const u8 = null,
            created_at: ?i64 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .model_name = "ModelName",
                    .model_arn = "ModelArn",
                    .dataset_name = "DatasetName",
                    .dataset_arn = "DatasetArn",
                    .status = "Status",
                    .created_at = "CreatedAt",
                };
                return @field(mappings, field_name);
            }
        } = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .next_token = "NextToken",
                .model_summaries = "ModelSummaries",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        InternalServer,
        Throttling,
        Validation,
    },
} = .{};
pub const list_tags_for_resource: struct {
    action_name: []const u8 = "ListTagsForResource",
    Request: type = struct {
        resource_arn: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .resource_arn = "ResourceArn",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_tags_for_resource) } {
            return .{ .service_metadata = service_metadata, .action = list_tags_for_resource };
        }
    },
    Response: type = struct {
        tags: ?[]Tag = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .tags = "Tags",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        InternalServer,
        ResourceNotFound,
        Throttling,
        Validation,
    },
} = .{};
pub const start_data_ingestion_job: struct {
    action_name: []const u8 = "StartDataIngestionJob",
    Request: type = struct {
        dataset_name: []const u8,
        ingestion_input_configuration: IngestionInputConfiguration,
        role_arn: []const u8,
        client_token: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .dataset_name = "DatasetName",
                .ingestion_input_configuration = "IngestionInputConfiguration",
                .role_arn = "RoleArn",
                .client_token = "ClientToken",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(start_data_ingestion_job) } {
            return .{ .service_metadata = service_metadata, .action = start_data_ingestion_job };
        }
    },
    Response: type = struct {
        job_id: ?[]const u8 = null,
        status: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .job_id = "JobId",
                .status = "Status",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        Conflict,
        InternalServer,
        ResourceNotFound,
        ServiceQuotaExceeded,
        Throttling,
        Validation,
    },
} = .{};
pub const start_inference_scheduler: struct {
    action_name: []const u8 = "StartInferenceScheduler",
    Request: type = struct {
        inference_scheduler_name: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .inference_scheduler_name = "InferenceSchedulerName",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(start_inference_scheduler) } {
            return .{ .service_metadata = service_metadata, .action = start_inference_scheduler };
        }
    },
    Response: type = struct {
        model_arn: ?[]const u8 = null,
        model_name: ?[]const u8 = null,
        inference_scheduler_name: ?[]const u8 = null,
        inference_scheduler_arn: ?[]const u8 = null,
        status: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .model_arn = "ModelArn",
                .model_name = "ModelName",
                .inference_scheduler_name = "InferenceSchedulerName",
                .inference_scheduler_arn = "InferenceSchedulerArn",
                .status = "Status",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        Conflict,
        InternalServer,
        ResourceNotFound,
        Throttling,
        Validation,
    },
} = .{};
pub const stop_inference_scheduler: struct {
    action_name: []const u8 = "StopInferenceScheduler",
    Request: type = struct {
        inference_scheduler_name: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .inference_scheduler_name = "InferenceSchedulerName",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(stop_inference_scheduler) } {
            return .{ .service_metadata = service_metadata, .action = stop_inference_scheduler };
        }
    },
    Response: type = struct {
        model_arn: ?[]const u8 = null,
        model_name: ?[]const u8 = null,
        inference_scheduler_name: ?[]const u8 = null,
        inference_scheduler_arn: ?[]const u8 = null,
        status: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .model_arn = "ModelArn",
                .model_name = "ModelName",
                .inference_scheduler_name = "InferenceSchedulerName",
                .inference_scheduler_arn = "InferenceSchedulerArn",
                .status = "Status",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        Conflict,
        InternalServer,
        ResourceNotFound,
        Throttling,
        Validation,
    },
} = .{};
pub const tag_resource: struct {
    action_name: []const u8 = "TagResource",
    Request: type = struct {
        resource_arn: []const u8,
        tags: []Tag,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .resource_arn = "ResourceArn",
                .tags = "Tags",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(tag_resource) } {
            return .{ .service_metadata = service_metadata, .action = tag_resource };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        InternalServer,
        ResourceNotFound,
        ServiceQuotaExceeded,
        Throttling,
        Validation,
    },
} = .{};
pub const untag_resource: struct {
    action_name: []const u8 = "UntagResource",
    Request: type = struct {
        resource_arn: []const u8,
        tag_keys: [][]const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .resource_arn = "ResourceArn",
                .tag_keys = "TagKeys",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(untag_resource) } {
            return .{ .service_metadata = service_metadata, .action = untag_resource };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        InternalServer,
        ResourceNotFound,
        Throttling,
        Validation,
    },
} = .{};
pub const update_inference_scheduler: struct {
    action_name: []const u8 = "UpdateInferenceScheduler",
    Request: type = struct {
        inference_scheduler_name: []const u8,
        data_delay_offset_in_minutes: ?i64 = null,
        data_upload_frequency: ?[]const u8 = null,
        data_input_configuration: ?InferenceInputConfiguration = null,
        data_output_configuration: ?InferenceOutputConfiguration = null,
        role_arn: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .inference_scheduler_name = "InferenceSchedulerName",
                .data_delay_offset_in_minutes = "DataDelayOffsetInMinutes",
                .data_upload_frequency = "DataUploadFrequency",
                .data_input_configuration = "DataInputConfiguration",
                .data_output_configuration = "DataOutputConfiguration",
                .role_arn = "RoleArn",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(update_inference_scheduler) } {
            return .{ .service_metadata = service_metadata, .action = update_inference_scheduler };
        }
    },
    Response: type = struct {},
    ServiceError: type = error{
        AccessDenied,
        Conflict,
        InternalServer,
        ResourceNotFound,
        Throttling,
        Validation,
    },
} = .{};

pub const InferenceOutputConfiguration = struct {
    s3_output_configuration: InferenceS3OutputConfiguration,
    kms_key_id: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .s3_output_configuration = "S3OutputConfiguration",
            .kms_key_id = "KmsKeyId",
        };
        return @field(mappings, field_name);
    }
};

pub const InferenceS3OutputConfiguration = struct {
    bucket: []const u8,
    prefix: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .bucket = "Bucket",
            .prefix = "Prefix",
        };
        return @field(mappings, field_name);
    }
};

pub const InferenceInputConfiguration = struct {
    s3_input_configuration: ?InferenceS3InputConfiguration = null,
    input_time_zone_offset: ?[]const u8 = null,
    inference_input_name_configuration: ?InferenceInputNameConfiguration = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .s3_input_configuration = "S3InputConfiguration",
            .input_time_zone_offset = "InputTimeZoneOffset",
            .inference_input_name_configuration = "InferenceInputNameConfiguration",
        };
        return @field(mappings, field_name);
    }
};

pub const InferenceInputNameConfiguration = struct {
    timestamp_format: ?[]const u8 = null,
    component_timestamp_delimiter: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .timestamp_format = "TimestampFormat",
            .component_timestamp_delimiter = "ComponentTimestampDelimiter",
        };
        return @field(mappings, field_name);
    }
};

pub const InferenceS3InputConfiguration = struct {
    bucket: []const u8,
    prefix: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .bucket = "Bucket",
            .prefix = "Prefix",
        };
        return @field(mappings, field_name);
    }
};

pub const Tag = struct {
    key: []const u8,
    value: []const u8,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .key = "Key",
            .value = "Value",
        };
        return @field(mappings, field_name);
    }
};

pub const IngestionInputConfiguration = struct {
    s3_input_configuration: IngestionS3InputConfiguration,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .s3_input_configuration = "S3InputConfiguration",
        };
        return @field(mappings, field_name);
    }
};

pub const IngestionS3InputConfiguration = struct {
    bucket: []const u8,
    prefix: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .bucket = "Bucket",
            .prefix = "Prefix",
        };
        return @field(mappings, field_name);
    }
};

pub const DataPreProcessingConfiguration = struct {
    target_sampling_rate: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .target_sampling_rate = "TargetSamplingRate",
        };
        return @field(mappings, field_name);
    }
};

pub const LabelsInputConfiguration = struct {
    s3_input_configuration: LabelsS3InputConfiguration,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .s3_input_configuration = "S3InputConfiguration",
        };
        return @field(mappings, field_name);
    }
};

pub const LabelsS3InputConfiguration = struct {
    bucket: []const u8,
    prefix: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .bucket = "Bucket",
            .prefix = "Prefix",
        };
        return @field(mappings, field_name);
    }
};

pub const DatasetSchema = struct {
    inline_data_schema: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .inline_data_schema = "InlineDataSchema",
        };
        return @field(mappings, field_name);
    }
};
