const std = @import("std");
const serializeMap = @import("json.zig").serializeMap;
const smithy = @import("smithy");

const Self = @This();
pub const version: []const u8 = "2020-08-01";
pub const sdk_id: []const u8 = "nimble";
pub const arn_namespace: []const u8 = "nimble";
pub const endpoint_prefix: []const u8 = "nimble";
pub const sigv4_name: []const u8 = "nimble";
pub const name: []const u8 = "nimble";
pub const aws_protocol: smithy.AwsProtocol = smithy.AwsProtocol.rest_json_1;

pub const service_metadata: struct {
    version: []const u8 = "2020-08-01",
    sdk_id: []const u8 = "nimble",
    arn_namespace: []const u8 = "nimble",
    endpoint_prefix: []const u8 = "nimble",
    sigv4_name: []const u8 = "nimble",
    name: []const u8 = "nimble",
    aws_protocol: smithy.AwsProtocol = smithy.AwsProtocol.rest_json_1,
} = .{};
pub const accept_eulas: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/2020-08-01/studios/{studioId}/eula-acceptances",
        .success_code = 200,
    };

    action_name: []const u8 = "AcceptEulas",
    Request: type = struct {
        client_token: ?[]const u8 = null,
        eula_ids: ?[][]const u8 = null,
        studio_id: []const u8,
        pub const http_header = .{
            .client_token = "X-Amz-Client-Token",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .client_token = "clientToken",
                .eula_ids = "eulaIds",
                .studio_id = "studioId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(accept_eulas) } {
            return .{ .service_metadata = service_metadata, .action = accept_eulas };
        }
    },
    Response: type = struct {
        eula_acceptances: ?[]EulaAcceptance = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .eula_acceptances = "eulaAcceptances",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        Conflict,
        InternalServerError,
        ResourceNotFound,
        ServiceQuotaExceeded,
        Throttling,
        Validation,
    },
} = .{};
pub const create_launch_profile: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/2020-08-01/studios/{studioId}/launch-profiles",
        .success_code = 200,
    };

    action_name: []const u8 = "CreateLaunchProfile",
    Request: type = struct {
        client_token: ?[]const u8 = null,
        description: ?[]const u8 = null,
        ec2_subnet_ids: [][]const u8,
        launch_profile_protocol_versions: [][]const u8,
        name: []const u8,
        stream_configuration: StreamConfigurationCreate,
        studio_component_ids: [][]const u8,
        studio_id: []const u8,
        tags: ?[]struct {
            key: ?[]const u8 = null,
            value: ?[]const u8 = null,
        } = null,
        pub const http_header = .{
            .client_token = "X-Amz-Client-Token",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .client_token = "clientToken",
                .description = "description",
                .ec2_subnet_ids = "ec2SubnetIds",
                .launch_profile_protocol_versions = "launchProfileProtocolVersions",
                .name = "name",
                .stream_configuration = "streamConfiguration",
                .studio_component_ids = "studioComponentIds",
                .studio_id = "studioId",
                .tags = "tags",
            };
            return @field(mappings, field_name);
        }

        pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
            if (std.mem.eql(u8, "tags", field_name))
                return try serializeMap(self.tags, self.fieldNameFor("tags"), options, out_stream);
            return false;
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(create_launch_profile) } {
            return .{ .service_metadata = service_metadata, .action = create_launch_profile };
        }
    },
    Response: type = struct {
        launch_profile: ?LaunchProfile = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .launch_profile = "launchProfile",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        Conflict,
        InternalServerError,
        ResourceNotFound,
        ServiceQuotaExceeded,
        Throttling,
        Validation,
    },
} = .{};
pub const create_streaming_image: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/2020-08-01/studios/{studioId}/streaming-images",
        .success_code = 200,
    };

    action_name: []const u8 = "CreateStreamingImage",
    Request: type = struct {
        client_token: ?[]const u8 = null,
        description: ?[]const u8 = null,
        ec2_image_id: []const u8,
        name: []const u8,
        studio_id: []const u8,
        tags: ?[]struct {
            key: ?[]const u8 = null,
            value: ?[]const u8 = null,
        } = null,
        pub const http_header = .{
            .client_token = "X-Amz-Client-Token",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .client_token = "clientToken",
                .description = "description",
                .ec2_image_id = "ec2ImageId",
                .name = "name",
                .studio_id = "studioId",
                .tags = "tags",
            };
            return @field(mappings, field_name);
        }

        pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
            if (std.mem.eql(u8, "tags", field_name))
                return try serializeMap(self.tags, self.fieldNameFor("tags"), options, out_stream);
            return false;
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(create_streaming_image) } {
            return .{ .service_metadata = service_metadata, .action = create_streaming_image };
        }
    },
    Response: type = struct {
        streaming_image: ?StreamingImage = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .streaming_image = "streamingImage",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        Conflict,
        InternalServerError,
        ResourceNotFound,
        ServiceQuotaExceeded,
        Throttling,
        Validation,
    },
} = .{};
pub const create_streaming_session: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/2020-08-01/studios/{studioId}/streaming-sessions",
        .success_code = 200,
    };

    action_name: []const u8 = "CreateStreamingSession",
    Request: type = struct {
        client_token: ?[]const u8 = null,
        ec2_instance_type: ?[]const u8 = null,
        launch_profile_id: ?[]const u8 = null,
        streaming_image_id: ?[]const u8 = null,
        studio_id: []const u8,
        tags: ?[]struct {
            key: ?[]const u8 = null,
            value: ?[]const u8 = null,
        } = null,
        pub const http_header = .{
            .client_token = "X-Amz-Client-Token",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .client_token = "clientToken",
                .ec2_instance_type = "ec2InstanceType",
                .launch_profile_id = "launchProfileId",
                .streaming_image_id = "streamingImageId",
                .studio_id = "studioId",
                .tags = "tags",
            };
            return @field(mappings, field_name);
        }

        pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
            if (std.mem.eql(u8, "tags", field_name))
                return try serializeMap(self.tags, self.fieldNameFor("tags"), options, out_stream);
            return false;
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(create_streaming_session) } {
            return .{ .service_metadata = service_metadata, .action = create_streaming_session };
        }
    },
    Response: type = struct {
        session: ?StreamingSession = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .session = "session",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        Conflict,
        InternalServerError,
        ResourceNotFound,
        ServiceQuotaExceeded,
        Throttling,
        Validation,
    },
} = .{};
pub const create_streaming_session_stream: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/2020-08-01/studios/{studioId}/streaming-sessions/{sessionId}/streams",
        .success_code = 200,
    };

    action_name: []const u8 = "CreateStreamingSessionStream",
    Request: type = struct {
        client_token: ?[]const u8 = null,
        expiration_in_seconds: ?i64 = null,
        session_id: []const u8,
        studio_id: []const u8,
        pub const http_header = .{
            .client_token = "X-Amz-Client-Token",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .client_token = "clientToken",
                .expiration_in_seconds = "expirationInSeconds",
                .session_id = "sessionId",
                .studio_id = "studioId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(create_streaming_session_stream) } {
            return .{ .service_metadata = service_metadata, .action = create_streaming_session_stream };
        }
    },
    Response: type = struct {
        stream: ?StreamingSessionStream = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .stream = "stream",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        Conflict,
        InternalServerError,
        ResourceNotFound,
        ServiceQuotaExceeded,
        Throttling,
        Validation,
    },
} = .{};
pub const create_studio: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/2020-08-01/studios",
        .success_code = 200,
    };

    action_name: []const u8 = "CreateStudio",
    Request: type = struct {
        admin_role_arn: []const u8,
        client_token: ?[]const u8 = null,
        display_name: []const u8,
        studio_encryption_configuration: ?StudioEncryptionConfiguration = null,
        studio_name: []const u8,
        tags: ?[]struct {
            key: ?[]const u8 = null,
            value: ?[]const u8 = null,
        } = null,
        user_role_arn: []const u8,
        pub const http_header = .{
            .client_token = "X-Amz-Client-Token",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .admin_role_arn = "adminRoleArn",
                .client_token = "clientToken",
                .display_name = "displayName",
                .studio_encryption_configuration = "studioEncryptionConfiguration",
                .studio_name = "studioName",
                .tags = "tags",
                .user_role_arn = "userRoleArn",
            };
            return @field(mappings, field_name);
        }

        pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
            if (std.mem.eql(u8, "tags", field_name))
                return try serializeMap(self.tags, self.fieldNameFor("tags"), options, out_stream);
            return false;
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(create_studio) } {
            return .{ .service_metadata = service_metadata, .action = create_studio };
        }
    },
    Response: type = struct {
        studio: ?Studio = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .studio = "studio",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        Conflict,
        InternalServerError,
        ResourceNotFound,
        ServiceQuotaExceeded,
        Throttling,
        Validation,
    },
} = .{};
pub const create_studio_component: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/2020-08-01/studios/{studioId}/studio-components",
        .success_code = 200,
    };

    action_name: []const u8 = "CreateStudioComponent",
    Request: type = struct {
        client_token: ?[]const u8 = null,
        configuration: ?StudioComponentConfiguration = null,
        description: ?[]const u8 = null,
        ec2_security_group_ids: ?[][]const u8 = null,
        initialization_scripts: ?[]StudioComponentInitializationScript = null,
        name: []const u8,
        script_parameters: ?[]ScriptParameterKeyValue = null,
        studio_id: []const u8,
        subtype: ?[]const u8 = null,
        tags: ?[]struct {
            key: ?[]const u8 = null,
            value: ?[]const u8 = null,
        } = null,
        type: []const u8,
        pub const http_header = .{
            .client_token = "X-Amz-Client-Token",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .client_token = "clientToken",
                .configuration = "configuration",
                .description = "description",
                .ec2_security_group_ids = "ec2SecurityGroupIds",
                .initialization_scripts = "initializationScripts",
                .name = "name",
                .script_parameters = "scriptParameters",
                .studio_id = "studioId",
                .subtype = "subtype",
                .tags = "tags",
                .type = "type",
            };
            return @field(mappings, field_name);
        }

        pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
            if (std.mem.eql(u8, "tags", field_name))
                return try serializeMap(self.tags, self.fieldNameFor("tags"), options, out_stream);
            return false;
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(create_studio_component) } {
            return .{ .service_metadata = service_metadata, .action = create_studio_component };
        }
    },
    Response: type = struct {
        studio_component: ?StudioComponent = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .studio_component = "studioComponent",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        Conflict,
        InternalServerError,
        ResourceNotFound,
        ServiceQuotaExceeded,
        Throttling,
        Validation,
    },
} = .{};
pub const delete_launch_profile: struct {
    pub const http_config = .{
        .method = "DELETE",
        .uri = "/2020-08-01/studios/{studioId}/launch-profiles/{launchProfileId}",
        .success_code = 200,
    };

    action_name: []const u8 = "DeleteLaunchProfile",
    Request: type = struct {
        client_token: ?[]const u8 = null,
        launch_profile_id: []const u8,
        studio_id: []const u8,
        pub const http_header = .{
            .client_token = "X-Amz-Client-Token",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .client_token = "clientToken",
                .launch_profile_id = "launchProfileId",
                .studio_id = "studioId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(delete_launch_profile) } {
            return .{ .service_metadata = service_metadata, .action = delete_launch_profile };
        }
    },
    Response: type = struct {
        launch_profile: ?LaunchProfile = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .launch_profile = "launchProfile",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        Conflict,
        InternalServerError,
        ResourceNotFound,
        ServiceQuotaExceeded,
        Throttling,
        Validation,
    },
} = .{};
pub const delete_launch_profile_member: struct {
    pub const http_config = .{
        .method = "DELETE",
        .uri = "/2020-08-01/studios/{studioId}/launch-profiles/{launchProfileId}/membership/{principalId}",
        .success_code = 200,
    };

    action_name: []const u8 = "DeleteLaunchProfileMember",
    Request: type = struct {
        client_token: ?[]const u8 = null,
        launch_profile_id: []const u8,
        principal_id: []const u8,
        studio_id: []const u8,
        pub const http_header = .{
            .client_token = "X-Amz-Client-Token",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .client_token = "clientToken",
                .launch_profile_id = "launchProfileId",
                .principal_id = "principalId",
                .studio_id = "studioId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(delete_launch_profile_member) } {
            return .{ .service_metadata = service_metadata, .action = delete_launch_profile_member };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        Conflict,
        InternalServerError,
        ResourceNotFound,
        ServiceQuotaExceeded,
        Throttling,
        Validation,
    },
} = .{};
pub const delete_streaming_image: struct {
    pub const http_config = .{
        .method = "DELETE",
        .uri = "/2020-08-01/studios/{studioId}/streaming-images/{streamingImageId}",
        .success_code = 200,
    };

    action_name: []const u8 = "DeleteStreamingImage",
    Request: type = struct {
        client_token: ?[]const u8 = null,
        streaming_image_id: []const u8,
        studio_id: []const u8,
        pub const http_header = .{
            .client_token = "X-Amz-Client-Token",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .client_token = "clientToken",
                .streaming_image_id = "streamingImageId",
                .studio_id = "studioId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(delete_streaming_image) } {
            return .{ .service_metadata = service_metadata, .action = delete_streaming_image };
        }
    },
    Response: type = struct {
        streaming_image: ?StreamingImage = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .streaming_image = "streamingImage",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        Conflict,
        InternalServerError,
        ResourceNotFound,
        ServiceQuotaExceeded,
        Throttling,
        Validation,
    },
} = .{};
pub const delete_streaming_session: struct {
    pub const http_config = .{
        .method = "DELETE",
        .uri = "/2020-08-01/studios/{studioId}/streaming-sessions/{sessionId}",
        .success_code = 200,
    };

    action_name: []const u8 = "DeleteStreamingSession",
    Request: type = struct {
        client_token: ?[]const u8 = null,
        session_id: []const u8,
        studio_id: []const u8,
        pub const http_header = .{
            .client_token = "X-Amz-Client-Token",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .client_token = "clientToken",
                .session_id = "sessionId",
                .studio_id = "studioId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(delete_streaming_session) } {
            return .{ .service_metadata = service_metadata, .action = delete_streaming_session };
        }
    },
    Response: type = struct {
        session: ?StreamingSession = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .session = "session",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        Conflict,
        InternalServerError,
        ResourceNotFound,
        ServiceQuotaExceeded,
        Throttling,
        Validation,
    },
} = .{};
pub const delete_studio: struct {
    pub const http_config = .{
        .method = "DELETE",
        .uri = "/2020-08-01/studios/{studioId}",
        .success_code = 200,
    };

    action_name: []const u8 = "DeleteStudio",
    Request: type = struct {
        client_token: ?[]const u8 = null,
        studio_id: []const u8,
        pub const http_header = .{
            .client_token = "X-Amz-Client-Token",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .client_token = "clientToken",
                .studio_id = "studioId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(delete_studio) } {
            return .{ .service_metadata = service_metadata, .action = delete_studio };
        }
    },
    Response: type = struct {
        studio: ?Studio = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .studio = "studio",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        Conflict,
        InternalServerError,
        ResourceNotFound,
        ServiceQuotaExceeded,
        Throttling,
        Validation,
    },
} = .{};
pub const delete_studio_component: struct {
    pub const http_config = .{
        .method = "DELETE",
        .uri = "/2020-08-01/studios/{studioId}/studio-components/{studioComponentId}",
        .success_code = 200,
    };

    action_name: []const u8 = "DeleteStudioComponent",
    Request: type = struct {
        client_token: ?[]const u8 = null,
        studio_component_id: []const u8,
        studio_id: []const u8,
        pub const http_header = .{
            .client_token = "X-Amz-Client-Token",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .client_token = "clientToken",
                .studio_component_id = "studioComponentId",
                .studio_id = "studioId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(delete_studio_component) } {
            return .{ .service_metadata = service_metadata, .action = delete_studio_component };
        }
    },
    Response: type = struct {
        studio_component: ?StudioComponent = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .studio_component = "studioComponent",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        Conflict,
        InternalServerError,
        ResourceNotFound,
        ServiceQuotaExceeded,
        Throttling,
        Validation,
    },
} = .{};
pub const delete_studio_member: struct {
    pub const http_config = .{
        .method = "DELETE",
        .uri = "/2020-08-01/studios/{studioId}/membership/{principalId}",
        .success_code = 200,
    };

    action_name: []const u8 = "DeleteStudioMember",
    Request: type = struct {
        client_token: ?[]const u8 = null,
        principal_id: []const u8,
        studio_id: []const u8,
        pub const http_header = .{
            .client_token = "X-Amz-Client-Token",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .client_token = "clientToken",
                .principal_id = "principalId",
                .studio_id = "studioId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(delete_studio_member) } {
            return .{ .service_metadata = service_metadata, .action = delete_studio_member };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        Conflict,
        InternalServerError,
        ResourceNotFound,
        ServiceQuotaExceeded,
        Throttling,
        Validation,
    },
} = .{};
pub const get_eula: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/2020-08-01/eulas/{eulaId}",
        .success_code = 200,
    };

    action_name: []const u8 = "GetEula",
    Request: type = struct {
        eula_id: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .eula_id = "eulaId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(get_eula) } {
            return .{ .service_metadata = service_metadata, .action = get_eula };
        }
    },
    Response: type = struct {
        eula: ?Eula = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .eula = "eula",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        Conflict,
        InternalServerError,
        ResourceNotFound,
        ServiceQuotaExceeded,
        Throttling,
        Validation,
    },
} = .{};
pub const get_launch_profile: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/2020-08-01/studios/{studioId}/launch-profiles/{launchProfileId}",
        .success_code = 200,
    };

    action_name: []const u8 = "GetLaunchProfile",
    Request: type = struct {
        launch_profile_id: []const u8,
        studio_id: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .launch_profile_id = "launchProfileId",
                .studio_id = "studioId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(get_launch_profile) } {
            return .{ .service_metadata = service_metadata, .action = get_launch_profile };
        }
    },
    Response: type = struct {
        launch_profile: ?LaunchProfile = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .launch_profile = "launchProfile",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        Conflict,
        InternalServerError,
        ResourceNotFound,
        ServiceQuotaExceeded,
        Throttling,
        Validation,
    },
} = .{};
pub const get_launch_profile_details: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/2020-08-01/studios/{studioId}/launch-profiles/{launchProfileId}/details",
        .success_code = 200,
    };

    action_name: []const u8 = "GetLaunchProfileDetails",
    Request: type = struct {
        launch_profile_id: []const u8,
        studio_id: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .launch_profile_id = "launchProfileId",
                .studio_id = "studioId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(get_launch_profile_details) } {
            return .{ .service_metadata = service_metadata, .action = get_launch_profile_details };
        }
    },
    Response: type = struct {
        launch_profile: ?LaunchProfile = null,
        streaming_images: ?[]StreamingImage = null,
        studio_component_summaries: ?[]struct {
            created_at: ?i64 = null,
            created_by: ?[]const u8 = null,
            description: ?[]const u8 = null,
            name: ?[]const u8 = null,
            studio_component_id: ?[]const u8 = null,
            subtype: ?[]const u8 = null,
            type: ?[]const u8 = null,
            updated_at: ?i64 = null,
            updated_by: ?[]const u8 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .created_at = "createdAt",
                    .created_by = "createdBy",
                    .description = "description",
                    .name = "name",
                    .studio_component_id = "studioComponentId",
                    .subtype = "subtype",
                    .type = "type",
                    .updated_at = "updatedAt",
                    .updated_by = "updatedBy",
                };
                return @field(mappings, field_name);
            }
        } = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .launch_profile = "launchProfile",
                .streaming_images = "streamingImages",
                .studio_component_summaries = "studioComponentSummaries",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        Conflict,
        InternalServerError,
        ResourceNotFound,
        ServiceQuotaExceeded,
        Throttling,
        Validation,
    },
} = .{};
pub const get_launch_profile_initialization: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/2020-08-01/studios/{studioId}/launch-profiles/{launchProfileId}/init",
        .success_code = 200,
    };

    action_name: []const u8 = "GetLaunchProfileInitialization",
    Request: type = struct {
        launch_profile_id: []const u8,
        launch_profile_protocol_versions: [][]const u8,
        launch_purpose: []const u8,
        platform: []const u8,
        studio_id: []const u8,

        pub const http_query = .{
            .launch_profile_protocol_versions = "launchProfileProtocolVersions",
            .launch_purpose = "launchPurpose",
            .platform = "platform",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .launch_profile_id = "launchProfileId",
                .launch_profile_protocol_versions = "launchProfileProtocolVersions",
                .launch_purpose = "launchPurpose",
                .platform = "platform",
                .studio_id = "studioId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(get_launch_profile_initialization) } {
            return .{ .service_metadata = service_metadata, .action = get_launch_profile_initialization };
        }
    },
    Response: type = struct {
        launch_profile_initialization: ?struct {
            active_directory: ?struct {
                computer_attributes: ?[]ActiveDirectoryComputerAttribute = null,
                directory_id: ?[]const u8 = null,
                directory_name: ?[]const u8 = null,
                dns_ip_addresses: ?[][]const u8 = null,
                organizational_unit_distinguished_name: ?[]const u8 = null,
                studio_component_id: ?[]const u8 = null,
                studio_component_name: ?[]const u8 = null,

                pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                    const mappings = .{
                        .computer_attributes = "computerAttributes",
                        .directory_id = "directoryId",
                        .directory_name = "directoryName",
                        .dns_ip_addresses = "dnsIpAddresses",
                        .organizational_unit_distinguished_name = "organizationalUnitDistinguishedName",
                        .studio_component_id = "studioComponentId",
                        .studio_component_name = "studioComponentName",
                    };
                    return @field(mappings, field_name);
                }
            } = null,
            ec2_security_group_ids: ?[][]const u8 = null,
            launch_profile_id: ?[]const u8 = null,
            launch_profile_protocol_version: ?[]const u8 = null,
            launch_purpose: ?[]const u8 = null,
            name: ?[]const u8 = null,
            platform: ?[]const u8 = null,
            system_initialization_scripts: ?[]LaunchProfileInitializationScript = null,
            user_initialization_scripts: ?[]LaunchProfileInitializationScript = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .active_directory = "activeDirectory",
                    .ec2_security_group_ids = "ec2SecurityGroupIds",
                    .launch_profile_id = "launchProfileId",
                    .launch_profile_protocol_version = "launchProfileProtocolVersion",
                    .launch_purpose = "launchPurpose",
                    .name = "name",
                    .platform = "platform",
                    .system_initialization_scripts = "systemInitializationScripts",
                    .user_initialization_scripts = "userInitializationScripts",
                };
                return @field(mappings, field_name);
            }
        } = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .launch_profile_initialization = "launchProfileInitialization",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        Conflict,
        InternalServerError,
        ResourceNotFound,
        ServiceQuotaExceeded,
        Throttling,
        Validation,
    },
} = .{};
pub const get_launch_profile_member: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/2020-08-01/studios/{studioId}/launch-profiles/{launchProfileId}/membership/{principalId}",
        .success_code = 200,
    };

    action_name: []const u8 = "GetLaunchProfileMember",
    Request: type = struct {
        launch_profile_id: []const u8,
        principal_id: []const u8,
        studio_id: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .launch_profile_id = "launchProfileId",
                .principal_id = "principalId",
                .studio_id = "studioId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(get_launch_profile_member) } {
            return .{ .service_metadata = service_metadata, .action = get_launch_profile_member };
        }
    },
    Response: type = struct {
        member: ?LaunchProfileMembership = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .member = "member",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        Conflict,
        InternalServerError,
        ResourceNotFound,
        ServiceQuotaExceeded,
        Throttling,
        Validation,
    },
} = .{};
pub const get_streaming_image: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/2020-08-01/studios/{studioId}/streaming-images/{streamingImageId}",
        .success_code = 200,
    };

    action_name: []const u8 = "GetStreamingImage",
    Request: type = struct {
        streaming_image_id: []const u8,
        studio_id: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .streaming_image_id = "streamingImageId",
                .studio_id = "studioId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(get_streaming_image) } {
            return .{ .service_metadata = service_metadata, .action = get_streaming_image };
        }
    },
    Response: type = struct {
        streaming_image: ?StreamingImage = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .streaming_image = "streamingImage",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        Conflict,
        InternalServerError,
        ResourceNotFound,
        ServiceQuotaExceeded,
        Throttling,
        Validation,
    },
} = .{};
pub const get_streaming_session: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/2020-08-01/studios/{studioId}/streaming-sessions/{sessionId}",
        .success_code = 200,
    };

    action_name: []const u8 = "GetStreamingSession",
    Request: type = struct {
        session_id: []const u8,
        studio_id: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .session_id = "sessionId",
                .studio_id = "studioId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(get_streaming_session) } {
            return .{ .service_metadata = service_metadata, .action = get_streaming_session };
        }
    },
    Response: type = struct {
        session: ?StreamingSession = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .session = "session",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        Conflict,
        InternalServerError,
        ResourceNotFound,
        ServiceQuotaExceeded,
        Throttling,
        Validation,
    },
} = .{};
pub const get_streaming_session_stream: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/2020-08-01/studios/{studioId}/streaming-sessions/{sessionId}/streams/{streamId}",
        .success_code = 200,
    };

    action_name: []const u8 = "GetStreamingSessionStream",
    Request: type = struct {
        session_id: []const u8,
        stream_id: []const u8,
        studio_id: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .session_id = "sessionId",
                .stream_id = "streamId",
                .studio_id = "studioId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(get_streaming_session_stream) } {
            return .{ .service_metadata = service_metadata, .action = get_streaming_session_stream };
        }
    },
    Response: type = struct {
        stream: ?StreamingSessionStream = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .stream = "stream",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        Conflict,
        InternalServerError,
        ResourceNotFound,
        ServiceQuotaExceeded,
        Throttling,
        Validation,
    },
} = .{};
pub const get_studio: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/2020-08-01/studios/{studioId}",
        .success_code = 200,
    };

    action_name: []const u8 = "GetStudio",
    Request: type = struct {
        studio_id: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .studio_id = "studioId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(get_studio) } {
            return .{ .service_metadata = service_metadata, .action = get_studio };
        }
    },
    Response: type = struct {
        studio: ?Studio = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .studio = "studio",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        Conflict,
        InternalServerError,
        ResourceNotFound,
        ServiceQuotaExceeded,
        Throttling,
        Validation,
    },
} = .{};
pub const get_studio_component: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/2020-08-01/studios/{studioId}/studio-components/{studioComponentId}",
        .success_code = 200,
    };

    action_name: []const u8 = "GetStudioComponent",
    Request: type = struct {
        studio_component_id: []const u8,
        studio_id: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .studio_component_id = "studioComponentId",
                .studio_id = "studioId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(get_studio_component) } {
            return .{ .service_metadata = service_metadata, .action = get_studio_component };
        }
    },
    Response: type = struct {
        studio_component: ?StudioComponent = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .studio_component = "studioComponent",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        Conflict,
        InternalServerError,
        ResourceNotFound,
        ServiceQuotaExceeded,
        Throttling,
        Validation,
    },
} = .{};
pub const get_studio_member: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/2020-08-01/studios/{studioId}/membership/{principalId}",
        .success_code = 200,
    };

    action_name: []const u8 = "GetStudioMember",
    Request: type = struct {
        principal_id: []const u8,
        studio_id: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .principal_id = "principalId",
                .studio_id = "studioId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(get_studio_member) } {
            return .{ .service_metadata = service_metadata, .action = get_studio_member };
        }
    },
    Response: type = struct {
        member: ?StudioMembership = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .member = "member",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        Conflict,
        InternalServerError,
        ResourceNotFound,
        ServiceQuotaExceeded,
        Throttling,
        Validation,
    },
} = .{};
pub const list_eula_acceptances: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/2020-08-01/studios/{studioId}/eula-acceptances",
        .success_code = 200,
    };

    action_name: []const u8 = "ListEulaAcceptances",
    Request: type = struct {
        eula_ids: ?[][]const u8 = null,
        next_token: ?[]const u8 = null,
        studio_id: []const u8,

        pub const http_query = .{
            .eula_ids = "eulaIds",
            .next_token = "nextToken",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .eula_ids = "eulaIds",
                .next_token = "nextToken",
                .studio_id = "studioId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_eula_acceptances) } {
            return .{ .service_metadata = service_metadata, .action = list_eula_acceptances };
        }
    },
    Response: type = struct {
        eula_acceptances: ?[]EulaAcceptance = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .eula_acceptances = "eulaAcceptances",
                .next_token = "nextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        Conflict,
        InternalServerError,
        ResourceNotFound,
        ServiceQuotaExceeded,
        Throttling,
        Validation,
    },
} = .{};
pub const list_eulas: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/2020-08-01/eulas",
        .success_code = 200,
    };

    action_name: []const u8 = "ListEulas",
    Request: type = struct {
        eula_ids: ?[][]const u8 = null,
        next_token: ?[]const u8 = null,

        pub const http_query = .{
            .eula_ids = "eulaIds",
            .next_token = "nextToken",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .eula_ids = "eulaIds",
                .next_token = "nextToken",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_eulas) } {
            return .{ .service_metadata = service_metadata, .action = list_eulas };
        }
    },
    Response: type = struct {
        eulas: ?[]Eula = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .eulas = "eulas",
                .next_token = "nextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        Conflict,
        InternalServerError,
        ResourceNotFound,
        ServiceQuotaExceeded,
        Throttling,
        Validation,
    },
} = .{};
pub const list_launch_profile_members: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/2020-08-01/studios/{studioId}/launch-profiles/{launchProfileId}/membership",
        .success_code = 200,
    };

    action_name: []const u8 = "ListLaunchProfileMembers",
    Request: type = struct {
        launch_profile_id: []const u8,
        max_results: ?i64 = null,
        next_token: ?[]const u8 = null,
        studio_id: []const u8,

        pub const http_query = .{
            .max_results = "maxResults",
            .next_token = "nextToken",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .launch_profile_id = "launchProfileId",
                .max_results = "maxResults",
                .next_token = "nextToken",
                .studio_id = "studioId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_launch_profile_members) } {
            return .{ .service_metadata = service_metadata, .action = list_launch_profile_members };
        }
    },
    Response: type = struct {
        members: ?[]LaunchProfileMembership = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .members = "members",
                .next_token = "nextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        Conflict,
        InternalServerError,
        ResourceNotFound,
        ServiceQuotaExceeded,
        Throttling,
        Validation,
    },
} = .{};
pub const list_launch_profiles: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/2020-08-01/studios/{studioId}/launch-profiles",
        .success_code = 200,
    };

    action_name: []const u8 = "ListLaunchProfiles",
    Request: type = struct {
        max_results: ?i64 = null,
        next_token: ?[]const u8 = null,
        principal_id: ?[]const u8 = null,
        states: ?[][]const u8 = null,
        studio_id: []const u8,

        pub const http_query = .{
            .max_results = "maxResults",
            .next_token = "nextToken",
            .principal_id = "principalId",
            .states = "states",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .max_results = "maxResults",
                .next_token = "nextToken",
                .principal_id = "principalId",
                .states = "states",
                .studio_id = "studioId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_launch_profiles) } {
            return .{ .service_metadata = service_metadata, .action = list_launch_profiles };
        }
    },
    Response: type = struct {
        launch_profiles: ?[]LaunchProfile = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .launch_profiles = "launchProfiles",
                .next_token = "nextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        Conflict,
        InternalServerError,
        ResourceNotFound,
        ServiceQuotaExceeded,
        Throttling,
        Validation,
    },
} = .{};
pub const list_streaming_images: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/2020-08-01/studios/{studioId}/streaming-images",
        .success_code = 200,
    };

    action_name: []const u8 = "ListStreamingImages",
    Request: type = struct {
        next_token: ?[]const u8 = null,
        owner: ?[]const u8 = null,
        studio_id: []const u8,

        pub const http_query = .{
            .next_token = "nextToken",
            .owner = "owner",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .next_token = "nextToken",
                .owner = "owner",
                .studio_id = "studioId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_streaming_images) } {
            return .{ .service_metadata = service_metadata, .action = list_streaming_images };
        }
    },
    Response: type = struct {
        next_token: ?[]const u8 = null,
        streaming_images: ?[]StreamingImage = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .next_token = "nextToken",
                .streaming_images = "streamingImages",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        Conflict,
        InternalServerError,
        ResourceNotFound,
        ServiceQuotaExceeded,
        Throttling,
        Validation,
    },
} = .{};
pub const list_streaming_sessions: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/2020-08-01/studios/{studioId}/streaming-sessions",
        .success_code = 200,
    };

    action_name: []const u8 = "ListStreamingSessions",
    Request: type = struct {
        created_by: ?[]const u8 = null,
        next_token: ?[]const u8 = null,
        session_ids: ?[]const u8 = null,
        studio_id: []const u8,

        pub const http_query = .{
            .created_by = "createdBy",
            .next_token = "nextToken",
            .session_ids = "sessionIds",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .created_by = "createdBy",
                .next_token = "nextToken",
                .session_ids = "sessionIds",
                .studio_id = "studioId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_streaming_sessions) } {
            return .{ .service_metadata = service_metadata, .action = list_streaming_sessions };
        }
    },
    Response: type = struct {
        next_token: ?[]const u8 = null,
        sessions: ?[]StreamingSession = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .next_token = "nextToken",
                .sessions = "sessions",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        Conflict,
        InternalServerError,
        ResourceNotFound,
        ServiceQuotaExceeded,
        Throttling,
        Validation,
    },
} = .{};
pub const list_studio_components: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/2020-08-01/studios/{studioId}/studio-components",
        .success_code = 200,
    };

    action_name: []const u8 = "ListStudioComponents",
    Request: type = struct {
        max_results: ?i64 = null,
        next_token: ?[]const u8 = null,
        states: ?[][]const u8 = null,
        studio_id: []const u8,
        types: ?[][]const u8 = null,

        pub const http_query = .{
            .max_results = "maxResults",
            .next_token = "nextToken",
            .states = "states",
            .types = "types",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .max_results = "maxResults",
                .next_token = "nextToken",
                .states = "states",
                .studio_id = "studioId",
                .types = "types",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_studio_components) } {
            return .{ .service_metadata = service_metadata, .action = list_studio_components };
        }
    },
    Response: type = struct {
        next_token: ?[]const u8 = null,
        studio_components: ?[]StudioComponent = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .next_token = "nextToken",
                .studio_components = "studioComponents",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        Conflict,
        InternalServerError,
        ResourceNotFound,
        ServiceQuotaExceeded,
        Throttling,
        Validation,
    },
} = .{};
pub const list_studio_members: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/2020-08-01/studios/{studioId}/membership",
        .success_code = 200,
    };

    action_name: []const u8 = "ListStudioMembers",
    Request: type = struct {
        max_results: ?i64 = null,
        next_token: ?[]const u8 = null,
        studio_id: []const u8,

        pub const http_query = .{
            .max_results = "maxResults",
            .next_token = "nextToken",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .max_results = "maxResults",
                .next_token = "nextToken",
                .studio_id = "studioId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_studio_members) } {
            return .{ .service_metadata = service_metadata, .action = list_studio_members };
        }
    },
    Response: type = struct {
        members: ?[]StudioMembership = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .members = "members",
                .next_token = "nextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        Conflict,
        InternalServerError,
        ResourceNotFound,
        ServiceQuotaExceeded,
        Throttling,
        Validation,
    },
} = .{};
pub const list_studios: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/2020-08-01/studios",
        .success_code = 200,
    };

    action_name: []const u8 = "ListStudios",
    Request: type = struct {
        next_token: ?[]const u8 = null,

        pub const http_query = .{
            .next_token = "nextToken",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .next_token = "nextToken",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_studios) } {
            return .{ .service_metadata = service_metadata, .action = list_studios };
        }
    },
    Response: type = struct {
        next_token: ?[]const u8 = null,
        studios: ?[]Studio = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .next_token = "nextToken",
                .studios = "studios",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        Conflict,
        InternalServerError,
        ResourceNotFound,
        ServiceQuotaExceeded,
        Throttling,
        Validation,
    },
} = .{};
pub const list_tags_for_resource: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/2020-08-01/tags/{resourceArn}",
        .success_code = 200,
    };

    action_name: []const u8 = "ListTagsForResource",
    Request: type = struct {
        resource_arn: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .resource_arn = "resourceArn",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_tags_for_resource) } {
            return .{ .service_metadata = service_metadata, .action = list_tags_for_resource };
        }
    },
    Response: type = struct {
        tags: ?[]struct {
            key: ?[]const u8 = null,
            value: ?[]const u8 = null,
        } = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .tags = "tags",
            };
            return @field(mappings, field_name);
        }

        pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
            if (std.mem.eql(u8, "tags", field_name))
                return try serializeMap(self.tags, self.fieldNameFor("tags"), options, out_stream);
            return false;
        }
    },
    ServiceError: type = error{
        AccessDenied,
        Conflict,
        InternalServerError,
        ResourceNotFound,
        ServiceQuotaExceeded,
        Throttling,
        Validation,
    },
} = .{};
pub const put_launch_profile_members: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/2020-08-01/studios/{studioId}/launch-profiles/{launchProfileId}/membership",
        .success_code = 200,
    };

    action_name: []const u8 = "PutLaunchProfileMembers",
    Request: type = struct {
        client_token: ?[]const u8 = null,
        identity_store_id: []const u8,
        launch_profile_id: []const u8,
        members: []struct {
            persona: []const u8,
            principal_id: []const u8,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .persona = "persona",
                    .principal_id = "principalId",
                };
                return @field(mappings, field_name);
            }
        },
        studio_id: []const u8,
        pub const http_header = .{
            .client_token = "X-Amz-Client-Token",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .client_token = "clientToken",
                .identity_store_id = "identityStoreId",
                .launch_profile_id = "launchProfileId",
                .members = "members",
                .studio_id = "studioId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(put_launch_profile_members) } {
            return .{ .service_metadata = service_metadata, .action = put_launch_profile_members };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        Conflict,
        InternalServerError,
        ResourceNotFound,
        ServiceQuotaExceeded,
        Throttling,
        Validation,
    },
} = .{};
pub const put_studio_members: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/2020-08-01/studios/{studioId}/membership",
        .success_code = 200,
    };

    action_name: []const u8 = "PutStudioMembers",
    Request: type = struct {
        client_token: ?[]const u8 = null,
        identity_store_id: []const u8,
        members: []struct {
            persona: []const u8,
            principal_id: []const u8,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .persona = "persona",
                    .principal_id = "principalId",
                };
                return @field(mappings, field_name);
            }
        },
        studio_id: []const u8,
        pub const http_header = .{
            .client_token = "X-Amz-Client-Token",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .client_token = "clientToken",
                .identity_store_id = "identityStoreId",
                .members = "members",
                .studio_id = "studioId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(put_studio_members) } {
            return .{ .service_metadata = service_metadata, .action = put_studio_members };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        Conflict,
        InternalServerError,
        ResourceNotFound,
        ServiceQuotaExceeded,
        Throttling,
        Validation,
    },
} = .{};
pub const start_studio_sso_configuration_repair: struct {
    pub const http_config = .{
        .method = "PUT",
        .uri = "/2020-08-01/studios/{studioId}/sso-configuration",
        .success_code = 200,
    };

    action_name: []const u8 = "StartStudioSSOConfigurationRepair",
    Request: type = struct {
        client_token: ?[]const u8 = null,
        studio_id: []const u8,
        pub const http_header = .{
            .client_token = "X-Amz-Client-Token",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .client_token = "clientToken",
                .studio_id = "studioId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(start_studio_sso_configuration_repair) } {
            return .{ .service_metadata = service_metadata, .action = start_studio_sso_configuration_repair };
        }
    },
    Response: type = struct {
        studio: ?Studio = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .studio = "studio",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        Conflict,
        InternalServerError,
        ResourceNotFound,
        ServiceQuotaExceeded,
        Throttling,
        Validation,
    },
} = .{};
pub const tag_resource: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/2020-08-01/tags/{resourceArn}",
        .success_code = 204,
    };

    action_name: []const u8 = "TagResource",
    Request: type = struct {
        resource_arn: []const u8,
        tags: ?[]struct {
            key: ?[]const u8 = null,
            value: ?[]const u8 = null,
        } = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .resource_arn = "resourceArn",
                .tags = "tags",
            };
            return @field(mappings, field_name);
        }

        pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
            if (std.mem.eql(u8, "tags", field_name))
                return try serializeMap(self.tags, self.fieldNameFor("tags"), options, out_stream);
            return false;
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(tag_resource) } {
            return .{ .service_metadata = service_metadata, .action = tag_resource };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        Conflict,
        InternalServerError,
        ResourceNotFound,
        ServiceQuotaExceeded,
        Throttling,
        Validation,
    },
} = .{};
pub const untag_resource: struct {
    pub const http_config = .{
        .method = "DELETE",
        .uri = "/2020-08-01/tags/{resourceArn}",
        .success_code = 204,
    };

    action_name: []const u8 = "UntagResource",
    Request: type = struct {
        resource_arn: []const u8,
        tag_keys: [][]const u8,

        pub const http_query = .{
            .tag_keys = "tagKeys",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .resource_arn = "resourceArn",
                .tag_keys = "tagKeys",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(untag_resource) } {
            return .{ .service_metadata = service_metadata, .action = untag_resource };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        Conflict,
        InternalServerError,
        ResourceNotFound,
        ServiceQuotaExceeded,
        Throttling,
        Validation,
    },
} = .{};
pub const update_launch_profile: struct {
    pub const http_config = .{
        .method = "PATCH",
        .uri = "/2020-08-01/studios/{studioId}/launch-profiles/{launchProfileId}",
        .success_code = 200,
    };

    action_name: []const u8 = "UpdateLaunchProfile",
    Request: type = struct {
        client_token: ?[]const u8 = null,
        description: ?[]const u8 = null,
        launch_profile_id: []const u8,
        launch_profile_protocol_versions: ?[][]const u8 = null,
        name: ?[]const u8 = null,
        stream_configuration: ?StreamConfigurationCreate = null,
        studio_component_ids: ?[][]const u8 = null,
        studio_id: []const u8,
        pub const http_header = .{
            .client_token = "X-Amz-Client-Token",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .client_token = "clientToken",
                .description = "description",
                .launch_profile_id = "launchProfileId",
                .launch_profile_protocol_versions = "launchProfileProtocolVersions",
                .name = "name",
                .stream_configuration = "streamConfiguration",
                .studio_component_ids = "studioComponentIds",
                .studio_id = "studioId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(update_launch_profile) } {
            return .{ .service_metadata = service_metadata, .action = update_launch_profile };
        }
    },
    Response: type = struct {
        launch_profile: ?LaunchProfile = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .launch_profile = "launchProfile",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        Conflict,
        InternalServerError,
        ResourceNotFound,
        ServiceQuotaExceeded,
        Throttling,
        Validation,
    },
} = .{};
pub const update_launch_profile_member: struct {
    pub const http_config = .{
        .method = "PATCH",
        .uri = "/2020-08-01/studios/{studioId}/launch-profiles/{launchProfileId}/membership/{principalId}",
        .success_code = 200,
    };

    action_name: []const u8 = "UpdateLaunchProfileMember",
    Request: type = struct {
        client_token: ?[]const u8 = null,
        launch_profile_id: []const u8,
        persona: []const u8,
        principal_id: []const u8,
        studio_id: []const u8,
        pub const http_header = .{
            .client_token = "X-Amz-Client-Token",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .client_token = "clientToken",
                .launch_profile_id = "launchProfileId",
                .persona = "persona",
                .principal_id = "principalId",
                .studio_id = "studioId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(update_launch_profile_member) } {
            return .{ .service_metadata = service_metadata, .action = update_launch_profile_member };
        }
    },
    Response: type = struct {
        member: ?LaunchProfileMembership = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .member = "member",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        Conflict,
        InternalServerError,
        ResourceNotFound,
        ServiceQuotaExceeded,
        Throttling,
        Validation,
    },
} = .{};
pub const update_streaming_image: struct {
    pub const http_config = .{
        .method = "PATCH",
        .uri = "/2020-08-01/studios/{studioId}/streaming-images/{streamingImageId}",
        .success_code = 200,
    };

    action_name: []const u8 = "UpdateStreamingImage",
    Request: type = struct {
        client_token: ?[]const u8 = null,
        description: ?[]const u8 = null,
        name: ?[]const u8 = null,
        streaming_image_id: []const u8,
        studio_id: []const u8,
        pub const http_header = .{
            .client_token = "X-Amz-Client-Token",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .client_token = "clientToken",
                .description = "description",
                .name = "name",
                .streaming_image_id = "streamingImageId",
                .studio_id = "studioId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(update_streaming_image) } {
            return .{ .service_metadata = service_metadata, .action = update_streaming_image };
        }
    },
    Response: type = struct {
        streaming_image: ?StreamingImage = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .streaming_image = "streamingImage",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        Conflict,
        InternalServerError,
        ResourceNotFound,
        ServiceQuotaExceeded,
        Throttling,
        Validation,
    },
} = .{};
pub const update_studio: struct {
    pub const http_config = .{
        .method = "PATCH",
        .uri = "/2020-08-01/studios/{studioId}",
        .success_code = 200,
    };

    action_name: []const u8 = "UpdateStudio",
    Request: type = struct {
        admin_role_arn: ?[]const u8 = null,
        client_token: ?[]const u8 = null,
        display_name: ?[]const u8 = null,
        studio_id: []const u8,
        user_role_arn: ?[]const u8 = null,
        pub const http_header = .{
            .client_token = "X-Amz-Client-Token",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .admin_role_arn = "adminRoleArn",
                .client_token = "clientToken",
                .display_name = "displayName",
                .studio_id = "studioId",
                .user_role_arn = "userRoleArn",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(update_studio) } {
            return .{ .service_metadata = service_metadata, .action = update_studio };
        }
    },
    Response: type = struct {
        studio: ?Studio = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .studio = "studio",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        Conflict,
        InternalServerError,
        ResourceNotFound,
        ServiceQuotaExceeded,
        Throttling,
        Validation,
    },
} = .{};
pub const update_studio_component: struct {
    pub const http_config = .{
        .method = "PATCH",
        .uri = "/2020-08-01/studios/{studioId}/studio-components/{studioComponentId}",
        .success_code = 200,
    };

    action_name: []const u8 = "UpdateStudioComponent",
    Request: type = struct {
        client_token: ?[]const u8 = null,
        configuration: ?StudioComponentConfiguration = null,
        description: ?[]const u8 = null,
        ec2_security_group_ids: ?[][]const u8 = null,
        initialization_scripts: ?[]StudioComponentInitializationScript = null,
        name: ?[]const u8 = null,
        script_parameters: ?[]ScriptParameterKeyValue = null,
        studio_component_id: []const u8,
        studio_id: []const u8,
        subtype: ?[]const u8 = null,
        type: ?[]const u8 = null,
        pub const http_header = .{
            .client_token = "X-Amz-Client-Token",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .client_token = "clientToken",
                .configuration = "configuration",
                .description = "description",
                .ec2_security_group_ids = "ec2SecurityGroupIds",
                .initialization_scripts = "initializationScripts",
                .name = "name",
                .script_parameters = "scriptParameters",
                .studio_component_id = "studioComponentId",
                .studio_id = "studioId",
                .subtype = "subtype",
                .type = "type",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(update_studio_component) } {
            return .{ .service_metadata = service_metadata, .action = update_studio_component };
        }
    },
    Response: type = struct {
        studio_component: ?StudioComponent = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .studio_component = "studioComponent",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        Conflict,
        InternalServerError,
        ResourceNotFound,
        ServiceQuotaExceeded,
        Throttling,
        Validation,
    },
} = .{};

pub const StudioComponent = struct {
    arn: ?[]const u8 = null,
    configuration: ?StudioComponentConfiguration = null,
    created_at: ?i64 = null,
    created_by: ?[]const u8 = null,
    description: ?[]const u8 = null,
    ec2_security_group_ids: ?[][]const u8 = null,
    initialization_scripts: ?[]StudioComponentInitializationScript = null,
    name: ?[]const u8 = null,
    script_parameters: ?[]ScriptParameterKeyValue = null,
    state: ?[]const u8 = null,
    status_code: ?[]const u8 = null,
    status_message: ?[]const u8 = null,
    studio_component_id: ?[]const u8 = null,
    subtype: ?[]const u8 = null,
    tags: ?[]struct {
        key: ?[]const u8 = null,
        value: ?[]const u8 = null,
    } = null,
    type: ?[]const u8 = null,
    updated_at: ?i64 = null,
    updated_by: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .arn = "arn",
            .configuration = "configuration",
            .created_at = "createdAt",
            .created_by = "createdBy",
            .description = "description",
            .ec2_security_group_ids = "ec2SecurityGroupIds",
            .initialization_scripts = "initializationScripts",
            .name = "name",
            .script_parameters = "scriptParameters",
            .state = "state",
            .status_code = "statusCode",
            .status_message = "statusMessage",
            .studio_component_id = "studioComponentId",
            .subtype = "subtype",
            .tags = "tags",
            .type = "type",
            .updated_at = "updatedAt",
            .updated_by = "updatedBy",
        };
        return @field(mappings, field_name);
    }

    pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
        if (std.mem.eql(u8, "tags", field_name))
            return try serializeMap(self.tags, self.fieldNameFor("tags"), options, out_stream);
        return false;
    }
};

pub const ScriptParameterKeyValue = struct {
    key: ?[]const u8 = null,
    value: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .key = "key",
            .value = "value",
        };
        return @field(mappings, field_name);
    }
};

pub const StudioComponentInitializationScript = struct {
    launch_profile_protocol_version: ?[]const u8 = null,
    platform: ?[]const u8 = null,
    run_context: ?[]const u8 = null,
    script: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .launch_profile_protocol_version = "launchProfileProtocolVersion",
            .platform = "platform",
            .run_context = "runContext",
            .script = "script",
        };
        return @field(mappings, field_name);
    }
};

pub const StudioComponentConfiguration = struct {
    active_directory_configuration: ?ActiveDirectoryConfiguration = null,
    compute_farm_configuration: ?ComputeFarmConfiguration = null,
    license_service_configuration: ?LicenseServiceConfiguration = null,
    shared_file_system_configuration: ?SharedFileSystemConfiguration = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .active_directory_configuration = "activeDirectoryConfiguration",
            .compute_farm_configuration = "computeFarmConfiguration",
            .license_service_configuration = "licenseServiceConfiguration",
            .shared_file_system_configuration = "sharedFileSystemConfiguration",
        };
        return @field(mappings, field_name);
    }
};

pub const SharedFileSystemConfiguration = struct {
    endpoint: ?[]const u8 = null,
    file_system_id: ?[]const u8 = null,
    linux_mount_point: ?[]const u8 = null,
    share_name: ?[]const u8 = null,
    windows_mount_drive: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .endpoint = "endpoint",
            .file_system_id = "fileSystemId",
            .linux_mount_point = "linuxMountPoint",
            .share_name = "shareName",
            .windows_mount_drive = "windowsMountDrive",
        };
        return @field(mappings, field_name);
    }
};

pub const LicenseServiceConfiguration = struct {
    endpoint: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .endpoint = "endpoint",
        };
        return @field(mappings, field_name);
    }
};

pub const ComputeFarmConfiguration = struct {
    active_directory_user: ?[]const u8 = null,
    endpoint: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .active_directory_user = "activeDirectoryUser",
            .endpoint = "endpoint",
        };
        return @field(mappings, field_name);
    }
};

pub const ActiveDirectoryConfiguration = struct {
    computer_attributes: ?[]ActiveDirectoryComputerAttribute = null,
    directory_id: ?[]const u8 = null,
    organizational_unit_distinguished_name: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .computer_attributes = "computerAttributes",
            .directory_id = "directoryId",
            .organizational_unit_distinguished_name = "organizationalUnitDistinguishedName",
        };
        return @field(mappings, field_name);
    }
};

pub const ActiveDirectoryComputerAttribute = struct {
    name: ?[]const u8 = null,
    value: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .name = "name",
            .value = "value",
        };
        return @field(mappings, field_name);
    }
};

pub const Studio = struct {
    admin_role_arn: ?[]const u8 = null,
    arn: ?[]const u8 = null,
    created_at: ?i64 = null,
    display_name: ?[]const u8 = null,
    home_region: ?[]const u8 = null,
    sso_client_id: ?[]const u8 = null,
    state: ?[]const u8 = null,
    status_code: ?[]const u8 = null,
    status_message: ?[]const u8 = null,
    studio_encryption_configuration: ?StudioEncryptionConfiguration = null,
    studio_id: ?[]const u8 = null,
    studio_name: ?[]const u8 = null,
    studio_url: ?[]const u8 = null,
    tags: ?[]struct {
        key: ?[]const u8 = null,
        value: ?[]const u8 = null,
    } = null,
    updated_at: ?i64 = null,
    user_role_arn: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .admin_role_arn = "adminRoleArn",
            .arn = "arn",
            .created_at = "createdAt",
            .display_name = "displayName",
            .home_region = "homeRegion",
            .sso_client_id = "ssoClientId",
            .state = "state",
            .status_code = "statusCode",
            .status_message = "statusMessage",
            .studio_encryption_configuration = "studioEncryptionConfiguration",
            .studio_id = "studioId",
            .studio_name = "studioName",
            .studio_url = "studioUrl",
            .tags = "tags",
            .updated_at = "updatedAt",
            .user_role_arn = "userRoleArn",
        };
        return @field(mappings, field_name);
    }

    pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
        if (std.mem.eql(u8, "tags", field_name))
            return try serializeMap(self.tags, self.fieldNameFor("tags"), options, out_stream);
        return false;
    }
};

pub const StudioEncryptionConfiguration = struct {
    key_arn: ?[]const u8 = null,
    key_type: []const u8,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .key_arn = "keyArn",
            .key_type = "keyType",
        };
        return @field(mappings, field_name);
    }
};

pub const StreamingImage = struct {
    arn: ?[]const u8 = null,
    description: ?[]const u8 = null,
    ec2_image_id: ?[]const u8 = null,
    encryption_configuration: ?StreamingImageEncryptionConfiguration = null,
    eula_ids: ?[][]const u8 = null,
    name: ?[]const u8 = null,
    owner: ?[]const u8 = null,
    platform: ?[]const u8 = null,
    state: ?[]const u8 = null,
    status_code: ?[]const u8 = null,
    status_message: ?[]const u8 = null,
    streaming_image_id: ?[]const u8 = null,
    tags: ?[]struct {
        key: ?[]const u8 = null,
        value: ?[]const u8 = null,
    } = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .arn = "arn",
            .description = "description",
            .ec2_image_id = "ec2ImageId",
            .encryption_configuration = "encryptionConfiguration",
            .eula_ids = "eulaIds",
            .name = "name",
            .owner = "owner",
            .platform = "platform",
            .state = "state",
            .status_code = "statusCode",
            .status_message = "statusMessage",
            .streaming_image_id = "streamingImageId",
            .tags = "tags",
        };
        return @field(mappings, field_name);
    }

    pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
        if (std.mem.eql(u8, "tags", field_name))
            return try serializeMap(self.tags, self.fieldNameFor("tags"), options, out_stream);
        return false;
    }
};

pub const StreamingImageEncryptionConfiguration = struct {
    key_arn: ?[]const u8 = null,
    key_type: []const u8,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .key_arn = "keyArn",
            .key_type = "keyType",
        };
        return @field(mappings, field_name);
    }
};

pub const LaunchProfileMembership = struct {
    identity_store_id: ?[]const u8 = null,
    persona: ?[]const u8 = null,
    principal_id: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .identity_store_id = "identityStoreId",
            .persona = "persona",
            .principal_id = "principalId",
        };
        return @field(mappings, field_name);
    }
};

pub const LaunchProfile = struct {
    arn: ?[]const u8 = null,
    created_at: ?i64 = null,
    created_by: ?[]const u8 = null,
    description: ?[]const u8 = null,
    ec2_subnet_ids: ?[][]const u8 = null,
    launch_profile_id: ?[]const u8 = null,
    launch_profile_protocol_versions: ?[][]const u8 = null,
    name: ?[]const u8 = null,
    state: ?[]const u8 = null,
    status_code: ?[]const u8 = null,
    status_message: ?[]const u8 = null,
    stream_configuration: ?StreamConfiguration = null,
    studio_component_ids: ?[][]const u8 = null,
    tags: ?[]struct {
        key: ?[]const u8 = null,
        value: ?[]const u8 = null,
    } = null,
    updated_at: ?i64 = null,
    updated_by: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .arn = "arn",
            .created_at = "createdAt",
            .created_by = "createdBy",
            .description = "description",
            .ec2_subnet_ids = "ec2SubnetIds",
            .launch_profile_id = "launchProfileId",
            .launch_profile_protocol_versions = "launchProfileProtocolVersions",
            .name = "name",
            .state = "state",
            .status_code = "statusCode",
            .status_message = "statusMessage",
            .stream_configuration = "streamConfiguration",
            .studio_component_ids = "studioComponentIds",
            .tags = "tags",
            .updated_at = "updatedAt",
            .updated_by = "updatedBy",
        };
        return @field(mappings, field_name);
    }

    pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
        if (std.mem.eql(u8, "tags", field_name))
            return try serializeMap(self.tags, self.fieldNameFor("tags"), options, out_stream);
        return false;
    }
};

pub const StreamConfiguration = struct {
    clipboard_mode: ?[]const u8 = null,
    ec2_instance_types: ?[][]const u8 = null,
    max_session_length_in_minutes: ?i64 = null,
    streaming_image_ids: ?[][]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .clipboard_mode = "clipboardMode",
            .ec2_instance_types = "ec2InstanceTypes",
            .max_session_length_in_minutes = "maxSessionLengthInMinutes",
            .streaming_image_ids = "streamingImageIds",
        };
        return @field(mappings, field_name);
    }
};

pub const StreamConfigurationCreate = struct {
    clipboard_mode: []const u8,
    ec2_instance_types: [][]const u8,
    max_session_length_in_minutes: ?i64 = null,
    streaming_image_ids: [][]const u8,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .clipboard_mode = "clipboardMode",
            .ec2_instance_types = "ec2InstanceTypes",
            .max_session_length_in_minutes = "maxSessionLengthInMinutes",
            .streaming_image_ids = "streamingImageIds",
        };
        return @field(mappings, field_name);
    }
};

pub const StudioMembership = struct {
    identity_store_id: ?[]const u8 = null,
    persona: ?[]const u8 = null,
    principal_id: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .identity_store_id = "identityStoreId",
            .persona = "persona",
            .principal_id = "principalId",
        };
        return @field(mappings, field_name);
    }
};

pub const StreamingSession = struct {
    arn: ?[]const u8 = null,
    created_at: ?i64 = null,
    created_by: ?[]const u8 = null,
    ec2_instance_type: ?[]const u8 = null,
    launch_profile_id: ?[]const u8 = null,
    session_id: ?[]const u8 = null,
    state: ?[]const u8 = null,
    status_code: ?[]const u8 = null,
    status_message: ?[]const u8 = null,
    streaming_image_id: ?[]const u8 = null,
    tags: ?[]struct {
        key: ?[]const u8 = null,
        value: ?[]const u8 = null,
    } = null,
    terminate_at: ?i64 = null,
    updated_at: ?i64 = null,
    updated_by: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .arn = "arn",
            .created_at = "createdAt",
            .created_by = "createdBy",
            .ec2_instance_type = "ec2InstanceType",
            .launch_profile_id = "launchProfileId",
            .session_id = "sessionId",
            .state = "state",
            .status_code = "statusCode",
            .status_message = "statusMessage",
            .streaming_image_id = "streamingImageId",
            .tags = "tags",
            .terminate_at = "terminateAt",
            .updated_at = "updatedAt",
            .updated_by = "updatedBy",
        };
        return @field(mappings, field_name);
    }

    pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
        if (std.mem.eql(u8, "tags", field_name))
            return try serializeMap(self.tags, self.fieldNameFor("tags"), options, out_stream);
        return false;
    }
};

pub const Eula = struct {
    content: ?[]const u8 = null,
    created_at: ?i64 = null,
    eula_id: ?[]const u8 = null,
    name: ?[]const u8 = null,
    updated_at: ?i64 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .content = "content",
            .created_at = "createdAt",
            .eula_id = "eulaId",
            .name = "name",
            .updated_at = "updatedAt",
        };
        return @field(mappings, field_name);
    }
};

pub const EulaAcceptance = struct {
    accepted_at: ?i64 = null,
    accepted_by: ?[]const u8 = null,
    acceptee_id: ?[]const u8 = null,
    eula_acceptance_id: ?[]const u8 = null,
    eula_id: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .accepted_at = "acceptedAt",
            .accepted_by = "acceptedBy",
            .acceptee_id = "accepteeId",
            .eula_acceptance_id = "eulaAcceptanceId",
            .eula_id = "eulaId",
        };
        return @field(mappings, field_name);
    }
};

pub const StreamingSessionStream = struct {
    created_at: ?i64 = null,
    created_by: ?[]const u8 = null,
    expires_at: ?i64 = null,
    state: ?[]const u8 = null,
    status_code: ?[]const u8 = null,
    stream_id: ?[]const u8 = null,
    url: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .created_at = "createdAt",
            .created_by = "createdBy",
            .expires_at = "expiresAt",
            .state = "state",
            .status_code = "statusCode",
            .stream_id = "streamId",
            .url = "url",
        };
        return @field(mappings, field_name);
    }
};

pub const LaunchProfileInitializationScript = struct {
    script: ?[]const u8 = null,
    studio_component_id: ?[]const u8 = null,
    studio_component_name: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .script = "script",
            .studio_component_id = "studioComponentId",
            .studio_component_name = "studioComponentName",
        };
        return @field(mappings, field_name);
    }
};
