const std = @import("std");
const serializeMap = @import("json.zig").serializeMap;
const smithy = @import("smithy");

const Self = @This();
pub const version: []const u8 = "2018-11-05";
pub const sdk_id: []const u8 = "Transfer";
pub const arn_namespace: []const u8 = "transfer";
pub const endpoint_prefix: []const u8 = "transfer";
pub const sigv4_name: []const u8 = "transfer";
pub const name: []const u8 = "TransferService";
pub const aws_protocol: smithy.AwsProtocol = smithy.AwsProtocol.json_1_1;

pub const service_metadata: struct {
    version: []const u8 = "2018-11-05",
    sdk_id: []const u8 = "Transfer",
    arn_namespace: []const u8 = "transfer",
    endpoint_prefix: []const u8 = "transfer",
    sigv4_name: []const u8 = "transfer",
    name: []const u8 = "TransferService",
    aws_protocol: smithy.AwsProtocol = smithy.AwsProtocol.json_1_1,
} = .{};
pub const create_access: struct {
    action_name: []const u8 = "CreateAccess",
    Request: type = struct {
        home_directory: ?[]const u8 = null,
        home_directory_type: ?[]const u8 = null,
        home_directory_mappings: ?[]HomeDirectoryMapEntry = null,
        policy: ?[]const u8 = null,
        posix_profile: ?PosixProfile = null,
        role: []const u8,
        server_id: []const u8,
        external_id: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .home_directory = "HomeDirectory",
                .home_directory_type = "HomeDirectoryType",
                .home_directory_mappings = "HomeDirectoryMappings",
                .policy = "Policy",
                .posix_profile = "PosixProfile",
                .role = "Role",
                .server_id = "ServerId",
                .external_id = "ExternalId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(create_access) } {
            return .{ .service_metadata = service_metadata, .action = create_access };
        }
    },
    Response: type = struct {
        server_id: []const u8,
        external_id: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .server_id = "ServerId",
                .external_id = "ExternalId",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalServiceError,
        InvalidRequest,
        ResourceExists,
        ResourceNotFound,
        ServiceUnavailable,
    },
} = .{};
pub const create_server: struct {
    action_name: []const u8 = "CreateServer",
    Request: type = struct {
        certificate: ?[]const u8 = null,
        domain: ?[]const u8 = null,
        endpoint_details: ?EndpointDetails = null,
        endpoint_type: ?[]const u8 = null,
        host_key: ?[]const u8 = null,
        identity_provider_details: ?IdentityProviderDetails = null,
        identity_provider_type: ?[]const u8 = null,
        logging_role: ?[]const u8 = null,
        protocols: ?[][]const u8 = null,
        security_policy_name: ?[]const u8 = null,
        tags: ?[]Tag = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .certificate = "Certificate",
                .domain = "Domain",
                .endpoint_details = "EndpointDetails",
                .endpoint_type = "EndpointType",
                .host_key = "HostKey",
                .identity_provider_details = "IdentityProviderDetails",
                .identity_provider_type = "IdentityProviderType",
                .logging_role = "LoggingRole",
                .protocols = "Protocols",
                .security_policy_name = "SecurityPolicyName",
                .tags = "Tags",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(create_server) } {
            return .{ .service_metadata = service_metadata, .action = create_server };
        }
    },
    Response: type = struct {
        server_id: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .server_id = "ServerId",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        InternalServiceError,
        InvalidRequest,
        ResourceExists,
        ServiceUnavailable,
        Throttling,
    },
} = .{};
pub const create_user: struct {
    action_name: []const u8 = "CreateUser",
    Request: type = struct {
        home_directory: ?[]const u8 = null,
        home_directory_type: ?[]const u8 = null,
        home_directory_mappings: ?[]HomeDirectoryMapEntry = null,
        policy: ?[]const u8 = null,
        posix_profile: ?PosixProfile = null,
        role: []const u8,
        server_id: []const u8,
        ssh_public_key_body: ?[]const u8 = null,
        tags: ?[]Tag = null,
        user_name: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .home_directory = "HomeDirectory",
                .home_directory_type = "HomeDirectoryType",
                .home_directory_mappings = "HomeDirectoryMappings",
                .policy = "Policy",
                .posix_profile = "PosixProfile",
                .role = "Role",
                .server_id = "ServerId",
                .ssh_public_key_body = "SshPublicKeyBody",
                .tags = "Tags",
                .user_name = "UserName",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(create_user) } {
            return .{ .service_metadata = service_metadata, .action = create_user };
        }
    },
    Response: type = struct {
        server_id: []const u8,
        user_name: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .server_id = "ServerId",
                .user_name = "UserName",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalServiceError,
        InvalidRequest,
        ResourceExists,
        ResourceNotFound,
        ServiceUnavailable,
    },
} = .{};
pub const delete_access: struct {
    action_name: []const u8 = "DeleteAccess",
    Request: type = struct {
        server_id: []const u8,
        external_id: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .server_id = "ServerId",
                .external_id = "ExternalId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(delete_access) } {
            return .{ .service_metadata = service_metadata, .action = delete_access };
        }
    },
    Response: type = struct {},
    ServiceError: type = error{
        InternalServiceError,
        InvalidRequest,
        ResourceNotFound,
        ServiceUnavailable,
    },
} = .{};
pub const delete_server: struct {
    action_name: []const u8 = "DeleteServer",
    Request: type = struct {
        server_id: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .server_id = "ServerId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(delete_server) } {
            return .{ .service_metadata = service_metadata, .action = delete_server };
        }
    },
    Response: type = struct {},
    ServiceError: type = error{
        AccessDenied,
        InternalServiceError,
        InvalidRequest,
        ResourceNotFound,
        ServiceUnavailable,
    },
} = .{};
pub const delete_ssh_public_key: struct {
    action_name: []const u8 = "DeleteSshPublicKey",
    Request: type = struct {
        server_id: []const u8,
        ssh_public_key_id: []const u8,
        user_name: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .server_id = "ServerId",
                .ssh_public_key_id = "SshPublicKeyId",
                .user_name = "UserName",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(delete_ssh_public_key) } {
            return .{ .service_metadata = service_metadata, .action = delete_ssh_public_key };
        }
    },
    Response: type = struct {},
    ServiceError: type = error{
        InternalServiceError,
        InvalidRequest,
        ResourceNotFound,
        ServiceUnavailable,
        Throttling,
    },
} = .{};
pub const delete_user: struct {
    action_name: []const u8 = "DeleteUser",
    Request: type = struct {
        server_id: []const u8,
        user_name: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .server_id = "ServerId",
                .user_name = "UserName",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(delete_user) } {
            return .{ .service_metadata = service_metadata, .action = delete_user };
        }
    },
    Response: type = struct {},
    ServiceError: type = error{
        InternalServiceError,
        InvalidRequest,
        ResourceNotFound,
        ServiceUnavailable,
    },
} = .{};
pub const describe_access: struct {
    action_name: []const u8 = "DescribeAccess",
    Request: type = struct {
        server_id: []const u8,
        external_id: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .server_id = "ServerId",
                .external_id = "ExternalId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(describe_access) } {
            return .{ .service_metadata = service_metadata, .action = describe_access };
        }
    },
    Response: type = struct {
        server_id: []const u8,
        access: struct {
            home_directory: ?[]const u8 = null,
            home_directory_mappings: ?[]HomeDirectoryMapEntry = null,
            home_directory_type: ?[]const u8 = null,
            policy: ?[]const u8 = null,
            posix_profile: ?PosixProfile = null,
            role: ?[]const u8 = null,
            external_id: ?[]const u8 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .home_directory = "HomeDirectory",
                    .home_directory_mappings = "HomeDirectoryMappings",
                    .home_directory_type = "HomeDirectoryType",
                    .policy = "Policy",
                    .posix_profile = "PosixProfile",
                    .role = "Role",
                    .external_id = "ExternalId",
                };
                return @field(mappings, field_name);
            }
        },

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .server_id = "ServerId",
                .access = "Access",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalServiceError,
        InvalidRequest,
        ResourceNotFound,
        ServiceUnavailable,
    },
} = .{};
pub const describe_security_policy: struct {
    action_name: []const u8 = "DescribeSecurityPolicy",
    Request: type = struct {
        security_policy_name: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .security_policy_name = "SecurityPolicyName",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(describe_security_policy) } {
            return .{ .service_metadata = service_metadata, .action = describe_security_policy };
        }
    },
    Response: type = struct {
        security_policy: struct {
            fips: ?bool = null,
            security_policy_name: []const u8,
            ssh_ciphers: ?[][]const u8 = null,
            ssh_kexs: ?[][]const u8 = null,
            ssh_macs: ?[][]const u8 = null,
            tls_ciphers: ?[][]const u8 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .fips = "Fips",
                    .security_policy_name = "SecurityPolicyName",
                    .ssh_ciphers = "SshCiphers",
                    .ssh_kexs = "SshKexs",
                    .ssh_macs = "SshMacs",
                    .tls_ciphers = "TlsCiphers",
                };
                return @field(mappings, field_name);
            }
        },

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .security_policy = "SecurityPolicy",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalServiceError,
        InvalidRequest,
        ResourceNotFound,
        ServiceUnavailable,
    },
} = .{};
pub const describe_server: struct {
    action_name: []const u8 = "DescribeServer",
    Request: type = struct {
        server_id: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .server_id = "ServerId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(describe_server) } {
            return .{ .service_metadata = service_metadata, .action = describe_server };
        }
    },
    Response: type = struct {
        server: struct {
            arn: []const u8,
            certificate: ?[]const u8 = null,
            domain: ?[]const u8 = null,
            endpoint_details: ?EndpointDetails = null,
            endpoint_type: ?[]const u8 = null,
            host_key_fingerprint: ?[]const u8 = null,
            identity_provider_details: ?IdentityProviderDetails = null,
            identity_provider_type: ?[]const u8 = null,
            logging_role: ?[]const u8 = null,
            protocols: ?[][]const u8 = null,
            security_policy_name: ?[]const u8 = null,
            server_id: ?[]const u8 = null,
            state: ?[]const u8 = null,
            tags: ?[]Tag = null,
            user_count: ?i64 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .arn = "Arn",
                    .certificate = "Certificate",
                    .domain = "Domain",
                    .endpoint_details = "EndpointDetails",
                    .endpoint_type = "EndpointType",
                    .host_key_fingerprint = "HostKeyFingerprint",
                    .identity_provider_details = "IdentityProviderDetails",
                    .identity_provider_type = "IdentityProviderType",
                    .logging_role = "LoggingRole",
                    .protocols = "Protocols",
                    .security_policy_name = "SecurityPolicyName",
                    .server_id = "ServerId",
                    .state = "State",
                    .tags = "Tags",
                    .user_count = "UserCount",
                };
                return @field(mappings, field_name);
            }
        },

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .server = "Server",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalServiceError,
        InvalidRequest,
        ResourceNotFound,
        ServiceUnavailable,
    },
} = .{};
pub const describe_user: struct {
    action_name: []const u8 = "DescribeUser",
    Request: type = struct {
        server_id: []const u8,
        user_name: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .server_id = "ServerId",
                .user_name = "UserName",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(describe_user) } {
            return .{ .service_metadata = service_metadata, .action = describe_user };
        }
    },
    Response: type = struct {
        server_id: []const u8,
        user: struct {
            arn: []const u8,
            home_directory: ?[]const u8 = null,
            home_directory_mappings: ?[]HomeDirectoryMapEntry = null,
            home_directory_type: ?[]const u8 = null,
            policy: ?[]const u8 = null,
            posix_profile: ?PosixProfile = null,
            role: ?[]const u8 = null,
            ssh_public_keys: ?[]struct {
                date_imported: i64,
                ssh_public_key_body: []const u8,
                ssh_public_key_id: []const u8,

                pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                    const mappings = .{
                        .date_imported = "DateImported",
                        .ssh_public_key_body = "SshPublicKeyBody",
                        .ssh_public_key_id = "SshPublicKeyId",
                    };
                    return @field(mappings, field_name);
                }
            } = null,
            tags: ?[]Tag = null,
            user_name: ?[]const u8 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .arn = "Arn",
                    .home_directory = "HomeDirectory",
                    .home_directory_mappings = "HomeDirectoryMappings",
                    .home_directory_type = "HomeDirectoryType",
                    .policy = "Policy",
                    .posix_profile = "PosixProfile",
                    .role = "Role",
                    .ssh_public_keys = "SshPublicKeys",
                    .tags = "Tags",
                    .user_name = "UserName",
                };
                return @field(mappings, field_name);
            }
        },

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .server_id = "ServerId",
                .user = "User",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalServiceError,
        InvalidRequest,
        ResourceNotFound,
        ServiceUnavailable,
    },
} = .{};
pub const import_ssh_public_key: struct {
    action_name: []const u8 = "ImportSshPublicKey",
    Request: type = struct {
        server_id: []const u8,
        ssh_public_key_body: []const u8,
        user_name: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .server_id = "ServerId",
                .ssh_public_key_body = "SshPublicKeyBody",
                .user_name = "UserName",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(import_ssh_public_key) } {
            return .{ .service_metadata = service_metadata, .action = import_ssh_public_key };
        }
    },
    Response: type = struct {
        server_id: []const u8,
        ssh_public_key_id: []const u8,
        user_name: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .server_id = "ServerId",
                .ssh_public_key_id = "SshPublicKeyId",
                .user_name = "UserName",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalServiceError,
        InvalidRequest,
        ResourceExists,
        ResourceNotFound,
        ServiceUnavailable,
        Throttling,
    },
} = .{};
pub const list_accesses: struct {
    action_name: []const u8 = "ListAccesses",
    Request: type = struct {
        max_results: ?i64 = null,
        next_token: ?[]const u8 = null,
        server_id: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .max_results = "MaxResults",
                .next_token = "NextToken",
                .server_id = "ServerId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_accesses) } {
            return .{ .service_metadata = service_metadata, .action = list_accesses };
        }
    },
    Response: type = struct {
        next_token: ?[]const u8 = null,
        server_id: []const u8,
        accesses: []struct {
            home_directory: ?[]const u8 = null,
            home_directory_type: ?[]const u8 = null,
            role: ?[]const u8 = null,
            external_id: ?[]const u8 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .home_directory = "HomeDirectory",
                    .home_directory_type = "HomeDirectoryType",
                    .role = "Role",
                    .external_id = "ExternalId",
                };
                return @field(mappings, field_name);
            }
        },

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .next_token = "NextToken",
                .server_id = "ServerId",
                .accesses = "Accesses",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalServiceError,
        InvalidNextToken,
        InvalidRequest,
        ResourceNotFound,
        ServiceUnavailable,
    },
} = .{};
pub const list_security_policies: struct {
    action_name: []const u8 = "ListSecurityPolicies",
    Request: type = struct {
        max_results: ?i64 = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .max_results = "MaxResults",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_security_policies) } {
            return .{ .service_metadata = service_metadata, .action = list_security_policies };
        }
    },
    Response: type = struct {
        next_token: ?[]const u8 = null,
        security_policy_names: [][]const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .next_token = "NextToken",
                .security_policy_names = "SecurityPolicyNames",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalServiceError,
        InvalidNextToken,
        InvalidRequest,
        ServiceUnavailable,
    },
} = .{};
pub const list_servers: struct {
    action_name: []const u8 = "ListServers",
    Request: type = struct {
        max_results: ?i64 = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .max_results = "MaxResults",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_servers) } {
            return .{ .service_metadata = service_metadata, .action = list_servers };
        }
    },
    Response: type = struct {
        next_token: ?[]const u8 = null,
        servers: []struct {
            arn: []const u8,
            domain: ?[]const u8 = null,
            identity_provider_type: ?[]const u8 = null,
            endpoint_type: ?[]const u8 = null,
            logging_role: ?[]const u8 = null,
            server_id: ?[]const u8 = null,
            state: ?[]const u8 = null,
            user_count: ?i64 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .arn = "Arn",
                    .domain = "Domain",
                    .identity_provider_type = "IdentityProviderType",
                    .endpoint_type = "EndpointType",
                    .logging_role = "LoggingRole",
                    .server_id = "ServerId",
                    .state = "State",
                    .user_count = "UserCount",
                };
                return @field(mappings, field_name);
            }
        },

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .next_token = "NextToken",
                .servers = "Servers",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalServiceError,
        InvalidNextToken,
        InvalidRequest,
        ServiceUnavailable,
    },
} = .{};
pub const list_tags_for_resource: struct {
    action_name: []const u8 = "ListTagsForResource",
    Request: type = struct {
        arn: []const u8,
        max_results: ?i64 = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .arn = "Arn",
                .max_results = "MaxResults",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_tags_for_resource) } {
            return .{ .service_metadata = service_metadata, .action = list_tags_for_resource };
        }
    },
    Response: type = struct {
        arn: ?[]const u8 = null,
        next_token: ?[]const u8 = null,
        tags: ?[]Tag = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .arn = "Arn",
                .next_token = "NextToken",
                .tags = "Tags",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalServiceError,
        InvalidNextToken,
        InvalidRequest,
        ServiceUnavailable,
    },
} = .{};
pub const list_users: struct {
    action_name: []const u8 = "ListUsers",
    Request: type = struct {
        max_results: ?i64 = null,
        next_token: ?[]const u8 = null,
        server_id: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .max_results = "MaxResults",
                .next_token = "NextToken",
                .server_id = "ServerId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_users) } {
            return .{ .service_metadata = service_metadata, .action = list_users };
        }
    },
    Response: type = struct {
        next_token: ?[]const u8 = null,
        server_id: []const u8,
        users: []struct {
            arn: []const u8,
            home_directory: ?[]const u8 = null,
            home_directory_type: ?[]const u8 = null,
            role: ?[]const u8 = null,
            ssh_public_key_count: ?i64 = null,
            user_name: ?[]const u8 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .arn = "Arn",
                    .home_directory = "HomeDirectory",
                    .home_directory_type = "HomeDirectoryType",
                    .role = "Role",
                    .ssh_public_key_count = "SshPublicKeyCount",
                    .user_name = "UserName",
                };
                return @field(mappings, field_name);
            }
        },

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .next_token = "NextToken",
                .server_id = "ServerId",
                .users = "Users",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalServiceError,
        InvalidNextToken,
        InvalidRequest,
        ResourceNotFound,
        ServiceUnavailable,
    },
} = .{};
pub const start_server: struct {
    action_name: []const u8 = "StartServer",
    Request: type = struct {
        server_id: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .server_id = "ServerId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(start_server) } {
            return .{ .service_metadata = service_metadata, .action = start_server };
        }
    },
    Response: type = struct {},
    ServiceError: type = error{
        InternalServiceError,
        InvalidRequest,
        ResourceNotFound,
        ServiceUnavailable,
        Throttling,
    },
} = .{};
pub const stop_server: struct {
    action_name: []const u8 = "StopServer",
    Request: type = struct {
        server_id: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .server_id = "ServerId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(stop_server) } {
            return .{ .service_metadata = service_metadata, .action = stop_server };
        }
    },
    Response: type = struct {},
    ServiceError: type = error{
        InternalServiceError,
        InvalidRequest,
        ResourceNotFound,
        ServiceUnavailable,
        Throttling,
    },
} = .{};
pub const tag_resource: struct {
    action_name: []const u8 = "TagResource",
    Request: type = struct {
        arn: []const u8,
        tags: []Tag,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .arn = "Arn",
                .tags = "Tags",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(tag_resource) } {
            return .{ .service_metadata = service_metadata, .action = tag_resource };
        }
    },
    Response: type = struct {},
    ServiceError: type = error{
        InternalServiceError,
        InvalidRequest,
        ResourceNotFound,
        ServiceUnavailable,
    },
} = .{};
pub const test_identity_provider: struct {
    action_name: []const u8 = "TestIdentityProvider",
    Request: type = struct {
        server_id: []const u8,
        server_protocol: ?[]const u8 = null,
        source_ip: ?[]const u8 = null,
        user_name: []const u8,
        user_password: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .server_id = "ServerId",
                .server_protocol = "ServerProtocol",
                .source_ip = "SourceIp",
                .user_name = "UserName",
                .user_password = "UserPassword",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(test_identity_provider) } {
            return .{ .service_metadata = service_metadata, .action = test_identity_provider };
        }
    },
    Response: type = struct {
        response: ?[]const u8 = null,
        status_code: i64,
        message: ?[]const u8 = null,
        url: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .response = "Response",
                .status_code = "StatusCode",
                .message = "Message",
                .url = "Url",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalServiceError,
        InvalidRequest,
        ResourceNotFound,
        ServiceUnavailable,
    },
} = .{};
pub const untag_resource: struct {
    action_name: []const u8 = "UntagResource",
    Request: type = struct {
        arn: []const u8,
        tag_keys: [][]const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .arn = "Arn",
                .tag_keys = "TagKeys",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(untag_resource) } {
            return .{ .service_metadata = service_metadata, .action = untag_resource };
        }
    },
    Response: type = struct {},
    ServiceError: type = error{
        InternalServiceError,
        InvalidRequest,
        ResourceNotFound,
        ServiceUnavailable,
    },
} = .{};
pub const update_access: struct {
    action_name: []const u8 = "UpdateAccess",
    Request: type = struct {
        home_directory: ?[]const u8 = null,
        home_directory_type: ?[]const u8 = null,
        home_directory_mappings: ?[]HomeDirectoryMapEntry = null,
        policy: ?[]const u8 = null,
        posix_profile: ?PosixProfile = null,
        role: ?[]const u8 = null,
        server_id: []const u8,
        external_id: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .home_directory = "HomeDirectory",
                .home_directory_type = "HomeDirectoryType",
                .home_directory_mappings = "HomeDirectoryMappings",
                .policy = "Policy",
                .posix_profile = "PosixProfile",
                .role = "Role",
                .server_id = "ServerId",
                .external_id = "ExternalId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(update_access) } {
            return .{ .service_metadata = service_metadata, .action = update_access };
        }
    },
    Response: type = struct {
        server_id: []const u8,
        external_id: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .server_id = "ServerId",
                .external_id = "ExternalId",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalServiceError,
        InvalidRequest,
        ResourceExists,
        ResourceNotFound,
        ServiceUnavailable,
    },
} = .{};
pub const update_server: struct {
    action_name: []const u8 = "UpdateServer",
    Request: type = struct {
        certificate: ?[]const u8 = null,
        endpoint_details: ?EndpointDetails = null,
        endpoint_type: ?[]const u8 = null,
        host_key: ?[]const u8 = null,
        identity_provider_details: ?IdentityProviderDetails = null,
        logging_role: ?[]const u8 = null,
        protocols: ?[][]const u8 = null,
        security_policy_name: ?[]const u8 = null,
        server_id: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .certificate = "Certificate",
                .endpoint_details = "EndpointDetails",
                .endpoint_type = "EndpointType",
                .host_key = "HostKey",
                .identity_provider_details = "IdentityProviderDetails",
                .logging_role = "LoggingRole",
                .protocols = "Protocols",
                .security_policy_name = "SecurityPolicyName",
                .server_id = "ServerId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(update_server) } {
            return .{ .service_metadata = service_metadata, .action = update_server };
        }
    },
    Response: type = struct {
        server_id: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .server_id = "ServerId",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        Conflict,
        InternalServiceError,
        InvalidRequest,
        ResourceExists,
        ResourceNotFound,
        ServiceUnavailable,
        Throttling,
    },
} = .{};
pub const update_user: struct {
    action_name: []const u8 = "UpdateUser",
    Request: type = struct {
        home_directory: ?[]const u8 = null,
        home_directory_type: ?[]const u8 = null,
        home_directory_mappings: ?[]HomeDirectoryMapEntry = null,
        policy: ?[]const u8 = null,
        posix_profile: ?PosixProfile = null,
        role: ?[]const u8 = null,
        server_id: []const u8,
        user_name: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .home_directory = "HomeDirectory",
                .home_directory_type = "HomeDirectoryType",
                .home_directory_mappings = "HomeDirectoryMappings",
                .policy = "Policy",
                .posix_profile = "PosixProfile",
                .role = "Role",
                .server_id = "ServerId",
                .user_name = "UserName",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(update_user) } {
            return .{ .service_metadata = service_metadata, .action = update_user };
        }
    },
    Response: type = struct {
        server_id: []const u8,
        user_name: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .server_id = "ServerId",
                .user_name = "UserName",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalServiceError,
        InvalidRequest,
        ResourceNotFound,
        ServiceUnavailable,
        Throttling,
    },
} = .{};

pub const PosixProfile = struct {
    uid: i64,
    gid: i64,
    secondary_gids: ?[]i64 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .uid = "Uid",
            .gid = "Gid",
            .secondary_gids = "SecondaryGids",
        };
        return @field(mappings, field_name);
    }
};

pub const HomeDirectoryMapEntry = struct {
    entry: []const u8,
    target: []const u8,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .entry = "Entry",
            .target = "Target",
        };
        return @field(mappings, field_name);
    }
};

pub const IdentityProviderDetails = struct {
    url: ?[]const u8 = null,
    invocation_role: ?[]const u8 = null,
    directory_id: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .url = "Url",
            .invocation_role = "InvocationRole",
            .directory_id = "DirectoryId",
        };
        return @field(mappings, field_name);
    }
};

pub const EndpointDetails = struct {
    address_allocation_ids: ?[][]const u8 = null,
    subnet_ids: ?[][]const u8 = null,
    vpc_endpoint_id: ?[]const u8 = null,
    vpc_id: ?[]const u8 = null,
    security_group_ids: ?[][]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .address_allocation_ids = "AddressAllocationIds",
            .subnet_ids = "SubnetIds",
            .vpc_endpoint_id = "VpcEndpointId",
            .vpc_id = "VpcId",
            .security_group_ids = "SecurityGroupIds",
        };
        return @field(mappings, field_name);
    }
};

pub const Tag = struct {
    key: []const u8,
    value: []const u8,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .key = "Key",
            .value = "Value",
        };
        return @field(mappings, field_name);
    }
};
