const std = @import("std");
const serializeMap = @import("json.zig").serializeMap;
const smithy = @import("smithy");

const Self = @This();
pub const version: []const u8 = "2015-04-08";
pub const sdk_id: []const u8 = "WorkSpaces";
pub const arn_namespace: []const u8 = "workspaces";
pub const endpoint_prefix: []const u8 = "workspaces";
pub const sigv4_name: []const u8 = "workspaces";
pub const name: []const u8 = "WorkspacesService";
pub const aws_protocol: smithy.AwsProtocol = smithy.AwsProtocol.json_1_1;

pub const service_metadata: struct {
    version: []const u8 = "2015-04-08",
    sdk_id: []const u8 = "WorkSpaces",
    arn_namespace: []const u8 = "workspaces",
    endpoint_prefix: []const u8 = "workspaces",
    sigv4_name: []const u8 = "workspaces",
    name: []const u8 = "WorkspacesService",
    aws_protocol: smithy.AwsProtocol = smithy.AwsProtocol.json_1_1,
} = .{};
pub const associate_connection_alias: struct {
    action_name: []const u8 = "AssociateConnectionAlias",
    Request: type = struct {
        alias_id: []const u8,
        resource_id: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .alias_id = "AliasId",
                .resource_id = "ResourceId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(associate_connection_alias) } {
            return .{ .service_metadata = service_metadata, .action = associate_connection_alias };
        }
    },
    Response: type = struct {
        connection_identifier: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .connection_identifier = "ConnectionIdentifier",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        InvalidParameterValues,
        InvalidResourceState,
        OperationNotSupported,
        ResourceAssociated,
        ResourceNotFound,
    },
} = .{};
pub const associate_ip_groups: struct {
    action_name: []const u8 = "AssociateIpGroups",
    Request: type = struct {
        directory_id: []const u8,
        group_ids: [][]const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .directory_id = "DirectoryId",
                .group_ids = "GroupIds",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(associate_ip_groups) } {
            return .{ .service_metadata = service_metadata, .action = associate_ip_groups };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        InvalidParameterValues,
        InvalidResourceState,
        OperationNotSupported,
        ResourceLimitExceeded,
        ResourceNotFound,
    },
} = .{};
pub const authorize_ip_rules: struct {
    action_name: []const u8 = "AuthorizeIpRules",
    Request: type = struct {
        group_id: []const u8,
        user_rules: []IpRuleItem,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .group_id = "GroupId",
                .user_rules = "UserRules",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(authorize_ip_rules) } {
            return .{ .service_metadata = service_metadata, .action = authorize_ip_rules };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        InvalidParameterValues,
        InvalidResourceState,
        ResourceLimitExceeded,
        ResourceNotFound,
    },
} = .{};
pub const copy_workspace_image: struct {
    action_name: []const u8 = "CopyWorkspaceImage",
    Request: type = struct {
        name: []const u8,
        description: ?[]const u8 = null,
        source_image_id: []const u8,
        source_region: []const u8,
        tags: ?[]Tag = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .name = "Name",
                .description = "Description",
                .source_image_id = "SourceImageId",
                .source_region = "SourceRegion",
                .tags = "Tags",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(copy_workspace_image) } {
            return .{ .service_metadata = service_metadata, .action = copy_workspace_image };
        }
    },
    Response: type = struct {
        image_id: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .image_id = "ImageId",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        InvalidParameterValues,
        OperationNotSupported,
        ResourceAlreadyExists,
        ResourceLimitExceeded,
        ResourceNotFound,
        ResourceUnavailable,
    },
} = .{};
pub const create_connection_alias: struct {
    action_name: []const u8 = "CreateConnectionAlias",
    Request: type = struct {
        connection_string: []const u8,
        tags: ?[]Tag = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .connection_string = "ConnectionString",
                .tags = "Tags",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(create_connection_alias) } {
            return .{ .service_metadata = service_metadata, .action = create_connection_alias };
        }
    },
    Response: type = struct {
        alias_id: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .alias_id = "AliasId",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        InvalidParameterValues,
        InvalidResourceState,
        OperationNotSupported,
        ResourceAlreadyExists,
        ResourceLimitExceeded,
    },
} = .{};
pub const create_ip_group: struct {
    action_name: []const u8 = "CreateIpGroup",
    Request: type = struct {
        group_name: []const u8,
        group_desc: ?[]const u8 = null,
        user_rules: ?[]IpRuleItem = null,
        tags: ?[]Tag = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .group_name = "GroupName",
                .group_desc = "GroupDesc",
                .user_rules = "UserRules",
                .tags = "Tags",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(create_ip_group) } {
            return .{ .service_metadata = service_metadata, .action = create_ip_group };
        }
    },
    Response: type = struct {
        group_id: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .group_id = "GroupId",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        InvalidParameterValues,
        ResourceAlreadyExists,
        ResourceCreationFailed,
        ResourceLimitExceeded,
    },
} = .{};
pub const create_tags: struct {
    action_name: []const u8 = "CreateTags",
    Request: type = struct {
        resource_id: []const u8,
        tags: []Tag,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .resource_id = "ResourceId",
                .tags = "Tags",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(create_tags) } {
            return .{ .service_metadata = service_metadata, .action = create_tags };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InvalidParameterValues,
        ResourceLimitExceeded,
        ResourceNotFound,
    },
} = .{};
pub const create_workspace_bundle: struct {
    action_name: []const u8 = "CreateWorkspaceBundle",
    Request: type = struct {
        bundle_name: []const u8,
        bundle_description: []const u8,
        image_id: []const u8,
        compute_type: ComputeType,
        user_storage: UserStorage,
        root_storage: ?RootStorage = null,
        tags: ?[]Tag = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .bundle_name = "BundleName",
                .bundle_description = "BundleDescription",
                .image_id = "ImageId",
                .compute_type = "ComputeType",
                .user_storage = "UserStorage",
                .root_storage = "RootStorage",
                .tags = "Tags",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(create_workspace_bundle) } {
            return .{ .service_metadata = service_metadata, .action = create_workspace_bundle };
        }
    },
    Response: type = struct {
        workspace_bundle: ?WorkspaceBundle = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .workspace_bundle = "WorkspaceBundle",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        InvalidParameterValues,
        ResourceAlreadyExists,
        ResourceLimitExceeded,
        ResourceNotFound,
        ResourceUnavailable,
    },
} = .{};
pub const create_workspaces: struct {
    action_name: []const u8 = "CreateWorkspaces",
    Request: type = struct {
        workspaces: []WorkspaceRequest,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .workspaces = "Workspaces",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(create_workspaces) } {
            return .{ .service_metadata = service_metadata, .action = create_workspaces };
        }
    },
    Response: type = struct {
        failed_requests: ?[]struct {
            workspace_request: ?WorkspaceRequest = null,
            error_code: ?[]const u8 = null,
            error_message: ?[]const u8 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .workspace_request = "WorkspaceRequest",
                    .error_code = "ErrorCode",
                    .error_message = "ErrorMessage",
                };
                return @field(mappings, field_name);
            }
        } = null,
        pending_requests: ?[]Workspace = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .failed_requests = "FailedRequests",
                .pending_requests = "PendingRequests",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InvalidParameterValues,
        ResourceLimitExceeded,
    },
} = .{};
pub const delete_connection_alias: struct {
    action_name: []const u8 = "DeleteConnectionAlias",
    Request: type = struct {
        alias_id: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .alias_id = "AliasId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(delete_connection_alias) } {
            return .{ .service_metadata = service_metadata, .action = delete_connection_alias };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        InvalidParameterValues,
        InvalidResourceState,
        OperationNotSupported,
        ResourceAssociated,
        ResourceNotFound,
    },
} = .{};
pub const delete_ip_group: struct {
    action_name: []const u8 = "DeleteIpGroup",
    Request: type = struct {
        group_id: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .group_id = "GroupId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(delete_ip_group) } {
            return .{ .service_metadata = service_metadata, .action = delete_ip_group };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        InvalidParameterValues,
        ResourceAssociated,
        ResourceNotFound,
    },
} = .{};
pub const delete_tags: struct {
    action_name: []const u8 = "DeleteTags",
    Request: type = struct {
        resource_id: []const u8,
        tag_keys: [][]const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .resource_id = "ResourceId",
                .tag_keys = "TagKeys",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(delete_tags) } {
            return .{ .service_metadata = service_metadata, .action = delete_tags };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InvalidParameterValues,
        ResourceNotFound,
    },
} = .{};
pub const delete_workspace_bundle: struct {
    action_name: []const u8 = "DeleteWorkspaceBundle",
    Request: type = struct {
        bundle_id: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .bundle_id = "BundleId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(delete_workspace_bundle) } {
            return .{ .service_metadata = service_metadata, .action = delete_workspace_bundle };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        InvalidParameterValues,
        ResourceAssociated,
        ResourceNotFound,
    },
} = .{};
pub const delete_workspace_image: struct {
    action_name: []const u8 = "DeleteWorkspaceImage",
    Request: type = struct {
        image_id: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .image_id = "ImageId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(delete_workspace_image) } {
            return .{ .service_metadata = service_metadata, .action = delete_workspace_image };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        InvalidResourceState,
        ResourceAssociated,
    },
} = .{};
pub const deregister_workspace_directory: struct {
    action_name: []const u8 = "DeregisterWorkspaceDirectory",
    Request: type = struct {
        directory_id: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .directory_id = "DirectoryId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(deregister_workspace_directory) } {
            return .{ .service_metadata = service_metadata, .action = deregister_workspace_directory };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        InvalidParameterValues,
        InvalidResourceState,
        OperationNotSupported,
        ResourceNotFound,
    },
} = .{};
pub const describe_account: struct {
    action_name: []const u8 = "DescribeAccount",
    Request: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(describe_account) } {
            return .{ .service_metadata = service_metadata, .action = describe_account };
        }
    },
    Response: type = struct {
        dedicated_tenancy_support: ?[]const u8 = null,
        dedicated_tenancy_management_cidr_range: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .dedicated_tenancy_support = "DedicatedTenancySupport",
                .dedicated_tenancy_management_cidr_range = "DedicatedTenancyManagementCidrRange",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
    },
} = .{};
pub const describe_account_modifications: struct {
    action_name: []const u8 = "DescribeAccountModifications",
    Request: type = struct {
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(describe_account_modifications) } {
            return .{ .service_metadata = service_metadata, .action = describe_account_modifications };
        }
    },
    Response: type = struct {
        account_modifications: ?[]struct {
            modification_state: ?[]const u8 = null,
            dedicated_tenancy_support: ?[]const u8 = null,
            dedicated_tenancy_management_cidr_range: ?[]const u8 = null,
            start_time: ?i64 = null,
            error_code: ?[]const u8 = null,
            error_message: ?[]const u8 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .modification_state = "ModificationState",
                    .dedicated_tenancy_support = "DedicatedTenancySupport",
                    .dedicated_tenancy_management_cidr_range = "DedicatedTenancyManagementCidrRange",
                    .start_time = "StartTime",
                    .error_code = "ErrorCode",
                    .error_message = "ErrorMessage",
                };
                return @field(mappings, field_name);
            }
        } = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .account_modifications = "AccountModifications",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
    },
} = .{};
pub const describe_client_properties: struct {
    action_name: []const u8 = "DescribeClientProperties",
    Request: type = struct {
        resource_ids: [][]const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .resource_ids = "ResourceIds",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(describe_client_properties) } {
            return .{ .service_metadata = service_metadata, .action = describe_client_properties };
        }
    },
    Response: type = struct {
        client_properties_list: ?[]struct {
            resource_id: ?[]const u8 = null,
            client_properties: ?ClientProperties = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .resource_id = "ResourceId",
                    .client_properties = "ClientProperties",
                };
                return @field(mappings, field_name);
            }
        } = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .client_properties_list = "ClientPropertiesList",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        InvalidParameterValues,
        ResourceNotFound,
    },
} = .{};
pub const describe_connection_aliases: struct {
    action_name: []const u8 = "DescribeConnectionAliases",
    Request: type = struct {
        alias_ids: ?[][]const u8 = null,
        resource_id: ?[]const u8 = null,
        limit: ?i64 = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .alias_ids = "AliasIds",
                .resource_id = "ResourceId",
                .limit = "Limit",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(describe_connection_aliases) } {
            return .{ .service_metadata = service_metadata, .action = describe_connection_aliases };
        }
    },
    Response: type = struct {
        connection_aliases: ?[]struct {
            connection_string: ?[]const u8 = null,
            alias_id: ?[]const u8 = null,
            state: ?[]const u8 = null,
            owner_account_id: ?[]const u8 = null,
            associations: ?[]struct {
                association_status: ?[]const u8 = null,
                associated_account_id: ?[]const u8 = null,
                resource_id: ?[]const u8 = null,
                connection_identifier: ?[]const u8 = null,

                pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                    const mappings = .{
                        .association_status = "AssociationStatus",
                        .associated_account_id = "AssociatedAccountId",
                        .resource_id = "ResourceId",
                        .connection_identifier = "ConnectionIdentifier",
                    };
                    return @field(mappings, field_name);
                }
            } = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .connection_string = "ConnectionString",
                    .alias_id = "AliasId",
                    .state = "State",
                    .owner_account_id = "OwnerAccountId",
                    .associations = "Associations",
                };
                return @field(mappings, field_name);
            }
        } = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .connection_aliases = "ConnectionAliases",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        InvalidParameterValues,
        OperationNotSupported,
    },
} = .{};
pub const describe_connection_alias_permissions: struct {
    action_name: []const u8 = "DescribeConnectionAliasPermissions",
    Request: type = struct {
        alias_id: []const u8,
        next_token: ?[]const u8 = null,
        max_results: ?i64 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .alias_id = "AliasId",
                .next_token = "NextToken",
                .max_results = "MaxResults",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(describe_connection_alias_permissions) } {
            return .{ .service_metadata = service_metadata, .action = describe_connection_alias_permissions };
        }
    },
    Response: type = struct {
        alias_id: ?[]const u8 = null,
        connection_alias_permissions: ?[]ConnectionAliasPermission = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .alias_id = "AliasId",
                .connection_alias_permissions = "ConnectionAliasPermissions",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        InvalidParameterValues,
        OperationNotSupported,
        ResourceNotFound,
    },
} = .{};
pub const describe_ip_groups: struct {
    action_name: []const u8 = "DescribeIpGroups",
    Request: type = struct {
        group_ids: ?[][]const u8 = null,
        next_token: ?[]const u8 = null,
        max_results: ?i64 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .group_ids = "GroupIds",
                .next_token = "NextToken",
                .max_results = "MaxResults",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(describe_ip_groups) } {
            return .{ .service_metadata = service_metadata, .action = describe_ip_groups };
        }
    },
    Response: type = struct {
        result: ?[]struct {
            group_id: ?[]const u8 = null,
            group_name: ?[]const u8 = null,
            group_desc: ?[]const u8 = null,
            user_rules: ?[]IpRuleItem = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .group_id = "groupId",
                    .group_name = "groupName",
                    .group_desc = "groupDesc",
                    .user_rules = "userRules",
                };
                return @field(mappings, field_name);
            }
        } = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .result = "Result",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        InvalidParameterValues,
    },
} = .{};
pub const describe_tags: struct {
    action_name: []const u8 = "DescribeTags",
    Request: type = struct {
        resource_id: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .resource_id = "ResourceId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(describe_tags) } {
            return .{ .service_metadata = service_metadata, .action = describe_tags };
        }
    },
    Response: type = struct {
        tag_list: ?[]Tag = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .tag_list = "TagList",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        ResourceNotFound,
    },
} = .{};
pub const describe_workspace_bundles: struct {
    action_name: []const u8 = "DescribeWorkspaceBundles",
    Request: type = struct {
        bundle_ids: ?[][]const u8 = null,
        owner: ?[]const u8 = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .bundle_ids = "BundleIds",
                .owner = "Owner",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(describe_workspace_bundles) } {
            return .{ .service_metadata = service_metadata, .action = describe_workspace_bundles };
        }
    },
    Response: type = struct {
        bundles: ?[]WorkspaceBundle = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .bundles = "Bundles",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InvalidParameterValues,
    },
} = .{};
pub const describe_workspace_directories: struct {
    action_name: []const u8 = "DescribeWorkspaceDirectories",
    Request: type = struct {
        directory_ids: ?[][]const u8 = null,
        limit: ?i64 = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .directory_ids = "DirectoryIds",
                .limit = "Limit",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(describe_workspace_directories) } {
            return .{ .service_metadata = service_metadata, .action = describe_workspace_directories };
        }
    },
    Response: type = struct {
        directories: ?[]struct {
            directory_id: ?[]const u8 = null,
            alias: ?[]const u8 = null,
            directory_name: ?[]const u8 = null,
            registration_code: ?[]const u8 = null,
            subnet_ids: ?[][]const u8 = null,
            dns_ip_addresses: ?[][]const u8 = null,
            customer_user_name: ?[]const u8 = null,
            iam_role_id: ?[]const u8 = null,
            directory_type: ?[]const u8 = null,
            workspace_security_group_id: ?[]const u8 = null,
            state: ?[]const u8 = null,
            workspace_creation_properties: ?struct {
                enable_work_docs: ?bool = null,
                enable_internet_access: ?bool = null,
                default_ou: ?[]const u8 = null,
                custom_security_group_id: ?[]const u8 = null,
                user_enabled_as_local_administrator: ?bool = null,
                enable_maintenance_mode: ?bool = null,

                pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                    const mappings = .{
                        .enable_work_docs = "EnableWorkDocs",
                        .enable_internet_access = "EnableInternetAccess",
                        .default_ou = "DefaultOu",
                        .custom_security_group_id = "CustomSecurityGroupId",
                        .user_enabled_as_local_administrator = "UserEnabledAsLocalAdministrator",
                        .enable_maintenance_mode = "EnableMaintenanceMode",
                    };
                    return @field(mappings, field_name);
                }
            } = null,
            ip_group_ids: ?[][]const u8 = null,
            workspace_access_properties: ?WorkspaceAccessProperties = null,
            tenancy: ?[]const u8 = null,
            selfservice_permissions: ?SelfservicePermissions = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .directory_id = "DirectoryId",
                    .alias = "Alias",
                    .directory_name = "DirectoryName",
                    .registration_code = "RegistrationCode",
                    .subnet_ids = "SubnetIds",
                    .dns_ip_addresses = "DnsIpAddresses",
                    .customer_user_name = "CustomerUserName",
                    .iam_role_id = "IamRoleId",
                    .directory_type = "DirectoryType",
                    .workspace_security_group_id = "WorkspaceSecurityGroupId",
                    .state = "State",
                    .workspace_creation_properties = "WorkspaceCreationProperties",
                    .ip_group_ids = "ipGroupIds",
                    .workspace_access_properties = "WorkspaceAccessProperties",
                    .tenancy = "Tenancy",
                    .selfservice_permissions = "SelfservicePermissions",
                };
                return @field(mappings, field_name);
            }
        } = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .directories = "Directories",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InvalidParameterValues,
    },
} = .{};
pub const describe_workspace_image_permissions: struct {
    action_name: []const u8 = "DescribeWorkspaceImagePermissions",
    Request: type = struct {
        image_id: []const u8,
        next_token: ?[]const u8 = null,
        max_results: ?i64 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .image_id = "ImageId",
                .next_token = "NextToken",
                .max_results = "MaxResults",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(describe_workspace_image_permissions) } {
            return .{ .service_metadata = service_metadata, .action = describe_workspace_image_permissions };
        }
    },
    Response: type = struct {
        image_id: ?[]const u8 = null,
        image_permissions: ?[]struct {
            shared_account_id: ?[]const u8 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .shared_account_id = "SharedAccountId",
                };
                return @field(mappings, field_name);
            }
        } = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .image_id = "ImageId",
                .image_permissions = "ImagePermissions",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        InvalidParameterValues,
        ResourceNotFound,
    },
} = .{};
pub const describe_workspace_images: struct {
    action_name: []const u8 = "DescribeWorkspaceImages",
    Request: type = struct {
        image_ids: ?[][]const u8 = null,
        image_type: ?[]const u8 = null,
        next_token: ?[]const u8 = null,
        max_results: ?i64 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .image_ids = "ImageIds",
                .image_type = "ImageType",
                .next_token = "NextToken",
                .max_results = "MaxResults",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(describe_workspace_images) } {
            return .{ .service_metadata = service_metadata, .action = describe_workspace_images };
        }
    },
    Response: type = struct {
        images: ?[]struct {
            image_id: ?[]const u8 = null,
            name: ?[]const u8 = null,
            description: ?[]const u8 = null,
            operating_system: ?struct {
                type: ?[]const u8 = null,

                pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                    const mappings = .{
                        .type = "Type",
                    };
                    return @field(mappings, field_name);
                }
            } = null,
            state: ?[]const u8 = null,
            required_tenancy: ?[]const u8 = null,
            error_code: ?[]const u8 = null,
            error_message: ?[]const u8 = null,
            created: ?i64 = null,
            owner_account_id: ?[]const u8 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .image_id = "ImageId",
                    .name = "Name",
                    .description = "Description",
                    .operating_system = "OperatingSystem",
                    .state = "State",
                    .required_tenancy = "RequiredTenancy",
                    .error_code = "ErrorCode",
                    .error_message = "ErrorMessage",
                    .created = "Created",
                    .owner_account_id = "OwnerAccountId",
                };
                return @field(mappings, field_name);
            }
        } = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .images = "Images",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
    },
} = .{};
pub const describe_workspaces: struct {
    action_name: []const u8 = "DescribeWorkspaces",
    Request: type = struct {
        workspace_ids: ?[][]const u8 = null,
        directory_id: ?[]const u8 = null,
        user_name: ?[]const u8 = null,
        bundle_id: ?[]const u8 = null,
        limit: ?i64 = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .workspace_ids = "WorkspaceIds",
                .directory_id = "DirectoryId",
                .user_name = "UserName",
                .bundle_id = "BundleId",
                .limit = "Limit",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(describe_workspaces) } {
            return .{ .service_metadata = service_metadata, .action = describe_workspaces };
        }
    },
    Response: type = struct {
        workspaces: ?[]Workspace = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .workspaces = "Workspaces",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InvalidParameterValues,
        ResourceUnavailable,
    },
} = .{};
pub const describe_workspaces_connection_status: struct {
    action_name: []const u8 = "DescribeWorkspacesConnectionStatus",
    Request: type = struct {
        workspace_ids: ?[][]const u8 = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .workspace_ids = "WorkspaceIds",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(describe_workspaces_connection_status) } {
            return .{ .service_metadata = service_metadata, .action = describe_workspaces_connection_status };
        }
    },
    Response: type = struct {
        workspaces_connection_status: ?[]struct {
            workspace_id: ?[]const u8 = null,
            connection_state: ?[]const u8 = null,
            connection_state_check_timestamp: ?i64 = null,
            last_known_user_connection_timestamp: ?i64 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .workspace_id = "WorkspaceId",
                    .connection_state = "ConnectionState",
                    .connection_state_check_timestamp = "ConnectionStateCheckTimestamp",
                    .last_known_user_connection_timestamp = "LastKnownUserConnectionTimestamp",
                };
                return @field(mappings, field_name);
            }
        } = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .workspaces_connection_status = "WorkspacesConnectionStatus",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InvalidParameterValues,
    },
} = .{};
pub const describe_workspace_snapshots: struct {
    action_name: []const u8 = "DescribeWorkspaceSnapshots",
    Request: type = struct {
        workspace_id: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .workspace_id = "WorkspaceId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(describe_workspace_snapshots) } {
            return .{ .service_metadata = service_metadata, .action = describe_workspace_snapshots };
        }
    },
    Response: type = struct {
        rebuild_snapshots: ?[]Snapshot = null,
        restore_snapshots: ?[]Snapshot = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .rebuild_snapshots = "RebuildSnapshots",
                .restore_snapshots = "RestoreSnapshots",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        InvalidParameterValues,
        ResourceNotFound,
    },
} = .{};
pub const disassociate_connection_alias: struct {
    action_name: []const u8 = "DisassociateConnectionAlias",
    Request: type = struct {
        alias_id: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .alias_id = "AliasId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(disassociate_connection_alias) } {
            return .{ .service_metadata = service_metadata, .action = disassociate_connection_alias };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        InvalidParameterValues,
        InvalidResourceState,
        OperationNotSupported,
        ResourceNotFound,
    },
} = .{};
pub const disassociate_ip_groups: struct {
    action_name: []const u8 = "DisassociateIpGroups",
    Request: type = struct {
        directory_id: []const u8,
        group_ids: [][]const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .directory_id = "DirectoryId",
                .group_ids = "GroupIds",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(disassociate_ip_groups) } {
            return .{ .service_metadata = service_metadata, .action = disassociate_ip_groups };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        InvalidParameterValues,
        InvalidResourceState,
        ResourceNotFound,
    },
} = .{};
pub const import_workspace_image: struct {
    action_name: []const u8 = "ImportWorkspaceImage",
    Request: type = struct {
        ec2_image_id: []const u8,
        ingestion_process: []const u8,
        image_name: []const u8,
        image_description: []const u8,
        tags: ?[]Tag = null,
        applications: ?[][]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .ec2_image_id = "Ec2ImageId",
                .ingestion_process = "IngestionProcess",
                .image_name = "ImageName",
                .image_description = "ImageDescription",
                .tags = "Tags",
                .applications = "Applications",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(import_workspace_image) } {
            return .{ .service_metadata = service_metadata, .action = import_workspace_image };
        }
    },
    Response: type = struct {
        image_id: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .image_id = "ImageId",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        InvalidParameterValues,
        OperationNotSupported,
        ResourceAlreadyExists,
        ResourceLimitExceeded,
        ResourceNotFound,
    },
} = .{};
pub const list_available_management_cidr_ranges: struct {
    action_name: []const u8 = "ListAvailableManagementCidrRanges",
    Request: type = struct {
        management_cidr_range_constraint: []const u8,
        max_results: ?i64 = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .management_cidr_range_constraint = "ManagementCidrRangeConstraint",
                .max_results = "MaxResults",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_available_management_cidr_ranges) } {
            return .{ .service_metadata = service_metadata, .action = list_available_management_cidr_ranges };
        }
    },
    Response: type = struct {
        management_cidr_ranges: ?[][]const u8 = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .management_cidr_ranges = "ManagementCidrRanges",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        InvalidParameterValues,
    },
} = .{};
pub const migrate_workspace: struct {
    action_name: []const u8 = "MigrateWorkspace",
    Request: type = struct {
        source_workspace_id: []const u8,
        bundle_id: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .source_workspace_id = "SourceWorkspaceId",
                .bundle_id = "BundleId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(migrate_workspace) } {
            return .{ .service_metadata = service_metadata, .action = migrate_workspace };
        }
    },
    Response: type = struct {
        source_workspace_id: ?[]const u8 = null,
        target_workspace_id: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .source_workspace_id = "SourceWorkspaceId",
                .target_workspace_id = "TargetWorkspaceId",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        InvalidParameterValues,
        OperationInProgress,
        OperationNotSupported,
        ResourceNotFound,
        ResourceUnavailable,
    },
} = .{};
pub const modify_account: struct {
    action_name: []const u8 = "ModifyAccount",
    Request: type = struct {
        dedicated_tenancy_support: ?[]const u8 = null,
        dedicated_tenancy_management_cidr_range: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .dedicated_tenancy_support = "DedicatedTenancySupport",
                .dedicated_tenancy_management_cidr_range = "DedicatedTenancyManagementCidrRange",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(modify_account) } {
            return .{ .service_metadata = service_metadata, .action = modify_account };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        InvalidParameterValues,
        InvalidResourceState,
        ResourceNotFound,
        ResourceUnavailable,
    },
} = .{};
pub const modify_client_properties: struct {
    action_name: []const u8 = "ModifyClientProperties",
    Request: type = struct {
        resource_id: []const u8,
        client_properties: ClientProperties,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .resource_id = "ResourceId",
                .client_properties = "ClientProperties",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(modify_client_properties) } {
            return .{ .service_metadata = service_metadata, .action = modify_client_properties };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        InvalidParameterValues,
        ResourceNotFound,
    },
} = .{};
pub const modify_selfservice_permissions: struct {
    action_name: []const u8 = "ModifySelfservicePermissions",
    Request: type = struct {
        resource_id: []const u8,
        selfservice_permissions: SelfservicePermissions,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .resource_id = "ResourceId",
                .selfservice_permissions = "SelfservicePermissions",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(modify_selfservice_permissions) } {
            return .{ .service_metadata = service_metadata, .action = modify_selfservice_permissions };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        InvalidParameterValues,
        ResourceNotFound,
    },
} = .{};
pub const modify_workspace_access_properties: struct {
    action_name: []const u8 = "ModifyWorkspaceAccessProperties",
    Request: type = struct {
        resource_id: []const u8,
        workspace_access_properties: WorkspaceAccessProperties,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .resource_id = "ResourceId",
                .workspace_access_properties = "WorkspaceAccessProperties",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(modify_workspace_access_properties) } {
            return .{ .service_metadata = service_metadata, .action = modify_workspace_access_properties };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        ResourceNotFound,
    },
} = .{};
pub const modify_workspace_creation_properties: struct {
    action_name: []const u8 = "ModifyWorkspaceCreationProperties",
    Request: type = struct {
        resource_id: []const u8,
        workspace_creation_properties: struct {
            enable_work_docs: ?bool = null,
            enable_internet_access: ?bool = null,
            default_ou: ?[]const u8 = null,
            custom_security_group_id: ?[]const u8 = null,
            user_enabled_as_local_administrator: ?bool = null,
            enable_maintenance_mode: ?bool = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .enable_work_docs = "EnableWorkDocs",
                    .enable_internet_access = "EnableInternetAccess",
                    .default_ou = "DefaultOu",
                    .custom_security_group_id = "CustomSecurityGroupId",
                    .user_enabled_as_local_administrator = "UserEnabledAsLocalAdministrator",
                    .enable_maintenance_mode = "EnableMaintenanceMode",
                };
                return @field(mappings, field_name);
            }
        },

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .resource_id = "ResourceId",
                .workspace_creation_properties = "WorkspaceCreationProperties",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(modify_workspace_creation_properties) } {
            return .{ .service_metadata = service_metadata, .action = modify_workspace_creation_properties };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        InvalidParameterValues,
        OperationNotSupported,
        ResourceNotFound,
    },
} = .{};
pub const modify_workspace_properties: struct {
    action_name: []const u8 = "ModifyWorkspaceProperties",
    Request: type = struct {
        workspace_id: []const u8,
        workspace_properties: WorkspaceProperties,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .workspace_id = "WorkspaceId",
                .workspace_properties = "WorkspaceProperties",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(modify_workspace_properties) } {
            return .{ .service_metadata = service_metadata, .action = modify_workspace_properties };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        InvalidParameterValues,
        InvalidResourceState,
        OperationInProgress,
        ResourceNotFound,
        ResourceUnavailable,
        UnsupportedWorkspaceConfiguration,
    },
} = .{};
pub const modify_workspace_state: struct {
    action_name: []const u8 = "ModifyWorkspaceState",
    Request: type = struct {
        workspace_id: []const u8,
        workspace_state: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .workspace_id = "WorkspaceId",
                .workspace_state = "WorkspaceState",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(modify_workspace_state) } {
            return .{ .service_metadata = service_metadata, .action = modify_workspace_state };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InvalidParameterValues,
        InvalidResourceState,
        ResourceNotFound,
    },
} = .{};
pub const reboot_workspaces: struct {
    action_name: []const u8 = "RebootWorkspaces",
    Request: type = struct {
        reboot_workspace_requests: []struct {
            workspace_id: []const u8,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .workspace_id = "WorkspaceId",
                };
                return @field(mappings, field_name);
            }
        },

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .reboot_workspace_requests = "RebootWorkspaceRequests",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(reboot_workspaces) } {
            return .{ .service_metadata = service_metadata, .action = reboot_workspaces };
        }
    },
    Response: type = struct {
        failed_requests: ?[]FailedWorkspaceChangeRequest = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .failed_requests = "FailedRequests",
            };
            return @field(mappings, field_name);
        }
    },
} = .{};
pub const rebuild_workspaces: struct {
    action_name: []const u8 = "RebuildWorkspaces",
    Request: type = struct {
        rebuild_workspace_requests: []struct {
            workspace_id: []const u8,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .workspace_id = "WorkspaceId",
                };
                return @field(mappings, field_name);
            }
        },

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .rebuild_workspace_requests = "RebuildWorkspaceRequests",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(rebuild_workspaces) } {
            return .{ .service_metadata = service_metadata, .action = rebuild_workspaces };
        }
    },
    Response: type = struct {
        failed_requests: ?[]FailedWorkspaceChangeRequest = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .failed_requests = "FailedRequests",
            };
            return @field(mappings, field_name);
        }
    },
} = .{};
pub const register_workspace_directory: struct {
    action_name: []const u8 = "RegisterWorkspaceDirectory",
    Request: type = struct {
        directory_id: []const u8,
        subnet_ids: ?[][]const u8 = null,
        enable_work_docs: bool,
        enable_self_service: ?bool = null,
        tenancy: ?[]const u8 = null,
        tags: ?[]Tag = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .directory_id = "DirectoryId",
                .subnet_ids = "SubnetIds",
                .enable_work_docs = "EnableWorkDocs",
                .enable_self_service = "EnableSelfService",
                .tenancy = "Tenancy",
                .tags = "Tags",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(register_workspace_directory) } {
            return .{ .service_metadata = service_metadata, .action = register_workspace_directory };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        InvalidParameterValues,
        InvalidResourceState,
        OperationNotSupported,
        ResourceLimitExceeded,
        ResourceNotFound,
        UnsupportedNetworkConfiguration,
        WorkspacesDefaultRoleNotFound,
    },
} = .{};
pub const restore_workspace: struct {
    action_name: []const u8 = "RestoreWorkspace",
    Request: type = struct {
        workspace_id: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .workspace_id = "WorkspaceId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(restore_workspace) } {
            return .{ .service_metadata = service_metadata, .action = restore_workspace };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        InvalidParameterValues,
        ResourceNotFound,
    },
} = .{};
pub const revoke_ip_rules: struct {
    action_name: []const u8 = "RevokeIpRules",
    Request: type = struct {
        group_id: []const u8,
        user_rules: [][]const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .group_id = "GroupId",
                .user_rules = "UserRules",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(revoke_ip_rules) } {
            return .{ .service_metadata = service_metadata, .action = revoke_ip_rules };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        InvalidParameterValues,
        InvalidResourceState,
        ResourceNotFound,
    },
} = .{};
pub const start_workspaces: struct {
    action_name: []const u8 = "StartWorkspaces",
    Request: type = struct {
        start_workspace_requests: []struct {
            workspace_id: ?[]const u8 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .workspace_id = "WorkspaceId",
                };
                return @field(mappings, field_name);
            }
        },

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .start_workspace_requests = "StartWorkspaceRequests",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(start_workspaces) } {
            return .{ .service_metadata = service_metadata, .action = start_workspaces };
        }
    },
    Response: type = struct {
        failed_requests: ?[]FailedWorkspaceChangeRequest = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .failed_requests = "FailedRequests",
            };
            return @field(mappings, field_name);
        }
    },
} = .{};
pub const stop_workspaces: struct {
    action_name: []const u8 = "StopWorkspaces",
    Request: type = struct {
        stop_workspace_requests: []struct {
            workspace_id: ?[]const u8 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .workspace_id = "WorkspaceId",
                };
                return @field(mappings, field_name);
            }
        },

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .stop_workspace_requests = "StopWorkspaceRequests",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(stop_workspaces) } {
            return .{ .service_metadata = service_metadata, .action = stop_workspaces };
        }
    },
    Response: type = struct {
        failed_requests: ?[]FailedWorkspaceChangeRequest = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .failed_requests = "FailedRequests",
            };
            return @field(mappings, field_name);
        }
    },
} = .{};
pub const terminate_workspaces: struct {
    action_name: []const u8 = "TerminateWorkspaces",
    Request: type = struct {
        terminate_workspace_requests: []struct {
            workspace_id: []const u8,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .workspace_id = "WorkspaceId",
                };
                return @field(mappings, field_name);
            }
        },

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .terminate_workspace_requests = "TerminateWorkspaceRequests",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(terminate_workspaces) } {
            return .{ .service_metadata = service_metadata, .action = terminate_workspaces };
        }
    },
    Response: type = struct {
        failed_requests: ?[]FailedWorkspaceChangeRequest = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .failed_requests = "FailedRequests",
            };
            return @field(mappings, field_name);
        }
    },
} = .{};
pub const update_connection_alias_permission: struct {
    action_name: []const u8 = "UpdateConnectionAliasPermission",
    Request: type = struct {
        alias_id: []const u8,
        connection_alias_permission: ConnectionAliasPermission,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .alias_id = "AliasId",
                .connection_alias_permission = "ConnectionAliasPermission",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(update_connection_alias_permission) } {
            return .{ .service_metadata = service_metadata, .action = update_connection_alias_permission };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        InvalidParameterValues,
        InvalidResourceState,
        OperationNotSupported,
        ResourceAssociated,
        ResourceLimitExceeded,
        ResourceNotFound,
    },
} = .{};
pub const update_rules_of_ip_group: struct {
    action_name: []const u8 = "UpdateRulesOfIpGroup",
    Request: type = struct {
        group_id: []const u8,
        user_rules: []IpRuleItem,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .group_id = "GroupId",
                .user_rules = "UserRules",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(update_rules_of_ip_group) } {
            return .{ .service_metadata = service_metadata, .action = update_rules_of_ip_group };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        InvalidParameterValues,
        InvalidResourceState,
        ResourceLimitExceeded,
        ResourceNotFound,
    },
} = .{};
pub const update_workspace_bundle: struct {
    action_name: []const u8 = "UpdateWorkspaceBundle",
    Request: type = struct {
        bundle_id: ?[]const u8 = null,
        image_id: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .bundle_id = "BundleId",
                .image_id = "ImageId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(update_workspace_bundle) } {
            return .{ .service_metadata = service_metadata, .action = update_workspace_bundle };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        InvalidParameterValues,
        ResourceNotFound,
        ResourceUnavailable,
    },
} = .{};
pub const update_workspace_image_permission: struct {
    action_name: []const u8 = "UpdateWorkspaceImagePermission",
    Request: type = struct {
        image_id: []const u8,
        allow_copy_image: bool,
        shared_account_id: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .image_id = "ImageId",
                .allow_copy_image = "AllowCopyImage",
                .shared_account_id = "SharedAccountId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(update_workspace_image_permission) } {
            return .{ .service_metadata = service_metadata, .action = update_workspace_image_permission };
        }
    },
    Response: type = struct {

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{};
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        InvalidParameterValues,
        OperationNotSupported,
        ResourceNotFound,
        ResourceUnavailable,
    },
} = .{};

pub const IpRuleItem = struct {
    ip_rule: ?[]const u8 = null,
    rule_desc: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .ip_rule = "ipRule",
            .rule_desc = "ruleDesc",
        };
        return @field(mappings, field_name);
    }
};

pub const ConnectionAliasPermission = struct {
    shared_account_id: []const u8,
    allow_association: bool,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .shared_account_id = "SharedAccountId",
            .allow_association = "AllowAssociation",
        };
        return @field(mappings, field_name);
    }
};

pub const FailedWorkspaceChangeRequest = struct {
    workspace_id: ?[]const u8 = null,
    error_code: ?[]const u8 = null,
    error_message: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .workspace_id = "WorkspaceId",
            .error_code = "ErrorCode",
            .error_message = "ErrorMessage",
        };
        return @field(mappings, field_name);
    }
};

pub const Tag = struct {
    key: []const u8,
    value: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .key = "Key",
            .value = "Value",
        };
        return @field(mappings, field_name);
    }
};

pub const WorkspaceProperties = struct {
    running_mode: ?[]const u8 = null,
    running_mode_auto_stop_timeout_in_minutes: ?i64 = null,
    root_volume_size_gib: ?i64 = null,
    user_volume_size_gib: ?i64 = null,
    compute_type_name: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .running_mode = "RunningMode",
            .running_mode_auto_stop_timeout_in_minutes = "RunningModeAutoStopTimeoutInMinutes",
            .root_volume_size_gib = "RootVolumeSizeGib",
            .user_volume_size_gib = "UserVolumeSizeGib",
            .compute_type_name = "ComputeTypeName",
        };
        return @field(mappings, field_name);
    }
};

pub const WorkspaceAccessProperties = struct {
    device_type_windows: ?[]const u8 = null,
    device_type_osx: ?[]const u8 = null,
    device_type_web: ?[]const u8 = null,
    device_type_ios: ?[]const u8 = null,
    device_type_android: ?[]const u8 = null,
    device_type_chrome_os: ?[]const u8 = null,
    device_type_zero_client: ?[]const u8 = null,
    device_type_linux: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .device_type_windows = "DeviceTypeWindows",
            .device_type_osx = "DeviceTypeOsx",
            .device_type_web = "DeviceTypeWeb",
            .device_type_ios = "DeviceTypeIos",
            .device_type_android = "DeviceTypeAndroid",
            .device_type_chrome_os = "DeviceTypeChromeOs",
            .device_type_zero_client = "DeviceTypeZeroClient",
            .device_type_linux = "DeviceTypeLinux",
        };
        return @field(mappings, field_name);
    }
};

pub const SelfservicePermissions = struct {
    restart_workspace: ?[]const u8 = null,
    increase_volume_size: ?[]const u8 = null,
    change_compute_type: ?[]const u8 = null,
    switch_running_mode: ?[]const u8 = null,
    rebuild_workspace: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .restart_workspace = "RestartWorkspace",
            .increase_volume_size = "IncreaseVolumeSize",
            .change_compute_type = "ChangeComputeType",
            .switch_running_mode = "SwitchRunningMode",
            .rebuild_workspace = "RebuildWorkspace",
        };
        return @field(mappings, field_name);
    }
};

pub const ClientProperties = struct {
    reconnect_enabled: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .reconnect_enabled = "ReconnectEnabled",
        };
        return @field(mappings, field_name);
    }
};

pub const Snapshot = struct {
    snapshot_time: ?i64 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .snapshot_time = "SnapshotTime",
        };
        return @field(mappings, field_name);
    }
};

pub const Workspace = struct {
    workspace_id: ?[]const u8 = null,
    directory_id: ?[]const u8 = null,
    user_name: ?[]const u8 = null,
    ip_address: ?[]const u8 = null,
    state: ?[]const u8 = null,
    bundle_id: ?[]const u8 = null,
    subnet_id: ?[]const u8 = null,
    error_message: ?[]const u8 = null,
    error_code: ?[]const u8 = null,
    computer_name: ?[]const u8 = null,
    volume_encryption_key: ?[]const u8 = null,
    user_volume_encryption_enabled: ?bool = null,
    root_volume_encryption_enabled: ?bool = null,
    workspace_properties: ?WorkspaceProperties = null,
    modification_states: ?[]ModificationState = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .workspace_id = "WorkspaceId",
            .directory_id = "DirectoryId",
            .user_name = "UserName",
            .ip_address = "IpAddress",
            .state = "State",
            .bundle_id = "BundleId",
            .subnet_id = "SubnetId",
            .error_message = "ErrorMessage",
            .error_code = "ErrorCode",
            .computer_name = "ComputerName",
            .volume_encryption_key = "VolumeEncryptionKey",
            .user_volume_encryption_enabled = "UserVolumeEncryptionEnabled",
            .root_volume_encryption_enabled = "RootVolumeEncryptionEnabled",
            .workspace_properties = "WorkspaceProperties",
            .modification_states = "ModificationStates",
        };
        return @field(mappings, field_name);
    }
};

pub const ModificationState = struct {
    resource: ?[]const u8 = null,
    state: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .resource = "Resource",
            .state = "State",
        };
        return @field(mappings, field_name);
    }
};

pub const WorkspaceBundle = struct {
    bundle_id: ?[]const u8 = null,
    name: ?[]const u8 = null,
    owner: ?[]const u8 = null,
    description: ?[]const u8 = null,
    image_id: ?[]const u8 = null,
    root_storage: ?RootStorage = null,
    user_storage: ?UserStorage = null,
    compute_type: ?ComputeType = null,
    last_updated_time: ?i64 = null,
    creation_time: ?i64 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .bundle_id = "BundleId",
            .name = "Name",
            .owner = "Owner",
            .description = "Description",
            .image_id = "ImageId",
            .root_storage = "RootStorage",
            .user_storage = "UserStorage",
            .compute_type = "ComputeType",
            .last_updated_time = "LastUpdatedTime",
            .creation_time = "CreationTime",
        };
        return @field(mappings, field_name);
    }
};

pub const ComputeType = struct {
    name: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .name = "Name",
        };
        return @field(mappings, field_name);
    }
};

pub const UserStorage = struct {
    capacity: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .capacity = "Capacity",
        };
        return @field(mappings, field_name);
    }
};

pub const RootStorage = struct {
    capacity: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .capacity = "Capacity",
        };
        return @field(mappings, field_name);
    }
};

pub const WorkspaceRequest = struct {
    directory_id: []const u8,
    user_name: []const u8,
    bundle_id: []const u8,
    volume_encryption_key: ?[]const u8 = null,
    user_volume_encryption_enabled: ?bool = null,
    root_volume_encryption_enabled: ?bool = null,
    workspace_properties: ?WorkspaceProperties = null,
    tags: ?[]Tag = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .directory_id = "DirectoryId",
            .user_name = "UserName",
            .bundle_id = "BundleId",
            .volume_encryption_key = "VolumeEncryptionKey",
            .user_volume_encryption_enabled = "UserVolumeEncryptionEnabled",
            .root_volume_encryption_enabled = "RootVolumeEncryptionEnabled",
            .workspace_properties = "WorkspaceProperties",
            .tags = "Tags",
        };
        return @field(mappings, field_name);
    }
};
