const std = @import("std");
const serializeMap = @import("json.zig").serializeMap;
const smithy = @import("smithy");

const Self = @This();
pub const version: []const u8 = "2018-04-01";
pub const sdk_id: []const u8 = "QuickSight";
pub const arn_namespace: []const u8 = "quicksight";
pub const endpoint_prefix: []const u8 = "quicksight";
pub const sigv4_name: []const u8 = "quicksight";
pub const name: []const u8 = "QuickSight_20180401";
pub const aws_protocol: smithy.AwsProtocol = smithy.AwsProtocol.rest_json_1;

pub const service_metadata: struct {
    version: []const u8 = "2018-04-01",
    sdk_id: []const u8 = "QuickSight",
    arn_namespace: []const u8 = "quicksight",
    endpoint_prefix: []const u8 = "quicksight",
    sigv4_name: []const u8 = "quicksight",
    name: []const u8 = "QuickSight_20180401",
    aws_protocol: smithy.AwsProtocol = smithy.AwsProtocol.rest_json_1,
} = .{};
pub const cancel_ingestion: struct {
    pub const http_config = .{
        .method = "DELETE",
        .uri = "/accounts/{AwsAccountId}/data-sets/{DataSetId}/ingestions/{IngestionId}",
        .success_code = 200,
    };

    action_name: []const u8 = "CancelIngestion",
    Request: type = struct {
        aws_account_id: []const u8,
        data_set_id: []const u8,
        ingestion_id: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .aws_account_id = "AwsAccountId",
                .data_set_id = "DataSetId",
                .ingestion_id = "IngestionId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(cancel_ingestion) } {
            return .{ .service_metadata = service_metadata, .action = cancel_ingestion };
        }
    },
    Response: type = struct {
        arn: ?[]const u8 = null,
        ingestion_id: ?[]const u8 = null,
        request_id: ?[]const u8 = null,
        status: ?i64 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .arn = "Arn",
                .ingestion_id = "IngestionId",
                .request_id = "RequestId",
                .status = "Status",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        InternalFailure,
        InvalidParameterValue,
        ResourceExists,
        ResourceNotFound,
        Throttling,
    },
} = .{};
pub const create_account_customization: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/accounts/{AwsAccountId}/customizations",
        .success_code = 200,
    };

    action_name: []const u8 = "CreateAccountCustomization",
    Request: type = struct {
        aws_account_id: []const u8,
        namespace: ?[]const u8 = null,
        account_customization: AccountCustomization,
        tags: ?[]Tag = null,

        pub const http_query = .{
            .namespace = "namespace",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .aws_account_id = "AwsAccountId",
                .namespace = "Namespace",
                .account_customization = "AccountCustomization",
                .tags = "Tags",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(create_account_customization) } {
            return .{ .service_metadata = service_metadata, .action = create_account_customization };
        }
    },
    Response: type = struct {
        arn: ?[]const u8 = null,
        aws_account_id: ?[]const u8 = null,
        namespace: ?[]const u8 = null,
        account_customization: ?AccountCustomization = null,
        request_id: ?[]const u8 = null,
        status: ?i64 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .arn = "Arn",
                .aws_account_id = "AwsAccountId",
                .namespace = "Namespace",
                .account_customization = "AccountCustomization",
                .request_id = "RequestId",
                .status = "Status",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        InternalFailure,
        InvalidParameterValue,
        ResourceExists,
        ResourceNotFound,
        ResourceUnavailable,
        Throttling,
    },
} = .{};
pub const create_analysis: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/accounts/{AwsAccountId}/analyses/{AnalysisId}",
        .success_code = 200,
    };

    action_name: []const u8 = "CreateAnalysis",
    Request: type = struct {
        aws_account_id: []const u8,
        analysis_id: []const u8,
        name: []const u8,
        parameters: ?Parameters = null,
        permissions: ?[]ResourcePermission = null,
        source_entity: AnalysisSourceEntity,
        theme_arn: ?[]const u8 = null,
        tags: ?[]Tag = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .aws_account_id = "AwsAccountId",
                .analysis_id = "AnalysisId",
                .name = "Name",
                .parameters = "Parameters",
                .permissions = "Permissions",
                .source_entity = "SourceEntity",
                .theme_arn = "ThemeArn",
                .tags = "Tags",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(create_analysis) } {
            return .{ .service_metadata = service_metadata, .action = create_analysis };
        }
    },
    Response: type = struct {
        arn: ?[]const u8 = null,
        analysis_id: ?[]const u8 = null,
        creation_status: ?[]const u8 = null,
        status: ?i64 = null,
        request_id: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .arn = "Arn",
                .analysis_id = "AnalysisId",
                .creation_status = "CreationStatus",
                .status = "Status",
                .request_id = "RequestId",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        Conflict,
        InternalFailure,
        InvalidParameterValue,
        ResourceExists,
        ResourceNotFound,
        Throttling,
        UnsupportedUserEdition,
    },
} = .{};
pub const create_dashboard: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/accounts/{AwsAccountId}/dashboards/{DashboardId}",
        .success_code = 200,
    };

    action_name: []const u8 = "CreateDashboard",
    Request: type = struct {
        aws_account_id: []const u8,
        dashboard_id: []const u8,
        name: []const u8,
        parameters: ?Parameters = null,
        permissions: ?[]ResourcePermission = null,
        source_entity: DashboardSourceEntity,
        tags: ?[]Tag = null,
        version_description: ?[]const u8 = null,
        dashboard_publish_options: ?DashboardPublishOptions = null,
        theme_arn: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .aws_account_id = "AwsAccountId",
                .dashboard_id = "DashboardId",
                .name = "Name",
                .parameters = "Parameters",
                .permissions = "Permissions",
                .source_entity = "SourceEntity",
                .tags = "Tags",
                .version_description = "VersionDescription",
                .dashboard_publish_options = "DashboardPublishOptions",
                .theme_arn = "ThemeArn",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(create_dashboard) } {
            return .{ .service_metadata = service_metadata, .action = create_dashboard };
        }
    },
    Response: type = struct {
        arn: ?[]const u8 = null,
        version_arn: ?[]const u8 = null,
        dashboard_id: ?[]const u8 = null,
        creation_status: ?[]const u8 = null,
        status: ?i64 = null,
        request_id: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .arn = "Arn",
                .version_arn = "VersionArn",
                .dashboard_id = "DashboardId",
                .creation_status = "CreationStatus",
                .status = "Status",
                .request_id = "RequestId",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        Conflict,
        InternalFailure,
        InvalidParameterValue,
        ResourceExists,
        ResourceNotFound,
        Throttling,
        UnsupportedUserEdition,
    },
} = .{};
pub const create_data_set: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/accounts/{AwsAccountId}/data-sets",
        .success_code = 200,
    };

    action_name: []const u8 = "CreateDataSet",
    Request: type = struct {
        aws_account_id: []const u8,
        data_set_id: []const u8,
        name: []const u8,
        physical_table_map: []struct {
            key: ?[]const u8 = null,
            value: ?PhysicalTable = null,
        },
        logical_table_map: ?[]struct {
            key: ?[]const u8 = null,
            value: ?LogicalTable = null,
        } = null,
        import_mode: []const u8,
        column_groups: ?[]ColumnGroup = null,
        field_folders: ?[]struct {
            key: ?[]const u8 = null,
            value: ?FieldFolder = null,
        } = null,
        permissions: ?[]ResourcePermission = null,
        row_level_permission_data_set: ?RowLevelPermissionDataSet = null,
        column_level_permission_rules: ?[]ColumnLevelPermissionRule = null,
        tags: ?[]Tag = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .aws_account_id = "AwsAccountId",
                .data_set_id = "DataSetId",
                .name = "Name",
                .physical_table_map = "PhysicalTableMap",
                .logical_table_map = "LogicalTableMap",
                .import_mode = "ImportMode",
                .column_groups = "ColumnGroups",
                .field_folders = "FieldFolders",
                .permissions = "Permissions",
                .row_level_permission_data_set = "RowLevelPermissionDataSet",
                .column_level_permission_rules = "ColumnLevelPermissionRules",
                .tags = "Tags",
            };
            return @field(mappings, field_name);
        }

        pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
            if (std.mem.eql(u8, "physical_table_map", field_name))
                return try serializeMap(self.physical_table_map, self.fieldNameFor("physical_table_map"), options, out_stream);
            if (std.mem.eql(u8, "logical_table_map", field_name))
                return try serializeMap(self.logical_table_map, self.fieldNameFor("logical_table_map"), options, out_stream);
            if (std.mem.eql(u8, "field_folders", field_name))
                return try serializeMap(self.field_folders, self.fieldNameFor("field_folders"), options, out_stream);
            return false;
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(create_data_set) } {
            return .{ .service_metadata = service_metadata, .action = create_data_set };
        }
    },
    Response: type = struct {
        arn: ?[]const u8 = null,
        data_set_id: ?[]const u8 = null,
        ingestion_arn: ?[]const u8 = null,
        ingestion_id: ?[]const u8 = null,
        request_id: ?[]const u8 = null,
        status: ?i64 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .arn = "Arn",
                .data_set_id = "DataSetId",
                .ingestion_arn = "IngestionArn",
                .ingestion_id = "IngestionId",
                .request_id = "RequestId",
                .status = "Status",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        Conflict,
        InternalFailure,
        InvalidParameterValue,
        LimitExceeded,
        ResourceExists,
        ResourceNotFound,
        Throttling,
        UnsupportedUserEdition,
    },
} = .{};
pub const create_data_source: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/accounts/{AwsAccountId}/data-sources",
        .success_code = 200,
    };

    action_name: []const u8 = "CreateDataSource",
    Request: type = struct {
        aws_account_id: []const u8,
        data_source_id: []const u8,
        name: []const u8,
        type: []const u8,
        data_source_parameters: ?DataSourceParameters = null,
        credentials: ?DataSourceCredentials = null,
        permissions: ?[]ResourcePermission = null,
        vpc_connection_properties: ?VpcConnectionProperties = null,
        ssl_properties: ?SslProperties = null,
        tags: ?[]Tag = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .aws_account_id = "AwsAccountId",
                .data_source_id = "DataSourceId",
                .name = "Name",
                .type = "Type",
                .data_source_parameters = "DataSourceParameters",
                .credentials = "Credentials",
                .permissions = "Permissions",
                .vpc_connection_properties = "VpcConnectionProperties",
                .ssl_properties = "SslProperties",
                .tags = "Tags",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(create_data_source) } {
            return .{ .service_metadata = service_metadata, .action = create_data_source };
        }
    },
    Response: type = struct {
        arn: ?[]const u8 = null,
        data_source_id: ?[]const u8 = null,
        creation_status: ?[]const u8 = null,
        request_id: ?[]const u8 = null,
        status: ?i64 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .arn = "Arn",
                .data_source_id = "DataSourceId",
                .creation_status = "CreationStatus",
                .request_id = "RequestId",
                .status = "Status",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        Conflict,
        InternalFailure,
        InvalidParameterValue,
        LimitExceeded,
        ResourceExists,
        ResourceNotFound,
        Throttling,
    },
} = .{};
pub const create_group: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/accounts/{AwsAccountId}/namespaces/{Namespace}/groups",
        .success_code = 200,
    };

    action_name: []const u8 = "CreateGroup",
    Request: type = struct {
        group_name: []const u8,
        description: ?[]const u8 = null,
        aws_account_id: []const u8,
        namespace: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .group_name = "GroupName",
                .description = "Description",
                .aws_account_id = "AwsAccountId",
                .namespace = "Namespace",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(create_group) } {
            return .{ .service_metadata = service_metadata, .action = create_group };
        }
    },
    Response: type = struct {
        group: ?Group = null,
        request_id: ?[]const u8 = null,
        status: ?i64 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .group = "Group",
                .request_id = "RequestId",
                .status = "Status",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        InternalFailure,
        InvalidParameterValue,
        LimitExceeded,
        PreconditionNotMet,
        ResourceExists,
        ResourceNotFound,
        ResourceUnavailable,
        Throttling,
    },
} = .{};
pub const create_group_membership: struct {
    pub const http_config = .{
        .method = "PUT",
        .uri = "/accounts/{AwsAccountId}/namespaces/{Namespace}/groups/{GroupName}/members/{MemberName}",
        .success_code = 200,
    };

    action_name: []const u8 = "CreateGroupMembership",
    Request: type = struct {
        member_name: []const u8,
        group_name: []const u8,
        aws_account_id: []const u8,
        namespace: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .member_name = "MemberName",
                .group_name = "GroupName",
                .aws_account_id = "AwsAccountId",
                .namespace = "Namespace",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(create_group_membership) } {
            return .{ .service_metadata = service_metadata, .action = create_group_membership };
        }
    },
    Response: type = struct {
        group_member: ?GroupMember = null,
        request_id: ?[]const u8 = null,
        status: ?i64 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .group_member = "GroupMember",
                .request_id = "RequestId",
                .status = "Status",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        InternalFailure,
        InvalidParameterValue,
        PreconditionNotMet,
        ResourceNotFound,
        ResourceUnavailable,
        Throttling,
    },
} = .{};
pub const create_iam_policy_assignment: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/accounts/{AwsAccountId}/namespaces/{Namespace}/iam-policy-assignments",
        .success_code = 200,
    };

    action_name: []const u8 = "CreateIAMPolicyAssignment",
    Request: type = struct {
        aws_account_id: []const u8,
        assignment_name: []const u8,
        assignment_status: []const u8,
        policy_arn: ?[]const u8 = null,
        identities: ?[]struct {
            key: ?[]const u8 = null,
            value: ?[][]const u8 = null,
        } = null,
        namespace: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .aws_account_id = "AwsAccountId",
                .assignment_name = "AssignmentName",
                .assignment_status = "AssignmentStatus",
                .policy_arn = "PolicyArn",
                .identities = "Identities",
                .namespace = "Namespace",
            };
            return @field(mappings, field_name);
        }

        pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
            if (std.mem.eql(u8, "identities", field_name))
                return try serializeMap(self.identities, self.fieldNameFor("identities"), options, out_stream);
            return false;
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(create_iam_policy_assignment) } {
            return .{ .service_metadata = service_metadata, .action = create_iam_policy_assignment };
        }
    },
    Response: type = struct {
        assignment_name: ?[]const u8 = null,
        assignment_id: ?[]const u8 = null,
        assignment_status: ?[]const u8 = null,
        policy_arn: ?[]const u8 = null,
        identities: ?[]struct {
            key: ?[]const u8 = null,
            value: ?[][]const u8 = null,
        } = null,
        request_id: ?[]const u8 = null,
        status: ?i64 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .assignment_name = "AssignmentName",
                .assignment_id = "AssignmentId",
                .assignment_status = "AssignmentStatus",
                .policy_arn = "PolicyArn",
                .identities = "Identities",
                .request_id = "RequestId",
                .status = "Status",
            };
            return @field(mappings, field_name);
        }

        pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
            if (std.mem.eql(u8, "identities", field_name))
                return try serializeMap(self.identities, self.fieldNameFor("identities"), options, out_stream);
            return false;
        }
    },
    ServiceError: type = error{
        AccessDenied,
        ConcurrentUpdating,
        InternalFailure,
        InvalidParameterValue,
        ResourceExists,
        ResourceNotFound,
        Throttling,
    },
} = .{};
pub const create_ingestion: struct {
    pub const http_config = .{
        .method = "PUT",
        .uri = "/accounts/{AwsAccountId}/data-sets/{DataSetId}/ingestions/{IngestionId}",
        .success_code = 200,
    };

    action_name: []const u8 = "CreateIngestion",
    Request: type = struct {
        data_set_id: []const u8,
        ingestion_id: []const u8,
        aws_account_id: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .data_set_id = "DataSetId",
                .ingestion_id = "IngestionId",
                .aws_account_id = "AwsAccountId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(create_ingestion) } {
            return .{ .service_metadata = service_metadata, .action = create_ingestion };
        }
    },
    Response: type = struct {
        arn: ?[]const u8 = null,
        ingestion_id: ?[]const u8 = null,
        ingestion_status: ?[]const u8 = null,
        request_id: ?[]const u8 = null,
        status: ?i64 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .arn = "Arn",
                .ingestion_id = "IngestionId",
                .ingestion_status = "IngestionStatus",
                .request_id = "RequestId",
                .status = "Status",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        InternalFailure,
        InvalidParameterValue,
        LimitExceeded,
        ResourceExists,
        ResourceNotFound,
        Throttling,
    },
} = .{};
pub const create_namespace: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/accounts/{AwsAccountId}",
        .success_code = 200,
    };

    action_name: []const u8 = "CreateNamespace",
    Request: type = struct {
        aws_account_id: []const u8,
        namespace: []const u8,
        identity_store: []const u8,
        tags: ?[]Tag = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .aws_account_id = "AwsAccountId",
                .namespace = "Namespace",
                .identity_store = "IdentityStore",
                .tags = "Tags",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(create_namespace) } {
            return .{ .service_metadata = service_metadata, .action = create_namespace };
        }
    },
    Response: type = struct {
        arn: ?[]const u8 = null,
        name: ?[]const u8 = null,
        capacity_region: ?[]const u8 = null,
        creation_status: ?[]const u8 = null,
        identity_store: ?[]const u8 = null,
        request_id: ?[]const u8 = null,
        status: ?i64 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .arn = "Arn",
                .name = "Name",
                .capacity_region = "CapacityRegion",
                .creation_status = "CreationStatus",
                .identity_store = "IdentityStore",
                .request_id = "RequestId",
                .status = "Status",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        Conflict,
        InternalFailure,
        InvalidParameterValue,
        LimitExceeded,
        PreconditionNotMet,
        ResourceExists,
        ResourceNotFound,
        ResourceUnavailable,
        Throttling,
    },
} = .{};
pub const create_template: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/accounts/{AwsAccountId}/templates/{TemplateId}",
        .success_code = 200,
    };

    action_name: []const u8 = "CreateTemplate",
    Request: type = struct {
        aws_account_id: []const u8,
        template_id: []const u8,
        name: ?[]const u8 = null,
        permissions: ?[]ResourcePermission = null,
        source_entity: TemplateSourceEntity,
        tags: ?[]Tag = null,
        version_description: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .aws_account_id = "AwsAccountId",
                .template_id = "TemplateId",
                .name = "Name",
                .permissions = "Permissions",
                .source_entity = "SourceEntity",
                .tags = "Tags",
                .version_description = "VersionDescription",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(create_template) } {
            return .{ .service_metadata = service_metadata, .action = create_template };
        }
    },
    Response: type = struct {
        arn: ?[]const u8 = null,
        version_arn: ?[]const u8 = null,
        template_id: ?[]const u8 = null,
        creation_status: ?[]const u8 = null,
        status: ?i64 = null,
        request_id: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .arn = "Arn",
                .version_arn = "VersionArn",
                .template_id = "TemplateId",
                .creation_status = "CreationStatus",
                .status = "Status",
                .request_id = "RequestId",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        Conflict,
        InternalFailure,
        InvalidParameterValue,
        LimitExceeded,
        ResourceExists,
        ResourceNotFound,
        Throttling,
        UnsupportedUserEdition,
    },
} = .{};
pub const create_template_alias: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/accounts/{AwsAccountId}/templates/{TemplateId}/aliases/{AliasName}",
        .success_code = 200,
    };

    action_name: []const u8 = "CreateTemplateAlias",
    Request: type = struct {
        aws_account_id: []const u8,
        template_id: []const u8,
        alias_name: []const u8,
        template_version_number: i64,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .aws_account_id = "AwsAccountId",
                .template_id = "TemplateId",
                .alias_name = "AliasName",
                .template_version_number = "TemplateVersionNumber",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(create_template_alias) } {
            return .{ .service_metadata = service_metadata, .action = create_template_alias };
        }
    },
    Response: type = struct {
        template_alias: ?TemplateAlias = null,
        status: ?i64 = null,
        request_id: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .template_alias = "TemplateAlias",
                .status = "Status",
                .request_id = "RequestId",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        Conflict,
        InternalFailure,
        LimitExceeded,
        ResourceExists,
        ResourceNotFound,
        Throttling,
        UnsupportedUserEdition,
    },
} = .{};
pub const create_theme: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/accounts/{AwsAccountId}/themes/{ThemeId}",
        .success_code = 200,
    };

    action_name: []const u8 = "CreateTheme",
    Request: type = struct {
        aws_account_id: []const u8,
        theme_id: []const u8,
        name: []const u8,
        base_theme_id: []const u8,
        version_description: ?[]const u8 = null,
        configuration: ThemeConfiguration,
        permissions: ?[]ResourcePermission = null,
        tags: ?[]Tag = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .aws_account_id = "AwsAccountId",
                .theme_id = "ThemeId",
                .name = "Name",
                .base_theme_id = "BaseThemeId",
                .version_description = "VersionDescription",
                .configuration = "Configuration",
                .permissions = "Permissions",
                .tags = "Tags",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(create_theme) } {
            return .{ .service_metadata = service_metadata, .action = create_theme };
        }
    },
    Response: type = struct {
        arn: ?[]const u8 = null,
        version_arn: ?[]const u8 = null,
        theme_id: ?[]const u8 = null,
        creation_status: ?[]const u8 = null,
        status: ?i64 = null,
        request_id: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .arn = "Arn",
                .version_arn = "VersionArn",
                .theme_id = "ThemeId",
                .creation_status = "CreationStatus",
                .status = "Status",
                .request_id = "RequestId",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        InternalFailure,
        InvalidParameterValue,
        LimitExceeded,
        ResourceExists,
        ResourceNotFound,
        Throttling,
        UnsupportedUserEdition,
    },
} = .{};
pub const create_theme_alias: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/accounts/{AwsAccountId}/themes/{ThemeId}/aliases/{AliasName}",
        .success_code = 200,
    };

    action_name: []const u8 = "CreateThemeAlias",
    Request: type = struct {
        aws_account_id: []const u8,
        theme_id: []const u8,
        alias_name: []const u8,
        theme_version_number: i64,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .aws_account_id = "AwsAccountId",
                .theme_id = "ThemeId",
                .alias_name = "AliasName",
                .theme_version_number = "ThemeVersionNumber",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(create_theme_alias) } {
            return .{ .service_metadata = service_metadata, .action = create_theme_alias };
        }
    },
    Response: type = struct {
        theme_alias: ?ThemeAlias = null,
        status: ?i64 = null,
        request_id: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .theme_alias = "ThemeAlias",
                .status = "Status",
                .request_id = "RequestId",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        Conflict,
        InternalFailure,
        InvalidParameterValue,
        LimitExceeded,
        ResourceExists,
        ResourceNotFound,
        Throttling,
        UnsupportedUserEdition,
    },
} = .{};
pub const delete_account_customization: struct {
    pub const http_config = .{
        .method = "DELETE",
        .uri = "/accounts/{AwsAccountId}/customizations",
        .success_code = 200,
    };

    action_name: []const u8 = "DeleteAccountCustomization",
    Request: type = struct {
        aws_account_id: []const u8,
        namespace: ?[]const u8 = null,

        pub const http_query = .{
            .namespace = "namespace",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .aws_account_id = "AwsAccountId",
                .namespace = "Namespace",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(delete_account_customization) } {
            return .{ .service_metadata = service_metadata, .action = delete_account_customization };
        }
    },
    Response: type = struct {
        request_id: ?[]const u8 = null,
        status: ?i64 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .request_id = "RequestId",
                .status = "Status",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        InternalFailure,
        InvalidParameterValue,
        ResourceNotFound,
        ResourceUnavailable,
        Throttling,
    },
} = .{};
pub const delete_analysis: struct {
    pub const http_config = .{
        .method = "DELETE",
        .uri = "/accounts/{AwsAccountId}/analyses/{AnalysisId}",
        .success_code = 200,
    };

    action_name: []const u8 = "DeleteAnalysis",
    Request: type = struct {
        aws_account_id: []const u8,
        analysis_id: []const u8,
        recovery_window_in_days: ?i64 = null,
        force_delete_without_recovery: ?bool = null,

        pub const http_query = .{
            .recovery_window_in_days = "recovery-window-in-days",
            .force_delete_without_recovery = "force-delete-without-recovery",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .aws_account_id = "AwsAccountId",
                .analysis_id = "AnalysisId",
                .recovery_window_in_days = "RecoveryWindowInDays",
                .force_delete_without_recovery = "ForceDeleteWithoutRecovery",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(delete_analysis) } {
            return .{ .service_metadata = service_metadata, .action = delete_analysis };
        }
    },
    Response: type = struct {
        status: ?i64 = null,
        arn: ?[]const u8 = null,
        analysis_id: ?[]const u8 = null,
        deletion_time: ?i64 = null,
        request_id: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .status = "Status",
                .arn = "Arn",
                .analysis_id = "AnalysisId",
                .deletion_time = "DeletionTime",
                .request_id = "RequestId",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        Conflict,
        InternalFailure,
        InvalidParameterValue,
        ResourceNotFound,
        Throttling,
        UnsupportedUserEdition,
    },
} = .{};
pub const delete_dashboard: struct {
    pub const http_config = .{
        .method = "DELETE",
        .uri = "/accounts/{AwsAccountId}/dashboards/{DashboardId}",
        .success_code = 200,
    };

    action_name: []const u8 = "DeleteDashboard",
    Request: type = struct {
        aws_account_id: []const u8,
        dashboard_id: []const u8,
        version_number: ?i64 = null,

        pub const http_query = .{
            .version_number = "version-number",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .aws_account_id = "AwsAccountId",
                .dashboard_id = "DashboardId",
                .version_number = "VersionNumber",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(delete_dashboard) } {
            return .{ .service_metadata = service_metadata, .action = delete_dashboard };
        }
    },
    Response: type = struct {
        status: ?i64 = null,
        arn: ?[]const u8 = null,
        dashboard_id: ?[]const u8 = null,
        request_id: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .status = "Status",
                .arn = "Arn",
                .dashboard_id = "DashboardId",
                .request_id = "RequestId",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        Conflict,
        InternalFailure,
        InvalidParameterValue,
        ResourceNotFound,
        Throttling,
        UnsupportedUserEdition,
    },
} = .{};
pub const delete_data_set: struct {
    pub const http_config = .{
        .method = "DELETE",
        .uri = "/accounts/{AwsAccountId}/data-sets/{DataSetId}",
        .success_code = 200,
    };

    action_name: []const u8 = "DeleteDataSet",
    Request: type = struct {
        aws_account_id: []const u8,
        data_set_id: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .aws_account_id = "AwsAccountId",
                .data_set_id = "DataSetId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(delete_data_set) } {
            return .{ .service_metadata = service_metadata, .action = delete_data_set };
        }
    },
    Response: type = struct {
        arn: ?[]const u8 = null,
        data_set_id: ?[]const u8 = null,
        request_id: ?[]const u8 = null,
        status: ?i64 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .arn = "Arn",
                .data_set_id = "DataSetId",
                .request_id = "RequestId",
                .status = "Status",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        InternalFailure,
        InvalidParameterValue,
        ResourceNotFound,
        Throttling,
    },
} = .{};
pub const delete_data_source: struct {
    pub const http_config = .{
        .method = "DELETE",
        .uri = "/accounts/{AwsAccountId}/data-sources/{DataSourceId}",
        .success_code = 200,
    };

    action_name: []const u8 = "DeleteDataSource",
    Request: type = struct {
        aws_account_id: []const u8,
        data_source_id: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .aws_account_id = "AwsAccountId",
                .data_source_id = "DataSourceId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(delete_data_source) } {
            return .{ .service_metadata = service_metadata, .action = delete_data_source };
        }
    },
    Response: type = struct {
        arn: ?[]const u8 = null,
        data_source_id: ?[]const u8 = null,
        request_id: ?[]const u8 = null,
        status: ?i64 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .arn = "Arn",
                .data_source_id = "DataSourceId",
                .request_id = "RequestId",
                .status = "Status",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        InternalFailure,
        InvalidParameterValue,
        ResourceNotFound,
        Throttling,
    },
} = .{};
pub const delete_group: struct {
    pub const http_config = .{
        .method = "DELETE",
        .uri = "/accounts/{AwsAccountId}/namespaces/{Namespace}/groups/{GroupName}",
        .success_code = 200,
    };

    action_name: []const u8 = "DeleteGroup",
    Request: type = struct {
        group_name: []const u8,
        aws_account_id: []const u8,
        namespace: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .group_name = "GroupName",
                .aws_account_id = "AwsAccountId",
                .namespace = "Namespace",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(delete_group) } {
            return .{ .service_metadata = service_metadata, .action = delete_group };
        }
    },
    Response: type = struct {
        request_id: ?[]const u8 = null,
        status: ?i64 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .request_id = "RequestId",
                .status = "Status",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        InternalFailure,
        InvalidParameterValue,
        PreconditionNotMet,
        ResourceNotFound,
        ResourceUnavailable,
        Throttling,
    },
} = .{};
pub const delete_group_membership: struct {
    pub const http_config = .{
        .method = "DELETE",
        .uri = "/accounts/{AwsAccountId}/namespaces/{Namespace}/groups/{GroupName}/members/{MemberName}",
        .success_code = 200,
    };

    action_name: []const u8 = "DeleteGroupMembership",
    Request: type = struct {
        member_name: []const u8,
        group_name: []const u8,
        aws_account_id: []const u8,
        namespace: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .member_name = "MemberName",
                .group_name = "GroupName",
                .aws_account_id = "AwsAccountId",
                .namespace = "Namespace",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(delete_group_membership) } {
            return .{ .service_metadata = service_metadata, .action = delete_group_membership };
        }
    },
    Response: type = struct {
        request_id: ?[]const u8 = null,
        status: ?i64 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .request_id = "RequestId",
                .status = "Status",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        InternalFailure,
        InvalidParameterValue,
        PreconditionNotMet,
        ResourceNotFound,
        ResourceUnavailable,
        Throttling,
    },
} = .{};
pub const delete_iam_policy_assignment: struct {
    pub const http_config = .{
        .method = "DELETE",
        .uri = "/accounts/{AwsAccountId}/namespace/{Namespace}/iam-policy-assignments/{AssignmentName}",
        .success_code = 200,
    };

    action_name: []const u8 = "DeleteIAMPolicyAssignment",
    Request: type = struct {
        aws_account_id: []const u8,
        assignment_name: []const u8,
        namespace: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .aws_account_id = "AwsAccountId",
                .assignment_name = "AssignmentName",
                .namespace = "Namespace",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(delete_iam_policy_assignment) } {
            return .{ .service_metadata = service_metadata, .action = delete_iam_policy_assignment };
        }
    },
    Response: type = struct {
        assignment_name: ?[]const u8 = null,
        request_id: ?[]const u8 = null,
        status: ?i64 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .assignment_name = "AssignmentName",
                .request_id = "RequestId",
                .status = "Status",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        ConcurrentUpdating,
        InternalFailure,
        InvalidParameterValue,
        ResourceExists,
        ResourceNotFound,
        Throttling,
    },
} = .{};
pub const delete_namespace: struct {
    pub const http_config = .{
        .method = "DELETE",
        .uri = "/accounts/{AwsAccountId}/namespaces/{Namespace}",
        .success_code = 200,
    };

    action_name: []const u8 = "DeleteNamespace",
    Request: type = struct {
        aws_account_id: []const u8,
        namespace: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .aws_account_id = "AwsAccountId",
                .namespace = "Namespace",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(delete_namespace) } {
            return .{ .service_metadata = service_metadata, .action = delete_namespace };
        }
    },
    Response: type = struct {
        request_id: ?[]const u8 = null,
        status: ?i64 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .request_id = "RequestId",
                .status = "Status",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        InternalFailure,
        InvalidParameterValue,
        PreconditionNotMet,
        ResourceNotFound,
        ResourceUnavailable,
        Throttling,
    },
} = .{};
pub const delete_template: struct {
    pub const http_config = .{
        .method = "DELETE",
        .uri = "/accounts/{AwsAccountId}/templates/{TemplateId}",
        .success_code = 200,
    };

    action_name: []const u8 = "DeleteTemplate",
    Request: type = struct {
        aws_account_id: []const u8,
        template_id: []const u8,
        version_number: ?i64 = null,

        pub const http_query = .{
            .version_number = "version-number",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .aws_account_id = "AwsAccountId",
                .template_id = "TemplateId",
                .version_number = "VersionNumber",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(delete_template) } {
            return .{ .service_metadata = service_metadata, .action = delete_template };
        }
    },
    Response: type = struct {
        request_id: ?[]const u8 = null,
        arn: ?[]const u8 = null,
        template_id: ?[]const u8 = null,
        status: ?i64 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .request_id = "RequestId",
                .arn = "Arn",
                .template_id = "TemplateId",
                .status = "Status",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        Conflict,
        InternalFailure,
        InvalidParameterValue,
        LimitExceeded,
        ResourceNotFound,
        Throttling,
        UnsupportedUserEdition,
    },
} = .{};
pub const delete_template_alias: struct {
    pub const http_config = .{
        .method = "DELETE",
        .uri = "/accounts/{AwsAccountId}/templates/{TemplateId}/aliases/{AliasName}",
        .success_code = 200,
    };

    action_name: []const u8 = "DeleteTemplateAlias",
    Request: type = struct {
        aws_account_id: []const u8,
        template_id: []const u8,
        alias_name: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .aws_account_id = "AwsAccountId",
                .template_id = "TemplateId",
                .alias_name = "AliasName",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(delete_template_alias) } {
            return .{ .service_metadata = service_metadata, .action = delete_template_alias };
        }
    },
    Response: type = struct {
        status: ?i64 = null,
        template_id: ?[]const u8 = null,
        alias_name: ?[]const u8 = null,
        arn: ?[]const u8 = null,
        request_id: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .status = "Status",
                .template_id = "TemplateId",
                .alias_name = "AliasName",
                .arn = "Arn",
                .request_id = "RequestId",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        Conflict,
        InternalFailure,
        ResourceNotFound,
        Throttling,
        UnsupportedUserEdition,
    },
} = .{};
pub const delete_theme: struct {
    pub const http_config = .{
        .method = "DELETE",
        .uri = "/accounts/{AwsAccountId}/themes/{ThemeId}",
        .success_code = 200,
    };

    action_name: []const u8 = "DeleteTheme",
    Request: type = struct {
        aws_account_id: []const u8,
        theme_id: []const u8,
        version_number: ?i64 = null,

        pub const http_query = .{
            .version_number = "version-number",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .aws_account_id = "AwsAccountId",
                .theme_id = "ThemeId",
                .version_number = "VersionNumber",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(delete_theme) } {
            return .{ .service_metadata = service_metadata, .action = delete_theme };
        }
    },
    Response: type = struct {
        arn: ?[]const u8 = null,
        request_id: ?[]const u8 = null,
        status: ?i64 = null,
        theme_id: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .arn = "Arn",
                .request_id = "RequestId",
                .status = "Status",
                .theme_id = "ThemeId",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        Conflict,
        InternalFailure,
        InvalidParameterValue,
        ResourceNotFound,
        Throttling,
        UnsupportedUserEdition,
    },
} = .{};
pub const delete_theme_alias: struct {
    pub const http_config = .{
        .method = "DELETE",
        .uri = "/accounts/{AwsAccountId}/themes/{ThemeId}/aliases/{AliasName}",
        .success_code = 200,
    };

    action_name: []const u8 = "DeleteThemeAlias",
    Request: type = struct {
        aws_account_id: []const u8,
        theme_id: []const u8,
        alias_name: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .aws_account_id = "AwsAccountId",
                .theme_id = "ThemeId",
                .alias_name = "AliasName",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(delete_theme_alias) } {
            return .{ .service_metadata = service_metadata, .action = delete_theme_alias };
        }
    },
    Response: type = struct {
        alias_name: ?[]const u8 = null,
        arn: ?[]const u8 = null,
        request_id: ?[]const u8 = null,
        status: ?i64 = null,
        theme_id: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .alias_name = "AliasName",
                .arn = "Arn",
                .request_id = "RequestId",
                .status = "Status",
                .theme_id = "ThemeId",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        Conflict,
        InternalFailure,
        InvalidParameterValue,
        ResourceNotFound,
        Throttling,
        UnsupportedUserEdition,
    },
} = .{};
pub const delete_user: struct {
    pub const http_config = .{
        .method = "DELETE",
        .uri = "/accounts/{AwsAccountId}/namespaces/{Namespace}/users/{UserName}",
        .success_code = 200,
    };

    action_name: []const u8 = "DeleteUser",
    Request: type = struct {
        user_name: []const u8,
        aws_account_id: []const u8,
        namespace: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .user_name = "UserName",
                .aws_account_id = "AwsAccountId",
                .namespace = "Namespace",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(delete_user) } {
            return .{ .service_metadata = service_metadata, .action = delete_user };
        }
    },
    Response: type = struct {
        request_id: ?[]const u8 = null,
        status: ?i64 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .request_id = "RequestId",
                .status = "Status",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        InternalFailure,
        InvalidParameterValue,
        PreconditionNotMet,
        ResourceNotFound,
        ResourceUnavailable,
        Throttling,
    },
} = .{};
pub const delete_user_by_principal_id: struct {
    pub const http_config = .{
        .method = "DELETE",
        .uri = "/accounts/{AwsAccountId}/namespaces/{Namespace}/user-principals/{PrincipalId}",
        .success_code = 200,
    };

    action_name: []const u8 = "DeleteUserByPrincipalId",
    Request: type = struct {
        principal_id: []const u8,
        aws_account_id: []const u8,
        namespace: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .principal_id = "PrincipalId",
                .aws_account_id = "AwsAccountId",
                .namespace = "Namespace",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(delete_user_by_principal_id) } {
            return .{ .service_metadata = service_metadata, .action = delete_user_by_principal_id };
        }
    },
    Response: type = struct {
        request_id: ?[]const u8 = null,
        status: ?i64 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .request_id = "RequestId",
                .status = "Status",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        InternalFailure,
        InvalidParameterValue,
        PreconditionNotMet,
        ResourceNotFound,
        ResourceUnavailable,
        Throttling,
    },
} = .{};
pub const describe_account_customization: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/accounts/{AwsAccountId}/customizations",
        .success_code = 200,
    };

    action_name: []const u8 = "DescribeAccountCustomization",
    Request: type = struct {
        aws_account_id: []const u8,
        namespace: ?[]const u8 = null,
        resolved: ?bool = null,

        pub const http_query = .{
            .namespace = "namespace",
            .resolved = "resolved",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .aws_account_id = "AwsAccountId",
                .namespace = "Namespace",
                .resolved = "Resolved",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(describe_account_customization) } {
            return .{ .service_metadata = service_metadata, .action = describe_account_customization };
        }
    },
    Response: type = struct {
        arn: ?[]const u8 = null,
        aws_account_id: ?[]const u8 = null,
        namespace: ?[]const u8 = null,
        account_customization: ?AccountCustomization = null,
        request_id: ?[]const u8 = null,
        status: ?i64 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .arn = "Arn",
                .aws_account_id = "AwsAccountId",
                .namespace = "Namespace",
                .account_customization = "AccountCustomization",
                .request_id = "RequestId",
                .status = "Status",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        InternalFailure,
        InvalidParameterValue,
        ResourceNotFound,
        ResourceUnavailable,
        Throttling,
    },
} = .{};
pub const describe_account_settings: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/accounts/{AwsAccountId}/settings",
        .success_code = 200,
    };

    action_name: []const u8 = "DescribeAccountSettings",
    Request: type = struct {
        aws_account_id: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .aws_account_id = "AwsAccountId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(describe_account_settings) } {
            return .{ .service_metadata = service_metadata, .action = describe_account_settings };
        }
    },
    Response: type = struct {
        account_settings: ?struct {
            account_name: ?[]const u8 = null,
            edition: ?[]const u8 = null,
            default_namespace: ?[]const u8 = null,
            notification_email: ?[]const u8 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .account_name = "AccountName",
                    .edition = "Edition",
                    .default_namespace = "DefaultNamespace",
                    .notification_email = "NotificationEmail",
                };
                return @field(mappings, field_name);
            }
        } = null,
        request_id: ?[]const u8 = null,
        status: ?i64 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .account_settings = "AccountSettings",
                .request_id = "RequestId",
                .status = "Status",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        InternalFailure,
        InvalidParameterValue,
        ResourceNotFound,
        ResourceUnavailable,
        Throttling,
    },
} = .{};
pub const describe_analysis: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/accounts/{AwsAccountId}/analyses/{AnalysisId}",
        .success_code = 200,
    };

    action_name: []const u8 = "DescribeAnalysis",
    Request: type = struct {
        aws_account_id: []const u8,
        analysis_id: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .aws_account_id = "AwsAccountId",
                .analysis_id = "AnalysisId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(describe_analysis) } {
            return .{ .service_metadata = service_metadata, .action = describe_analysis };
        }
    },
    Response: type = struct {
        analysis: ?struct {
            analysis_id: ?[]const u8 = null,
            arn: ?[]const u8 = null,
            name: ?[]const u8 = null,
            status: ?[]const u8 = null,
            errors: ?[]struct {
                type: ?[]const u8 = null,
                message: ?[]const u8 = null,

                pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                    const mappings = .{
                        .type = "Type",
                        .message = "Message",
                    };
                    return @field(mappings, field_name);
                }
            } = null,
            data_set_arns: ?[][]const u8 = null,
            theme_arn: ?[]const u8 = null,
            created_time: ?i64 = null,
            last_updated_time: ?i64 = null,
            sheets: ?[]Sheet = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .analysis_id = "AnalysisId",
                    .arn = "Arn",
                    .name = "Name",
                    .status = "Status",
                    .errors = "Errors",
                    .data_set_arns = "DataSetArns",
                    .theme_arn = "ThemeArn",
                    .created_time = "CreatedTime",
                    .last_updated_time = "LastUpdatedTime",
                    .sheets = "Sheets",
                };
                return @field(mappings, field_name);
            }
        } = null,
        status: ?i64 = null,
        request_id: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .analysis = "Analysis",
                .status = "Status",
                .request_id = "RequestId",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        InternalFailure,
        InvalidParameterValue,
        ResourceNotFound,
        Throttling,
        UnsupportedUserEdition,
    },
} = .{};
pub const describe_analysis_permissions: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/accounts/{AwsAccountId}/analyses/{AnalysisId}/permissions",
        .success_code = 200,
    };

    action_name: []const u8 = "DescribeAnalysisPermissions",
    Request: type = struct {
        aws_account_id: []const u8,
        analysis_id: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .aws_account_id = "AwsAccountId",
                .analysis_id = "AnalysisId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(describe_analysis_permissions) } {
            return .{ .service_metadata = service_metadata, .action = describe_analysis_permissions };
        }
    },
    Response: type = struct {
        analysis_id: ?[]const u8 = null,
        analysis_arn: ?[]const u8 = null,
        permissions: ?[]ResourcePermission = null,
        status: ?i64 = null,
        request_id: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .analysis_id = "AnalysisId",
                .analysis_arn = "AnalysisArn",
                .permissions = "Permissions",
                .status = "Status",
                .request_id = "RequestId",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalFailure,
        InvalidParameterValue,
        ResourceNotFound,
        Throttling,
        UnsupportedUserEdition,
    },
} = .{};
pub const describe_dashboard: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/accounts/{AwsAccountId}/dashboards/{DashboardId}",
        .success_code = 200,
    };

    action_name: []const u8 = "DescribeDashboard",
    Request: type = struct {
        aws_account_id: []const u8,
        dashboard_id: []const u8,
        version_number: ?i64 = null,
        alias_name: ?[]const u8 = null,

        pub const http_query = .{
            .version_number = "version-number",
            .alias_name = "alias-name",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .aws_account_id = "AwsAccountId",
                .dashboard_id = "DashboardId",
                .version_number = "VersionNumber",
                .alias_name = "AliasName",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(describe_dashboard) } {
            return .{ .service_metadata = service_metadata, .action = describe_dashboard };
        }
    },
    Response: type = struct {
        dashboard: ?struct {
            dashboard_id: ?[]const u8 = null,
            arn: ?[]const u8 = null,
            name: ?[]const u8 = null,
            version: ?struct {
                created_time: ?i64 = null,
                errors: ?[]struct {
                    type: ?[]const u8 = null,
                    message: ?[]const u8 = null,

                    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                        const mappings = .{
                            .type = "Type",
                            .message = "Message",
                        };
                        return @field(mappings, field_name);
                    }
                } = null,
                version_number: ?i64 = null,
                status: ?[]const u8 = null,
                arn: ?[]const u8 = null,
                source_entity_arn: ?[]const u8 = null,
                data_set_arns: ?[][]const u8 = null,
                description: ?[]const u8 = null,
                theme_arn: ?[]const u8 = null,
                sheets: ?[]Sheet = null,

                pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                    const mappings = .{
                        .created_time = "CreatedTime",
                        .errors = "Errors",
                        .version_number = "VersionNumber",
                        .status = "Status",
                        .arn = "Arn",
                        .source_entity_arn = "SourceEntityArn",
                        .data_set_arns = "DataSetArns",
                        .description = "Description",
                        .theme_arn = "ThemeArn",
                        .sheets = "Sheets",
                    };
                    return @field(mappings, field_name);
                }
            } = null,
            created_time: ?i64 = null,
            last_published_time: ?i64 = null,
            last_updated_time: ?i64 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .dashboard_id = "DashboardId",
                    .arn = "Arn",
                    .name = "Name",
                    .version = "Version",
                    .created_time = "CreatedTime",
                    .last_published_time = "LastPublishedTime",
                    .last_updated_time = "LastUpdatedTime",
                };
                return @field(mappings, field_name);
            }
        } = null,
        status: ?i64 = null,
        request_id: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .dashboard = "Dashboard",
                .status = "Status",
                .request_id = "RequestId",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        InternalFailure,
        InvalidParameterValue,
        ResourceNotFound,
        Throttling,
        UnsupportedUserEdition,
    },
} = .{};
pub const describe_dashboard_permissions: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/accounts/{AwsAccountId}/dashboards/{DashboardId}/permissions",
        .success_code = 200,
    };

    action_name: []const u8 = "DescribeDashboardPermissions",
    Request: type = struct {
        aws_account_id: []const u8,
        dashboard_id: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .aws_account_id = "AwsAccountId",
                .dashboard_id = "DashboardId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(describe_dashboard_permissions) } {
            return .{ .service_metadata = service_metadata, .action = describe_dashboard_permissions };
        }
    },
    Response: type = struct {
        dashboard_id: ?[]const u8 = null,
        dashboard_arn: ?[]const u8 = null,
        permissions: ?[]ResourcePermission = null,
        status: ?i64 = null,
        request_id: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .dashboard_id = "DashboardId",
                .dashboard_arn = "DashboardArn",
                .permissions = "Permissions",
                .status = "Status",
                .request_id = "RequestId",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalFailure,
        InvalidParameterValue,
        ResourceNotFound,
        Throttling,
        UnsupportedUserEdition,
    },
} = .{};
pub const describe_data_set: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/accounts/{AwsAccountId}/data-sets/{DataSetId}",
        .success_code = 200,
    };

    action_name: []const u8 = "DescribeDataSet",
    Request: type = struct {
        aws_account_id: []const u8,
        data_set_id: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .aws_account_id = "AwsAccountId",
                .data_set_id = "DataSetId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(describe_data_set) } {
            return .{ .service_metadata = service_metadata, .action = describe_data_set };
        }
    },
    Response: type = struct {
        data_set: ?struct {
            arn: ?[]const u8 = null,
            data_set_id: ?[]const u8 = null,
            name: ?[]const u8 = null,
            created_time: ?i64 = null,
            last_updated_time: ?i64 = null,
            physical_table_map: ?[]struct {
                key: ?[]const u8 = null,
                value: ?PhysicalTable = null,
            } = null,
            logical_table_map: ?[]struct {
                key: ?[]const u8 = null,
                value: ?LogicalTable = null,
            } = null,
            output_columns: ?[]struct {
                name: ?[]const u8 = null,
                description: ?[]const u8 = null,
                type: ?[]const u8 = null,

                pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                    const mappings = .{
                        .name = "Name",
                        .description = "Description",
                        .type = "Type",
                    };
                    return @field(mappings, field_name);
                }
            } = null,
            import_mode: ?[]const u8 = null,
            consumed_spice_capacity_in_bytes: ?i64 = null,
            column_groups: ?[]ColumnGroup = null,
            field_folders: ?[]struct {
                key: ?[]const u8 = null,
                value: ?FieldFolder = null,
            } = null,
            row_level_permission_data_set: ?RowLevelPermissionDataSet = null,
            column_level_permission_rules: ?[]ColumnLevelPermissionRule = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .arn = "Arn",
                    .data_set_id = "DataSetId",
                    .name = "Name",
                    .created_time = "CreatedTime",
                    .last_updated_time = "LastUpdatedTime",
                    .physical_table_map = "PhysicalTableMap",
                    .logical_table_map = "LogicalTableMap",
                    .output_columns = "OutputColumns",
                    .import_mode = "ImportMode",
                    .consumed_spice_capacity_in_bytes = "ConsumedSpiceCapacityInBytes",
                    .column_groups = "ColumnGroups",
                    .field_folders = "FieldFolders",
                    .row_level_permission_data_set = "RowLevelPermissionDataSet",
                    .column_level_permission_rules = "ColumnLevelPermissionRules",
                };
                return @field(mappings, field_name);
            }

            pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
                if (std.mem.eql(u8, "physical_table_map", field_name))
                    return try serializeMap(self.physical_table_map, self.fieldNameFor("physical_table_map"), options, out_stream);
                if (std.mem.eql(u8, "logical_table_map", field_name))
                    return try serializeMap(self.logical_table_map, self.fieldNameFor("logical_table_map"), options, out_stream);
                if (std.mem.eql(u8, "field_folders", field_name))
                    return try serializeMap(self.field_folders, self.fieldNameFor("field_folders"), options, out_stream);
                return false;
            }
        } = null,
        request_id: ?[]const u8 = null,
        status: ?i64 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .data_set = "DataSet",
                .request_id = "RequestId",
                .status = "Status",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        InternalFailure,
        InvalidParameterValue,
        ResourceNotFound,
        Throttling,
    },
} = .{};
pub const describe_data_set_permissions: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/accounts/{AwsAccountId}/data-sets/{DataSetId}/permissions",
        .success_code = 200,
    };

    action_name: []const u8 = "DescribeDataSetPermissions",
    Request: type = struct {
        aws_account_id: []const u8,
        data_set_id: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .aws_account_id = "AwsAccountId",
                .data_set_id = "DataSetId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(describe_data_set_permissions) } {
            return .{ .service_metadata = service_metadata, .action = describe_data_set_permissions };
        }
    },
    Response: type = struct {
        data_set_arn: ?[]const u8 = null,
        data_set_id: ?[]const u8 = null,
        permissions: ?[]ResourcePermission = null,
        request_id: ?[]const u8 = null,
        status: ?i64 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .data_set_arn = "DataSetArn",
                .data_set_id = "DataSetId",
                .permissions = "Permissions",
                .request_id = "RequestId",
                .status = "Status",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        InternalFailure,
        InvalidParameterValue,
        ResourceNotFound,
        Throttling,
    },
} = .{};
pub const describe_data_source: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/accounts/{AwsAccountId}/data-sources/{DataSourceId}",
        .success_code = 200,
    };

    action_name: []const u8 = "DescribeDataSource",
    Request: type = struct {
        aws_account_id: []const u8,
        data_source_id: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .aws_account_id = "AwsAccountId",
                .data_source_id = "DataSourceId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(describe_data_source) } {
            return .{ .service_metadata = service_metadata, .action = describe_data_source };
        }
    },
    Response: type = struct {
        data_source: ?DataSource = null,
        request_id: ?[]const u8 = null,
        status: ?i64 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .data_source = "DataSource",
                .request_id = "RequestId",
                .status = "Status",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        InternalFailure,
        InvalidParameterValue,
        ResourceNotFound,
        Throttling,
    },
} = .{};
pub const describe_data_source_permissions: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/accounts/{AwsAccountId}/data-sources/{DataSourceId}/permissions",
        .success_code = 200,
    };

    action_name: []const u8 = "DescribeDataSourcePermissions",
    Request: type = struct {
        aws_account_id: []const u8,
        data_source_id: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .aws_account_id = "AwsAccountId",
                .data_source_id = "DataSourceId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(describe_data_source_permissions) } {
            return .{ .service_metadata = service_metadata, .action = describe_data_source_permissions };
        }
    },
    Response: type = struct {
        data_source_arn: ?[]const u8 = null,
        data_source_id: ?[]const u8 = null,
        permissions: ?[]ResourcePermission = null,
        request_id: ?[]const u8 = null,
        status: ?i64 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .data_source_arn = "DataSourceArn",
                .data_source_id = "DataSourceId",
                .permissions = "Permissions",
                .request_id = "RequestId",
                .status = "Status",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        InternalFailure,
        InvalidParameterValue,
        ResourceNotFound,
        Throttling,
    },
} = .{};
pub const describe_group: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/accounts/{AwsAccountId}/namespaces/{Namespace}/groups/{GroupName}",
        .success_code = 200,
    };

    action_name: []const u8 = "DescribeGroup",
    Request: type = struct {
        group_name: []const u8,
        aws_account_id: []const u8,
        namespace: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .group_name = "GroupName",
                .aws_account_id = "AwsAccountId",
                .namespace = "Namespace",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(describe_group) } {
            return .{ .service_metadata = service_metadata, .action = describe_group };
        }
    },
    Response: type = struct {
        group: ?Group = null,
        request_id: ?[]const u8 = null,
        status: ?i64 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .group = "Group",
                .request_id = "RequestId",
                .status = "Status",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        InternalFailure,
        InvalidParameterValue,
        PreconditionNotMet,
        ResourceNotFound,
        ResourceUnavailable,
        Throttling,
    },
} = .{};
pub const describe_iam_policy_assignment: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/accounts/{AwsAccountId}/namespaces/{Namespace}/iam-policy-assignments/{AssignmentName}",
        .success_code = 200,
    };

    action_name: []const u8 = "DescribeIAMPolicyAssignment",
    Request: type = struct {
        aws_account_id: []const u8,
        assignment_name: []const u8,
        namespace: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .aws_account_id = "AwsAccountId",
                .assignment_name = "AssignmentName",
                .namespace = "Namespace",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(describe_iam_policy_assignment) } {
            return .{ .service_metadata = service_metadata, .action = describe_iam_policy_assignment };
        }
    },
    Response: type = struct {
        iam_policy_assignment: ?struct {
            aws_account_id: ?[]const u8 = null,
            assignment_id: ?[]const u8 = null,
            assignment_name: ?[]const u8 = null,
            policy_arn: ?[]const u8 = null,
            identities: ?[]struct {
                key: ?[]const u8 = null,
                value: ?[][]const u8 = null,
            } = null,
            assignment_status: ?[]const u8 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .aws_account_id = "AwsAccountId",
                    .assignment_id = "AssignmentId",
                    .assignment_name = "AssignmentName",
                    .policy_arn = "PolicyArn",
                    .identities = "Identities",
                    .assignment_status = "AssignmentStatus",
                };
                return @field(mappings, field_name);
            }

            pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
                if (std.mem.eql(u8, "identities", field_name))
                    return try serializeMap(self.identities, self.fieldNameFor("identities"), options, out_stream);
                return false;
            }
        } = null,
        request_id: ?[]const u8 = null,
        status: ?i64 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .iam_policy_assignment = "IAMPolicyAssignment",
                .request_id = "RequestId",
                .status = "Status",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        InternalFailure,
        InvalidNextToken,
        InvalidParameterValue,
        ResourceNotFound,
        Throttling,
    },
} = .{};
pub const describe_ingestion: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/accounts/{AwsAccountId}/data-sets/{DataSetId}/ingestions/{IngestionId}",
        .success_code = 200,
    };

    action_name: []const u8 = "DescribeIngestion",
    Request: type = struct {
        aws_account_id: []const u8,
        data_set_id: []const u8,
        ingestion_id: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .aws_account_id = "AwsAccountId",
                .data_set_id = "DataSetId",
                .ingestion_id = "IngestionId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(describe_ingestion) } {
            return .{ .service_metadata = service_metadata, .action = describe_ingestion };
        }
    },
    Response: type = struct {
        ingestion: ?Ingestion = null,
        request_id: ?[]const u8 = null,
        status: ?i64 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .ingestion = "Ingestion",
                .request_id = "RequestId",
                .status = "Status",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        InternalFailure,
        InvalidParameterValue,
        ResourceExists,
        ResourceNotFound,
        Throttling,
    },
} = .{};
pub const describe_namespace: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/accounts/{AwsAccountId}/namespaces/{Namespace}",
        .success_code = 200,
    };

    action_name: []const u8 = "DescribeNamespace",
    Request: type = struct {
        aws_account_id: []const u8,
        namespace: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .aws_account_id = "AwsAccountId",
                .namespace = "Namespace",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(describe_namespace) } {
            return .{ .service_metadata = service_metadata, .action = describe_namespace };
        }
    },
    Response: type = struct {
        namespace: ?NamespaceInfoV2 = null,
        request_id: ?[]const u8 = null,
        status: ?i64 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .namespace = "Namespace",
                .request_id = "RequestId",
                .status = "Status",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        InternalFailure,
        InvalidParameterValue,
        ResourceNotFound,
        ResourceUnavailable,
        Throttling,
    },
} = .{};
pub const describe_template: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/accounts/{AwsAccountId}/templates/{TemplateId}",
        .success_code = 200,
    };

    action_name: []const u8 = "DescribeTemplate",
    Request: type = struct {
        aws_account_id: []const u8,
        template_id: []const u8,
        version_number: ?i64 = null,
        alias_name: ?[]const u8 = null,

        pub const http_query = .{
            .version_number = "version-number",
            .alias_name = "alias-name",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .aws_account_id = "AwsAccountId",
                .template_id = "TemplateId",
                .version_number = "VersionNumber",
                .alias_name = "AliasName",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(describe_template) } {
            return .{ .service_metadata = service_metadata, .action = describe_template };
        }
    },
    Response: type = struct {
        template: ?struct {
            arn: ?[]const u8 = null,
            name: ?[]const u8 = null,
            version: ?struct {
                created_time: ?i64 = null,
                errors: ?[]struct {
                    type: ?[]const u8 = null,
                    message: ?[]const u8 = null,

                    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                        const mappings = .{
                            .type = "Type",
                            .message = "Message",
                        };
                        return @field(mappings, field_name);
                    }
                } = null,
                version_number: ?i64 = null,
                status: ?[]const u8 = null,
                data_set_configurations: ?[]struct {
                    placeholder: ?[]const u8 = null,
                    data_set_schema: ?struct {
                        column_schema_list: ?[]struct {
                            name: ?[]const u8 = null,
                            data_type: ?[]const u8 = null,
                            geographic_role: ?[]const u8 = null,

                            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                                const mappings = .{
                                    .name = "Name",
                                    .data_type = "DataType",
                                    .geographic_role = "GeographicRole",
                                };
                                return @field(mappings, field_name);
                            }
                        } = null,

                        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                            const mappings = .{
                                .column_schema_list = "ColumnSchemaList",
                            };
                            return @field(mappings, field_name);
                        }
                    } = null,
                    column_group_schema_list: ?[]struct {
                        name: ?[]const u8 = null,
                        column_group_column_schema_list: ?[]struct {
                            name: ?[]const u8 = null,

                            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                                const mappings = .{
                                    .name = "Name",
                                };
                                return @field(mappings, field_name);
                            }
                        } = null,

                        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                            const mappings = .{
                                .name = "Name",
                                .column_group_column_schema_list = "ColumnGroupColumnSchemaList",
                            };
                            return @field(mappings, field_name);
                        }
                    } = null,

                    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                        const mappings = .{
                            .placeholder = "Placeholder",
                            .data_set_schema = "DataSetSchema",
                            .column_group_schema_list = "ColumnGroupSchemaList",
                        };
                        return @field(mappings, field_name);
                    }
                } = null,
                description: ?[]const u8 = null,
                source_entity_arn: ?[]const u8 = null,
                theme_arn: ?[]const u8 = null,
                sheets: ?[]Sheet = null,

                pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                    const mappings = .{
                        .created_time = "CreatedTime",
                        .errors = "Errors",
                        .version_number = "VersionNumber",
                        .status = "Status",
                        .data_set_configurations = "DataSetConfigurations",
                        .description = "Description",
                        .source_entity_arn = "SourceEntityArn",
                        .theme_arn = "ThemeArn",
                        .sheets = "Sheets",
                    };
                    return @field(mappings, field_name);
                }
            } = null,
            template_id: ?[]const u8 = null,
            last_updated_time: ?i64 = null,
            created_time: ?i64 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .arn = "Arn",
                    .name = "Name",
                    .version = "Version",
                    .template_id = "TemplateId",
                    .last_updated_time = "LastUpdatedTime",
                    .created_time = "CreatedTime",
                };
                return @field(mappings, field_name);
            }
        } = null,
        status: ?i64 = null,
        request_id: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .template = "Template",
                .status = "Status",
                .request_id = "RequestId",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        Conflict,
        InternalFailure,
        InvalidParameterValue,
        ResourceExists,
        ResourceNotFound,
        Throttling,
        UnsupportedUserEdition,
    },
} = .{};
pub const describe_template_alias: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/accounts/{AwsAccountId}/templates/{TemplateId}/aliases/{AliasName}",
        .success_code = 200,
    };

    action_name: []const u8 = "DescribeTemplateAlias",
    Request: type = struct {
        aws_account_id: []const u8,
        template_id: []const u8,
        alias_name: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .aws_account_id = "AwsAccountId",
                .template_id = "TemplateId",
                .alias_name = "AliasName",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(describe_template_alias) } {
            return .{ .service_metadata = service_metadata, .action = describe_template_alias };
        }
    },
    Response: type = struct {
        template_alias: ?TemplateAlias = null,
        status: ?i64 = null,
        request_id: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .template_alias = "TemplateAlias",
                .status = "Status",
                .request_id = "RequestId",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalFailure,
        ResourceNotFound,
        Throttling,
        UnsupportedUserEdition,
    },
} = .{};
pub const describe_template_permissions: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/accounts/{AwsAccountId}/templates/{TemplateId}/permissions",
        .success_code = 200,
    };

    action_name: []const u8 = "DescribeTemplatePermissions",
    Request: type = struct {
        aws_account_id: []const u8,
        template_id: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .aws_account_id = "AwsAccountId",
                .template_id = "TemplateId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(describe_template_permissions) } {
            return .{ .service_metadata = service_metadata, .action = describe_template_permissions };
        }
    },
    Response: type = struct {
        template_id: ?[]const u8 = null,
        template_arn: ?[]const u8 = null,
        permissions: ?[]ResourcePermission = null,
        request_id: ?[]const u8 = null,
        status: ?i64 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .template_id = "TemplateId",
                .template_arn = "TemplateArn",
                .permissions = "Permissions",
                .request_id = "RequestId",
                .status = "Status",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        Conflict,
        InternalFailure,
        InvalidParameterValue,
        ResourceNotFound,
        Throttling,
        UnsupportedUserEdition,
    },
} = .{};
pub const describe_theme: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/accounts/{AwsAccountId}/themes/{ThemeId}",
        .success_code = 200,
    };

    action_name: []const u8 = "DescribeTheme",
    Request: type = struct {
        aws_account_id: []const u8,
        theme_id: []const u8,
        version_number: ?i64 = null,
        alias_name: ?[]const u8 = null,

        pub const http_query = .{
            .version_number = "version-number",
            .alias_name = "alias-name",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .aws_account_id = "AwsAccountId",
                .theme_id = "ThemeId",
                .version_number = "VersionNumber",
                .alias_name = "AliasName",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(describe_theme) } {
            return .{ .service_metadata = service_metadata, .action = describe_theme };
        }
    },
    Response: type = struct {
        theme: ?struct {
            arn: ?[]const u8 = null,
            name: ?[]const u8 = null,
            theme_id: ?[]const u8 = null,
            version: ?struct {
                version_number: ?i64 = null,
                arn: ?[]const u8 = null,
                description: ?[]const u8 = null,
                base_theme_id: ?[]const u8 = null,
                created_time: ?i64 = null,
                configuration: ?ThemeConfiguration = null,
                errors: ?[]struct {
                    type: ?[]const u8 = null,
                    message: ?[]const u8 = null,

                    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                        const mappings = .{
                            .type = "Type",
                            .message = "Message",
                        };
                        return @field(mappings, field_name);
                    }
                } = null,
                status: ?[]const u8 = null,

                pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                    const mappings = .{
                        .version_number = "VersionNumber",
                        .arn = "Arn",
                        .description = "Description",
                        .base_theme_id = "BaseThemeId",
                        .created_time = "CreatedTime",
                        .configuration = "Configuration",
                        .errors = "Errors",
                        .status = "Status",
                    };
                    return @field(mappings, field_name);
                }
            } = null,
            created_time: ?i64 = null,
            last_updated_time: ?i64 = null,
            type: ?[]const u8 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .arn = "Arn",
                    .name = "Name",
                    .theme_id = "ThemeId",
                    .version = "Version",
                    .created_time = "CreatedTime",
                    .last_updated_time = "LastUpdatedTime",
                    .type = "Type",
                };
                return @field(mappings, field_name);
            }
        } = null,
        status: ?i64 = null,
        request_id: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .theme = "Theme",
                .status = "Status",
                .request_id = "RequestId",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        InternalFailure,
        InvalidParameterValue,
        ResourceExists,
        ResourceNotFound,
        Throttling,
        UnsupportedUserEdition,
    },
} = .{};
pub const describe_theme_alias: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/accounts/{AwsAccountId}/themes/{ThemeId}/aliases/{AliasName}",
        .success_code = 200,
    };

    action_name: []const u8 = "DescribeThemeAlias",
    Request: type = struct {
        aws_account_id: []const u8,
        theme_id: []const u8,
        alias_name: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .aws_account_id = "AwsAccountId",
                .theme_id = "ThemeId",
                .alias_name = "AliasName",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(describe_theme_alias) } {
            return .{ .service_metadata = service_metadata, .action = describe_theme_alias };
        }
    },
    Response: type = struct {
        theme_alias: ?ThemeAlias = null,
        status: ?i64 = null,
        request_id: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .theme_alias = "ThemeAlias",
                .status = "Status",
                .request_id = "RequestId",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        Conflict,
        InternalFailure,
        InvalidParameterValue,
        ResourceNotFound,
        Throttling,
        UnsupportedUserEdition,
    },
} = .{};
pub const describe_theme_permissions: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/accounts/{AwsAccountId}/themes/{ThemeId}/permissions",
        .success_code = 200,
    };

    action_name: []const u8 = "DescribeThemePermissions",
    Request: type = struct {
        aws_account_id: []const u8,
        theme_id: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .aws_account_id = "AwsAccountId",
                .theme_id = "ThemeId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(describe_theme_permissions) } {
            return .{ .service_metadata = service_metadata, .action = describe_theme_permissions };
        }
    },
    Response: type = struct {
        theme_id: ?[]const u8 = null,
        theme_arn: ?[]const u8 = null,
        permissions: ?[]ResourcePermission = null,
        request_id: ?[]const u8 = null,
        status: ?i64 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .theme_id = "ThemeId",
                .theme_arn = "ThemeArn",
                .permissions = "Permissions",
                .request_id = "RequestId",
                .status = "Status",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        InternalFailure,
        InvalidParameterValue,
        ResourceNotFound,
        Throttling,
        UnsupportedUserEdition,
    },
} = .{};
pub const describe_user: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/accounts/{AwsAccountId}/namespaces/{Namespace}/users/{UserName}",
        .success_code = 200,
    };

    action_name: []const u8 = "DescribeUser",
    Request: type = struct {
        user_name: []const u8,
        aws_account_id: []const u8,
        namespace: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .user_name = "UserName",
                .aws_account_id = "AwsAccountId",
                .namespace = "Namespace",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(describe_user) } {
            return .{ .service_metadata = service_metadata, .action = describe_user };
        }
    },
    Response: type = struct {
        user: ?User = null,
        request_id: ?[]const u8 = null,
        status: ?i64 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .user = "User",
                .request_id = "RequestId",
                .status = "Status",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        InternalFailure,
        InvalidParameterValue,
        PreconditionNotMet,
        ResourceNotFound,
        ResourceUnavailable,
        Throttling,
    },
} = .{};
pub const get_dashboard_embed_url: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/accounts/{AwsAccountId}/dashboards/{DashboardId}/embed-url",
        .success_code = 200,
    };

    action_name: []const u8 = "GetDashboardEmbedUrl",
    Request: type = struct {
        aws_account_id: []const u8,
        dashboard_id: []const u8,
        identity_type: []const u8,
        session_lifetime_in_minutes: ?i64 = null,
        undo_redo_disabled: ?bool = null,
        reset_disabled: ?bool = null,
        state_persistence_enabled: ?bool = null,
        user_arn: ?[]const u8 = null,
        namespace: ?[]const u8 = null,
        additional_dashboard_ids: ?[][]const u8 = null,

        pub const http_query = .{
            .identity_type = "creds-type",
            .session_lifetime_in_minutes = "session-lifetime",
            .undo_redo_disabled = "undo-redo-disabled",
            .reset_disabled = "reset-disabled",
            .state_persistence_enabled = "state-persistence-enabled",
            .user_arn = "user-arn",
            .namespace = "namespace",
            .additional_dashboard_ids = "additional-dashboard-ids",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .aws_account_id = "AwsAccountId",
                .dashboard_id = "DashboardId",
                .identity_type = "IdentityType",
                .session_lifetime_in_minutes = "SessionLifetimeInMinutes",
                .undo_redo_disabled = "UndoRedoDisabled",
                .reset_disabled = "ResetDisabled",
                .state_persistence_enabled = "StatePersistenceEnabled",
                .user_arn = "UserArn",
                .namespace = "Namespace",
                .additional_dashboard_ids = "AdditionalDashboardIds",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(get_dashboard_embed_url) } {
            return .{ .service_metadata = service_metadata, .action = get_dashboard_embed_url };
        }
    },
    Response: type = struct {
        embed_url: ?[]const u8 = null,
        status: ?i64 = null,
        request_id: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .embed_url = "EmbedUrl",
                .status = "Status",
                .request_id = "RequestId",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        DomainNotWhitelisted,
        IdentityTypeNotSupported,
        InternalFailure,
        InvalidParameterValue,
        QuickSightUserNotFound,
        ResourceExists,
        ResourceNotFound,
        SessionLifetimeInMinutesInvalid,
        Throttling,
        UnsupportedPricingPlan,
        UnsupportedUserEdition,
    },
} = .{};
pub const get_session_embed_url: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/accounts/{AwsAccountId}/session-embed-url",
        .success_code = 200,
    };

    action_name: []const u8 = "GetSessionEmbedUrl",
    Request: type = struct {
        aws_account_id: []const u8,
        entry_point: ?[]const u8 = null,
        session_lifetime_in_minutes: ?i64 = null,
        user_arn: ?[]const u8 = null,

        pub const http_query = .{
            .entry_point = "entry-point",
            .session_lifetime_in_minutes = "session-lifetime",
            .user_arn = "user-arn",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .aws_account_id = "AwsAccountId",
                .entry_point = "EntryPoint",
                .session_lifetime_in_minutes = "SessionLifetimeInMinutes",
                .user_arn = "UserArn",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(get_session_embed_url) } {
            return .{ .service_metadata = service_metadata, .action = get_session_embed_url };
        }
    },
    Response: type = struct {
        embed_url: ?[]const u8 = null,
        status: ?i64 = null,
        request_id: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .embed_url = "EmbedUrl",
                .status = "Status",
                .request_id = "RequestId",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        InternalFailure,
        InvalidParameterValue,
        QuickSightUserNotFound,
        ResourceExists,
        ResourceNotFound,
        SessionLifetimeInMinutesInvalid,
        Throttling,
        UnsupportedUserEdition,
    },
} = .{};
pub const list_analyses: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/accounts/{AwsAccountId}/analyses",
        .success_code = 200,
    };

    action_name: []const u8 = "ListAnalyses",
    Request: type = struct {
        aws_account_id: []const u8,
        next_token: ?[]const u8 = null,
        max_results: ?i64 = null,

        pub const http_query = .{
            .next_token = "next-token",
            .max_results = "max-results",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .aws_account_id = "AwsAccountId",
                .next_token = "NextToken",
                .max_results = "MaxResults",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_analyses) } {
            return .{ .service_metadata = service_metadata, .action = list_analyses };
        }
    },
    Response: type = struct {
        analysis_summary_list: ?[]AnalysisSummary = null,
        next_token: ?[]const u8 = null,
        status: ?i64 = null,
        request_id: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .analysis_summary_list = "AnalysisSummaryList",
                .next_token = "NextToken",
                .status = "Status",
                .request_id = "RequestId",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalFailure,
        InvalidNextToken,
        Throttling,
        UnsupportedUserEdition,
    },
} = .{};
pub const list_dashboards: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/accounts/{AwsAccountId}/dashboards",
        .success_code = 200,
    };

    action_name: []const u8 = "ListDashboards",
    Request: type = struct {
        aws_account_id: []const u8,
        next_token: ?[]const u8 = null,
        max_results: ?i64 = null,

        pub const http_query = .{
            .next_token = "next-token",
            .max_results = "max-results",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .aws_account_id = "AwsAccountId",
                .next_token = "NextToken",
                .max_results = "MaxResults",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_dashboards) } {
            return .{ .service_metadata = service_metadata, .action = list_dashboards };
        }
    },
    Response: type = struct {
        dashboard_summary_list: ?[]DashboardSummary = null,
        next_token: ?[]const u8 = null,
        status: ?i64 = null,
        request_id: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .dashboard_summary_list = "DashboardSummaryList",
                .next_token = "NextToken",
                .status = "Status",
                .request_id = "RequestId",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalFailure,
        InvalidNextToken,
        Throttling,
        UnsupportedUserEdition,
    },
} = .{};
pub const list_dashboard_versions: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/accounts/{AwsAccountId}/dashboards/{DashboardId}/versions",
        .success_code = 200,
    };

    action_name: []const u8 = "ListDashboardVersions",
    Request: type = struct {
        aws_account_id: []const u8,
        dashboard_id: []const u8,
        next_token: ?[]const u8 = null,
        max_results: ?i64 = null,

        pub const http_query = .{
            .next_token = "next-token",
            .max_results = "max-results",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .aws_account_id = "AwsAccountId",
                .dashboard_id = "DashboardId",
                .next_token = "NextToken",
                .max_results = "MaxResults",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_dashboard_versions) } {
            return .{ .service_metadata = service_metadata, .action = list_dashboard_versions };
        }
    },
    Response: type = struct {
        dashboard_version_summary_list: ?[]struct {
            arn: ?[]const u8 = null,
            created_time: ?i64 = null,
            version_number: ?i64 = null,
            status: ?[]const u8 = null,
            source_entity_arn: ?[]const u8 = null,
            description: ?[]const u8 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .arn = "Arn",
                    .created_time = "CreatedTime",
                    .version_number = "VersionNumber",
                    .status = "Status",
                    .source_entity_arn = "SourceEntityArn",
                    .description = "Description",
                };
                return @field(mappings, field_name);
            }
        } = null,
        next_token: ?[]const u8 = null,
        status: ?i64 = null,
        request_id: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .dashboard_version_summary_list = "DashboardVersionSummaryList",
                .next_token = "NextToken",
                .status = "Status",
                .request_id = "RequestId",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalFailure,
        InvalidNextToken,
        InvalidParameterValue,
        ResourceNotFound,
        Throttling,
        UnsupportedUserEdition,
    },
} = .{};
pub const list_data_sets: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/accounts/{AwsAccountId}/data-sets",
        .success_code = 200,
    };

    action_name: []const u8 = "ListDataSets",
    Request: type = struct {
        aws_account_id: []const u8,
        next_token: ?[]const u8 = null,
        max_results: ?i64 = null,

        pub const http_query = .{
            .next_token = "next-token",
            .max_results = "max-results",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .aws_account_id = "AwsAccountId",
                .next_token = "NextToken",
                .max_results = "MaxResults",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_data_sets) } {
            return .{ .service_metadata = service_metadata, .action = list_data_sets };
        }
    },
    Response: type = struct {
        data_set_summaries: ?[]struct {
            arn: ?[]const u8 = null,
            data_set_id: ?[]const u8 = null,
            name: ?[]const u8 = null,
            created_time: ?i64 = null,
            last_updated_time: ?i64 = null,
            import_mode: ?[]const u8 = null,
            row_level_permission_data_set: ?RowLevelPermissionDataSet = null,
            column_level_permission_rules_applied: ?bool = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .arn = "Arn",
                    .data_set_id = "DataSetId",
                    .name = "Name",
                    .created_time = "CreatedTime",
                    .last_updated_time = "LastUpdatedTime",
                    .import_mode = "ImportMode",
                    .row_level_permission_data_set = "RowLevelPermissionDataSet",
                    .column_level_permission_rules_applied = "ColumnLevelPermissionRulesApplied",
                };
                return @field(mappings, field_name);
            }
        } = null,
        next_token: ?[]const u8 = null,
        request_id: ?[]const u8 = null,
        status: ?i64 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .data_set_summaries = "DataSetSummaries",
                .next_token = "NextToken",
                .request_id = "RequestId",
                .status = "Status",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        InternalFailure,
        InvalidNextToken,
        InvalidParameterValue,
        Throttling,
    },
} = .{};
pub const list_data_sources: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/accounts/{AwsAccountId}/data-sources",
        .success_code = 200,
    };

    action_name: []const u8 = "ListDataSources",
    Request: type = struct {
        aws_account_id: []const u8,
        next_token: ?[]const u8 = null,
        max_results: ?i64 = null,

        pub const http_query = .{
            .next_token = "next-token",
            .max_results = "max-results",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .aws_account_id = "AwsAccountId",
                .next_token = "NextToken",
                .max_results = "MaxResults",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_data_sources) } {
            return .{ .service_metadata = service_metadata, .action = list_data_sources };
        }
    },
    Response: type = struct {
        data_sources: ?[]DataSource = null,
        next_token: ?[]const u8 = null,
        request_id: ?[]const u8 = null,
        status: ?i64 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .data_sources = "DataSources",
                .next_token = "NextToken",
                .request_id = "RequestId",
                .status = "Status",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        InternalFailure,
        InvalidNextToken,
        InvalidParameterValue,
        Throttling,
    },
} = .{};
pub const list_group_memberships: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/accounts/{AwsAccountId}/namespaces/{Namespace}/groups/{GroupName}/members",
        .success_code = 200,
    };

    action_name: []const u8 = "ListGroupMemberships",
    Request: type = struct {
        group_name: []const u8,
        next_token: ?[]const u8 = null,
        max_results: ?i64 = null,
        aws_account_id: []const u8,
        namespace: []const u8,

        pub const http_query = .{
            .next_token = "next-token",
            .max_results = "max-results",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .group_name = "GroupName",
                .next_token = "NextToken",
                .max_results = "MaxResults",
                .aws_account_id = "AwsAccountId",
                .namespace = "Namespace",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_group_memberships) } {
            return .{ .service_metadata = service_metadata, .action = list_group_memberships };
        }
    },
    Response: type = struct {
        group_member_list: ?[]GroupMember = null,
        next_token: ?[]const u8 = null,
        request_id: ?[]const u8 = null,
        status: ?i64 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .group_member_list = "GroupMemberList",
                .next_token = "NextToken",
                .request_id = "RequestId",
                .status = "Status",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        InternalFailure,
        InvalidNextToken,
        InvalidParameterValue,
        PreconditionNotMet,
        ResourceNotFound,
        ResourceUnavailable,
        Throttling,
    },
} = .{};
pub const list_groups: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/accounts/{AwsAccountId}/namespaces/{Namespace}/groups",
        .success_code = 200,
    };

    action_name: []const u8 = "ListGroups",
    Request: type = struct {
        aws_account_id: []const u8,
        next_token: ?[]const u8 = null,
        max_results: ?i64 = null,
        namespace: []const u8,

        pub const http_query = .{
            .next_token = "next-token",
            .max_results = "max-results",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .aws_account_id = "AwsAccountId",
                .next_token = "NextToken",
                .max_results = "MaxResults",
                .namespace = "Namespace",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_groups) } {
            return .{ .service_metadata = service_metadata, .action = list_groups };
        }
    },
    Response: type = struct {
        group_list: ?[]Group = null,
        next_token: ?[]const u8 = null,
        request_id: ?[]const u8 = null,
        status: ?i64 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .group_list = "GroupList",
                .next_token = "NextToken",
                .request_id = "RequestId",
                .status = "Status",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        InternalFailure,
        InvalidNextToken,
        InvalidParameterValue,
        PreconditionNotMet,
        ResourceNotFound,
        ResourceUnavailable,
        Throttling,
    },
} = .{};
pub const list_iam_policy_assignments: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/accounts/{AwsAccountId}/namespaces/{Namespace}/iam-policy-assignments",
        .success_code = 200,
    };

    action_name: []const u8 = "ListIAMPolicyAssignments",
    Request: type = struct {
        aws_account_id: []const u8,
        assignment_status: ?[]const u8 = null,
        namespace: []const u8,
        next_token: ?[]const u8 = null,
        max_results: ?i64 = null,

        pub const http_query = .{
            .next_token = "next-token",
            .max_results = "max-results",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .aws_account_id = "AwsAccountId",
                .assignment_status = "AssignmentStatus",
                .namespace = "Namespace",
                .next_token = "NextToken",
                .max_results = "MaxResults",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_iam_policy_assignments) } {
            return .{ .service_metadata = service_metadata, .action = list_iam_policy_assignments };
        }
    },
    Response: type = struct {
        iam_policy_assignments: ?[]struct {
            assignment_name: ?[]const u8 = null,
            assignment_status: ?[]const u8 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .assignment_name = "AssignmentName",
                    .assignment_status = "AssignmentStatus",
                };
                return @field(mappings, field_name);
            }
        } = null,
        next_token: ?[]const u8 = null,
        request_id: ?[]const u8 = null,
        status: ?i64 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .iam_policy_assignments = "IAMPolicyAssignments",
                .next_token = "NextToken",
                .request_id = "RequestId",
                .status = "Status",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        InternalFailure,
        InvalidNextToken,
        InvalidParameterValue,
        ResourceNotFound,
        Throttling,
    },
} = .{};
pub const list_iam_policy_assignments_for_user: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/accounts/{AwsAccountId}/namespaces/{Namespace}/users/{UserName}/iam-policy-assignments",
        .success_code = 200,
    };

    action_name: []const u8 = "ListIAMPolicyAssignmentsForUser",
    Request: type = struct {
        aws_account_id: []const u8,
        user_name: []const u8,
        next_token: ?[]const u8 = null,
        max_results: ?i64 = null,
        namespace: []const u8,

        pub const http_query = .{
            .next_token = "next-token",
            .max_results = "max-results",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .aws_account_id = "AwsAccountId",
                .user_name = "UserName",
                .next_token = "NextToken",
                .max_results = "MaxResults",
                .namespace = "Namespace",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_iam_policy_assignments_for_user) } {
            return .{ .service_metadata = service_metadata, .action = list_iam_policy_assignments_for_user };
        }
    },
    Response: type = struct {
        active_assignments: ?[]struct {
            assignment_name: ?[]const u8 = null,
            policy_arn: ?[]const u8 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .assignment_name = "AssignmentName",
                    .policy_arn = "PolicyArn",
                };
                return @field(mappings, field_name);
            }
        } = null,
        request_id: ?[]const u8 = null,
        next_token: ?[]const u8 = null,
        status: ?i64 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .active_assignments = "ActiveAssignments",
                .request_id = "RequestId",
                .next_token = "NextToken",
                .status = "Status",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        ConcurrentUpdating,
        InternalFailure,
        InvalidParameterValue,
        ResourceExists,
        ResourceNotFound,
        Throttling,
    },
} = .{};
pub const list_ingestions: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/accounts/{AwsAccountId}/data-sets/{DataSetId}/ingestions",
        .success_code = 200,
    };

    action_name: []const u8 = "ListIngestions",
    Request: type = struct {
        data_set_id: []const u8,
        next_token: ?[]const u8 = null,
        aws_account_id: []const u8,
        max_results: ?i64 = null,

        pub const http_query = .{
            .next_token = "next-token",
            .max_results = "max-results",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .data_set_id = "DataSetId",
                .next_token = "NextToken",
                .aws_account_id = "AwsAccountId",
                .max_results = "MaxResults",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_ingestions) } {
            return .{ .service_metadata = service_metadata, .action = list_ingestions };
        }
    },
    Response: type = struct {
        ingestions: ?[]Ingestion = null,
        next_token: ?[]const u8 = null,
        request_id: ?[]const u8 = null,
        status: ?i64 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .ingestions = "Ingestions",
                .next_token = "NextToken",
                .request_id = "RequestId",
                .status = "Status",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        InternalFailure,
        InvalidNextToken,
        InvalidParameterValue,
        ResourceExists,
        ResourceNotFound,
        Throttling,
    },
} = .{};
pub const list_namespaces: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/accounts/{AwsAccountId}/namespaces",
        .success_code = 200,
    };

    action_name: []const u8 = "ListNamespaces",
    Request: type = struct {
        aws_account_id: []const u8,
        next_token: ?[]const u8 = null,
        max_results: ?i64 = null,

        pub const http_query = .{
            .next_token = "next-token",
            .max_results = "max-results",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .aws_account_id = "AwsAccountId",
                .next_token = "NextToken",
                .max_results = "MaxResults",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_namespaces) } {
            return .{ .service_metadata = service_metadata, .action = list_namespaces };
        }
    },
    Response: type = struct {
        namespaces: ?[]NamespaceInfoV2 = null,
        next_token: ?[]const u8 = null,
        request_id: ?[]const u8 = null,
        status: ?i64 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .namespaces = "Namespaces",
                .next_token = "NextToken",
                .request_id = "RequestId",
                .status = "Status",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        InternalFailure,
        InvalidNextToken,
        InvalidParameterValue,
        PreconditionNotMet,
        ResourceNotFound,
        ResourceUnavailable,
        Throttling,
    },
} = .{};
pub const list_tags_for_resource: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/resources/{ResourceArn}/tags",
        .success_code = 200,
    };

    action_name: []const u8 = "ListTagsForResource",
    Request: type = struct {
        resource_arn: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .resource_arn = "ResourceArn",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_tags_for_resource) } {
            return .{ .service_metadata = service_metadata, .action = list_tags_for_resource };
        }
    },
    Response: type = struct {
        tags: ?[]Tag = null,
        request_id: ?[]const u8 = null,
        status: ?i64 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .tags = "Tags",
                .request_id = "RequestId",
                .status = "Status",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        InternalFailure,
        InvalidParameterValue,
        ResourceNotFound,
        Throttling,
    },
} = .{};
pub const list_template_aliases: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/accounts/{AwsAccountId}/templates/{TemplateId}/aliases",
        .success_code = 200,
    };

    action_name: []const u8 = "ListTemplateAliases",
    Request: type = struct {
        aws_account_id: []const u8,
        template_id: []const u8,
        next_token: ?[]const u8 = null,
        max_results: ?i64 = null,

        pub const http_query = .{
            .next_token = "next-token",
            .max_results = "max-result",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .aws_account_id = "AwsAccountId",
                .template_id = "TemplateId",
                .next_token = "NextToken",
                .max_results = "MaxResults",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_template_aliases) } {
            return .{ .service_metadata = service_metadata, .action = list_template_aliases };
        }
    },
    Response: type = struct {
        template_alias_list: ?[]TemplateAlias = null,
        status: ?i64 = null,
        request_id: ?[]const u8 = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .template_alias_list = "TemplateAliasList",
                .status = "Status",
                .request_id = "RequestId",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalFailure,
        InvalidNextToken,
        ResourceNotFound,
        Throttling,
        UnsupportedUserEdition,
    },
} = .{};
pub const list_templates: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/accounts/{AwsAccountId}/templates",
        .success_code = 200,
    };

    action_name: []const u8 = "ListTemplates",
    Request: type = struct {
        aws_account_id: []const u8,
        next_token: ?[]const u8 = null,
        max_results: ?i64 = null,

        pub const http_query = .{
            .next_token = "next-token",
            .max_results = "max-result",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .aws_account_id = "AwsAccountId",
                .next_token = "NextToken",
                .max_results = "MaxResults",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_templates) } {
            return .{ .service_metadata = service_metadata, .action = list_templates };
        }
    },
    Response: type = struct {
        template_summary_list: ?[]struct {
            arn: ?[]const u8 = null,
            template_id: ?[]const u8 = null,
            name: ?[]const u8 = null,
            latest_version_number: ?i64 = null,
            created_time: ?i64 = null,
            last_updated_time: ?i64 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .arn = "Arn",
                    .template_id = "TemplateId",
                    .name = "Name",
                    .latest_version_number = "LatestVersionNumber",
                    .created_time = "CreatedTime",
                    .last_updated_time = "LastUpdatedTime",
                };
                return @field(mappings, field_name);
            }
        } = null,
        next_token: ?[]const u8 = null,
        status: ?i64 = null,
        request_id: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .template_summary_list = "TemplateSummaryList",
                .next_token = "NextToken",
                .status = "Status",
                .request_id = "RequestId",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalFailure,
        InvalidNextToken,
        InvalidParameterValue,
        ResourceNotFound,
        Throttling,
        UnsupportedUserEdition,
    },
} = .{};
pub const list_template_versions: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/accounts/{AwsAccountId}/templates/{TemplateId}/versions",
        .success_code = 200,
    };

    action_name: []const u8 = "ListTemplateVersions",
    Request: type = struct {
        aws_account_id: []const u8,
        template_id: []const u8,
        next_token: ?[]const u8 = null,
        max_results: ?i64 = null,

        pub const http_query = .{
            .next_token = "next-token",
            .max_results = "max-results",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .aws_account_id = "AwsAccountId",
                .template_id = "TemplateId",
                .next_token = "NextToken",
                .max_results = "MaxResults",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_template_versions) } {
            return .{ .service_metadata = service_metadata, .action = list_template_versions };
        }
    },
    Response: type = struct {
        template_version_summary_list: ?[]struct {
            arn: ?[]const u8 = null,
            version_number: ?i64 = null,
            created_time: ?i64 = null,
            status: ?[]const u8 = null,
            description: ?[]const u8 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .arn = "Arn",
                    .version_number = "VersionNumber",
                    .created_time = "CreatedTime",
                    .status = "Status",
                    .description = "Description",
                };
                return @field(mappings, field_name);
            }
        } = null,
        next_token: ?[]const u8 = null,
        status: ?i64 = null,
        request_id: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .template_version_summary_list = "TemplateVersionSummaryList",
                .next_token = "NextToken",
                .status = "Status",
                .request_id = "RequestId",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalFailure,
        InvalidNextToken,
        InvalidParameterValue,
        ResourceNotFound,
        Throttling,
        UnsupportedUserEdition,
    },
} = .{};
pub const list_theme_aliases: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/accounts/{AwsAccountId}/themes/{ThemeId}/aliases",
        .success_code = 200,
    };

    action_name: []const u8 = "ListThemeAliases",
    Request: type = struct {
        aws_account_id: []const u8,
        theme_id: []const u8,
        next_token: ?[]const u8 = null,
        max_results: ?i64 = null,

        pub const http_query = .{
            .next_token = "next-token",
            .max_results = "max-result",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .aws_account_id = "AwsAccountId",
                .theme_id = "ThemeId",
                .next_token = "NextToken",
                .max_results = "MaxResults",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_theme_aliases) } {
            return .{ .service_metadata = service_metadata, .action = list_theme_aliases };
        }
    },
    Response: type = struct {
        theme_alias_list: ?[]ThemeAlias = null,
        status: ?i64 = null,
        request_id: ?[]const u8 = null,
        next_token: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .theme_alias_list = "ThemeAliasList",
                .status = "Status",
                .request_id = "RequestId",
                .next_token = "NextToken",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        Conflict,
        InternalFailure,
        InvalidNextToken,
        InvalidParameterValue,
        ResourceNotFound,
        Throttling,
        UnsupportedUserEdition,
    },
} = .{};
pub const list_themes: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/accounts/{AwsAccountId}/themes",
        .success_code = 200,
    };

    action_name: []const u8 = "ListThemes",
    Request: type = struct {
        aws_account_id: []const u8,
        next_token: ?[]const u8 = null,
        max_results: ?i64 = null,
        type: ?[]const u8 = null,

        pub const http_query = .{
            .next_token = "next-token",
            .max_results = "max-results",
            .type = "type",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .aws_account_id = "AwsAccountId",
                .next_token = "NextToken",
                .max_results = "MaxResults",
                .type = "Type",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_themes) } {
            return .{ .service_metadata = service_metadata, .action = list_themes };
        }
    },
    Response: type = struct {
        theme_summary_list: ?[]struct {
            arn: ?[]const u8 = null,
            name: ?[]const u8 = null,
            theme_id: ?[]const u8 = null,
            latest_version_number: ?i64 = null,
            created_time: ?i64 = null,
            last_updated_time: ?i64 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .arn = "Arn",
                    .name = "Name",
                    .theme_id = "ThemeId",
                    .latest_version_number = "LatestVersionNumber",
                    .created_time = "CreatedTime",
                    .last_updated_time = "LastUpdatedTime",
                };
                return @field(mappings, field_name);
            }
        } = null,
        next_token: ?[]const u8 = null,
        status: ?i64 = null,
        request_id: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .theme_summary_list = "ThemeSummaryList",
                .next_token = "NextToken",
                .status = "Status",
                .request_id = "RequestId",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        InternalFailure,
        InvalidNextToken,
        InvalidParameterValue,
        ResourceNotFound,
        Throttling,
        UnsupportedUserEdition,
    },
} = .{};
pub const list_theme_versions: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/accounts/{AwsAccountId}/themes/{ThemeId}/versions",
        .success_code = 200,
    };

    action_name: []const u8 = "ListThemeVersions",
    Request: type = struct {
        aws_account_id: []const u8,
        theme_id: []const u8,
        next_token: ?[]const u8 = null,
        max_results: ?i64 = null,

        pub const http_query = .{
            .next_token = "next-token",
            .max_results = "max-results",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .aws_account_id = "AwsAccountId",
                .theme_id = "ThemeId",
                .next_token = "NextToken",
                .max_results = "MaxResults",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_theme_versions) } {
            return .{ .service_metadata = service_metadata, .action = list_theme_versions };
        }
    },
    Response: type = struct {
        theme_version_summary_list: ?[]struct {
            version_number: ?i64 = null,
            arn: ?[]const u8 = null,
            description: ?[]const u8 = null,
            created_time: ?i64 = null,
            status: ?[]const u8 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .version_number = "VersionNumber",
                    .arn = "Arn",
                    .description = "Description",
                    .created_time = "CreatedTime",
                    .status = "Status",
                };
                return @field(mappings, field_name);
            }
        } = null,
        next_token: ?[]const u8 = null,
        status: ?i64 = null,
        request_id: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .theme_version_summary_list = "ThemeVersionSummaryList",
                .next_token = "NextToken",
                .status = "Status",
                .request_id = "RequestId",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        InternalFailure,
        InvalidNextToken,
        InvalidParameterValue,
        ResourceNotFound,
        Throttling,
        UnsupportedUserEdition,
    },
} = .{};
pub const list_user_groups: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/accounts/{AwsAccountId}/namespaces/{Namespace}/users/{UserName}/groups",
        .success_code = 200,
    };

    action_name: []const u8 = "ListUserGroups",
    Request: type = struct {
        user_name: []const u8,
        aws_account_id: []const u8,
        namespace: []const u8,
        next_token: ?[]const u8 = null,
        max_results: ?i64 = null,

        pub const http_query = .{
            .next_token = "next-token",
            .max_results = "max-results",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .user_name = "UserName",
                .aws_account_id = "AwsAccountId",
                .namespace = "Namespace",
                .next_token = "NextToken",
                .max_results = "MaxResults",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_user_groups) } {
            return .{ .service_metadata = service_metadata, .action = list_user_groups };
        }
    },
    Response: type = struct {
        group_list: ?[]Group = null,
        next_token: ?[]const u8 = null,
        request_id: ?[]const u8 = null,
        status: ?i64 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .group_list = "GroupList",
                .next_token = "NextToken",
                .request_id = "RequestId",
                .status = "Status",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        InternalFailure,
        InvalidParameterValue,
        PreconditionNotMet,
        ResourceNotFound,
        ResourceUnavailable,
        Throttling,
    },
} = .{};
pub const list_users: struct {
    pub const http_config = .{
        .method = "GET",
        .uri = "/accounts/{AwsAccountId}/namespaces/{Namespace}/users",
        .success_code = 200,
    };

    action_name: []const u8 = "ListUsers",
    Request: type = struct {
        aws_account_id: []const u8,
        next_token: ?[]const u8 = null,
        max_results: ?i64 = null,
        namespace: []const u8,

        pub const http_query = .{
            .next_token = "next-token",
            .max_results = "max-results",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .aws_account_id = "AwsAccountId",
                .next_token = "NextToken",
                .max_results = "MaxResults",
                .namespace = "Namespace",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(list_users) } {
            return .{ .service_metadata = service_metadata, .action = list_users };
        }
    },
    Response: type = struct {
        user_list: ?[]User = null,
        next_token: ?[]const u8 = null,
        request_id: ?[]const u8 = null,
        status: ?i64 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .user_list = "UserList",
                .next_token = "NextToken",
                .request_id = "RequestId",
                .status = "Status",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        InternalFailure,
        InvalidNextToken,
        InvalidParameterValue,
        PreconditionNotMet,
        ResourceNotFound,
        ResourceUnavailable,
        Throttling,
    },
} = .{};
pub const register_user: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/accounts/{AwsAccountId}/namespaces/{Namespace}/users",
        .success_code = 200,
    };

    action_name: []const u8 = "RegisterUser",
    Request: type = struct {
        identity_type: []const u8,
        email: []const u8,
        user_role: []const u8,
        iam_arn: ?[]const u8 = null,
        session_name: ?[]const u8 = null,
        aws_account_id: []const u8,
        namespace: []const u8,
        user_name: ?[]const u8 = null,
        custom_permissions_name: ?[]const u8 = null,
        external_login_federation_provider_type: ?[]const u8 = null,
        custom_federation_provider_url: ?[]const u8 = null,
        external_login_id: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .identity_type = "IdentityType",
                .email = "Email",
                .user_role = "UserRole",
                .iam_arn = "IamArn",
                .session_name = "SessionName",
                .aws_account_id = "AwsAccountId",
                .namespace = "Namespace",
                .user_name = "UserName",
                .custom_permissions_name = "CustomPermissionsName",
                .external_login_federation_provider_type = "ExternalLoginFederationProviderType",
                .custom_federation_provider_url = "CustomFederationProviderUrl",
                .external_login_id = "ExternalLoginId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(register_user) } {
            return .{ .service_metadata = service_metadata, .action = register_user };
        }
    },
    Response: type = struct {
        user: ?User = null,
        user_invitation_url: ?[]const u8 = null,
        request_id: ?[]const u8 = null,
        status: ?i64 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .user = "User",
                .user_invitation_url = "UserInvitationUrl",
                .request_id = "RequestId",
                .status = "Status",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        InternalFailure,
        InvalidParameterValue,
        LimitExceeded,
        PreconditionNotMet,
        ResourceExists,
        ResourceNotFound,
        ResourceUnavailable,
        Throttling,
    },
} = .{};
pub const restore_analysis: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/accounts/{AwsAccountId}/restore/analyses/{AnalysisId}",
        .success_code = 200,
    };

    action_name: []const u8 = "RestoreAnalysis",
    Request: type = struct {
        aws_account_id: []const u8,
        analysis_id: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .aws_account_id = "AwsAccountId",
                .analysis_id = "AnalysisId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(restore_analysis) } {
            return .{ .service_metadata = service_metadata, .action = restore_analysis };
        }
    },
    Response: type = struct {
        status: ?i64 = null,
        arn: ?[]const u8 = null,
        analysis_id: ?[]const u8 = null,
        request_id: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .status = "Status",
                .arn = "Arn",
                .analysis_id = "AnalysisId",
                .request_id = "RequestId",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        Conflict,
        InternalFailure,
        InvalidParameterValue,
        ResourceNotFound,
        Throttling,
        UnsupportedUserEdition,
    },
} = .{};
pub const search_analyses: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/accounts/{AwsAccountId}/search/analyses",
        .success_code = 200,
    };

    action_name: []const u8 = "SearchAnalyses",
    Request: type = struct {
        aws_account_id: []const u8,
        filters: []struct {
            operator: ?[]const u8 = null,
            name: ?[]const u8 = null,
            value: ?[]const u8 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .operator = "Operator",
                    .name = "Name",
                    .value = "Value",
                };
                return @field(mappings, field_name);
            }
        },
        next_token: ?[]const u8 = null,
        max_results: ?i64 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .aws_account_id = "AwsAccountId",
                .filters = "Filters",
                .next_token = "NextToken",
                .max_results = "MaxResults",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(search_analyses) } {
            return .{ .service_metadata = service_metadata, .action = search_analyses };
        }
    },
    Response: type = struct {
        analysis_summary_list: ?[]AnalysisSummary = null,
        next_token: ?[]const u8 = null,
        status: ?i64 = null,
        request_id: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .analysis_summary_list = "AnalysisSummaryList",
                .next_token = "NextToken",
                .status = "Status",
                .request_id = "RequestId",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalFailure,
        InvalidNextToken,
        InvalidParameterValue,
        ResourceNotFound,
        Throttling,
        UnsupportedUserEdition,
    },
} = .{};
pub const search_dashboards: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/accounts/{AwsAccountId}/search/dashboards",
        .success_code = 200,
    };

    action_name: []const u8 = "SearchDashboards",
    Request: type = struct {
        aws_account_id: []const u8,
        filters: []struct {
            operator: []const u8,
            name: ?[]const u8 = null,
            value: ?[]const u8 = null,

            pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
                const mappings = .{
                    .operator = "Operator",
                    .name = "Name",
                    .value = "Value",
                };
                return @field(mappings, field_name);
            }
        },
        next_token: ?[]const u8 = null,
        max_results: ?i64 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .aws_account_id = "AwsAccountId",
                .filters = "Filters",
                .next_token = "NextToken",
                .max_results = "MaxResults",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(search_dashboards) } {
            return .{ .service_metadata = service_metadata, .action = search_dashboards };
        }
    },
    Response: type = struct {
        dashboard_summary_list: ?[]DashboardSummary = null,
        next_token: ?[]const u8 = null,
        status: ?i64 = null,
        request_id: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .dashboard_summary_list = "DashboardSummaryList",
                .next_token = "NextToken",
                .status = "Status",
                .request_id = "RequestId",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        InternalFailure,
        InvalidNextToken,
        InvalidParameterValue,
        ResourceNotFound,
        Throttling,
        UnsupportedUserEdition,
    },
} = .{};
pub const tag_resource: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/resources/{ResourceArn}/tags",
        .success_code = 200,
    };

    action_name: []const u8 = "TagResource",
    Request: type = struct {
        resource_arn: []const u8,
        tags: []Tag,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .resource_arn = "ResourceArn",
                .tags = "Tags",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(tag_resource) } {
            return .{ .service_metadata = service_metadata, .action = tag_resource };
        }
    },
    Response: type = struct {
        request_id: ?[]const u8 = null,
        status: ?i64 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .request_id = "RequestId",
                .status = "Status",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        InternalFailure,
        InvalidParameterValue,
        LimitExceeded,
        ResourceNotFound,
        Throttling,
    },
} = .{};
pub const untag_resource: struct {
    pub const http_config = .{
        .method = "DELETE",
        .uri = "/resources/{ResourceArn}/tags",
        .success_code = 200,
    };

    action_name: []const u8 = "UntagResource",
    Request: type = struct {
        resource_arn: []const u8,
        tag_keys: [][]const u8,

        pub const http_query = .{
            .tag_keys = "keys",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .resource_arn = "ResourceArn",
                .tag_keys = "TagKeys",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(untag_resource) } {
            return .{ .service_metadata = service_metadata, .action = untag_resource };
        }
    },
    Response: type = struct {
        request_id: ?[]const u8 = null,
        status: ?i64 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .request_id = "RequestId",
                .status = "Status",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        InternalFailure,
        InvalidParameterValue,
        ResourceNotFound,
        Throttling,
    },
} = .{};
pub const update_account_customization: struct {
    pub const http_config = .{
        .method = "PUT",
        .uri = "/accounts/{AwsAccountId}/customizations",
        .success_code = 200,
    };

    action_name: []const u8 = "UpdateAccountCustomization",
    Request: type = struct {
        aws_account_id: []const u8,
        namespace: ?[]const u8 = null,
        account_customization: AccountCustomization,

        pub const http_query = .{
            .namespace = "namespace",
        };

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .aws_account_id = "AwsAccountId",
                .namespace = "Namespace",
                .account_customization = "AccountCustomization",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(update_account_customization) } {
            return .{ .service_metadata = service_metadata, .action = update_account_customization };
        }
    },
    Response: type = struct {
        arn: ?[]const u8 = null,
        aws_account_id: ?[]const u8 = null,
        namespace: ?[]const u8 = null,
        account_customization: ?AccountCustomization = null,
        request_id: ?[]const u8 = null,
        status: ?i64 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .arn = "Arn",
                .aws_account_id = "AwsAccountId",
                .namespace = "Namespace",
                .account_customization = "AccountCustomization",
                .request_id = "RequestId",
                .status = "Status",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        InternalFailure,
        InvalidParameterValue,
        ResourceNotFound,
        ResourceUnavailable,
        Throttling,
    },
} = .{};
pub const update_account_settings: struct {
    pub const http_config = .{
        .method = "PUT",
        .uri = "/accounts/{AwsAccountId}/settings",
        .success_code = 200,
    };

    action_name: []const u8 = "UpdateAccountSettings",
    Request: type = struct {
        aws_account_id: []const u8,
        default_namespace: []const u8,
        notification_email: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .aws_account_id = "AwsAccountId",
                .default_namespace = "DefaultNamespace",
                .notification_email = "NotificationEmail",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(update_account_settings) } {
            return .{ .service_metadata = service_metadata, .action = update_account_settings };
        }
    },
    Response: type = struct {
        request_id: ?[]const u8 = null,
        status: ?i64 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .request_id = "RequestId",
                .status = "Status",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        InternalFailure,
        InvalidParameterValue,
        ResourceNotFound,
        ResourceUnavailable,
        Throttling,
    },
} = .{};
pub const update_analysis: struct {
    pub const http_config = .{
        .method = "PUT",
        .uri = "/accounts/{AwsAccountId}/analyses/{AnalysisId}",
        .success_code = 200,
    };

    action_name: []const u8 = "UpdateAnalysis",
    Request: type = struct {
        aws_account_id: []const u8,
        analysis_id: []const u8,
        name: []const u8,
        parameters: ?Parameters = null,
        source_entity: AnalysisSourceEntity,
        theme_arn: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .aws_account_id = "AwsAccountId",
                .analysis_id = "AnalysisId",
                .name = "Name",
                .parameters = "Parameters",
                .source_entity = "SourceEntity",
                .theme_arn = "ThemeArn",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(update_analysis) } {
            return .{ .service_metadata = service_metadata, .action = update_analysis };
        }
    },
    Response: type = struct {
        arn: ?[]const u8 = null,
        analysis_id: ?[]const u8 = null,
        update_status: ?[]const u8 = null,
        status: ?i64 = null,
        request_id: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .arn = "Arn",
                .analysis_id = "AnalysisId",
                .update_status = "UpdateStatus",
                .status = "Status",
                .request_id = "RequestId",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        Conflict,
        InternalFailure,
        InvalidParameterValue,
        ResourceExists,
        ResourceNotFound,
        Throttling,
        UnsupportedUserEdition,
    },
} = .{};
pub const update_analysis_permissions: struct {
    pub const http_config = .{
        .method = "PUT",
        .uri = "/accounts/{AwsAccountId}/analyses/{AnalysisId}/permissions",
        .success_code = 200,
    };

    action_name: []const u8 = "UpdateAnalysisPermissions",
    Request: type = struct {
        aws_account_id: []const u8,
        analysis_id: []const u8,
        grant_permissions: ?[]ResourcePermission = null,
        revoke_permissions: ?[]ResourcePermission = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .aws_account_id = "AwsAccountId",
                .analysis_id = "AnalysisId",
                .grant_permissions = "GrantPermissions",
                .revoke_permissions = "RevokePermissions",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(update_analysis_permissions) } {
            return .{ .service_metadata = service_metadata, .action = update_analysis_permissions };
        }
    },
    Response: type = struct {
        analysis_arn: ?[]const u8 = null,
        analysis_id: ?[]const u8 = null,
        permissions: ?[]ResourcePermission = null,
        request_id: ?[]const u8 = null,
        status: ?i64 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .analysis_arn = "AnalysisArn",
                .analysis_id = "AnalysisId",
                .permissions = "Permissions",
                .request_id = "RequestId",
                .status = "Status",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        Conflict,
        InternalFailure,
        InvalidParameterValue,
        ResourceNotFound,
        Throttling,
        UnsupportedUserEdition,
    },
} = .{};
pub const update_dashboard: struct {
    pub const http_config = .{
        .method = "PUT",
        .uri = "/accounts/{AwsAccountId}/dashboards/{DashboardId}",
        .success_code = 200,
    };

    action_name: []const u8 = "UpdateDashboard",
    Request: type = struct {
        aws_account_id: []const u8,
        dashboard_id: []const u8,
        name: []const u8,
        source_entity: DashboardSourceEntity,
        parameters: ?Parameters = null,
        version_description: ?[]const u8 = null,
        dashboard_publish_options: ?DashboardPublishOptions = null,
        theme_arn: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .aws_account_id = "AwsAccountId",
                .dashboard_id = "DashboardId",
                .name = "Name",
                .source_entity = "SourceEntity",
                .parameters = "Parameters",
                .version_description = "VersionDescription",
                .dashboard_publish_options = "DashboardPublishOptions",
                .theme_arn = "ThemeArn",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(update_dashboard) } {
            return .{ .service_metadata = service_metadata, .action = update_dashboard };
        }
    },
    Response: type = struct {
        arn: ?[]const u8 = null,
        version_arn: ?[]const u8 = null,
        dashboard_id: ?[]const u8 = null,
        creation_status: ?[]const u8 = null,
        status: ?i64 = null,
        request_id: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .arn = "Arn",
                .version_arn = "VersionArn",
                .dashboard_id = "DashboardId",
                .creation_status = "CreationStatus",
                .status = "Status",
                .request_id = "RequestId",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        Conflict,
        InternalFailure,
        InvalidParameterValue,
        LimitExceeded,
        ResourceNotFound,
        Throttling,
        UnsupportedUserEdition,
    },
} = .{};
pub const update_dashboard_permissions: struct {
    pub const http_config = .{
        .method = "PUT",
        .uri = "/accounts/{AwsAccountId}/dashboards/{DashboardId}/permissions",
        .success_code = 200,
    };

    action_name: []const u8 = "UpdateDashboardPermissions",
    Request: type = struct {
        aws_account_id: []const u8,
        dashboard_id: []const u8,
        grant_permissions: ?[]ResourcePermission = null,
        revoke_permissions: ?[]ResourcePermission = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .aws_account_id = "AwsAccountId",
                .dashboard_id = "DashboardId",
                .grant_permissions = "GrantPermissions",
                .revoke_permissions = "RevokePermissions",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(update_dashboard_permissions) } {
            return .{ .service_metadata = service_metadata, .action = update_dashboard_permissions };
        }
    },
    Response: type = struct {
        dashboard_arn: ?[]const u8 = null,
        dashboard_id: ?[]const u8 = null,
        permissions: ?[]ResourcePermission = null,
        request_id: ?[]const u8 = null,
        status: ?i64 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .dashboard_arn = "DashboardArn",
                .dashboard_id = "DashboardId",
                .permissions = "Permissions",
                .request_id = "RequestId",
                .status = "Status",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        Conflict,
        InternalFailure,
        InvalidParameterValue,
        ResourceNotFound,
        Throttling,
        UnsupportedUserEdition,
    },
} = .{};
pub const update_dashboard_published_version: struct {
    pub const http_config = .{
        .method = "PUT",
        .uri = "/accounts/{AwsAccountId}/dashboards/{DashboardId}/versions/{VersionNumber}",
        .success_code = 200,
    };

    action_name: []const u8 = "UpdateDashboardPublishedVersion",
    Request: type = struct {
        aws_account_id: []const u8,
        dashboard_id: []const u8,
        version_number: i64,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .aws_account_id = "AwsAccountId",
                .dashboard_id = "DashboardId",
                .version_number = "VersionNumber",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(update_dashboard_published_version) } {
            return .{ .service_metadata = service_metadata, .action = update_dashboard_published_version };
        }
    },
    Response: type = struct {
        dashboard_id: ?[]const u8 = null,
        dashboard_arn: ?[]const u8 = null,
        status: ?i64 = null,
        request_id: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .dashboard_id = "DashboardId",
                .dashboard_arn = "DashboardArn",
                .status = "Status",
                .request_id = "RequestId",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        Conflict,
        InternalFailure,
        InvalidParameterValue,
        ResourceNotFound,
        Throttling,
        UnsupportedUserEdition,
    },
} = .{};
pub const update_data_set: struct {
    pub const http_config = .{
        .method = "PUT",
        .uri = "/accounts/{AwsAccountId}/data-sets/{DataSetId}",
        .success_code = 200,
    };

    action_name: []const u8 = "UpdateDataSet",
    Request: type = struct {
        aws_account_id: []const u8,
        data_set_id: []const u8,
        name: []const u8,
        physical_table_map: []struct {
            key: ?[]const u8 = null,
            value: ?PhysicalTable = null,
        },
        logical_table_map: ?[]struct {
            key: ?[]const u8 = null,
            value: ?LogicalTable = null,
        } = null,
        import_mode: []const u8,
        column_groups: ?[]ColumnGroup = null,
        field_folders: ?[]struct {
            key: ?[]const u8 = null,
            value: ?FieldFolder = null,
        } = null,
        row_level_permission_data_set: ?RowLevelPermissionDataSet = null,
        column_level_permission_rules: ?[]ColumnLevelPermissionRule = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .aws_account_id = "AwsAccountId",
                .data_set_id = "DataSetId",
                .name = "Name",
                .physical_table_map = "PhysicalTableMap",
                .logical_table_map = "LogicalTableMap",
                .import_mode = "ImportMode",
                .column_groups = "ColumnGroups",
                .field_folders = "FieldFolders",
                .row_level_permission_data_set = "RowLevelPermissionDataSet",
                .column_level_permission_rules = "ColumnLevelPermissionRules",
            };
            return @field(mappings, field_name);
        }

        pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
            if (std.mem.eql(u8, "physical_table_map", field_name))
                return try serializeMap(self.physical_table_map, self.fieldNameFor("physical_table_map"), options, out_stream);
            if (std.mem.eql(u8, "logical_table_map", field_name))
                return try serializeMap(self.logical_table_map, self.fieldNameFor("logical_table_map"), options, out_stream);
            if (std.mem.eql(u8, "field_folders", field_name))
                return try serializeMap(self.field_folders, self.fieldNameFor("field_folders"), options, out_stream);
            return false;
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(update_data_set) } {
            return .{ .service_metadata = service_metadata, .action = update_data_set };
        }
    },
    Response: type = struct {
        arn: ?[]const u8 = null,
        data_set_id: ?[]const u8 = null,
        ingestion_arn: ?[]const u8 = null,
        ingestion_id: ?[]const u8 = null,
        request_id: ?[]const u8 = null,
        status: ?i64 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .arn = "Arn",
                .data_set_id = "DataSetId",
                .ingestion_arn = "IngestionArn",
                .ingestion_id = "IngestionId",
                .request_id = "RequestId",
                .status = "Status",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        Conflict,
        InternalFailure,
        InvalidParameterValue,
        LimitExceeded,
        ResourceNotFound,
        Throttling,
        UnsupportedUserEdition,
    },
} = .{};
pub const update_data_set_permissions: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/accounts/{AwsAccountId}/data-sets/{DataSetId}/permissions",
        .success_code = 200,
    };

    action_name: []const u8 = "UpdateDataSetPermissions",
    Request: type = struct {
        aws_account_id: []const u8,
        data_set_id: []const u8,
        grant_permissions: ?[]ResourcePermission = null,
        revoke_permissions: ?[]ResourcePermission = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .aws_account_id = "AwsAccountId",
                .data_set_id = "DataSetId",
                .grant_permissions = "GrantPermissions",
                .revoke_permissions = "RevokePermissions",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(update_data_set_permissions) } {
            return .{ .service_metadata = service_metadata, .action = update_data_set_permissions };
        }
    },
    Response: type = struct {
        data_set_arn: ?[]const u8 = null,
        data_set_id: ?[]const u8 = null,
        request_id: ?[]const u8 = null,
        status: ?i64 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .data_set_arn = "DataSetArn",
                .data_set_id = "DataSetId",
                .request_id = "RequestId",
                .status = "Status",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        Conflict,
        InternalFailure,
        InvalidParameterValue,
        ResourceNotFound,
        Throttling,
    },
} = .{};
pub const update_data_source: struct {
    pub const http_config = .{
        .method = "PUT",
        .uri = "/accounts/{AwsAccountId}/data-sources/{DataSourceId}",
        .success_code = 200,
    };

    action_name: []const u8 = "UpdateDataSource",
    Request: type = struct {
        aws_account_id: []const u8,
        data_source_id: []const u8,
        name: []const u8,
        data_source_parameters: ?DataSourceParameters = null,
        credentials: ?DataSourceCredentials = null,
        vpc_connection_properties: ?VpcConnectionProperties = null,
        ssl_properties: ?SslProperties = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .aws_account_id = "AwsAccountId",
                .data_source_id = "DataSourceId",
                .name = "Name",
                .data_source_parameters = "DataSourceParameters",
                .credentials = "Credentials",
                .vpc_connection_properties = "VpcConnectionProperties",
                .ssl_properties = "SslProperties",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(update_data_source) } {
            return .{ .service_metadata = service_metadata, .action = update_data_source };
        }
    },
    Response: type = struct {
        arn: ?[]const u8 = null,
        data_source_id: ?[]const u8 = null,
        update_status: ?[]const u8 = null,
        request_id: ?[]const u8 = null,
        status: ?i64 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .arn = "Arn",
                .data_source_id = "DataSourceId",
                .update_status = "UpdateStatus",
                .request_id = "RequestId",
                .status = "Status",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        Conflict,
        InternalFailure,
        InvalidParameterValue,
        ResourceNotFound,
        Throttling,
    },
} = .{};
pub const update_data_source_permissions: struct {
    pub const http_config = .{
        .method = "POST",
        .uri = "/accounts/{AwsAccountId}/data-sources/{DataSourceId}/permissions",
        .success_code = 200,
    };

    action_name: []const u8 = "UpdateDataSourcePermissions",
    Request: type = struct {
        aws_account_id: []const u8,
        data_source_id: []const u8,
        grant_permissions: ?[]ResourcePermission = null,
        revoke_permissions: ?[]ResourcePermission = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .aws_account_id = "AwsAccountId",
                .data_source_id = "DataSourceId",
                .grant_permissions = "GrantPermissions",
                .revoke_permissions = "RevokePermissions",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(update_data_source_permissions) } {
            return .{ .service_metadata = service_metadata, .action = update_data_source_permissions };
        }
    },
    Response: type = struct {
        data_source_arn: ?[]const u8 = null,
        data_source_id: ?[]const u8 = null,
        request_id: ?[]const u8 = null,
        status: ?i64 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .data_source_arn = "DataSourceArn",
                .data_source_id = "DataSourceId",
                .request_id = "RequestId",
                .status = "Status",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        Conflict,
        InternalFailure,
        InvalidParameterValue,
        ResourceNotFound,
        Throttling,
    },
} = .{};
pub const update_group: struct {
    pub const http_config = .{
        .method = "PUT",
        .uri = "/accounts/{AwsAccountId}/namespaces/{Namespace}/groups/{GroupName}",
        .success_code = 200,
    };

    action_name: []const u8 = "UpdateGroup",
    Request: type = struct {
        group_name: []const u8,
        description: ?[]const u8 = null,
        aws_account_id: []const u8,
        namespace: []const u8,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .group_name = "GroupName",
                .description = "Description",
                .aws_account_id = "AwsAccountId",
                .namespace = "Namespace",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(update_group) } {
            return .{ .service_metadata = service_metadata, .action = update_group };
        }
    },
    Response: type = struct {
        group: ?Group = null,
        request_id: ?[]const u8 = null,
        status: ?i64 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .group = "Group",
                .request_id = "RequestId",
                .status = "Status",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        InternalFailure,
        InvalidParameterValue,
        PreconditionNotMet,
        ResourceNotFound,
        ResourceUnavailable,
        Throttling,
    },
} = .{};
pub const update_iam_policy_assignment: struct {
    pub const http_config = .{
        .method = "PUT",
        .uri = "/accounts/{AwsAccountId}/namespaces/{Namespace}/iam-policy-assignments/{AssignmentName}",
        .success_code = 200,
    };

    action_name: []const u8 = "UpdateIAMPolicyAssignment",
    Request: type = struct {
        aws_account_id: []const u8,
        assignment_name: []const u8,
        namespace: []const u8,
        assignment_status: ?[]const u8 = null,
        policy_arn: ?[]const u8 = null,
        identities: ?[]struct {
            key: ?[]const u8 = null,
            value: ?[][]const u8 = null,
        } = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .aws_account_id = "AwsAccountId",
                .assignment_name = "AssignmentName",
                .namespace = "Namespace",
                .assignment_status = "AssignmentStatus",
                .policy_arn = "PolicyArn",
                .identities = "Identities",
            };
            return @field(mappings, field_name);
        }

        pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
            if (std.mem.eql(u8, "identities", field_name))
                return try serializeMap(self.identities, self.fieldNameFor("identities"), options, out_stream);
            return false;
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(update_iam_policy_assignment) } {
            return .{ .service_metadata = service_metadata, .action = update_iam_policy_assignment };
        }
    },
    Response: type = struct {
        assignment_name: ?[]const u8 = null,
        assignment_id: ?[]const u8 = null,
        policy_arn: ?[]const u8 = null,
        identities: ?[]struct {
            key: ?[]const u8 = null,
            value: ?[][]const u8 = null,
        } = null,
        assignment_status: ?[]const u8 = null,
        request_id: ?[]const u8 = null,
        status: ?i64 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .assignment_name = "AssignmentName",
                .assignment_id = "AssignmentId",
                .policy_arn = "PolicyArn",
                .identities = "Identities",
                .assignment_status = "AssignmentStatus",
                .request_id = "RequestId",
                .status = "Status",
            };
            return @field(mappings, field_name);
        }

        pub fn jsonStringifyField(self: @This(), comptime field_name: []const u8, options: anytype, out_stream: anytype) !bool {
            if (std.mem.eql(u8, "identities", field_name))
                return try serializeMap(self.identities, self.fieldNameFor("identities"), options, out_stream);
            return false;
        }
    },
    ServiceError: type = error{
        AccessDenied,
        ConcurrentUpdating,
        InternalFailure,
        InvalidParameterValue,
        ResourceExists,
        ResourceNotFound,
        Throttling,
    },
} = .{};
pub const update_template: struct {
    pub const http_config = .{
        .method = "PUT",
        .uri = "/accounts/{AwsAccountId}/templates/{TemplateId}",
        .success_code = 200,
    };

    action_name: []const u8 = "UpdateTemplate",
    Request: type = struct {
        aws_account_id: []const u8,
        template_id: []const u8,
        source_entity: TemplateSourceEntity,
        version_description: ?[]const u8 = null,
        name: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .aws_account_id = "AwsAccountId",
                .template_id = "TemplateId",
                .source_entity = "SourceEntity",
                .version_description = "VersionDescription",
                .name = "Name",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(update_template) } {
            return .{ .service_metadata = service_metadata, .action = update_template };
        }
    },
    Response: type = struct {
        template_id: ?[]const u8 = null,
        arn: ?[]const u8 = null,
        version_arn: ?[]const u8 = null,
        creation_status: ?[]const u8 = null,
        status: ?i64 = null,
        request_id: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .template_id = "TemplateId",
                .arn = "Arn",
                .version_arn = "VersionArn",
                .creation_status = "CreationStatus",
                .status = "Status",
                .request_id = "RequestId",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        Conflict,
        InternalFailure,
        InvalidParameterValue,
        LimitExceeded,
        ResourceExists,
        ResourceNotFound,
        Throttling,
        UnsupportedUserEdition,
    },
} = .{};
pub const update_template_alias: struct {
    pub const http_config = .{
        .method = "PUT",
        .uri = "/accounts/{AwsAccountId}/templates/{TemplateId}/aliases/{AliasName}",
        .success_code = 200,
    };

    action_name: []const u8 = "UpdateTemplateAlias",
    Request: type = struct {
        aws_account_id: []const u8,
        template_id: []const u8,
        alias_name: []const u8,
        template_version_number: i64,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .aws_account_id = "AwsAccountId",
                .template_id = "TemplateId",
                .alias_name = "AliasName",
                .template_version_number = "TemplateVersionNumber",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(update_template_alias) } {
            return .{ .service_metadata = service_metadata, .action = update_template_alias };
        }
    },
    Response: type = struct {
        template_alias: ?TemplateAlias = null,
        status: ?i64 = null,
        request_id: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .template_alias = "TemplateAlias",
                .status = "Status",
                .request_id = "RequestId",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        Conflict,
        InternalFailure,
        ResourceNotFound,
        Throttling,
        UnsupportedUserEdition,
    },
} = .{};
pub const update_template_permissions: struct {
    pub const http_config = .{
        .method = "PUT",
        .uri = "/accounts/{AwsAccountId}/templates/{TemplateId}/permissions",
        .success_code = 200,
    };

    action_name: []const u8 = "UpdateTemplatePermissions",
    Request: type = struct {
        aws_account_id: []const u8,
        template_id: []const u8,
        grant_permissions: ?[]ResourcePermission = null,
        revoke_permissions: ?[]ResourcePermission = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .aws_account_id = "AwsAccountId",
                .template_id = "TemplateId",
                .grant_permissions = "GrantPermissions",
                .revoke_permissions = "RevokePermissions",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(update_template_permissions) } {
            return .{ .service_metadata = service_metadata, .action = update_template_permissions };
        }
    },
    Response: type = struct {
        template_id: ?[]const u8 = null,
        template_arn: ?[]const u8 = null,
        permissions: ?[]ResourcePermission = null,
        request_id: ?[]const u8 = null,
        status: ?i64 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .template_id = "TemplateId",
                .template_arn = "TemplateArn",
                .permissions = "Permissions",
                .request_id = "RequestId",
                .status = "Status",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        Conflict,
        InternalFailure,
        InvalidParameterValue,
        ResourceNotFound,
        Throttling,
        UnsupportedUserEdition,
    },
} = .{};
pub const update_theme: struct {
    pub const http_config = .{
        .method = "PUT",
        .uri = "/accounts/{AwsAccountId}/themes/{ThemeId}",
        .success_code = 200,
    };

    action_name: []const u8 = "UpdateTheme",
    Request: type = struct {
        aws_account_id: []const u8,
        theme_id: []const u8,
        name: ?[]const u8 = null,
        base_theme_id: []const u8,
        version_description: ?[]const u8 = null,
        configuration: ?ThemeConfiguration = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .aws_account_id = "AwsAccountId",
                .theme_id = "ThemeId",
                .name = "Name",
                .base_theme_id = "BaseThemeId",
                .version_description = "VersionDescription",
                .configuration = "Configuration",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(update_theme) } {
            return .{ .service_metadata = service_metadata, .action = update_theme };
        }
    },
    Response: type = struct {
        theme_id: ?[]const u8 = null,
        arn: ?[]const u8 = null,
        version_arn: ?[]const u8 = null,
        creation_status: ?[]const u8 = null,
        status: ?i64 = null,
        request_id: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .theme_id = "ThemeId",
                .arn = "Arn",
                .version_arn = "VersionArn",
                .creation_status = "CreationStatus",
                .status = "Status",
                .request_id = "RequestId",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        InternalFailure,
        InvalidParameterValue,
        LimitExceeded,
        ResourceExists,
        ResourceNotFound,
        Throttling,
        UnsupportedUserEdition,
    },
} = .{};
pub const update_theme_alias: struct {
    pub const http_config = .{
        .method = "PUT",
        .uri = "/accounts/{AwsAccountId}/themes/{ThemeId}/aliases/{AliasName}",
        .success_code = 200,
    };

    action_name: []const u8 = "UpdateThemeAlias",
    Request: type = struct {
        aws_account_id: []const u8,
        theme_id: []const u8,
        alias_name: []const u8,
        theme_version_number: i64,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .aws_account_id = "AwsAccountId",
                .theme_id = "ThemeId",
                .alias_name = "AliasName",
                .theme_version_number = "ThemeVersionNumber",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(update_theme_alias) } {
            return .{ .service_metadata = service_metadata, .action = update_theme_alias };
        }
    },
    Response: type = struct {
        theme_alias: ?ThemeAlias = null,
        status: ?i64 = null,
        request_id: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .theme_alias = "ThemeAlias",
                .status = "Status",
                .request_id = "RequestId",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        Conflict,
        InternalFailure,
        InvalidParameterValue,
        ResourceExists,
        ResourceNotFound,
        Throttling,
        UnsupportedUserEdition,
    },
} = .{};
pub const update_theme_permissions: struct {
    pub const http_config = .{
        .method = "PUT",
        .uri = "/accounts/{AwsAccountId}/themes/{ThemeId}/permissions",
        .success_code = 200,
    };

    action_name: []const u8 = "UpdateThemePermissions",
    Request: type = struct {
        aws_account_id: []const u8,
        theme_id: []const u8,
        grant_permissions: ?[]ResourcePermission = null,
        revoke_permissions: ?[]ResourcePermission = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .aws_account_id = "AwsAccountId",
                .theme_id = "ThemeId",
                .grant_permissions = "GrantPermissions",
                .revoke_permissions = "RevokePermissions",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(update_theme_permissions) } {
            return .{ .service_metadata = service_metadata, .action = update_theme_permissions };
        }
    },
    Response: type = struct {
        theme_id: ?[]const u8 = null,
        theme_arn: ?[]const u8 = null,
        permissions: ?[]ResourcePermission = null,
        request_id: ?[]const u8 = null,
        status: ?i64 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .theme_id = "ThemeId",
                .theme_arn = "ThemeArn",
                .permissions = "Permissions",
                .request_id = "RequestId",
                .status = "Status",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        InternalFailure,
        InvalidParameterValue,
        ResourceNotFound,
        Throttling,
        UnsupportedUserEdition,
    },
} = .{};
pub const update_user: struct {
    pub const http_config = .{
        .method = "PUT",
        .uri = "/accounts/{AwsAccountId}/namespaces/{Namespace}/users/{UserName}",
        .success_code = 200,
    };

    action_name: []const u8 = "UpdateUser",
    Request: type = struct {
        user_name: []const u8,
        aws_account_id: []const u8,
        namespace: []const u8,
        email: []const u8,
        role: []const u8,
        custom_permissions_name: ?[]const u8 = null,
        unapply_custom_permissions: ?bool = null,
        external_login_federation_provider_type: ?[]const u8 = null,
        custom_federation_provider_url: ?[]const u8 = null,
        external_login_id: ?[]const u8 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .user_name = "UserName",
                .aws_account_id = "AwsAccountId",
                .namespace = "Namespace",
                .email = "Email",
                .role = "Role",
                .custom_permissions_name = "CustomPermissionsName",
                .unapply_custom_permissions = "UnapplyCustomPermissions",
                .external_login_federation_provider_type = "ExternalLoginFederationProviderType",
                .custom_federation_provider_url = "CustomFederationProviderUrl",
                .external_login_id = "ExternalLoginId",
            };
            return @field(mappings, field_name);
        }

        pub fn metaInfo() struct { service_metadata: @TypeOf(service_metadata), action: @TypeOf(update_user) } {
            return .{ .service_metadata = service_metadata, .action = update_user };
        }
    },
    Response: type = struct {
        user: ?User = null,
        request_id: ?[]const u8 = null,
        status: ?i64 = null,

        pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
            const mappings = .{
                .user = "User",
                .request_id = "RequestId",
                .status = "Status",
            };
            return @field(mappings, field_name);
        }
    },
    ServiceError: type = error{
        AccessDenied,
        InternalFailure,
        InvalidParameterValue,
        PreconditionNotMet,
        ResourceNotFound,
        ResourceUnavailable,
        Throttling,
    },
} = .{};

pub const User = struct {
    arn: ?[]const u8 = null,
    user_name: ?[]const u8 = null,
    email: ?[]const u8 = null,
    role: ?[]const u8 = null,
    identity_type: ?[]const u8 = null,
    active: ?bool = null,
    principal_id: ?[]const u8 = null,
    custom_permissions_name: ?[]const u8 = null,
    external_login_federation_provider_type: ?[]const u8 = null,
    external_login_federation_provider_url: ?[]const u8 = null,
    external_login_id: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .arn = "Arn",
            .user_name = "UserName",
            .email = "Email",
            .role = "Role",
            .identity_type = "IdentityType",
            .active = "Active",
            .principal_id = "PrincipalId",
            .custom_permissions_name = "CustomPermissionsName",
            .external_login_federation_provider_type = "ExternalLoginFederationProviderType",
            .external_login_federation_provider_url = "ExternalLoginFederationProviderUrl",
            .external_login_id = "ExternalLoginId",
        };
        return @field(mappings, field_name);
    }
};

pub const ResourcePermission = struct {
    principal: []const u8,
    actions: [][]const u8,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .principal = "Principal",
            .actions = "Actions",
        };
        return @field(mappings, field_name);
    }
};

pub const ThemeAlias = struct {
    arn: ?[]const u8 = null,
    alias_name: ?[]const u8 = null,
    theme_version_number: ?i64 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .arn = "Arn",
            .alias_name = "AliasName",
            .theme_version_number = "ThemeVersionNumber",
        };
        return @field(mappings, field_name);
    }
};

pub const ThemeConfiguration = struct {
    data_color_palette: ?DataColorPalette = null,
    ui_color_palette: ?UIColorPalette = null,
    sheet: ?SheetStyle = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .data_color_palette = "DataColorPalette",
            .ui_color_palette = "UIColorPalette",
            .sheet = "Sheet",
        };
        return @field(mappings, field_name);
    }
};

pub const SheetStyle = struct {
    tile: ?TileStyle = null,
    tile_layout: ?TileLayoutStyle = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .tile = "Tile",
            .tile_layout = "TileLayout",
        };
        return @field(mappings, field_name);
    }
};

pub const TileLayoutStyle = struct {
    gutter: ?GutterStyle = null,
    margin: ?MarginStyle = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .gutter = "Gutter",
            .margin = "Margin",
        };
        return @field(mappings, field_name);
    }
};

pub const MarginStyle = struct {
    show: ?bool = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .show = "Show",
        };
        return @field(mappings, field_name);
    }
};

pub const GutterStyle = struct {
    show: ?bool = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .show = "Show",
        };
        return @field(mappings, field_name);
    }
};

pub const TileStyle = struct {
    border: ?BorderStyle = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .border = "Border",
        };
        return @field(mappings, field_name);
    }
};

pub const BorderStyle = struct {
    show: ?bool = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .show = "Show",
        };
        return @field(mappings, field_name);
    }
};

pub const UIColorPalette = struct {
    primary_foreground: ?[]const u8 = null,
    primary_background: ?[]const u8 = null,
    secondary_foreground: ?[]const u8 = null,
    secondary_background: ?[]const u8 = null,
    accent: ?[]const u8 = null,
    accent_foreground: ?[]const u8 = null,
    danger: ?[]const u8 = null,
    danger_foreground: ?[]const u8 = null,
    warning: ?[]const u8 = null,
    warning_foreground: ?[]const u8 = null,
    success: ?[]const u8 = null,
    success_foreground: ?[]const u8 = null,
    dimension: ?[]const u8 = null,
    dimension_foreground: ?[]const u8 = null,
    measure: ?[]const u8 = null,
    measure_foreground: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .primary_foreground = "PrimaryForeground",
            .primary_background = "PrimaryBackground",
            .secondary_foreground = "SecondaryForeground",
            .secondary_background = "SecondaryBackground",
            .accent = "Accent",
            .accent_foreground = "AccentForeground",
            .danger = "Danger",
            .danger_foreground = "DangerForeground",
            .warning = "Warning",
            .warning_foreground = "WarningForeground",
            .success = "Success",
            .success_foreground = "SuccessForeground",
            .dimension = "Dimension",
            .dimension_foreground = "DimensionForeground",
            .measure = "Measure",
            .measure_foreground = "MeasureForeground",
        };
        return @field(mappings, field_name);
    }
};

pub const DataColorPalette = struct {
    colors: ?[][]const u8 = null,
    min_max_gradient: ?[][]const u8 = null,
    empty_fill_color: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .colors = "Colors",
            .min_max_gradient = "MinMaxGradient",
            .empty_fill_color = "EmptyFillColor",
        };
        return @field(mappings, field_name);
    }
};

pub const TemplateAlias = struct {
    alias_name: ?[]const u8 = null,
    arn: ?[]const u8 = null,
    template_version_number: ?i64 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .alias_name = "AliasName",
            .arn = "Arn",
            .template_version_number = "TemplateVersionNumber",
        };
        return @field(mappings, field_name);
    }
};

pub const TemplateSourceEntity = struct {
    source_analysis: ?TemplateSourceAnalysis = null,
    source_template: ?TemplateSourceTemplate = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .source_analysis = "SourceAnalysis",
            .source_template = "SourceTemplate",
        };
        return @field(mappings, field_name);
    }
};

pub const TemplateSourceTemplate = struct {
    arn: []const u8,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .arn = "Arn",
        };
        return @field(mappings, field_name);
    }
};

pub const TemplateSourceAnalysis = struct {
    arn: []const u8,
    data_set_references: []DataSetReference,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .arn = "Arn",
            .data_set_references = "DataSetReferences",
        };
        return @field(mappings, field_name);
    }
};

pub const DataSetReference = struct {
    data_set_placeholder: []const u8,
    data_set_arn: []const u8,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .data_set_placeholder = "DataSetPlaceholder",
            .data_set_arn = "DataSetArn",
        };
        return @field(mappings, field_name);
    }
};

pub const Group = struct {
    arn: ?[]const u8 = null,
    group_name: ?[]const u8 = null,
    description: ?[]const u8 = null,
    principal_id: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .arn = "Arn",
            .group_name = "GroupName",
            .description = "Description",
            .principal_id = "PrincipalId",
        };
        return @field(mappings, field_name);
    }
};

pub const SslProperties = struct {
    disable_ssl: ?bool = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .disable_ssl = "DisableSsl",
        };
        return @field(mappings, field_name);
    }
};

pub const VpcConnectionProperties = struct {
    vpc_connection_arn: []const u8,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .vpc_connection_arn = "VpcConnectionArn",
        };
        return @field(mappings, field_name);
    }
};

pub const DataSourceCredentials = struct {
    credential_pair: ?CredentialPair = null,
    copy_source_arn: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .credential_pair = "CredentialPair",
            .copy_source_arn = "CopySourceArn",
        };
        return @field(mappings, field_name);
    }
};

pub const CredentialPair = struct {
    username: []const u8,
    password: []const u8,
    alternate_data_source_parameters: ?[]DataSourceParameters = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .username = "Username",
            .password = "Password",
            .alternate_data_source_parameters = "AlternateDataSourceParameters",
        };
        return @field(mappings, field_name);
    }
};

pub const DataSourceParameters = union {
    amazon_elasticsearch_parameters: ?AmazonElasticsearchParameters,
    athena_parameters: ?AthenaParameters,
    aurora_parameters: ?AuroraParameters,
    aurora_postgre_sql_parameters: ?AuroraPostgreSqlParameters,
    aws_iot_analytics_parameters: ?AwsIotAnalyticsParameters,
    jira_parameters: ?JiraParameters,
    maria_db_parameters: ?MariaDbParameters,
    my_sql_parameters: ?MySqlParameters,
    oracle_parameters: ?OracleParameters,
    postgre_sql_parameters: ?PostgreSqlParameters,
    presto_parameters: ?PrestoParameters,
    rds_parameters: ?RdsParameters,
    redshift_parameters: ?RedshiftParameters,
    s3_parameters: ?S3Parameters,
    service_now_parameters: ?ServiceNowParameters,
    snowflake_parameters: ?SnowflakeParameters,
    spark_parameters: ?SparkParameters,
    sql_server_parameters: ?SqlServerParameters,
    teradata_parameters: ?TeradataParameters,
    twitter_parameters: ?TwitterParameters,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .amazon_elasticsearch_parameters = "AmazonElasticsearchParameters",
            .athena_parameters = "AthenaParameters",
            .aurora_parameters = "AuroraParameters",
            .aurora_postgre_sql_parameters = "AuroraPostgreSqlParameters",
            .aws_iot_analytics_parameters = "AwsIotAnalyticsParameters",
            .jira_parameters = "JiraParameters",
            .maria_db_parameters = "MariaDbParameters",
            .my_sql_parameters = "MySqlParameters",
            .oracle_parameters = "OracleParameters",
            .postgre_sql_parameters = "PostgreSqlParameters",
            .presto_parameters = "PrestoParameters",
            .rds_parameters = "RdsParameters",
            .redshift_parameters = "RedshiftParameters",
            .s3_parameters = "S3Parameters",
            .service_now_parameters = "ServiceNowParameters",
            .snowflake_parameters = "SnowflakeParameters",
            .spark_parameters = "SparkParameters",
            .sql_server_parameters = "SqlServerParameters",
            .teradata_parameters = "TeradataParameters",
            .twitter_parameters = "TwitterParameters",
        };
        return @field(mappings, field_name);
    }
};

pub const TwitterParameters = struct {
    query: []const u8,
    max_rows: i64,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .query = "Query",
            .max_rows = "MaxRows",
        };
        return @field(mappings, field_name);
    }
};

pub const TeradataParameters = struct {
    host: []const u8,
    port: i64,
    database: []const u8,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .host = "Host",
            .port = "Port",
            .database = "Database",
        };
        return @field(mappings, field_name);
    }
};

pub const SqlServerParameters = struct {
    host: []const u8,
    port: i64,
    database: []const u8,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .host = "Host",
            .port = "Port",
            .database = "Database",
        };
        return @field(mappings, field_name);
    }
};

pub const SparkParameters = struct {
    host: []const u8,
    port: i64,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .host = "Host",
            .port = "Port",
        };
        return @field(mappings, field_name);
    }
};

pub const SnowflakeParameters = struct {
    host: []const u8,
    database: []const u8,
    warehouse: []const u8,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .host = "Host",
            .database = "Database",
            .warehouse = "Warehouse",
        };
        return @field(mappings, field_name);
    }
};

pub const ServiceNowParameters = struct {
    site_base_url: []const u8,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .site_base_url = "SiteBaseUrl",
        };
        return @field(mappings, field_name);
    }
};

pub const S3Parameters = struct {
    manifest_file_location: ManifestFileLocation,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .manifest_file_location = "ManifestFileLocation",
        };
        return @field(mappings, field_name);
    }
};

pub const ManifestFileLocation = struct {
    bucket: []const u8,
    key: []const u8,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .bucket = "Bucket",
            .key = "Key",
        };
        return @field(mappings, field_name);
    }
};

pub const RedshiftParameters = struct {
    host: ?[]const u8 = null,
    port: ?i64 = null,
    database: []const u8,
    cluster_id: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .host = "Host",
            .port = "Port",
            .database = "Database",
            .cluster_id = "ClusterId",
        };
        return @field(mappings, field_name);
    }
};

pub const RdsParameters = struct {
    instance_id: []const u8,
    database: []const u8,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .instance_id = "InstanceId",
            .database = "Database",
        };
        return @field(mappings, field_name);
    }
};

pub const PrestoParameters = struct {
    host: []const u8,
    port: i64,
    catalog: []const u8,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .host = "Host",
            .port = "Port",
            .catalog = "Catalog",
        };
        return @field(mappings, field_name);
    }
};

pub const PostgreSqlParameters = struct {
    host: []const u8,
    port: i64,
    database: []const u8,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .host = "Host",
            .port = "Port",
            .database = "Database",
        };
        return @field(mappings, field_name);
    }
};

pub const OracleParameters = struct {
    host: []const u8,
    port: i64,
    database: []const u8,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .host = "Host",
            .port = "Port",
            .database = "Database",
        };
        return @field(mappings, field_name);
    }
};

pub const MySqlParameters = struct {
    host: []const u8,
    port: i64,
    database: []const u8,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .host = "Host",
            .port = "Port",
            .database = "Database",
        };
        return @field(mappings, field_name);
    }
};

pub const MariaDbParameters = struct {
    host: []const u8,
    port: i64,
    database: []const u8,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .host = "Host",
            .port = "Port",
            .database = "Database",
        };
        return @field(mappings, field_name);
    }
};

pub const JiraParameters = struct {
    site_base_url: []const u8,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .site_base_url = "SiteBaseUrl",
        };
        return @field(mappings, field_name);
    }
};

pub const AwsIotAnalyticsParameters = struct {
    data_set_name: []const u8,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .data_set_name = "DataSetName",
        };
        return @field(mappings, field_name);
    }
};

pub const AuroraPostgreSqlParameters = struct {
    host: []const u8,
    port: i64,
    database: []const u8,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .host = "Host",
            .port = "Port",
            .database = "Database",
        };
        return @field(mappings, field_name);
    }
};

pub const AuroraParameters = struct {
    host: []const u8,
    port: i64,
    database: []const u8,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .host = "Host",
            .port = "Port",
            .database = "Database",
        };
        return @field(mappings, field_name);
    }
};

pub const AthenaParameters = struct {
    work_group: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .work_group = "WorkGroup",
        };
        return @field(mappings, field_name);
    }
};

pub const AmazonElasticsearchParameters = struct {
    domain: []const u8,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .domain = "Domain",
        };
        return @field(mappings, field_name);
    }
};

pub const ColumnLevelPermissionRule = struct {
    principals: ?[][]const u8 = null,
    column_names: ?[][]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .principals = "Principals",
            .column_names = "ColumnNames",
        };
        return @field(mappings, field_name);
    }
};

pub const RowLevelPermissionDataSet = struct {
    namespace: ?[]const u8 = null,
    arn: []const u8,
    permission_policy: []const u8,
    format_version: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .namespace = "Namespace",
            .arn = "Arn",
            .permission_policy = "PermissionPolicy",
            .format_version = "FormatVersion",
        };
        return @field(mappings, field_name);
    }
};

pub const FieldFolder = struct {
    description: ?[]const u8 = null,
    columns: ?[][]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .description = "description",
            .columns = "columns",
        };
        return @field(mappings, field_name);
    }
};

pub const ColumnGroup = struct {
    geo_spatial_column_group: ?GeoSpatialColumnGroup = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .geo_spatial_column_group = "GeoSpatialColumnGroup",
        };
        return @field(mappings, field_name);
    }
};

pub const GeoSpatialColumnGroup = struct {
    name: []const u8,
    country_code: []const u8,
    columns: [][]const u8,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .name = "Name",
            .country_code = "CountryCode",
            .columns = "Columns",
        };
        return @field(mappings, field_name);
    }
};

pub const LogicalTable = struct {
    alias: []const u8,
    data_transforms: ?[]TransformOperation = null,
    source: LogicalTableSource,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .alias = "Alias",
            .data_transforms = "DataTransforms",
            .source = "Source",
        };
        return @field(mappings, field_name);
    }
};

pub const LogicalTableSource = struct {
    join_instruction: ?JoinInstruction = null,
    physical_table_id: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .join_instruction = "JoinInstruction",
            .physical_table_id = "PhysicalTableId",
        };
        return @field(mappings, field_name);
    }
};

pub const JoinInstruction = struct {
    left_operand: []const u8,
    right_operand: []const u8,
    left_join_key_properties: ?JoinKeyProperties = null,
    right_join_key_properties: ?JoinKeyProperties = null,
    type: []const u8,
    on_clause: []const u8,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .left_operand = "LeftOperand",
            .right_operand = "RightOperand",
            .left_join_key_properties = "LeftJoinKeyProperties",
            .right_join_key_properties = "RightJoinKeyProperties",
            .type = "Type",
            .on_clause = "OnClause",
        };
        return @field(mappings, field_name);
    }
};

pub const JoinKeyProperties = struct {
    unique_key: ?bool = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .unique_key = "UniqueKey",
        };
        return @field(mappings, field_name);
    }
};

pub const TransformOperation = union {
    project_operation: ?ProjectOperation,
    filter_operation: ?FilterOperation,
    create_columns_operation: ?CreateColumnsOperation,
    rename_column_operation: ?RenameColumnOperation,
    cast_column_type_operation: ?CastColumnTypeOperation,
    tag_column_operation: ?TagColumnOperation,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .project_operation = "ProjectOperation",
            .filter_operation = "FilterOperation",
            .create_columns_operation = "CreateColumnsOperation",
            .rename_column_operation = "RenameColumnOperation",
            .cast_column_type_operation = "CastColumnTypeOperation",
            .tag_column_operation = "TagColumnOperation",
        };
        return @field(mappings, field_name);
    }
};

pub const TagColumnOperation = struct {
    column_name: []const u8,
    tags: []ColumnTag,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .column_name = "ColumnName",
            .tags = "Tags",
        };
        return @field(mappings, field_name);
    }
};

pub const ColumnTag = struct {
    column_geographic_role: ?[]const u8 = null,
    column_description: ?ColumnDescription = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .column_geographic_role = "ColumnGeographicRole",
            .column_description = "ColumnDescription",
        };
        return @field(mappings, field_name);
    }
};

pub const ColumnDescription = struct {
    text: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .text = "Text",
        };
        return @field(mappings, field_name);
    }
};

pub const CastColumnTypeOperation = struct {
    column_name: []const u8,
    new_column_type: []const u8,
    format: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .column_name = "ColumnName",
            .new_column_type = "NewColumnType",
            .format = "Format",
        };
        return @field(mappings, field_name);
    }
};

pub const RenameColumnOperation = struct {
    column_name: []const u8,
    new_column_name: []const u8,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .column_name = "ColumnName",
            .new_column_name = "NewColumnName",
        };
        return @field(mappings, field_name);
    }
};

pub const CreateColumnsOperation = struct {
    columns: []CalculatedColumn,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .columns = "Columns",
        };
        return @field(mappings, field_name);
    }
};

pub const CalculatedColumn = struct {
    column_name: []const u8,
    column_id: []const u8,
    expression: []const u8,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .column_name = "ColumnName",
            .column_id = "ColumnId",
            .expression = "Expression",
        };
        return @field(mappings, field_name);
    }
};

pub const FilterOperation = struct {
    condition_expression: []const u8,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .condition_expression = "ConditionExpression",
        };
        return @field(mappings, field_name);
    }
};

pub const ProjectOperation = struct {
    projected_columns: [][]const u8,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .projected_columns = "ProjectedColumns",
        };
        return @field(mappings, field_name);
    }
};

pub const PhysicalTable = union {
    relational_table: ?RelationalTable,
    custom_sql: ?CustomSql,
    s3_source: ?S3Source,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .relational_table = "RelationalTable",
            .custom_sql = "CustomSql",
            .s3_source = "S3Source",
        };
        return @field(mappings, field_name);
    }
};

pub const S3Source = struct {
    data_source_arn: []const u8,
    upload_settings: ?UploadSettings = null,
    input_columns: []InputColumn,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .data_source_arn = "DataSourceArn",
            .upload_settings = "UploadSettings",
            .input_columns = "InputColumns",
        };
        return @field(mappings, field_name);
    }
};

pub const InputColumn = struct {
    name: []const u8,
    type: []const u8,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .name = "Name",
            .type = "Type",
        };
        return @field(mappings, field_name);
    }
};

pub const UploadSettings = struct {
    format: ?[]const u8 = null,
    start_from_row: ?i64 = null,
    contains_header: ?bool = null,
    text_qualifier: ?[]const u8 = null,
    delimiter: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .format = "Format",
            .start_from_row = "StartFromRow",
            .contains_header = "ContainsHeader",
            .text_qualifier = "TextQualifier",
            .delimiter = "Delimiter",
        };
        return @field(mappings, field_name);
    }
};

pub const CustomSql = struct {
    data_source_arn: []const u8,
    name: []const u8,
    sql_query: []const u8,
    columns: ?[]InputColumn = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .data_source_arn = "DataSourceArn",
            .name = "Name",
            .sql_query = "SqlQuery",
            .columns = "Columns",
        };
        return @field(mappings, field_name);
    }
};

pub const RelationalTable = struct {
    data_source_arn: []const u8,
    catalog: ?[]const u8 = null,
    schema: ?[]const u8 = null,
    name: []const u8,
    input_columns: []InputColumn,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .data_source_arn = "DataSourceArn",
            .catalog = "Catalog",
            .schema = "Schema",
            .name = "Name",
            .input_columns = "InputColumns",
        };
        return @field(mappings, field_name);
    }
};

pub const DashboardPublishOptions = struct {
    ad_hoc_filtering_option: ?AdHocFilteringOption = null,
    export_to_csv_option: ?ExportToCSVOption = null,
    sheet_controls_option: ?SheetControlsOption = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .ad_hoc_filtering_option = "AdHocFilteringOption",
            .export_to_csv_option = "ExportToCSVOption",
            .sheet_controls_option = "SheetControlsOption",
        };
        return @field(mappings, field_name);
    }
};

pub const SheetControlsOption = struct {
    visibility_state: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .visibility_state = "VisibilityState",
        };
        return @field(mappings, field_name);
    }
};

pub const ExportToCSVOption = struct {
    availability_status: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .availability_status = "AvailabilityStatus",
        };
        return @field(mappings, field_name);
    }
};

pub const AdHocFilteringOption = struct {
    availability_status: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .availability_status = "AvailabilityStatus",
        };
        return @field(mappings, field_name);
    }
};

pub const Parameters = struct {
    string_parameters: ?[]StringParameter = null,
    integer_parameters: ?[]IntegerParameter = null,
    decimal_parameters: ?[]DecimalParameter = null,
    date_time_parameters: ?[]DateTimeParameter = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .string_parameters = "StringParameters",
            .integer_parameters = "IntegerParameters",
            .decimal_parameters = "DecimalParameters",
            .date_time_parameters = "DateTimeParameters",
        };
        return @field(mappings, field_name);
    }
};

pub const DateTimeParameter = struct {
    name: []const u8,
    values: []i64,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .name = "Name",
            .values = "Values",
        };
        return @field(mappings, field_name);
    }
};

pub const DecimalParameter = struct {
    name: []const u8,
    values: []f64,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .name = "Name",
            .values = "Values",
        };
        return @field(mappings, field_name);
    }
};

pub const IntegerParameter = struct {
    name: []const u8,
    values: []i64,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .name = "Name",
            .values = "Values",
        };
        return @field(mappings, field_name);
    }
};

pub const StringParameter = struct {
    name: []const u8,
    values: [][]const u8,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .name = "Name",
            .values = "Values",
        };
        return @field(mappings, field_name);
    }
};

pub const DashboardSourceEntity = struct {
    source_template: ?DashboardSourceTemplate = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .source_template = "SourceTemplate",
        };
        return @field(mappings, field_name);
    }
};

pub const DashboardSourceTemplate = struct {
    data_set_references: []DataSetReference,
    arn: []const u8,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .data_set_references = "DataSetReferences",
            .arn = "Arn",
        };
        return @field(mappings, field_name);
    }
};

pub const AnalysisSourceEntity = struct {
    source_template: ?AnalysisSourceTemplate = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .source_template = "SourceTemplate",
        };
        return @field(mappings, field_name);
    }
};

pub const AnalysisSourceTemplate = struct {
    data_set_references: []DataSetReference,
    arn: []const u8,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .data_set_references = "DataSetReferences",
            .arn = "Arn",
        };
        return @field(mappings, field_name);
    }
};

pub const AccountCustomization = struct {
    default_theme: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .default_theme = "DefaultTheme",
        };
        return @field(mappings, field_name);
    }
};

pub const Tag = struct {
    key: []const u8,
    value: []const u8,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .key = "Key",
            .value = "Value",
        };
        return @field(mappings, field_name);
    }
};

pub const DashboardSummary = struct {
    arn: ?[]const u8 = null,
    dashboard_id: ?[]const u8 = null,
    name: ?[]const u8 = null,
    created_time: ?i64 = null,
    last_updated_time: ?i64 = null,
    published_version_number: ?i64 = null,
    last_published_time: ?i64 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .arn = "Arn",
            .dashboard_id = "DashboardId",
            .name = "Name",
            .created_time = "CreatedTime",
            .last_updated_time = "LastUpdatedTime",
            .published_version_number = "PublishedVersionNumber",
            .last_published_time = "LastPublishedTime",
        };
        return @field(mappings, field_name);
    }
};

pub const AnalysisSummary = struct {
    arn: ?[]const u8 = null,
    analysis_id: ?[]const u8 = null,
    name: ?[]const u8 = null,
    status: ?[]const u8 = null,
    created_time: ?i64 = null,
    last_updated_time: ?i64 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .arn = "Arn",
            .analysis_id = "AnalysisId",
            .name = "Name",
            .status = "Status",
            .created_time = "CreatedTime",
            .last_updated_time = "LastUpdatedTime",
        };
        return @field(mappings, field_name);
    }
};

pub const NamespaceInfoV2 = struct {
    name: ?[]const u8 = null,
    arn: ?[]const u8 = null,
    capacity_region: ?[]const u8 = null,
    creation_status: ?[]const u8 = null,
    identity_store: ?[]const u8 = null,
    namespace_error: ?NamespaceError = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .name = "Name",
            .arn = "Arn",
            .capacity_region = "CapacityRegion",
            .creation_status = "CreationStatus",
            .identity_store = "IdentityStore",
            .namespace_error = "NamespaceError",
        };
        return @field(mappings, field_name);
    }
};

pub const NamespaceError = struct {
    type: ?[]const u8 = null,
    message: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .type = "Type",
            .message = "Message",
        };
        return @field(mappings, field_name);
    }
};

pub const Ingestion = struct {
    arn: []const u8,
    ingestion_id: ?[]const u8 = null,
    ingestion_status: []const u8,
    error_info: ?ErrorInfo = null,
    row_info: ?RowInfo = null,
    queue_info: ?QueueInfo = null,
    created_time: i64,
    ingestion_time_in_seconds: ?i64 = null,
    ingestion_size_in_bytes: ?i64 = null,
    request_source: ?[]const u8 = null,
    request_type: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .arn = "Arn",
            .ingestion_id = "IngestionId",
            .ingestion_status = "IngestionStatus",
            .error_info = "ErrorInfo",
            .row_info = "RowInfo",
            .queue_info = "QueueInfo",
            .created_time = "CreatedTime",
            .ingestion_time_in_seconds = "IngestionTimeInSeconds",
            .ingestion_size_in_bytes = "IngestionSizeInBytes",
            .request_source = "RequestSource",
            .request_type = "RequestType",
        };
        return @field(mappings, field_name);
    }
};

pub const QueueInfo = struct {
    waiting_on_ingestion: []const u8,
    queued_ingestion: []const u8,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .waiting_on_ingestion = "WaitingOnIngestion",
            .queued_ingestion = "QueuedIngestion",
        };
        return @field(mappings, field_name);
    }
};

pub const RowInfo = struct {
    rows_ingested: ?i64 = null,
    rows_dropped: ?i64 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .rows_ingested = "RowsIngested",
            .rows_dropped = "RowsDropped",
        };
        return @field(mappings, field_name);
    }
};

pub const ErrorInfo = struct {
    type: ?[]const u8 = null,
    message: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .type = "Type",
            .message = "Message",
        };
        return @field(mappings, field_name);
    }
};

pub const GroupMember = struct {
    arn: ?[]const u8 = null,
    member_name: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .arn = "Arn",
            .member_name = "MemberName",
        };
        return @field(mappings, field_name);
    }
};

pub const DataSource = struct {
    arn: ?[]const u8 = null,
    data_source_id: ?[]const u8 = null,
    name: ?[]const u8 = null,
    type: ?[]const u8 = null,
    status: ?[]const u8 = null,
    created_time: ?i64 = null,
    last_updated_time: ?i64 = null,
    data_source_parameters: ?DataSourceParameters = null,
    alternate_data_source_parameters: ?[]DataSourceParameters = null,
    vpc_connection_properties: ?VpcConnectionProperties = null,
    ssl_properties: ?SslProperties = null,
    error_info: ?DataSourceErrorInfo = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .arn = "Arn",
            .data_source_id = "DataSourceId",
            .name = "Name",
            .type = "Type",
            .status = "Status",
            .created_time = "CreatedTime",
            .last_updated_time = "LastUpdatedTime",
            .data_source_parameters = "DataSourceParameters",
            .alternate_data_source_parameters = "AlternateDataSourceParameters",
            .vpc_connection_properties = "VpcConnectionProperties",
            .ssl_properties = "SslProperties",
            .error_info = "ErrorInfo",
        };
        return @field(mappings, field_name);
    }
};

pub const DataSourceErrorInfo = struct {
    type: ?[]const u8 = null,
    message: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .type = "Type",
            .message = "Message",
        };
        return @field(mappings, field_name);
    }
};

pub const Sheet = struct {
    sheet_id: ?[]const u8 = null,
    name: ?[]const u8 = null,

    pub fn fieldNameFor(_: @This(), comptime field_name: []const u8) []const u8 {
        const mappings = .{
            .sheet_id = "SheetId",
            .name = "Name",
        };
        return @field(mappings, field_name);
    }
};
